BNIA – Baltimore Neighborhood Indicators Alliance
Description: BNIA - Baltimore Neighborhood Indicators Alliance, Providing reliable, actionable quality of life indicators for Baltimore’s neighborhoods
Keywords: BNIA - Baltimore Neighborhood Indicators Alliance, Providing reliable, actionable quality of life indicators for Baltimore’s neighborhoods

# convertVSSheetForWPUpload

This script will prepare our VitalSignsXl Doc for upload.

1. It uses the meta data table to replace the datasheets column headers with a shortname
2. Then empties columns that should not have their data uploaded yet according to section
3. Then it Deletes placeholder columns for our wishlist indicators

xlsheet = '19' year = '20'import pandas as pd # df = pd.read_excel(open('VS19_Indicator_Data_Form.xlsm', 'rb'), sheet_name="Vital Signs 19 Indicators", header=None, names=['vsid', 'xlsmid', 'longname','shortname', 'UPLOAD_WP',]) df = pd.read_excel(open('VS'+xlsheet+'_Indicator_Data_Form.xlsm', 'rb'), sheet_name="Vital Signs "+xlsheet+" Indicators") df = df[['ShortName', 'Section']] df.ShortName = df.ShortName.astype(str).str[:-2] df.loc[-1] = ['CSA2010', 'Section'] df.index = df.index + 1 df.sort_index(inplace=True) display( df.head(1) )

| ShortName | Section
--- | --- | ---
0 | CSA2010 | Section

Replace Column Headers of our data with the ShortNames

import pandas as pd vsdf = pd.read_excel(open('VS'+xlsheet+'_Indicator_Data_Form.xlsm', 'rb'), sheet_name='VS'+year, header=1) vsdf = vsdf.drop(columns='Unnamed: 0') vsdf.columns = df["ShortName"].values display( vsdf.columns ) display( vsdf.head(1) )Index(['CSA2010', 'tpop', 'male', 'female', 'paa', 'pwhite', 'pasi', 'p2more', 'ppac', 'phisp', ... 'pmath3', 'pread3', 'pmath5', 'pread5', 'pmath8', 'pread8', 'palg1', 'palg2', 'kra', 'lights'], dtype='object', length=216)

| CSA2010 | tpop | male | female | paa | pwhite | pasi | p2more | ppac | phisp | racdiv | age5_ | age18_ | age24_ | age64_ | age65_ | hhs | femhhs | fam | hhsize | mhhi | hh25inc | hh40inc | hh60inc | hh75inc | hhm75 | n | hhpov | hhchpov | salepr | dom | shomes | ownroc | fore | vacant | vio | resrehab | totalres | cashsa | reosa | ... | waterc | n | n | n | n | n | heatgas | elheat | novhcl | n | weather | wlksc | n | busload | n | n | bkln | n | othrcom | eenrol | menrol | hsenrol | hfai | treeplnt | hcvhouse | cebus | ceemp | murals | totjobs | arrest | pmath3 | pread3 | pmath5 | pread5 | pmath8 | pread8 | palg1 | palg2 | kra | lights
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
0 | Allendale/Irvington/S. Hilton | -- | -- | -- | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 25.5 | NaN | 52.26087 | 0.4 | 6.469565 | 2.869565 | 3.947826 | 5750 | 49.565217 | 12.608696 | ... | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 5.024264 | NaN | NaN | 718 | 459 | 632 | NaN | NaN | NaN | NaN | NaN | 5 | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 20.595671

1 rows × 216 columns

vsdf.head(1)

| CSA2010 | tpop | male | female | paa | pwhite | pasi | p2more | ppac | phisp | racdiv | age5_ | age18_ | age24_ | age64_ | age65_ | hhs | femhhs | fam | hhsize | mhhi | hh25inc | hh40inc | hh60inc | hh75inc | hhm75 | n | hhpov | hhchpov | salepr | dom | shomes | ownroc | fore | vacant | vio | resrehab | totalres | cashsa | reosa | ... | waterc | n | n | n | n | n | heatgas | elheat | novhcl | n | weather | wlksc | n | busload | n | n | bkln | n | othrcom | eenrol | menrol | hsenrol | hfai | treeplnt | hcvhouse | cebus | ceemp | murals | totjobs | arrest | pmath3 | pread3 | pmath5 | pread5 | pmath8 | pread8 | palg1 | palg2 | kra | lights
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
0 | Allendale/Irvington/S. Hilton | -- | -- | -- | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 25.5 | NaN | 52.26087 | 0.4 | 6.469565 | 2.869565 | 3.947826 | 5750 | 49.565217 | 12.608696 | ... | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 5.024264 | NaN | NaN | 718 | 459 | 632 | NaN | NaN | NaN | NaN | NaN | 5 | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 20.595671

1 rows × 216 columns

Now Remove Data from Columns Not on Our Publishing List.

keep = ['Section', 'Crime and Safety','Census Demographics', 'Workforce and Economic Development', 'Sustainability', 'Housing and Community Development', 'Children and Family Health', 'Arts and Culture', 'Education and Youth'] rm = [] # For Each Column for currentColumn in vsdf.columns: # Get the Section indSection = df[ df['ShortName'] == currentColumn ]['Section'].values[0] # Delete Records if Not In Keep List if ( not indSection in set( keep ) ): vsdf[currentColumn] = '' # Delete columns if on wishlist. vsdf = vsdf[ df[ df['ShortName'] != 'n' ].ShortName.values ] vsdf = vsdf.add_suffix(year) vsdf.rename(columns = {f"CSA2010{year}": "CSA2010"}, inplace=True) vsdf.head()

| CSA2010 | tpop20 | male20 | female20 | paa20 | pwhite20 | pasi20 | p2more20 | ppac20 | phisp20 | racdiv20 | age5_20 | age18_20 | age24_20 | age64_20 | age65_20 | hhs20 | femhhs20 | fam20 | hhsize20 | mhhi20 | hh25inc20 | hh40inc20 | hh60inc20 | hh75inc20 | hhm7520 | hhpov20 | hhchpov20 | salepr20 | dom20 | shomes20 | ownroc20 | fore20 | vacant20 | vio20 | resrehab20 | totalres20 | cashsa20 | reosa20 | taxlien20 | ... | drvalone20 | carpool20 | pubtran20 | walked20 | trav1420 | trav2920 | trav4420 | trav4520 | trees20 | cmos20 | waterc20 | heatgas20 | elheat20 | novhcl20 | weather20 | wlksc20 | busload20 | bkln20 | othrcom20 | eenrol20 | menrol20 | hsenrol20 | hfai20 | treeplnt20 | hcvhouse20 | cebus20 | ceemp20 | murals20 | totjobs20 | arrest20 | pmath320 | pread320 | pmath520 | pread520 | pmath820 | pread820 | palg120 | palg220 | kra20 | lights20
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
0 | Allendale/Irvington/S. Hilton | -- | -- | -- | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 25.5 | NaN | 52.260870 | 0.400000 | 6.469565 | 2.869565 | 3.947826 | 5750 | 49.565217 | 12.608696 | NaN | ... | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 5.024264 | NaN | 718 | 459 | 632 | NaN | NaN | NaN | NaN | NaN | 5 | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 20.595671
1 | Beechfield/Ten Hills/West Hills | -- | -- | -- | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 15.0 | NaN | 75.512465 | 0.249307 | 0.554017 | 0.831025 | 3.767313 | 3610 | 13.496933 | 7.361963 | NaN | ... | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 4.883832 | NaN | 532 | 312 | 359 | NaN | NaN | NaN | NaN | NaN | 1 | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 17.286367
2 | Belair-Edison | -- | -- | -- | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 20.5 | NaN | 54.227591 | 0.445010 | 3.337572 | 2.304514 | 3.305785 | 6292 | 40.157480 | 9.448819 | NaN | ... | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 2.776037 | NaN | 1004 | 624 | 788 | NaN | NaN | NaN | NaN | NaN | 4 | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 13.493339
3 | Brooklyn/Curtis Bay/Hawkins Point | -- | -- | -- | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 22.0 | NaN | 36.952960 | 0.397847 | 8.073953 | 3.533817 | 2.550901 | 4273 | 56.321839 | 8.620690 | NaN | ... | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 1.824821 | NaN | 1004 | 575 | 593 | NaN | NaN | NaN | NaN | NaN | 3 | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 11.093169
4 | Canton | -- | -- | -- | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 28.0 | NaN | 65.113974 | 0.198216 | 0.396432 | 1.065411 | 6.070367 | 4036 | 9.895833 | 2.083333 | NaN | ... | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 9.346937 | NaN | 84 | 38 | 15 | NaN | NaN | NaN | NaN | NaN | 2 | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 22.098765

5 rows × 180 columns

vsdf.to_csv('export'+year+'.csv', index=False)

# Create vs db meta data table

import pandas as pd # df = pd.read_excel(open('VS19_Indicator_Data_Form.xlsm', 'rb'), sheet_name="Vital Signs 19 Indicators", header=None, names=['vsid', 'xlsmid', 'longname','shortname', 'UPLOAD_WP',]) df = pd.read_excel(open('VS'+xlsheet+'_Indicator_Data_Form.xlsm', 'rb'), sheet_name="Vital Signs "+xlsheet+" Indicators")df[['Indicator', 'ShortName', 'Section', 'Subsection', 'Short Source', 'Full Source', 'Years', 'Definition']].to_csv('bniajfi_vsigns__vs_details_14.csv')

# Create IndList.js

Life expecancy Mortgage approvals

Cached using Content>Themes>Grido>footer.php

xlsheet = '19' year = '19'import pandas as pd # df = pd.read_excel(open('VS19_Indicator_Data_Form.xlsm', 'rb'), sheet_name="Vital Signs 19 Indicators", header=None, names=['vsid', 'xlsmid', 'longname','shortname', 'UPLOAD_WP',]) df = pd.read_excel(open('VS'+xlsheet+'_Indicator_Data_Form.xlsm', 'rb'), sheet_name="Vital Signs "+xlsheet+" Indicators") df.ShortName = df.ShortName.astype(str) df['IndicatorPath'] = "/indicators/"+df['Section']+"/"+df['ShortName'].astype(str).str[:-2] print(df.columns) df = df[['Indicator', 'ShortName', 'Section', 'Full Source', 'Section', 'Definition', 'Years', 'IndicatorPath']]Index(['Indicator Number', 'Indicator', 'ShortName', 'Section', 'Subsection', 'Short Source', 'Full Source', 'Years', 'Normalization Source', 'Potential Source', 'VS Year', 'ACS_Table', 'Notes', 'Other', 'Esri_Endpoint', 'Definition', 'IndicatorPath'], dtype='object') indList = [] for i, row in df.iterrows(): indList.append( { 'Indicator': { "IndicatorName": row['Indicator'], "ShortName": row['ShortName'], "Section": str(row['Section'][0]), "Source": str(row['Full Source']), "IndicatorPath": row['IndicatorPath'], "Definition": str(row['Definition']), "Years": str(row['Years']) } } )indListimport json txt = """var indList = """ + json.dumps(indList)txt'var indList = [{"Indicator": {"IndicatorName": "Total Population", "ShortName": "tpopXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau", "IndicatorPath": "/indicators/Census Demographics/tpop", "Definition": "The total number of persons of all ages that live within an area. This indicator is frequently used to normalize data to allow for comparison across areas.", "Years": "2010"}}, {"Indicator": {"IndicatorName": "Total Male Population", "ShortName": "maleXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau", "IndicatorPath": "/indicators/Census Demographics/male", "Definition": "The total number of men of all ages of all ages that live within an area.", "Years": "2010"}}, {"Indicator": {"IndicatorName": "Total Female Population", "ShortName": "femaleXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau", "IndicatorPath": "/indicators/Census Demographics/female", "Definition": "The total number of women of all ages that live within an area.", "Years": "2010"}}, {"Indicator": {"IndicatorName": "Percent of Residents - Black/African-American (Non-Hispanic)", "ShortName": "paaXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/paa", "Definition": "The total number of persons that identify themselves as being racially Black or African American (and ethnically non-Hispanic) out of the total number of persons living in an area. \\u201cBlack or African American\\u201d refers to a person having origins in any of the Black racial groups of Africa. It includes people who indicated their race as \\u201cBlack\\u201d.", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Residents - White/Caucasian (Non-Hispanic)", "ShortName": "pwhiteXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/pwhite", "Definition": "The total number of persons that identify themselves as being racially White (and ethnically non-Hispanic) out of the total number of persons living in an area. \\u201cWhite\\u201d refers to a person having origins in any of the original peoples of Europe, the Middle East, or North Africa. It includes people who indicated their race(s) as \\u201cWhite\\u201d. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Residents - Asian (Non-Hispanic)", "ShortName": "pasiXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/pasi", "Definition": "The total number of persons that identify themselves as being Asian (and non-Hispanic) out of the total number of persons living in an area. \\u201cAsian\\u201d refers to a person having origins in any of the original peoples of the Far East, Southeast Asia, or the Indian subcontinent, including, for example, Cambodia, China, India, Japan, Korea, Malaysia, Pakistan, the Philippine Islands, Thailand, and Vietnam. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Residents - Two or More Races (Non-Hispanic)", "ShortName": "p2moreXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/p2more", "Definition": "The total number of persons that identify themselves as being of two or more races (and non-Hispanic) out of the total number of persons living in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Residents - All Other Races (Hawaiian/ Pacific Islander, Alaskan/ Native American Other Race) (Non-Hispanic)", "ShortName": "ppacXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/ppac", "Definition": "The total number of persons that identify themselves as being of either American Indian, Alaskan Native, Native Hawaiian or Other Pacific Islander, or some other race (non-Hispanic) out of the total number of persons living in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Residents - Hispanic", "ShortName": "phispXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/phisp", "Definition": "The total number of persons that identify their ethnicity as being Hispanic or Latino out of the total number of persons living in an area. Hispanic origin can be viewed as the heritage, nationality group, lineage, or country of birth of the person or the person\\u2019s parents or ancestors before their arrival in the United States. People who identify their origin as Hispanic, Latino, or Spanish may be any race. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Racial Diversity Index", "ShortName": "racdivXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/racdiv", "Definition": "The percent chance that two people picked at random within an area will be of a different race/ethnicity. This number does not reflect which race/ethnicity is predominant within an area. The higher the value, the more racially and ethnically diverse an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population Under 5 Years old", "ShortName": "age5_XX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/age5_", "Definition": "The percent of persons 5 years or under out of all persons living in an area.", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population 5-17 Years old", "ShortName": "age18_XX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/age18_", "Definition": "The percent of persons aged 6 to 18 years old out of all persons living in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population 18-24 Years old", "ShortName": "age24_XX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/age24_", "Definition": "The percent of persons aged 19 to 24 years old out of all persons living in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population 25-64 Years old", "ShortName": "age64_XX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/age64_", "Definition": "The percent of persons aged 25 to 64 years old out of all persons living in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population 65 Years and over", "ShortName": "age65_XX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/age65_", "Definition": "The total number of persons 65 years old and above out of all persons living in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Total Number of Households", "ShortName": "hhsXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hhs", "Definition": "A household consists of all the people occupying a housing unit. A household includes related and unrelated persons, if any, such as lodgers, foster children, wards, or employees who share the housing unit. A person living alone in a housing unit, or a group of unrelated people sharing a housing unit such as partners or roomers, is also counted as a household. The count of households excludes group quarters. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Female-Headed Households with Children Under 18", "ShortName": "femhhsXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/femhhs", "Definition": "The percentage of female-headed households with children under 18 out of all households with children under 18 in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households with Children Under 18", "ShortName": "famXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/fam", "Definition": "The percentage of households with children living in the household that are under the age of 18 out of all households. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Average Household Size", "ShortName": "hhsizeXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hhsize", "Definition": "The median value of number of persons living within a household. The average size of a household is obtained by dividing the number of persons in households by the number of households (or householders). ", "Years": "2010"}}, {"Indicator": {"IndicatorName": "Median Household Income", "ShortName": "mhhiXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/mhhi", "Definition": "The median household income is the middle value of the incomes earned in the prior year by households within an area. Income and earnings are inflation-adjusted for the last year of the 5-year period. The median value is used as opposed to the average so that both extremely high and extremely low prices do not distort the total amount of income earned by households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households Earning Less than $25,000", "ShortName": "hh25incXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hh25inc", "Definition": "The percentage of households earning less than $25,000 out of all households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households Earning $25,000 to $40,000", "ShortName": "hh40incXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hh40inc", "Definition": "The percentage of households earning between $25,000 and $39,999 out of all households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households Earning $40,000 to $60,000", "ShortName": "hh60incXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hh60inc", "Definition": "The percentage of households earning between $40,000 and $59,999 out of all households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households Earning $60,000 to $75,000", "ShortName": "hh75incXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hh75inc", "Definition": "The percentage of households earning between $60,000 and $74,999 out of all households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households Earning More than $75,000", "ShortName": "hhm75XX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hhm75", "Definition": "The percentage of households earning more than $75,000 out of all households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Inequality Index", "ShortName": "nan", "Section": "Census Demographics", "Source": "nan", "IndicatorPath": "/indicators/Census Demographics/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Family Households Living Below the Poverty Line", "ShortName": "hhpovXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hhpov", "Definition": "This indicator measures the percentage of households whose income fell below the poverty threshold out of all households in an area. Federal and state governments use such estimates to allocate funds to local communities. Local communities use these estimates to identify the number of individuals or families eligible for various programs. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Children Living Below the Poverty Line", "ShortName": "hhchpovXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hhchpov", "Definition": "This indicator measures the percentage of persons under the age of 18 living in households where the total income fell below the poverty threshold out of all children in households in an area. Federal and state governments use such estimates to allocate funds to local communities. Local communities use these estimates to identify the number of individuals or families eligible for various programs. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Median Price of Homes Sold", "ShortName": "saleprXX", "Section": "Housing and Community Development", "Source": "First American Real Estate Solutions", "IndicatorPath": "/indicators/Housing and Community Development/salepr", "Definition": "The median home sales price is the middle value of the prices for which homes are sold (both market and private transactions) within a calendar year. The median value is used as opposed to the average so that both extremely high and extremely low prices do not distort the prices for which homes are sold. This measure does not take into account the assessed value of a property.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Median Number of Days on the Market", "ShortName": "domXX", "Section": "Housing and Community Development", "Source": "RBIntel, Inc.", "IndicatorPath": "/indicators/Housing and Community Development/dom", "Definition": "The median number of days that homes listed for sale sit on the public market in a given area. This time period is from the date it is listed for sale till the day the contract of sale is signed. Private (non-listed) home sale transactions are not included in this indicator. The median days on market is used as opposed to the average so that both extremely high and extremely low days on the market do not distort the length of time for which homes are listed on the market.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Homes Sold", "ShortName": "shomesXX", "Section": "Housing and Community Development", "Source": "First American Real Estate Solutions", "IndicatorPath": "/indicators/Housing and Community Development/shomes", "Definition": "The total number of residential properties sold in a calendar year. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Percentage of Housing Units that are Owner-Occupied", "ShortName": "ownrocXX", "Section": "Housing and Community Development", "Source": "MdProperty View", "IndicatorPath": "/indicators/Housing and Community Development/ownroc", "Definition": "The percentage of homeowners that are the principal residents of a particular residential property out of all residential properties. It is important to note that a portion of these owner-occupied properties may be subdivided and have tenants that pay rent and are not included in the calculation.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Properties Under Mortgage Foreclosure", "ShortName": "foreXX", "Section": "Housing and Community Development", "Source": "Baltimore City Circuit Court", "IndicatorPath": "/indicators/Housing and Community Development/fore", "Definition": "The percentage of properties where the lending company or loan servicer has filed a foreclosure proceeding with the Baltimore City Circuit Court out of all residential properties within an area. This is not a measure of actual foreclosures since not every property that receives a filing results in a property dispossession.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Residential Properties that are Vacant and Abandoned", "ShortName": "vacantXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Housing and Community Development", "IndicatorPath": "/indicators/Housing and Community Development/vacant", "Definition": "The percentage of residential properties that have been classified as being vacant and abandoned by the Baltimore City Department of Housing out of all properties. Properties are classified as being vacant and abandoned if: the property is not habitable and appears boarded up or open to the elements; the property was designated as being vacant prior to the current year and still remains vacant; and the property is a multi-family structure where all units are considered to be vacant. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Residential Properties with Housing Violations (Excluding Vacants)", "ShortName": "vioXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Housing and Community Development", "IndicatorPath": "/indicators/Housing and Community Development/vio", "Definition": "The percentage of residential properties that have received at least one housing code violation from the Baltimore City Department of Housing out of all properties. Properties whose fa\\u00e7ade, structure, and/or surrounding area violate the City\\u2019s Housing Code are issued a notice and are considered open till the property is found in compliance. A property may receive multiple violations. ", "Years": "2010, 2011, 2012, 2013, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Properties with Rehabilitation Permits Exceeding $5,000", "ShortName": "resrehabXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Housing and Community Development", "IndicatorPath": "/indicators/Housing and Community Development/resrehab", "Definition": "The percent of residential properties that have applied for and received a permit to renovate the interior and/or exterior of a property where the cost of renovation will exceed $5,000. The threshold of $5,000 is used to differentiate a minor and more significant renovation project. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Total Number of Residential Properties", "ShortName": "totalresXX", "Section": "Housing and Community Development", "Source": "MdProperty View", "IndicatorPath": "/indicators/Housing and Community Development/totalres", "Definition": "The total number of residential properties located within an area as identified by Maryland Property View. It is important to note that that this indicator is a count of properties (single family homes, condominiums, and duplexes) and that a property can be comprised of multiple housing units. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Residential Sales for Cash", "ShortName": "cashsaXX", "Section": "Housing and Community Development", "Source": "RBIntel, Inc.", "IndicatorPath": "/indicators/Housing and Community Development/cashsa", "Definition": "The percent of homes and condominiums sold for cash out of all residential properties sold in a calendar year. These types of sales tend to signify investor-based purchases as homes purchased for cash either become rental properties or later sold again in an effort to generate a profit. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Percentage of Residential Sales in Foreclosure (REO)", "ShortName": "reosaXX", "Section": "Housing and Community Development", "Source": "RBIntel, Inc.", "IndicatorPath": "/indicators/Housing and Community Development/reosa", "Definition": "The portion of the homes and condominiums sold that were identified as being owned by the bank (REO) out of all residential properties sold in a calendar year.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Residential Tax Lien Sales", "ShortName": "taxlienXX", "Section": "Housing and Community Development", "Source": "BidBaltimore", "IndicatorPath": "/indicators/Housing and Community Development/taxlien", "Definition": "The percentage of residential properties with city liens sold as tax certificates at the annual tax lien certificate sale held in May. Tax sales are used to collect delinquent real property taxes and other unpaid charges to the city, which are liens against the real property. The tax certificate sale is a public online auction of City lien interests on properties that occurs annually in May.", "Years": "2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Demolition Permits per 1,000 Residential Properties", "ShortName": "demperXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Housing and Community Development", "IndicatorPath": "/indicators/Housing and Community Development/demper", "Definition": "The number of permits issued for the demolition of residential buildings per 1,000 existing residential properties. The permits are analyzed by date of issue and not date of actual demolition. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of New Construction Permits per 1,000 Residential Properties", "ShortName": "constperXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Housing and Community Development", "IndicatorPath": "/indicators/Housing and Community Development/constper", "Definition": "The number of permits issued for new residential buildings per 1,000 existing residential properties within a community. The permits are analyzed by date of issue and not date of completion. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Vacant Properties Owned by Baltimore City", "ShortName": "baltvacXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Housing and Community Development", "IndicatorPath": "/indicators/Housing and Community Development/baltvac", "Definition": "The percent of properties that are classified as being vacant and abandoned that are owned by Baltimore City. Baltimore City has come to own these properties through a variety of ways including (but not limited to) eminent domain, unpaid tax or water bills, and direct purchase.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Affordability Index - Mortgage", "ShortName": "affordmXX", "Section": "Housing and Community Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Housing and Community Development/affordm", "Definition": "The percentage of households that pay more than 30% of their total household income on mortgage and other housing-related expenses. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Affordability Index - Rent", "ShortName": "affordrXX", "Section": "Housing and Community Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Housing and Community Development/affordr", "Definition": "The percentage of households that pay more than 30% of their total household income on rent and related expenses out of all households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Number of Historic Tax Credits per 1,000 Residential Units", "ShortName": "histaxXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Finance", "IndicatorPath": "/indicators/Housing and Community Development/histax", "Definition": "The number of residential properties that received the Historic Tax Credit per 1,000 residential properties within an area. The credit is granted on the increased assessment directly resulting from qualified improvements. The duration of the credit is for 10 years, and is applicable to properties located in designated areas of significant historical value.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Homestead Tax Credits per 1,000 Residential Units", "ShortName": "homtaxXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Finance", "IndicatorPath": "/indicators/Housing and Community Development/homtax", "Definition": "The number of residential properties that received the homestead tax credit per 1,000 residential properties within an area. The Homestead Credit limits the increase in taxable assessments each year to a fixed percentage. Every county and municipality in Maryland is required to limit taxable assessment increases to 10% or less each year, with the Baltimore City rate capped at 4%.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Homeowner\'s Tax Credits per 1,000 Residential Units", "ShortName": "owntaxXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Finance", "IndicatorPath": "/indicators/Housing and Community Development/owntax", "Definition": "The number of residential properties that received the homeowners tax credit per 1,000 residential properties within an area. The homeowner\\u2019s tax credit sets a limit on the amount of property taxes any homeowner must pay based upon his or her income.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent Residential Properties that do Not Receive Mail", "ShortName": "nomailXX", "Section": "Housing and Community Development", "Source": "U.S. Postal Service, U.S. Department of Housing and Urban Development", "IndicatorPath": "/indicators/Housing and Community Development/nomail", "Definition": "The percentage of residential addresses for which the United States Postal Service has identified as being unoccupied (no mail collection) for a period of at least 90 days or longer. These properties may be habitable, but are not currently being occupied. It is important to note that a single residential property can contain more than one address.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Part 1 Crime Rate per 1,000 Residents", "ShortName": "crimeXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/crime", "Definition": "The Part 1 crime rate captures incidents of homicide, rape, aggravated assault, robbery, burglary, larceny, and auto theft that are reported to the Police Department. These incidents are per 1,000 residents in the neighborhood to allow for comparison across areas.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Daytime Crime Rate per 1,000 Population", "ShortName": "nan", "Section": "Crime and Safety", "Source": "nan", "IndicatorPath": "/indicators/Crime and Safety/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Violent Crime Rate per 1,000 Residents", "ShortName": "violXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/viol", "Definition": "The violent crime rate measures the number of Part 1 crimes identified as being violent (homicide, rape, aggravated assault, and robbery) that are reported to the Police Department. These incidents are per 1,000 residents in the neighborhood to allow for comparison across areas.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Property Crime Rate per 1,000 Residents", "ShortName": "propXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/prop", "Definition": "The property crime rate measures the number of Part 1 crimes identified as being property-based (burglary and auto theft) that are reported to the Police Department. These incidents are per 1,000 residents in the neighborhood to allow for comparison across areas. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Domestic Violence Calls For Service per 1,000 Residents", "ShortName": "domvioXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/domvio", "Definition": "The rate of calls to emergency 911 for domestic violence per 1,000 residents in an area. Calls for service are used rather than actual crime incidents since domestic violence can be classified as one of several types of criminal offenses. It is important to also note that not every case of domestic violence is reported and some claims of abuse may be unfounded. ", "Years": "2010, 2011, 2012"}}, {"Indicator": {"IndicatorName": "Juvenile Arrest Rate per 1,000 Juveniles", "ShortName": "juvarrXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/juvarr", "Definition": "The number of persons aged 10 to 17 arrested per 1,000 juveniles that live in an area. This indicator is calculated by where the arrested juvenile was arrested and not by where the crime is committed. Arrests are used instead of crimes committed since not all juveniles that are arrested are charged with committing a crime. This indicator also excludes offenders who are later charged as adults for their crime(s).", "Years": "2011, 2012, 2013, 2014, 2015"}}, {"Indicator": {"IndicatorName": "Juvenile Arrest Rate for Violent Offenses per 1,000 Juveniles", "ShortName": "juvviolXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/juvviol", "Definition": "The number of persons aged 10 to 17 arrested for violent offenses per 1,000 juveniles that live in an area. Violent offenses may include homicide, rape, assault (with or without a weapon), and robbery. This indicator is calculated by where the arrested juvenile was arrested and not by where the crime is committed. Arrests are used instead of crimes committed since not all juveniles that are arrested are charged with committing a crime. This indicator also excludes offenders who are later charged as adults for their crime(s).", "Years": "2011, 2012, 2013, 2014, 2015"}}, {"Indicator": {"IndicatorName": "Juvenile Arrest Rate for Drug-Related Offenses per 1,000 Juveniles", "ShortName": "juvdrugXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/juvdrug", "Definition": "The number of persons aged 10 to 17 arrested for drug-related offenses per 1,000 juveniles that live in an area. Drug-related offenses include arrests for possession, sale, manufacture, or abuse of illegal drugs, including alcohol. This indicator is calculated by where the arrested juvenile was arrested and not by where the crime is committed. Arrests are used instead of crimes committed since not all juveniles that are arrested are charged with committing a crime. This indicator also excludes offenders who are later charged as adults for their crime(s).", "Years": "2011, 2012, 2013, 2014, 2015"}}, {"Indicator": {"IndicatorName": "Number of Shootings per 1,000 Residents", "ShortName": "shootXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/shoot", "Definition": "The rate of 911 calls for shootings per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Gun-Related Homicides per 1,000 Residents", "ShortName": "gunhomXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/gunhom", "Definition": "The rate of homicides by firearm as reported in the Part 1 crime data per 1,000 residents in an area. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Common Assault Calls for Service per 1,000 Residents", "ShortName": "casltXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/caslt", "Definition": "The rate of calls for assaults that do not involve a weapon per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Narcotics Calls for Service per 1,000 Residents", "ShortName": "narcXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/narc", "Definition": "The rate of calls for narcotics per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Automobile Accident Calls for Service per 1,000 Residents", "ShortName": "caraccXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/caracc", "Definition": "The rate of calls for accidents involving motor vehicles per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident. Additionally, not every accident involving a motor vehicle is reported to the Police Department. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Rate of Fire and EMS Calls for Service per 1,000 Residents", "ShortName": "nan", "Section": "Crime and Safety", "Source": "nan", "IndicatorPath": "/indicators/Crime and Safety/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Average Fire and EMS Response Time", "ShortName": "nan", "Section": "Crime and Safety", "Source": "nan", "IndicatorPath": "/indicators/Crime and Safety/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Children Enrolled in Head Start Programs", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Students Ever Attended 1st - 5th Grade", "ShortName": "eattendXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/eattend", "Definition": "The number of children who have registered for and attend 1st through 5th grade at a Baltimore City Public School at any point during the school year. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Number of Students Ever Attended 6th - 8th Grade", "ShortName": "mattendXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/mattend", "Definition": "The number of children who have registered for and attend 6th through 8th grade at a Baltimore City Public School at any point in the school year. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Number of Students Ever Attended 9th - 12th Grade", "ShortName": "hsattendXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hsattend", "Definition": "The number of children who have registered for and attend 9th through 12th grade at a Baltimore City Public School at any point in the school year.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Percent of Students Enolled in CTE Programs", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Students that are African American (non-Hispanic)", "ShortName": "aastudXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/aastud", "Definition": "The percentage of Black/African American students of any grade that attend any Baltimore City Public School out of all public school students within an area in a school year.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Percent of Students that are White (non-Hispanic)", "ShortName": "wstudXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/wstud", "Definition": "The percentage of white (non-Hispanic) students of any grade that attend any Baltimore City Public School out of all public school students within an area in a school year. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Percent of Students that are Hispanic", "ShortName": "hstudXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hstud", "Definition": "The percentage of students of any grade level who identify their ethnicity as being Hispanic that attend any Baltimore City Public School out of all public school students within an area in a school year. Ethnicity is separate from a student\\u2019s race. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Percent of 1st-5th Grade Students that are Chronically Absent (Missing at least 20 days)", "ShortName": "abseXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/abse", "Definition": "The percentage of 1st-5th grade students that were recognized as being absent from public school 20 or more days out of all students. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019"}}, {"Indicator": {"IndicatorName": "Percent of 6th-8th Grade Students that are Chronically Absent (Missing at least 20 days)", "ShortName": "absmdXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/absmd", "Definition": "The percentage of 6th-8th grade students that were recognized as being absent from public school 20 or more days out of all students. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019"}}, {"Indicator": {"IndicatorName": "Percent of 9th-12th Grade Students that are Chronically Absent (Missing at least 20 days)", "ShortName": "abshsXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/abshs", "Definition": " The percentage of 9th-12th grade students that were recognized as being absent from public school 20 or more days out of all students. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019"}}, {"Indicator": {"IndicatorName": "Percentage of Students Suspended or Expelled During School Year", "ShortName": "suspXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/susp", "Definition": "The percentage of students of any grade level that were formally suspended or expelled for any reason during the school year out of all public school students within an area. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013"}}, {"Indicator": {"IndicatorName": "Percentage of Students Receiving Free or Reduced Meals", "ShortName": "farmsXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/farms", "Definition": "The percentage of students of any grade that are eligible for and received free or reduced school meals out of all public school students. Eligibility for this program is based on the student\\u2019s household income. ", "Years": "2009-2010, 2010-2011, 2011-2012"}}, {"Indicator": {"IndicatorName": "Percentage of Students Enrolled in Special Education Programs", "ShortName": "spedXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/sped", "Definition": "The percentage of students of any grade that are eligible for and participated in public school special education programs out of all students. This includes all students with any diagnosed disability.", "Years": "2009-2010, 2010-2011, 2011-2012"}}, {"Indicator": {"IndicatorName": "Percentage of Students Enrolled in After School Programs", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Kindergarten School Readiness", "ShortName": "readyXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/ready", "Definition": "The percentage of children whose composite score indicates full school readiness out of all kindergarten school children tested within an area in a school year. The Maryland Model for School Readiness (MMSR) is an assessment and instructional system that was designed to provide parents, teachers, and early childhood providers with a common understanding of what children know and are able to do upon entering school. Under the MMSR system, all children entering kindergarten are assessed for level of mastery across several learning domains. These domains include: social and personal development; language and literacy; mathematical thinking; scientific thinking; social studies; the arts; and physical development and health. Kindergarten teachers must evaluate students during the first few months of the kindergarten year using selected Work Sampling System (WSS) indicators and report their ratings by the end of November of each year to the state. ", "Years": "2010-2011, 2011-2012"}}, {"Indicator": {"IndicatorName": "Percentage of 3rd Grade Students Passing MSA Math", "ShortName": "math3XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/math3", "Definition": "The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of 3rd Grade Students Passing MSA Reading", "ShortName": "read3XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/read3", "Definition": "The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of 5th Grade Students Passing MSA Math", "ShortName": "math5XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/math5", "Definition": "The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of 5th Grade Students Passing MSA Reading", "ShortName": "read5XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/read5", "Definition": "The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of 8th Grade Students Passing MSA Math", "ShortName": "math8XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/math8", "Definition": "The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of 8th Grade Students Passing MSA Reading", "ShortName": "read8XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/read8", "Definition": "The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of Students Passing H.S.A. English ", "ShortName": "hsaengXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hsaeng", "Definition": "The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of Students Passing H.S.A. Biology", "ShortName": "hsabioXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hsabio", "Definition": "The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of Students Passing H.S.A. Government", "ShortName": "hsagovXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hsagov", "Definition": "The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of Students Passing H.S.A. Algebra", "ShortName": "hsaalgXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hsaalg", "Definition": "The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "High School Dropout/Withdrawl Rate", "ShortName": "dropXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/drop", "Definition": "The percentage of 9th through 12th graders who withdrew from public school out of all high school students in a school year. Withdraw codes are used as a proxy for dropping out of school based upon the expectation that withdrawn students are no longer receiving educational services. A dropout is defined as a student who, for any reason other than death, leaves school before graduation or the completion of a Maryland-approved education program and is not known to enroll in another school or State-approved program during a current school year.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "High School Completion Rate", "ShortName": "complXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/compl", "Definition": "The percentage of 12th graders in a school year that successfully completed high school out of all 12th graders within an area. Completers are identified as completing their program of study at the high school level and satisfying the graduation requirements for a Maryland High School Diploma or the requirements for a Maryland Certificate of Program Completion.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Persons Receiving a GED", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Students Switching Schools within School Year", "ShortName": "sclswXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/sclsw", "Definition": "The percentage of 1st through 12th graders who change schools out of all students in a school year. Students must have attended both schools for which they were registered for at least one day. Additionally, this indicator only identifies the share of students that change schools for any reasons and not the frequency, number of school switches, or change in residences in a school year. The percentage reflects the last home address available for the student who changed schools. This may or may not be the home address provided for the first school that they are registered to attend. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019"}}, {"Indicator": {"IndicatorName": "Percentage of Students Attending Zoned School ", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Average Distance Travelled to School (6th-8th Grade)", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Average Distance Travelled to School (9th-12th Grade)", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percentage of Population aged 16-19 in School and/or Employed", "ShortName": "sclempXX", "Section": "Education and Youth", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Education and Youth/sclemp", "Definition": "The percentage of persons aged 16 to 19 who are in school and/or are employed out of all persons in their age cohort.", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Teen Birth Rate per 1,000 Females (Aged 15-19)", "ShortName": "teenbirXX", "Section": "Children and Family Health", "Source": "Maryland Department of Vital Statistics", "IndicatorPath": "/indicators/Children and Family Health/teenbir", "Definition": "The rate of female teens aged 15-19 that gave birth per 1,000 females aged 15-19. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Births Delivered at Term (37-42 Weeks)", "ShortName": "termbirXX", "Section": "Children and Family Health", "Source": "Maryland Department of Vital Statistics", "IndicatorPath": "/indicators/Children and Family Health/termbir", "Definition": "The percentage of births delivered at term measures the percentage of births in a calendar year where the baby is delivered between 37 and 42 weeks of gestation.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Babies Born with a Satisfactory Birth Weight", "ShortName": "birthwtXX", "Section": "Children and Family Health", "Source": "Maryland Department of Vital Statistics", "IndicatorPath": "/indicators/Children and Family Health/birthwt", "Definition": "The percentage of children born with a birth weight of at least 5 \\u00bd pounds out of all births in the area. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Births Where the Mother Received Early Prenatal Care (First Trimester)", "ShortName": "prenatalXX", "Section": "Children and Family Health", "Source": "Maryland Department of Vital Statistics", "IndicatorPath": "/indicators/Children and Family Health/prenatal", "Definition": "The percentage of births where the mother received prenatal care during the first trimester of the pregnancy in a calendar year out of all births within an area. This information is calculated by the Vital Statistics registration information collected from each live birth. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Children (Aged 0-6) Tested for Elevated Blood Lead Levels", "ShortName": "leadtestXX", "Section": "Children and Family Health", "Source": "Maryland Department of the Environment, Lead Poisoning Prevention Program", "IndicatorPath": "/indicators/Children and Family Health/leadtest", "Definition": "This indicator reflects the total number of children aged 0-6 who are tested for the presence of blood lead in a calendar year.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Children (Aged 0-6) with Elevated Blood Lead Levels", "ShortName": "ebllXX", "Section": "Children and Family Health", "Source": "Maryland Department of the Environment, Lead Poisoning Prevention Program", "IndicatorPath": "/indicators/Children and Family Health/ebll", "Definition": "The number of children aged 0-6 that are found to either have elevated blood lead levels (\\u226510Mg/dL) or lead poisoning (\\u226520 Mg/dL) out of the number of children tested within an area in a calendar year. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Lead Violations per 1,000 Residential Units", "ShortName": "nan", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Families Receiving TANF", "ShortName": "tanfXX", "Section": "Children and Family Health", "Source": "Maryland Department of Human Resources", "IndicatorPath": "/indicators/Children and Family Health/tanf", "Definition": "Temporary Assistance for Needy Families (TANF) is a federal assistance program. The Act provides temporary financial assistance while aiming to get people off of that assistance, primarily through employment. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Persons receiving SNAP", "ShortName": "snapXX", "Section": "Children and Family Health", "Source": "Maryland Department of Human Resources", "IndicatorPath": "/indicators/Children and Family Health/snap", "Definition": "The Supplemental Nutrition Assistance Program (SNAP), formerly known as Food Stamps, helps low-income households buy the food they need for good health. ", "Years": "2019"}}, {"Indicator": {"IndicatorName": "Fetal Mortality Rate", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Liquor Outlet Density (per 1,000 Residents)", "ShortName": "liquorXX", "Section": "Children and Family Health", "Source": "Baltimore City Liquor Board", "IndicatorPath": "/indicators/Children and Family Health/liquor", "Definition": "This indicator reflects the number of business establishments that possess a Class A (Off Sale package goods no on-premises consumption - 6 days, 6:00 a.m.- Midnight. No Sunday sales except Sundays between Thanksgiving Day and New Year\'s Day upon issuance of a special license for each Sunday) or BD7 (tavern) business license that allows them to sell beer, wine, or liquor. Other liquor licenses to restaurants or on-premise consumption were not included in this analysis. This number is provided by 1,000 residents to allow for comparison across neighborhoods.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Fast Food Outlet Density (per 1,000 Residents)", "ShortName": "fastfdXX", "Section": "Children and Family Health", "Source": "Johns Hopkins University, Center for a Livable Future", "IndicatorPath": "/indicators/Children and Family Health/fastfd", "Definition": "The Johns Hopkins Center for a Livable Future (CLF) obtained the food permit list from the Baltimore City Health Department in August 2011, which includes all sites that sell food, such as stores, restaurants and temporary locations such as farmers\\u2019 market stands and street carts. The restaurants were grouped into three categories, including full service restaurants, fast food chains and carryouts. Carryout and fast food chain restaurants were extracted from the restaurant layer and spatially joined with the 2010 Community Statistical Area (CSA) data layer, provided by BNIA-JFI. The prepared foods density, per 1,000 people, was calculated for each CSA using the CSA\\u2019s population and the total number of carryout and fast food restaurants, including vendors selling prepared foods in public markets, in each CSA.", "Years": "2011, 2013, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Persons calling UWCM 211 for Health-Related Services ", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Rate of STDs per 1,000 Residents (Chlamydia, Gonorrhea, and Syphilis)", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Rate of HIV/AIDS per 1,000 Residents", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Life Expectancy", "ShortName": "lifexpXX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/lifexp", "Definition": "The average number of years a newborn can expect to live, assuming he or she experiences the currently prevailing rates of death through their lifespan. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Infant Mortality Rate", "ShortName": "mort1XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort1", "Definition": "The number of infant deaths (babies under one year of age) per 1,000 live births within the area in a five year period. This is the most stable and commonly measured indicator of mortality in this age group. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Mortality by Age (1-14 Years old)", "ShortName": "mort14XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort14", "Definition": "The number of deaths of persons between the ages of one and 14 per 10,000 persons within the area in a five year period. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Mortality by Age (15-24 Years Old)", "ShortName": "mort24XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort24", "Definition": "The number of deaths of persons between the ages of 15 and 24 per 10,000 persons within the area in a five year period.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Mortality by Age (25-44 Years Old)", "ShortName": "mort44XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort44", "Definition": "The number of deaths of persons between the ages of 25 and 44 per 10,000 persons within the area in a five year period.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Mortality by Age (45-64 Years Old)", "ShortName": "mort64XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort64", "Definition": "The number of deaths of persons between the ages of 45 and 64 per 10,000 persons within the area in a five year period. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Mortality by Age (65-84 Years Old)", "ShortName": "mort84XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort84", "Definition": "The number of deaths of persons between the ages of 65 and 84 per 10,000 persons within the area in a five year period.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Mortality by Age (85 and Over)", "ShortName": "mort85XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort85", "Definition": "The number of deaths of persons 85 years and older per 10,000 persons within the area in a five year period. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Number of Overdose Calls for Service per 1,000 Residents", "ShortName": "overdXX", "Section": "Children and Family Health", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Children and Family Health/overd", "Definition": "The rate of 911 calls to police for overdoses per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident.", "Years": "2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Causes of Death (analysis of top causes)", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Causes of Death (analysis of top causes)", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Causes of Death (analysis of top causes)", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Causes of Death (analysis of top causes)", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of persons with health insurance", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Persons with Library Cards per 1,000 Residents", "ShortName": "libcardXX", "Section": "Arts and Culture", "Source": "Enoch Pratt Free Library", "IndicatorPath": "/indicators/Arts and Culture/libcard", "Definition": "The rate of persons per 1,000 residents that possess a valid public library system card. This includes all library card types (first card, juvenile, young adult, adult). ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Event Permits Requested per 1,000 Residents", "ShortName": "artevntXX", "Section": "Arts and Culture", "Source": "ENVISTA, with permission from the Baltimore City Department of Transportation", "IndicatorPath": "/indicators/Arts and Culture/artevnt", "Definition": "The number of event permits requested per 1,000 residents. Events include, but are not limited to, festivals, block parties, races, and parades. In the event of a large event, the central point is used to calculate the location of the request.", "Years": "2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Public Art per 1,000 Residents", "ShortName": "publartxx", "Section": "Arts and Culture", "Source": "Baltimore Office of Promotion and the Arts", "IndicatorPath": "/indicators/Arts and Culture/publart", "Definition": "The number of works of public art per 1,000 residents. These works include, but are not exclusive to, murals, monuments, sculptures, mosaics, and stained glass. The Baltimore Office of Promotion and the Arts tracks works created through the 1% for Public Art and Baltimore Mural Programs and maintains general inventories of public art and murals. Additional inventories of public art exist, but not at a comprehensive citywide scale and hence cannot be broken down into cross-neighborhood analyses.", "Years": "2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Businesses that are Arts-Related per 1,000 Residents", "ShortName": "artbusXX", "Section": "Arts and Culture", "Source": "InfoUSA", "IndicatorPath": "/indicators/Arts and Culture/artbus", "Definition": "The rate of businesses (both for-profit and non-profit) that are directly related to arts and culture per 1,000 residents. Arts-related businesses are defined as belonging to industries that allow for the consumption and enjoyment of arts and culture. The following industries are identified by their primary NAICS code: music, literary, and visual arts-related retail/supplies (451140, 451211, 451220); art dealers (453920, 453920); libraries (519120); motion picture and film (521310, 532230); art schools (611610); performing arts (711110, 711120, 711130, 711190); independent artists, writers, and performers (711510); museums (712110); historical sites (712120); and zoos, gardens and nature parks (712130, 712190). The following industries are identified by their primary SIC codes: designers (152106); art publishers (274101), music, literary, and visual arts-related retail/supplies (393101, 519202, 573608, 573609, 593201, 594201, 594205, 594501, 594520, 594601, 599965, 769969); art galleries, dealers, and consultants (599969, 599988, 599989); photography (722121); calligraphers (733607); embroidery (738942); theatres (783201, 792207); theatrical support (792211, 792212); musical and live entertainment (792903, 792905, 792906, 792908, 792917, 792918, 792927); parks (799951); art and music instruction (804958, 829915, 829919); libraries (823111); museums (841201); arts organizations (841202); zoos (842201); writers (899903); visual artists (899907, 899912); art restoring (899908); and music arrangers and composers (899921).", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Total Employment in Arts-Related Businesses", "ShortName": "artempXX", "Section": "Arts and Culture", "Source": "InfoUSA", "IndicatorPath": "/indicators/Arts and Culture/artemp", "Definition": "The number of persons employed in arts-related businesses (both for-profit and non-profit). This number does not count those persons who identify themselves as being artists and does not count sole proprietorships or persons who work part-time in the arts. The same industries used to calculate the rate of arts-related businesses are used to calculate total employment in arts-related businesses. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percentage of Businesses that are Non-Profits", "ShortName": "nan", "Section": "Arts and Culture", "Source": "nan", "IndicatorPath": "/indicators/Arts and Culture/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent Population 16-64 Employed", "ShortName": "emplXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/empl", "Definition": "The percent of persons between the ages of 16 and 64 formally employed or self-employed and earning a formal income. It is used to understand how many persons are working out of the entire population, not just those in the labor force (persons who may be looking for work or working). ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent Population 16-64 Unemployed and Looking for Work", "ShortName": "unemplXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/unempl", "Definition": "The percent of persons between the ages of 16 and 64 not working out of all persons, not just those in the labor force (persons who may be looking for work). These persons are seeking work that pays a formal income. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent Population 16-64 Not in Labor Force", "ShortName": "nilfXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/nilf", "Definition": "The percent of persons who are not in the labor force out of all persons between the ages of 16 and 64 in the area. There are several reasons why persons may not be included in the labor force. These reasons may include: they are caretakers for children or other family members; they attend school or job training; they may have a disability; and they are discouraged or frustrated and have given up seeking a job or have a history that may include criminal activity. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Unemployment Rate", "ShortName": "unemprXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/unempr", "Definition": "The percent of persons between the ages of 16 and 64 that are in the labor force (and are looking for work) but are not currently working. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent Population (25 Years and over) With Less Than a High School Diploma or GED", "ShortName": "lesshsXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/lesshs", "Definition": "The percentage of persons that have not completed, graduated, or received a high school diploma or GED. This is a standard indicator used to measure the portion of the population with less than a basic level of skills needed for the workplace. Persons under the age of 25 are not included in this analysis since many of these persons are still attending various levels of schooling. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent Population (25 Years and over) With High School Diploma and Some College or Associates Degree", "ShortName": "hsdiplXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/hsdipl", "Definition": "The percentage of persons that have completed, graduated, or received a high school diploma or GED and also have taken some college courses or completed their Associate\'s degree. This is a standard indicator used to measure the portion of the population with a basic level of skills needed for the workplace. Persons under the age of 25 are not included in this analysis since many of these persons are still attending various levels of schooling. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent Population (25 Years and over) with a Bachelor\'s Degree or Above", "ShortName": "bahigherXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/bahigher", "Definition": "The percentage of persons that have completed, graduated, or received a Bachelor\\u2019s or an advanced degree. This is an indicator used to measure the portion of the population having an advanced level of skills needed for the workplace. Persons under the age of 25 are not included in this analysis since many of these persons are still attending various levels of schooling. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Total Number of Commercial Properties", "ShortName": "compropXX", "Section": "Workforce and Economic Development", "Source": "MdProperty View", "IndicatorPath": "/indicators/Workforce and Economic Development/comprop", "Definition": "The total number of commercial properties located within an area in a particular year. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Percent of Commercial Properties with Rehab Permits Above $5,000", "ShortName": "crehabXX", "Section": "Workforce and Economic Development", "Source": "Baltimore City Department of Housing", "IndicatorPath": "/indicators/Workforce and Economic Development/crehab", "Definition": "The percentage of properties that are investing within their current establishment and not the level of their investment. Permits for work below $5,000 are considered to be minor and not included in this indicator. A single establishment can apply for and receive multiple permits. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Total Number of Businesses", "ShortName": "numbusXX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/numbus", "Definition": "The total number of businesses (both for-profit and non-profit) within an area at a single time in a year. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Total Number of Employees", "ShortName": "totempXX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/totemp", "Definition": "The total number of persons employed by businesses (both for-profit and non-profit) within an area at a single time in a year. ", "Years": "2010, 2011, 2012, 2013"}}, {"Indicator": {"IndicatorName": "Number of Businesses with Under 50 Employees", "ShortName": "smlbusXX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/smlbus", "Definition": "The total number of businesses (both for-profit and non-profit) that report having less than 50 persons employed within an area at a single time in a year. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Employed Residents who Work Outside the City", "ShortName": "wrkoutXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, Longitudinal Employer-Household Dynamics", "IndicatorPath": "/indicators/Workforce and Economic Development/wrkout", "Definition": "The percentage of workers that are employed by jobs located outside of Baltimore City. Only persons who report being employed and are at least 16 years old are included in the analysis. ", "Years": "2010, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Total Dollar Amount Invested in Small Businesses per 50 Businesses", "ShortName": "smlinvstXX", "Section": "Workforce and Economic Development", "Source": "Johns Hopkins University, 21st Century Cities Initiative", "IndicatorPath": "/indicators/Workforce and Economic Development/smlinvst", "Definition": "The total dollar amount invested in businesses with fewer than 500 employees per 50 businesses. Small business lending data to include FFIEC insured bank loans under $1 million to businesses made by large banks; venture capital investments; US Export-Import Bank loans; Small Business Innovation Research (SBIR) and Small business Technology Transfer Research (STTR) grants; government, philanthropic, and institutional grants supporting small businesses; Maryland Department of Commerce loans; State of Maryland Neighborhood BusinessWorks loans; Baltimore Development Corporation loans; and Small Business Administration 7a and 504 loans.", "Years": "2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Residential Mortgages Originated or Approved", "ShortName": "hmdaXX", "Section": "Housing and Community Development", "Source": "Consumer Financial Protection Bureau", "IndicatorPath": "/indicators/Housing and Community Development/hmda", "Definition": "The percent of first lien mortgage applications for single family homes that were originated or approved out of all applications in the area. The Home Mortgage Disclosure Act (HMDA) requires many financial institutions to maintain, report, and publicly disclose information about mortgages in neighborhoods. ", "Years": "2019"}}, {"Indicator": {"IndicatorName": "Number of Banks and Bank Branches per 1,000 Residents", "ShortName": "banksXX", "Section": "Workforce and Economic Development", "Source": "Federal Deposit Insurance Corporation", "IndicatorPath": "/indicators/Workforce and Economic Development/banks", "Definition": "The number of banks and bank branches per 1,000 residents within an area. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Businesses that are 1 Year old or Less", "ShortName": "biz1_XX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/biz1_", "Definition": "The percentage of businesses (both for-profit and non-profit) that report their establishment as being one year old or less. The age of the business is determined by the year that the first year they appeared in the InfoUSA database. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Businesses that are 2 Years old or Less", "ShortName": "biz2_XX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/biz2_", "Definition": "The percentage of businesses (both for-profit and non-profit) that report their establishment as being two years old or less. The age of the business is determined by the year that the first year they appeared in the business database. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Businesses that are 4 Years old or Less", "ShortName": "biz4_XX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/biz4_", "Definition": "The percentage of businesses (both for-profit and non-profit) that report their establishment as being four years old or less. The age of the business is determined by the year that the first year they appeared in the business database. A business that has been in operation more than four years has a greater likelihood of remaining open for a longer period of time. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Adult Population on Parole/Probation", "ShortName": "prbprlXX", "Section": "Workforce and Economic Development", "Source": "nan", "IndicatorPath": "/indicators/Workforce and Economic Development/prbprl", "Definition": "The percentage of the population age 18 and older that are on parole or probation.", "Years": "2013"}}, {"Indicator": {"IndicatorName": "Percent of CSA that is Either Low or Moderate income (by Census tract)", "ShortName": "nan", "Section": "Workforce and Economic Development", "Source": "nan", "IndicatorPath": "/indicators/Workforce and Economic Development/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of persons in MOED training programs (per 1,000 Residents)", "ShortName": "nan", "Section": "Workforce and Economic Development", "Source": "nan", "IndicatorPath": "/indicators/Workforce and Economic Development/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Households with No Internet at Home", "ShortName": "nohhintXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/nohhint", "Definition": "Percent of households with no home Internet of any kindThe percentage of households without an internet subscription at home.", "Years": "2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Number of Businesses by Selected Neighborhood Industry (NAICS Sectors)", "ShortName": "neiindXX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/neiind", "Definition": "The number of businesses (both for-profit and non-profit) that provide products and services to local residents. The industries included in this indicator are: Retail Trade (NAICS 44-45); Finance and Insurance (NAICS 52); Professional, Scientific, and Technical Services (NAICS 54); Health Care and Social Assistance (NAICS 62); Arts, Entertainment, and Recreation (NAICS 71); Accommodation and Food Services (NAICS 72); and Other Services except Public Administration (NAICS 81). The primary industry reported by each business was used to determine their inclusion. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Neighborhood Businesses per 1,000 Residents (NAICS Sectors)", "ShortName": "neibusXX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/neibus", "Definition": "The number of businesses (both for-profit and non-profit) that provide products and services to local residents per 1,000. The industries included in this indicator are: Retail Trade (NAICS 44-45); Finance and Insurance (NAICS 52); Professional, Scientific, and Technical Services (NAICS 54); Health Care and Social Assistance (NAICS 62); Arts, Entertainment, and Recreation (NAICS 71); Accommodation and Food Services (NAICS 72); and Other Services except Public Administration (NAICS 81). The primary industry reported by each business was used to deter-mine their inclusion. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Total number of Employees by Selected Neighborhood Industry (NAICS Sectors)", "ShortName": "neiempXX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/neiemp", "Definition": "The number of persons employed by businesses (both for-profit and non-profit) that provide products and services to local residents. The industries included in this indicator are: Retail Trade (NAICS 44-45); Finance and Insurance (NAICS 52); Professional, Scientific, and Technical Services (NAICS 54); Health Care and Social Assistance (NAICS 62); Arts, Entertainment, and Recreation (NAICS 71); Accommodation and Food Services (NAICS 72); and Other Services except Public Administration (NAICS 81). The primary industry reported by each business was used to determine their inclusion. The persons employed by these businesses may not necessarily live in the neighborhood where the business is located. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Population (Over the Age of 18) Who are Registered to Vote", "ShortName": "regvoteXX", "Section": "Sustainability", "Source": "Baltimore City Board of Elections", "IndicatorPath": "/indicators/Sustainability/regvote", "Definition": "The percentage of persons over the age of 18 registered to vote out of all persons 18 years and over.", "Years": "2010, 2012, 2014, 2016, 2018"}}, {"Indicator": {"IndicatorName": "Percent Population (Over the Age of 18) Who Voted in the General Election", "ShortName": "votedXX", "Section": "Sustainability", "Source": "Baltimore City Board of Elections", "IndicatorPath": "/indicators/Sustainability/voted", "Definition": "The percentage of persons who voted in the last general election out of all registered voters. ", "Years": "2010, 2012, 2014, 2016, 2018"}}, {"Indicator": {"IndicatorName": "Rate of Dirty Streets and Alleys Reports per 1,000 Residents", "ShortName": "dirtystXX", "Section": "Sustainability", "Source": "Baltimore City CitiStat", "IndicatorPath": "/indicators/Sustainability/dirtyst", "Definition": "The rate of service requests for dirty streets and alleys through Baltimore\\u2019s 311 system per 1,000 residents. More than one service request may be made for the same issue but is logged as a unique request.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Rate of Clogged Storm Drain Reports per 1,000 Residents", "ShortName": "cloggedXX", "Section": "Sustainability", "Source": "Baltimore City CitiStat", "IndicatorPath": "/indicators/Sustainability/clogged", "Definition": "The rate of service requests for addressing clogged storm drains made through Baltimore\\u2019s 311 system per 1,000 residents. More than one service request may be made for the same issue but is logged as a unique request.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percent of Population that Drove Alone to Work", "ShortName": "drvaloneXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/drvalone", "Definition": "The percentage of commuters driving alone out of all commuters aged 16 and above. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population that Carpool to Work", "ShortName": "carpoolXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/carpool", "Definition": "The percentage of commuters that carpool out of all commuters aged 16 and above. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population that Uses Public Transportation to Get to Work", "ShortName": "pubtranXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/pubtran", "Definition": "The percentage of commuters that use public transit out of all commuters aged 16 and above.", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population that Walks to Work", "ShortName": "walkedXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/walked", "Definition": "The percentage of commuters that walk to work out of all commuters aged 16 and above.", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Employed Population with Travel Time to Work of 0-14 Minutes", "ShortName": "trav14XX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/trav14", "Definition": "The percentage of commuters that spend less than 15 minutes commuting to work out of all commuters aged 16 and above. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Employed Population with Travel Time to Work of 15-29 Minutes", "ShortName": "trav29XX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/trav29", "Definition": "The percentage of commuters that spend between 15 and 29 minutes commuting to work out of all commuters aged 16 and above. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Employed Population with Travel Time to Work of 30-44 Minutes", "ShortName": "trav44XX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/trav44", "Definition": "The percentage of commuters that spend between 30 and 44 minutes travelling to work out of all commuters aged 16 and above. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Employed Population with Travel Time to Work of 45 Minutes and Over", "ShortName": "trav45XX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/trav45", "Definition": "The percentage of commuters that spend more than 45 minutes travelling to work out of all commuters aged 16 and above. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Area Covered by Trees", "ShortName": "treesXX", "Section": "Sustainability", "Source": "University of Vermont Spatial Analysis Lab", "IndicatorPath": "/indicators/Sustainability/trees", "Definition": "The percent of total land area comprised of tree canopy. The primary sources for this land cover layer were 2004 pan-sharpened 1m Ikonos satellite imagery, a normalized Digital Surface Model (nDSM) derived from 2006 LiDAR data, and LiDAR intensity data resulting from the 2006 acquisition. Other sources of data include the City\'s planimetric GIS database (building footprints and road casing polygons). The land cover classification was performed using automated object-based image analysis (OBIA) techniques in Definiens Developer/eCognition Server. No accuracy assessment was conducted, but the dataset was thoroughly reviewed at a scale of 1:2000. Over 370 corrections were made to the classification. ", "Years": "2007, 2015, 2017"}}, {"Indicator": {"IndicatorName": "Air Quality Risk", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Area Covered by Impervious Surface", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Community Managed Open Spaces", "ShortName": "cmosXX", "Section": "Sustainability", "Source": "Baltimore Neighborhood Indicators Alliance - Jacob France Institute", "IndicatorPath": "/indicators/Sustainability/cmos", "Definition": "The number of community managed open spaces in an area that include community gardens (food-producing or ornamental), Adopt-A-Lots, or some other green space managed by the community. ", "Years": "2011, 2014, 2015"}}, {"Indicator": {"IndicatorName": "Median Daily Water Consumption", "ShortName": "watercXX", "Section": "Sustainability", "Source": "Baltimore City Department of Public Works", "IndicatorPath": "/indicators/Sustainability/waterc", "Definition": "The median daily average water consumption of all city meters registering greater than 0.0 cubic meters per day.", "Years": "2011"}}, {"Indicator": {"IndicatorName": "Number of Downspout Disconnections per 1,000 Residential Units", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Public Trashcans", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Rate of Sewer/Water Main Breaks per 1,000 Residents", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Natural Gas Utilization", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Energy Use", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Residences Heated by Utility Gas", "ShortName": "heatgasXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/heatgas", "Definition": "The percentage of homes that use utility gas for heat and cooking out of all homes. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Residences Heated by Electricity", "ShortName": "elheatXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/elheat", "Definition": "The percentage of homes that use electricity for heat and cooking out of all homes. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households with No Vehicles Available", "ShortName": "novhclXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/novhcl", "Definition": "The percentage of households that do not have a personal vehicle available for use out of all households in an area. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Number of Photovoltaic/Solar Permits", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Homes Weatherized", "ShortName": "weatherXX", "Section": "Sustainability", "Source": "Maryland Department of Housing and Community Development", "IndicatorPath": "/indicators/Sustainability/weather", "Definition": "The percent of residential properties that were eligible for and received weatherization assistance such as air sealing or furnace replacements. The Weatherization Assistance Program helps eligible low-income households lower their energy costs by increasing the energy efficiency of their homes, while ensuring their health and safety. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016"}}, {"Indicator": {"IndicatorName": "Walk Score", "ShortName": "wlkscXX", "Section": "Sustainability", "Source": "Walk Score", "IndicatorPath": "/indicators/Sustainability/wlksc", "Definition": "The Walk Score\\u00ae is calculated by mapping out the distance to amenities in nine different categories (grocery stores, restaurants, shopping, coffee shops, banks, parks, schools, book stores/libraries, and entertainment) and are weighted according to importance. The distance to a location, counts, and weights determine a base score of an address, which is then normalized to a score from 0 to 100. More information on Walk Score can be found at http://www.walkscore.com/. ", "Years": "2011, 2017"}}, {"Indicator": {"IndicatorName": "Aggregate Number of Community Assets", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Daily Bus Stop Loadings per 1,000 Residents", "ShortName": "busloadXX", "Section": "Sustainability", "Source": "Maryland Transit Administration", "IndicatorPath": "/indicators/Sustainability/busload", "Definition": "The median number of daily passengers getting on and off MTA buses by community.", "Years": "2017, 2018"}}, {"Indicator": {"IndicatorName": "Number of Bike Racks per 1,000 Residents", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Road Quality", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Miles of Bike Lanes", "ShortName": "bklnXX", "Section": "Sustainability", "Source": "Department of Transportation", "IndicatorPath": "/indicators/Sustainability/bkln", "Definition": "Measures the linear miles of designated bike lanes within the roadway system.", "Years": "2012, 2020"}}, {"Indicator": {"IndicatorName": "Percent of persons by occupation classification (major classifications)", "ShortName": "nan", "Section": "Workforce and Economic Development", "Source": "nan", "IndicatorPath": "/indicators/Workforce and Economic Development/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Population Using Other Means to Commute to Work (Taxi, Motorcycle, Bicycle, Other)", "ShortName": "othrcomXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/othrcom", "Definition": "The percentage of commuters that use other means to travel to work out of all commuters aged 16 and above.", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Number of Students Officially Enrolled in 1st - 5th Grade", "ShortName": "eenrolXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/eenrol", "Definition": "The number of children who have registered for and attend 1st through 5th grade at a Baltimore City Public School as of September 30th. This count only includes students enrolled in public schools. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Number of Students Officially Enrolled in 6th - 8th Grade", "ShortName": "menrolXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/menrol", "Definition": "The number of children who have registered for and attend 6th through 8th grade at a Baltimore City Public School as of September 30th. This count only includes students enrolled in public schools. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Number of Students Officially Enrolled in 9th - 12th Grade", "ShortName": "hsenrolXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hsenrol", "Definition": "The number of children who have registered for and attend 9th through 12th grade at a Baltimore City Public School as of September 30th. This count only includes students enrolled in public schools.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Average Healthy Food Availability Index", "ShortName": "hfaiXX", "Section": "Children and Family Health", "Source": "Johns Hopkins University, Center for a Livable Future", "IndicatorPath": "/indicators/Children and Family Health/hfai", "Definition": "The Johns Hopkins Center for a Livable Future (CLF) calculated HFAI scores for all food stores in Baltimore, in summer 2012, using an adapted version of the NEMS-S (Nutrition Environment Measures Survey in Stores) tool. The NEMS-S tool was developed by researchers at the Rollins School of Public Health at Emory University to measure the nutritional environment of food retail stores and was designed to assess healthy food availability in grocery and convenience stores. CLF obtained a food permit list from the Baltimore City Health Department in August 2011, which includes all sites that sell food, such as stores, restaurants, and temporary locations such as farmers\\u2019 market stands and street carts. HFAI scores range from zero to 28.5, with higher scores indicating more availability of healthy and whole food in a food store.", "Years": "2012, 2015"}}, {"Indicator": {"IndicatorName": "Number of Trees Planted", "ShortName": "treeplntXX", "Section": "Sustainability", "Source": "TreeBaltimore", "IndicatorPath": "/indicators/Sustainability/treeplnt", "Definition": "Measures the number of trees planted annually by the TreeBaltimore program. ", "Years": "2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Rate of Housing Vouchers per 1,000 Rental Units", "ShortName": "hcvhouseXX", "Section": "Housing and Community Development", "Source": "Picture of Subsidized Housing, HUD", "IndicatorPath": "/indicators/Housing and Community Development/hcvhouse", "Definition": "Measures the ability of housing voucher holders to find housing in the private rental market. The Housing Choice Voucher (HCV) program is the federal government\\u2019s largest low-income housing assistance program where people can seek housing in the private market. The maximum housing assistance is generally the lesser of the payment standard minus 30% of the family\\u2019s monthly adjusted income or the gross rent for the unit minus 30% of monthly adjusted income.", "Years": "2013, 2014, 2015, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Rate of Businesses in the Creative Economy per 1,000 Residents", "ShortName": "cebusXX", "Section": "Arts and Culture", "Source": "InfoUSA", "IndicatorPath": "/indicators/Arts and Culture/cebus", "Definition": "The rate of businesses (both for-profit and non-profit) that are in the creative economy per 1,000 residents. The creative economy is defined as industries that use and support artistic and cultural skillsets to attract and generate capital, knowledge, and information. Arts-based businesses are included in the creative economy. In addition to the industries included in the rate of arts-based businesses indictor, the following industries are identified by their primary NAICS code: Textiles (313220); Commercial Printing (323111, 323113); Book Printers and Publishers (323117, 511130); Print Media (451212, 511110, 511120, 511199, 519110); Motion Picture & Video Production (512110); Music Publishers (512230); Sound Recording (512240); Radio (515112); Architecture (541310, 541320); Interior Design (541410); Graphic Design (541430); Advertising (541810, 541890); and Photography (541921, 541922). In addition to the industries included in the rate of arts-based businesses indictor, the following industries are identified by their primary SIC code: Print Media (271101, 271102, 271198, 272101, 272102, 272104, 273101, 273198, 596302, 599401); Publishers (273298, 274104, 274105, 874205); Printers (275202, 275202, 275902, 275998); Bookbinders (278902); Radio (483201); Television (483301, 484101, 792205, 824911); Textiles (513122, 594904); Advertising (519917, 731101, 731115, 731305, 731999); Fashion Designers (569901, 594408); Photography (722101, 722113, 722120, 733501, 738401); Graphic Design (733603); Commercial Artists (733604); Website Design (737311); General Media (738301); Interior Design (738902); Restoration (764112); Landscape Design (781030); Motion Picture and Video Support (781205, 781211, 781901); Architecture (871202, 871207, 871209, 874892); and Business Writers (899902).", "Years": "2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Employees in the Creative Economy", "ShortName": "ceempXX", "Section": "Arts and Culture", "Source": "InfoUSA", "IndicatorPath": "/indicators/Arts and Culture/ceemp", "Definition": "The number of persons employed in the creative economy (both for-profit and non-profit). This number does not count those persons who identify themselves as being artists and does not count sole proprietorships or persons who work part-time in the arts. The same industries used to calculate the rate businesses in the creative economy are used to calculate total employment in the creative economy.", "Years": "2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Public Murals", "ShortName": "muralsXX", "Section": "Arts and Culture", "Source": "Baltimore Office of Promotion of the Arts", "IndicatorPath": "/indicators/Arts and Culture/murals", "Definition": "The number of murals per CSA. Murals are also included in the \\u201cPublic Art per 1,000 residents\\u201d indicator. Murals are separated out as a sub-indicator so they can be analyzed at the point-level.", "Years": "2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Total Jobs Filled by Employees ", "ShortName": "totjobsXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, Longitudinal Employer-Household Dynamics", "IndicatorPath": "/indicators/Workforce and Economic Development/totjobs", "Definition": "The total number of jobs per neighborhood. This indicator only counts jobs that are currently held by employees.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017"}}, {"Indicator": {"IndicatorName": "Number of Arrests per 1,000 Residents", "ShortName": "arrestXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/arrest", "Definition": "The number of persons aged 18 and over arrested per 1,000 adults that live in an area. This indicator is calculated by where the individual was arrested and not by where the crime is committed. ", "Years": "2014, 2015, 2016"}}, {"Indicator": {"IndicatorName": "Percentage of 3rd Grade Students who Met or Exceeded PARCC Math", "ShortName": "pmath3XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/pmath3", "Definition": "The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of 3rd Grade Students who Met or Exceeded PARCC Reading", "ShortName": "pread3XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/pread3", "Definition": "The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of 5th Grade Students who Met or Exceeded PARCC Math", "ShortName": "pmath5XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/pmath5", "Definition": "The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of 5th Grade Students who Met or Exceeded PARCC Reading", "ShortName": "pread5XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/pread5", "Definition": "The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of 8th Grade Students who Met or Exceeded PARCC Math", "ShortName": "pmath8XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/pmath8", "Definition": "The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of 8th Grade Students who Met or Exceeded PARCC Reading", "ShortName": "pread8XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/pread8", "Definition": "The percentage of 8th grade students who met or exceeded expectations on the PARCC exam for reading. The Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of Students who Met or Exceeded PARCC Algebra I", "ShortName": "palg1XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/palg1", "Definition": "The percentage of high school students who have met or exceeded expectations on PARCC Algebra I exams out of all high school students that took the exam in the school year. ", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of Students who Met or Exceeded PARCC Algebra II", "ShortName": "palg2XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/palg2", "Definition": "The percentage of high school students who have met or exceeded expectations on PARCC Algebra II exams out of all high school students that took the exam in the school year. ", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Kindergarten Readiness", "ShortName": "kraXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/kra", "Definition": "The Kindergarten Readiness Assessment (KRA) measure children\\u2019s readiness to do kindergarten work. The KRA is a developmentally appropriate assessment tool that measures of incoming public-school kindergarteners across four learning domains. A child is considered to be ready for kindergarten if assessed as \\u201cdemonstrating\\u201d the foundational skills and behaviors that prepare him/her for curriculum based on the kindergarten standards. ", "Years": "2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Rate of Street Light Outages per 1,000 Residents", "ShortName": "lightsXX", "Section": "Crime and Safety", "Source": "Baltimore City CitiStat", "IndicatorPath": "/indicators/Crime and Safety/lights", "Definition": "The rate of service requests for addressing street light outages made through Baltimore\\u2019s 311 system per 1,000 residents. More than one service request may be made for the same issue but is logged as a unique request.", "Years": "2016, 2017, 2018, 2019, 2020"}}]'print(txt)var indList = [{"Indicator": {"IndicatorName": "Total Population", "ShortName": "tpopXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau", "IndicatorPath": "/indicators/Census Demographics/tpop", "Definition": "The total number of persons of all ages that live within an area. This indicator is frequently used to normalize data to allow for comparison across areas.", "Years": "2010"}}, {"Indicator": {"IndicatorName": "Total Male Population", "ShortName": "maleXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau", "IndicatorPath": "/indicators/Census Demographics/male", "Definition": "The total number of men of all ages of all ages that live within an area.", "Years": "2010"}}, {"Indicator": {"IndicatorName": "Total Female Population", "ShortName": "femaleXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau", "IndicatorPath": "/indicators/Census Demographics/female", "Definition": "The total number of women of all ages that live within an area.", "Years": "2010"}}, {"Indicator": {"IndicatorName": "Percent of Residents - Black/African-American (Non-Hispanic)", "ShortName": "paaXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/paa", "Definition": "The total number of persons that identify themselves as being racially Black or African American (and ethnically non-Hispanic) out of the total number of persons living in an area. \u201cBlack or African American\u201d refers to a person having origins in any of the Black racial groups of Africa. It includes people who indicated their race as \u201cBlack\u201d.", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Residents - White/Caucasian (Non-Hispanic)", "ShortName": "pwhiteXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/pwhite", "Definition": "The total number of persons that identify themselves as being racially White (and ethnically non-Hispanic) out of the total number of persons living in an area. \u201cWhite\u201d refers to a person having origins in any of the original peoples of Europe, the Middle East, or North Africa. It includes people who indicated their race(s) as \u201cWhite\u201d. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Residents - Asian (Non-Hispanic)", "ShortName": "pasiXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/pasi", "Definition": "The total number of persons that identify themselves as being Asian (and non-Hispanic) out of the total number of persons living in an area. \u201cAsian\u201d refers to a person having origins in any of the original peoples of the Far East, Southeast Asia, or the Indian subcontinent, including, for example, Cambodia, China, India, Japan, Korea, Malaysia, Pakistan, the Philippine Islands, Thailand, and Vietnam. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Residents - Two or More Races (Non-Hispanic)", "ShortName": "p2moreXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/p2more", "Definition": "The total number of persons that identify themselves as being of two or more races (and non-Hispanic) out of the total number of persons living in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Residents - All Other Races (Hawaiian/ Pacific Islander, Alaskan/ Native American Other Race) (Non-Hispanic)", "ShortName": "ppacXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/ppac", "Definition": "The total number of persons that identify themselves as being of either American Indian, Alaskan Native, Native Hawaiian or Other Pacific Islander, or some other race (non-Hispanic) out of the total number of persons living in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Residents - Hispanic", "ShortName": "phispXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/phisp", "Definition": "The total number of persons that identify their ethnicity as being Hispanic or Latino out of the total number of persons living in an area. Hispanic origin can be viewed as the heritage, nationality group, lineage, or country of birth of the person or the person\u2019s parents or ancestors before their arrival in the United States. People who identify their origin as Hispanic, Latino, or Spanish may be any race. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Racial Diversity Index", "ShortName": "racdivXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/racdiv", "Definition": "The percent chance that two people picked at random within an area will be of a different race/ethnicity. This number does not reflect which race/ethnicity is predominant within an area. The higher the value, the more racially and ethnically diverse an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population Under 5 Years old", "ShortName": "age5_XX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/age5_", "Definition": "The percent of persons 5 years or under out of all persons living in an area.", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population 5-17 Years old", "ShortName": "age18_XX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/age18_", "Definition": "The percent of persons aged 6 to 18 years old out of all persons living in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population 18-24 Years old", "ShortName": "age24_XX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/age24_", "Definition": "The percent of persons aged 19 to 24 years old out of all persons living in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population 25-64 Years old", "ShortName": "age64_XX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/age64_", "Definition": "The percent of persons aged 25 to 64 years old out of all persons living in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population 65 Years and over", "ShortName": "age65_XX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/age65_", "Definition": "The total number of persons 65 years old and above out of all persons living in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Total Number of Households", "ShortName": "hhsXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hhs", "Definition": "A household consists of all the people occupying a housing unit. A household includes related and unrelated persons, if any, such as lodgers, foster children, wards, or employees who share the housing unit. A person living alone in a housing unit, or a group of unrelated people sharing a housing unit such as partners or roomers, is also counted as a household. The count of households excludes group quarters. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Female-Headed Households with Children Under 18", "ShortName": "femhhsXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/femhhs", "Definition": "The percentage of female-headed households with children under 18 out of all households with children under 18 in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households with Children Under 18", "ShortName": "famXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/fam", "Definition": "The percentage of households with children living in the household that are under the age of 18 out of all households. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Average Household Size", "ShortName": "hhsizeXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hhsize", "Definition": "The median value of number of persons living within a household. The average size of a household is obtained by dividing the number of persons in households by the number of households (or householders). ", "Years": "2010"}}, {"Indicator": {"IndicatorName": "Median Household Income", "ShortName": "mhhiXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/mhhi", "Definition": "The median household income is the middle value of the incomes earned in the prior year by households within an area. Income and earnings are inflation-adjusted for the last year of the 5-year period. The median value is used as opposed to the average so that both extremely high and extremely low prices do not distort the total amount of income earned by households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households Earning Less than $25,000", "ShortName": "hh25incXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hh25inc", "Definition": "The percentage of households earning less than $25,000 out of all households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households Earning $25,000 to $40,000", "ShortName": "hh40incXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hh40inc", "Definition": "The percentage of households earning between $25,000 and $39,999 out of all households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households Earning $40,000 to $60,000", "ShortName": "hh60incXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hh60inc", "Definition": "The percentage of households earning between $40,000 and $59,999 out of all households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households Earning $60,000 to $75,000", "ShortName": "hh75incXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hh75inc", "Definition": "The percentage of households earning between $60,000 and $74,999 out of all households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households Earning More than $75,000", "ShortName": "hhm75XX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hhm75", "Definition": "The percentage of households earning more than $75,000 out of all households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Inequality Index", "ShortName": "nan", "Section": "Census Demographics", "Source": "nan", "IndicatorPath": "/indicators/Census Demographics/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Family Households Living Below the Poverty Line", "ShortName": "hhpovXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hhpov", "Definition": "This indicator measures the percentage of households whose income fell below the poverty threshold out of all households in an area. Federal and state governments use such estimates to allocate funds to local communities. Local communities use these estimates to identify the number of individuals or families eligible for various programs. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Children Living Below the Poverty Line", "ShortName": "hhchpovXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hhchpov", "Definition": "This indicator measures the percentage of persons under the age of 18 living in households where the total income fell below the poverty threshold out of all children in households in an area. Federal and state governments use such estimates to allocate funds to local communities. Local communities use these estimates to identify the number of individuals or families eligible for various programs. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Median Price of Homes Sold", "ShortName": "saleprXX", "Section": "Housing and Community Development", "Source": "First American Real Estate Solutions", "IndicatorPath": "/indicators/Housing and Community Development/salepr", "Definition": "The median home sales price is the middle value of the prices for which homes are sold (both market and private transactions) within a calendar year. The median value is used as opposed to the average so that both extremely high and extremely low prices do not distort the prices for which homes are sold. This measure does not take into account the assessed value of a property.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Median Number of Days on the Market", "ShortName": "domXX", "Section": "Housing and Community Development", "Source": "RBIntel, Inc.", "IndicatorPath": "/indicators/Housing and Community Development/dom", "Definition": "The median number of days that homes listed for sale sit on the public market in a given area. This time period is from the date it is listed for sale till the day the contract of sale is signed. Private (non-listed) home sale transactions are not included in this indicator. The median days on market is used as opposed to the average so that both extremely high and extremely low days on the market do not distort the length of time for which homes are listed on the market.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Homes Sold", "ShortName": "shomesXX", "Section": "Housing and Community Development", "Source": "First American Real Estate Solutions", "IndicatorPath": "/indicators/Housing and Community Development/shomes", "Definition": "The total number of residential properties sold in a calendar year. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Percentage of Housing Units that are Owner-Occupied", "ShortName": "ownrocXX", "Section": "Housing and Community Development", "Source": "MdProperty View", "IndicatorPath": "/indicators/Housing and Community Development/ownroc", "Definition": "The percentage of homeowners that are the principal residents of a particular residential property out of all residential properties. It is important to note that a portion of these owner-occupied properties may be subdivided and have tenants that pay rent and are not included in the calculation.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Properties Under Mortgage Foreclosure", "ShortName": "foreXX", "Section": "Housing and Community Development", "Source": "Baltimore City Circuit Court", "IndicatorPath": "/indicators/Housing and Community Development/fore", "Definition": "The percentage of properties where the lending company or loan servicer has filed a foreclosure proceeding with the Baltimore City Circuit Court out of all residential properties within an area. This is not a measure of actual foreclosures since not every property that receives a filing results in a property dispossession.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Residential Properties that are Vacant and Abandoned", "ShortName": "vacantXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Housing and Community Development", "IndicatorPath": "/indicators/Housing and Community Development/vacant", "Definition": "The percentage of residential properties that have been classified as being vacant and abandoned by the Baltimore City Department of Housing out of all properties. Properties are classified as being vacant and abandoned if: the property is not habitable and appears boarded up or open to the elements; the property was designated as being vacant prior to the current year and still remains vacant; and the property is a multi-family structure where all units are considered to be vacant. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Residential Properties with Housing Violations (Excluding Vacants)", "ShortName": "vioXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Housing and Community Development", "IndicatorPath": "/indicators/Housing and Community Development/vio", "Definition": "The percentage of residential properties that have received at least one housing code violation from the Baltimore City Department of Housing out of all properties. Properties whose fa\u00e7ade, structure, and/or surrounding area violate the City\u2019s Housing Code are issued a notice and are considered open till the property is found in compliance. A property may receive multiple violations. ", "Years": "2010, 2011, 2012, 2013, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Properties with Rehabilitation Permits Exceeding $5,000", "ShortName": "resrehabXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Housing and Community Development", "IndicatorPath": "/indicators/Housing and Community Development/resrehab", "Definition": "The percent of residential properties that have applied for and received a permit to renovate the interior and/or exterior of a property where the cost of renovation will exceed $5,000. The threshold of $5,000 is used to differentiate a minor and more significant renovation project. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Total Number of Residential Properties", "ShortName": "totalresXX", "Section": "Housing and Community Development", "Source": "MdProperty View", "IndicatorPath": "/indicators/Housing and Community Development/totalres", "Definition": "The total number of residential properties located within an area as identified by Maryland Property View. It is important to note that that this indicator is a count of properties (single family homes, condominiums, and duplexes) and that a property can be comprised of multiple housing units. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Residential Sales for Cash", "ShortName": "cashsaXX", "Section": "Housing and Community Development", "Source": "RBIntel, Inc.", "IndicatorPath": "/indicators/Housing and Community Development/cashsa", "Definition": "The percent of homes and condominiums sold for cash out of all residential properties sold in a calendar year. These types of sales tend to signify investor-based purchases as homes purchased for cash either become rental properties or later sold again in an effort to generate a profit. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Percentage of Residential Sales in Foreclosure (REO)", "ShortName": "reosaXX", "Section": "Housing and Community Development", "Source": "RBIntel, Inc.", "IndicatorPath": "/indicators/Housing and Community Development/reosa", "Definition": "The portion of the homes and condominiums sold that were identified as being owned by the bank (REO) out of all residential properties sold in a calendar year.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Residential Tax Lien Sales", "ShortName": "taxlienXX", "Section": "Housing and Community Development", "Source": "BidBaltimore", "IndicatorPath": "/indicators/Housing and Community Development/taxlien", "Definition": "The percentage of residential properties with city liens sold as tax certificates at the annual tax lien certificate sale held in May. Tax sales are used to collect delinquent real property taxes and other unpaid charges to the city, which are liens against the real property. The tax certificate sale is a public online auction of City lien interests on properties that occurs annually in May.", "Years": "2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Demolition Permits per 1,000 Residential Properties", "ShortName": "demperXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Housing and Community Development", "IndicatorPath": "/indicators/Housing and Community Development/demper", "Definition": "The number of permits issued for the demolition of residential buildings per 1,000 existing residential properties. The permits are analyzed by date of issue and not date of actual demolition. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of New Construction Permits per 1,000 Residential Properties", "ShortName": "constperXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Housing and Community Development", "IndicatorPath": "/indicators/Housing and Community Development/constper", "Definition": "The number of permits issued for new residential buildings per 1,000 existing residential properties within a community. The permits are analyzed by date of issue and not date of completion. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Vacant Properties Owned by Baltimore City", "ShortName": "baltvacXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Housing and Community Development", "IndicatorPath": "/indicators/Housing and Community Development/baltvac", "Definition": "The percent of properties that are classified as being vacant and abandoned that are owned by Baltimore City. Baltimore City has come to own these properties through a variety of ways including (but not limited to) eminent domain, unpaid tax or water bills, and direct purchase.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Affordability Index - Mortgage", "ShortName": "affordmXX", "Section": "Housing and Community Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Housing and Community Development/affordm", "Definition": "The percentage of households that pay more than 30% of their total household income on mortgage and other housing-related expenses. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Affordability Index - Rent", "ShortName": "affordrXX", "Section": "Housing and Community Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Housing and Community Development/affordr", "Definition": "The percentage of households that pay more than 30% of their total household income on rent and related expenses out of all households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Number of Historic Tax Credits per 1,000 Residential Units", "ShortName": "histaxXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Finance", "IndicatorPath": "/indicators/Housing and Community Development/histax", "Definition": "The number of residential properties that received the Historic Tax Credit per 1,000 residential properties within an area. The credit is granted on the increased assessment directly resulting from qualified improvements. The duration of the credit is for 10 years, and is applicable to properties located in designated areas of significant historical value.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Homestead Tax Credits per 1,000 Residential Units", "ShortName": "homtaxXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Finance", "IndicatorPath": "/indicators/Housing and Community Development/homtax", "Definition": "The number of residential properties that received the homestead tax credit per 1,000 residential properties within an area. The Homestead Credit limits the increase in taxable assessments each year to a fixed percentage. Every county and municipality in Maryland is required to limit taxable assessment increases to 10% or less each year, with the Baltimore City rate capped at 4%.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Homeowner's Tax Credits per 1,000 Residential Units", "ShortName": "owntaxXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Finance", "IndicatorPath": "/indicators/Housing and Community Development/owntax", "Definition": "The number of residential properties that received the homeowners tax credit per 1,000 residential properties within an area. The homeowner\u2019s tax credit sets a limit on the amount of property taxes any homeowner must pay based upon his or her income.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent Residential Properties that do Not Receive Mail", "ShortName": "nomailXX", "Section": "Housing and Community Development", "Source": "U.S. Postal Service, U.S. Department of Housing and Urban Development", "IndicatorPath": "/indicators/Housing and Community Development/nomail", "Definition": "The percentage of residential addresses for which the United States Postal Service has identified as being unoccupied (no mail collection) for a period of at least 90 days or longer. These properties may be habitable, but are not currently being occupied. It is important to note that a single residential property can contain more than one address.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Part 1 Crime Rate per 1,000 Residents", "ShortName": "crimeXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/crime", "Definition": "The Part 1 crime rate captures incidents of homicide, rape, aggravated assault, robbery, burglary, larceny, and auto theft that are reported to the Police Department. These incidents are per 1,000 residents in the neighborhood to allow for comparison across areas.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Daytime Crime Rate per 1,000 Population", "ShortName": "nan", "Section": "Crime and Safety", "Source": "nan", "IndicatorPath": "/indicators/Crime and Safety/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Violent Crime Rate per 1,000 Residents", "ShortName": "violXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/viol", "Definition": "The violent crime rate measures the number of Part 1 crimes identified as being violent (homicide, rape, aggravated assault, and robbery) that are reported to the Police Department. These incidents are per 1,000 residents in the neighborhood to allow for comparison across areas.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Property Crime Rate per 1,000 Residents", "ShortName": "propXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/prop", "Definition": "The property crime rate measures the number of Part 1 crimes identified as being property-based (burglary and auto theft) that are reported to the Police Department. These incidents are per 1,000 residents in the neighborhood to allow for comparison across areas. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Domestic Violence Calls For Service per 1,000 Residents", "ShortName": "domvioXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/domvio", "Definition": "The rate of calls to emergency 911 for domestic violence per 1,000 residents in an area. Calls for service are used rather than actual crime incidents since domestic violence can be classified as one of several types of criminal offenses. It is important to also note that not every case of domestic violence is reported and some claims of abuse may be unfounded. ", "Years": "2010, 2011, 2012"}}, {"Indicator": {"IndicatorName": "Juvenile Arrest Rate per 1,000 Juveniles", "ShortName": "juvarrXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/juvarr", "Definition": "The number of persons aged 10 to 17 arrested per 1,000 juveniles that live in an area. This indicator is calculated by where the arrested juvenile was arrested and not by where the crime is committed. Arrests are used instead of crimes committed since not all juveniles that are arrested are charged with committing a crime. This indicator also excludes offenders who are later charged as adults for their crime(s).", "Years": "2011, 2012, 2013, 2014, 2015"}}, {"Indicator": {"IndicatorName": "Juvenile Arrest Rate for Violent Offenses per 1,000 Juveniles", "ShortName": "juvviolXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/juvviol", "Definition": "The number of persons aged 10 to 17 arrested for violent offenses per 1,000 juveniles that live in an area. Violent offenses may include homicide, rape, assault (with or without a weapon), and robbery. This indicator is calculated by where the arrested juvenile was arrested and not by where the crime is committed. Arrests are used instead of crimes committed since not all juveniles that are arrested are charged with committing a crime. This indicator also excludes offenders who are later charged as adults for their crime(s).", "Years": "2011, 2012, 2013, 2014, 2015"}}, {"Indicator": {"IndicatorName": "Juvenile Arrest Rate for Drug-Related Offenses per 1,000 Juveniles", "ShortName": "juvdrugXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/juvdrug", "Definition": "The number of persons aged 10 to 17 arrested for drug-related offenses per 1,000 juveniles that live in an area. Drug-related offenses include arrests for possession, sale, manufacture, or abuse of illegal drugs, including alcohol. This indicator is calculated by where the arrested juvenile was arrested and not by where the crime is committed. Arrests are used instead of crimes committed since not all juveniles that are arrested are charged with committing a crime. This indicator also excludes offenders who are later charged as adults for their crime(s).", "Years": "2011, 2012, 2013, 2014, 2015"}}, {"Indicator": {"IndicatorName": "Number of Shootings per 1,000 Residents", "ShortName": "shootXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/shoot", "Definition": "The rate of 911 calls for shootings per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Gun-Related Homicides per 1,000 Residents", "ShortName": "gunhomXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/gunhom", "Definition": "The rate of homicides by firearm as reported in the Part 1 crime data per 1,000 residents in an area. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Common Assault Calls for Service per 1,000 Residents", "ShortName": "casltXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/caslt", "Definition": "The rate of calls for assaults that do not involve a weapon per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Narcotics Calls for Service per 1,000 Residents", "ShortName": "narcXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/narc", "Definition": "The rate of calls for narcotics per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Automobile Accident Calls for Service per 1,000 Residents", "ShortName": "caraccXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/caracc", "Definition": "The rate of calls for accidents involving motor vehicles per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident. Additionally, not every accident involving a motor vehicle is reported to the Police Department. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Rate of Fire and EMS Calls for Service per 1,000 Residents", "ShortName": "nan", "Section": "Crime and Safety", "Source": "nan", "IndicatorPath": "/indicators/Crime and Safety/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Average Fire and EMS Response Time", "ShortName": "nan", "Section": "Crime and Safety", "Source": "nan", "IndicatorPath": "/indicators/Crime and Safety/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Children Enrolled in Head Start Programs", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Students Ever Attended 1st - 5th Grade", "ShortName": "eattendXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/eattend", "Definition": "The number of children who have registered for and attend 1st through 5th grade at a Baltimore City Public School at any point during the school year. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Number of Students Ever Attended 6th - 8th Grade", "ShortName": "mattendXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/mattend", "Definition": "The number of children who have registered for and attend 6th through 8th grade at a Baltimore City Public School at any point in the school year. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Number of Students Ever Attended 9th - 12th Grade", "ShortName": "hsattendXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hsattend", "Definition": "The number of children who have registered for and attend 9th through 12th grade at a Baltimore City Public School at any point in the school year.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Percent of Students Enolled in CTE Programs", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Students that are African American (non-Hispanic)", "ShortName": "aastudXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/aastud", "Definition": "The percentage of Black/African American students of any grade that attend any Baltimore City Public School out of all public school students within an area in a school year.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Percent of Students that are White (non-Hispanic)", "ShortName": "wstudXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/wstud", "Definition": "The percentage of white (non-Hispanic) students of any grade that attend any Baltimore City Public School out of all public school students within an area in a school year. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Percent of Students that are Hispanic", "ShortName": "hstudXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hstud", "Definition": "The percentage of students of any grade level who identify their ethnicity as being Hispanic that attend any Baltimore City Public School out of all public school students within an area in a school year. Ethnicity is separate from a student\u2019s race. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Percent of 1st-5th Grade Students that are Chronically Absent (Missing at least 20 days)", "ShortName": "abseXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/abse", "Definition": "The percentage of 1st-5th grade students that were recognized as being absent from public school 20 or more days out of all students. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019"}}, {"Indicator": {"IndicatorName": "Percent of 6th-8th Grade Students that are Chronically Absent (Missing at least 20 days)", "ShortName": "absmdXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/absmd", "Definition": "The percentage of 6th-8th grade students that were recognized as being absent from public school 20 or more days out of all students. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019"}}, {"Indicator": {"IndicatorName": "Percent of 9th-12th Grade Students that are Chronically Absent (Missing at least 20 days)", "ShortName": "abshsXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/abshs", "Definition": " The percentage of 9th-12th grade students that were recognized as being absent from public school 20 or more days out of all students. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019"}}, {"Indicator": {"IndicatorName": "Percentage of Students Suspended or Expelled During School Year", "ShortName": "suspXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/susp", "Definition": "The percentage of students of any grade level that were formally suspended or expelled for any reason during the school year out of all public school students within an area. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013"}}, {"Indicator": {"IndicatorName": "Percentage of Students Receiving Free or Reduced Meals", "ShortName": "farmsXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/farms", "Definition": "The percentage of students of any grade that are eligible for and received free or reduced school meals out of all public school students. Eligibility for this program is based on the student\u2019s household income. ", "Years": "2009-2010, 2010-2011, 2011-2012"}}, {"Indicator": {"IndicatorName": "Percentage of Students Enrolled in Special Education Programs", "ShortName": "spedXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/sped", "Definition": "The percentage of students of any grade that are eligible for and participated in public school special education programs out of all students. This includes all students with any diagnosed disability.", "Years": "2009-2010, 2010-2011, 2011-2012"}}, {"Indicator": {"IndicatorName": "Percentage of Students Enrolled in After School Programs", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Kindergarten School Readiness", "ShortName": "readyXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/ready", "Definition": "The percentage of children whose composite score indicates full school readiness out of all kindergarten school children tested within an area in a school year. The Maryland Model for School Readiness (MMSR) is an assessment and instructional system that was designed to provide parents, teachers, and early childhood providers with a common understanding of what children know and are able to do upon entering school. Under the MMSR system, all children entering kindergarten are assessed for level of mastery across several learning domains. These domains include: social and personal development; language and literacy; mathematical thinking; scientific thinking; social studies; the arts; and physical development and health. Kindergarten teachers must evaluate students during the first few months of the kindergarten year using selected Work Sampling System (WSS) indicators and report their ratings by the end of November of each year to the state. ", "Years": "2010-2011, 2011-2012"}}, {"Indicator": {"IndicatorName": "Percentage of 3rd Grade Students Passing MSA Math", "ShortName": "math3XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/math3", "Definition": "The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of 3rd Grade Students Passing MSA Reading", "ShortName": "read3XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/read3", "Definition": "The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of 5th Grade Students Passing MSA Math", "ShortName": "math5XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/math5", "Definition": "The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of 5th Grade Students Passing MSA Reading", "ShortName": "read5XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/read5", "Definition": "The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of 8th Grade Students Passing MSA Math", "ShortName": "math8XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/math8", "Definition": "The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of 8th Grade Students Passing MSA Reading", "ShortName": "read8XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/read8", "Definition": "The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of Students Passing H.S.A. English ", "ShortName": "hsaengXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hsaeng", "Definition": "The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of Students Passing H.S.A. Biology", "ShortName": "hsabioXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hsabio", "Definition": "The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of Students Passing H.S.A. Government", "ShortName": "hsagovXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hsagov", "Definition": "The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of Students Passing H.S.A. Algebra", "ShortName": "hsaalgXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hsaalg", "Definition": "The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "High School Dropout/Withdrawl Rate", "ShortName": "dropXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/drop", "Definition": "The percentage of 9th through 12th graders who withdrew from public school out of all high school students in a school year. Withdraw codes are used as a proxy for dropping out of school based upon the expectation that withdrawn students are no longer receiving educational services. A dropout is defined as a student who, for any reason other than death, leaves school before graduation or the completion of a Maryland-approved education program and is not known to enroll in another school or State-approved program during a current school year.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "High School Completion Rate", "ShortName": "complXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/compl", "Definition": "The percentage of 12th graders in a school year that successfully completed high school out of all 12th graders within an area. Completers are identified as completing their program of study at the high school level and satisfying the graduation requirements for a Maryland High School Diploma or the requirements for a Maryland Certificate of Program Completion.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Persons Receiving a GED", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Students Switching Schools within School Year", "ShortName": "sclswXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/sclsw", "Definition": "The percentage of 1st through 12th graders who change schools out of all students in a school year. Students must have attended both schools for which they were registered for at least one day. Additionally, this indicator only identifies the share of students that change schools for any reasons and not the frequency, number of school switches, or change in residences in a school year. The percentage reflects the last home address available for the student who changed schools. This may or may not be the home address provided for the first school that they are registered to attend. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019"}}, {"Indicator": {"IndicatorName": "Percentage of Students Attending Zoned School ", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Average Distance Travelled to School (6th-8th Grade)", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Average Distance Travelled to School (9th-12th Grade)", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percentage of Population aged 16-19 in School and/or Employed", "ShortName": "sclempXX", "Section": "Education and Youth", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Education and Youth/sclemp", "Definition": "The percentage of persons aged 16 to 19 who are in school and/or are employed out of all persons in their age cohort.", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Teen Birth Rate per 1,000 Females (Aged 15-19)", "ShortName": "teenbirXX", "Section": "Children and Family Health", "Source": "Maryland Department of Vital Statistics", "IndicatorPath": "/indicators/Children and Family Health/teenbir", "Definition": "The rate of female teens aged 15-19 that gave birth per 1,000 females aged 15-19. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Births Delivered at Term (37-42 Weeks)", "ShortName": "termbirXX", "Section": "Children and Family Health", "Source": "Maryland Department of Vital Statistics", "IndicatorPath": "/indicators/Children and Family Health/termbir", "Definition": "The percentage of births delivered at term measures the percentage of births in a calendar year where the baby is delivered between 37 and 42 weeks of gestation.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Babies Born with a Satisfactory Birth Weight", "ShortName": "birthwtXX", "Section": "Children and Family Health", "Source": "Maryland Department of Vital Statistics", "IndicatorPath": "/indicators/Children and Family Health/birthwt", "Definition": "The percentage of children born with a birth weight of at least 5 \u00bd pounds out of all births in the area. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Births Where the Mother Received Early Prenatal Care (First Trimester)", "ShortName": "prenatalXX", "Section": "Children and Family Health", "Source": "Maryland Department of Vital Statistics", "IndicatorPath": "/indicators/Children and Family Health/prenatal", "Definition": "The percentage of births where the mother received prenatal care during the first trimester of the pregnancy in a calendar year out of all births within an area. This information is calculated by the Vital Statistics registration information collected from each live birth. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Children (Aged 0-6) Tested for Elevated Blood Lead Levels", "ShortName": "leadtestXX", "Section": "Children and Family Health", "Source": "Maryland Department of the Environment, Lead Poisoning Prevention Program", "IndicatorPath": "/indicators/Children and Family Health/leadtest", "Definition": "This indicator reflects the total number of children aged 0-6 who are tested for the presence of blood lead in a calendar year.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Children (Aged 0-6) with Elevated Blood Lead Levels", "ShortName": "ebllXX", "Section": "Children and Family Health", "Source": "Maryland Department of the Environment, Lead Poisoning Prevention Program", "IndicatorPath": "/indicators/Children and Family Health/ebll", "Definition": "The number of children aged 0-6 that are found to either have elevated blood lead levels (\u226510Mg/dL) or lead poisoning (\u226520 Mg/dL) out of the number of children tested within an area in a calendar year. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Lead Violations per 1,000 Residential Units", "ShortName": "nan", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Families Receiving TANF", "ShortName": "tanfXX", "Section": "Children and Family Health", "Source": "Maryland Department of Human Resources", "IndicatorPath": "/indicators/Children and Family Health/tanf", "Definition": "Temporary Assistance for Needy Families (TANF) is a federal assistance program. The Act provides temporary financial assistance while aiming to get people off of that assistance, primarily through employment. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Persons receiving SNAP", "ShortName": "snapXX", "Section": "Children and Family Health", "Source": "Maryland Department of Human Resources", "IndicatorPath": "/indicators/Children and Family Health/snap", "Definition": "The Supplemental Nutrition Assistance Program (SNAP), formerly known as Food Stamps, helps low-income households buy the food they need for good health. ", "Years": "2019"}}, {"Indicator": {"IndicatorName": "Fetal Mortality Rate", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Liquor Outlet Density (per 1,000 Residents)", "ShortName": "liquorXX", "Section": "Children and Family Health", "Source": "Baltimore City Liquor Board", "IndicatorPath": "/indicators/Children and Family Health/liquor", "Definition": "This indicator reflects the number of business establishments that possess a Class A (Off Sale package goods no on-premises consumption - 6 days, 6:00 a.m.- Midnight. No Sunday sales except Sundays between Thanksgiving Day and New Year's Day upon issuance of a special license for each Sunday) or BD7 (tavern) business license that allows them to sell beer, wine, or liquor. Other liquor licenses to restaurants or on-premise consumption were not included in this analysis. This number is provided by 1,000 residents to allow for comparison across neighborhoods.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Fast Food Outlet Density (per 1,000 Residents)", "ShortName": "fastfdXX", "Section": "Children and Family Health", "Source": "Johns Hopkins University, Center for a Livable Future", "IndicatorPath": "/indicators/Children and Family Health/fastfd", "Definition": "The Johns Hopkins Center for a Livable Future (CLF) obtained the food permit list from the Baltimore City Health Department in August 2011, which includes all sites that sell food, such as stores, restaurants and temporary locations such as farmers\u2019 market stands and street carts. The restaurants were grouped into three categories, including full service restaurants, fast food chains and carryouts. Carryout and fast food chain restaurants were extracted from the restaurant layer and spatially joined with the 2010 Community Statistical Area (CSA) data layer, provided by BNIA-JFI. The prepared foods density, per 1,000 people, was calculated for each CSA using the CSA\u2019s population and the total number of carryout and fast food restaurants, including vendors selling prepared foods in public markets, in each CSA.", "Years": "2011, 2013, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Persons calling UWCM 211 for Health-Related Services ", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Rate of STDs per 1,000 Residents (Chlamydia, Gonorrhea, and Syphilis)", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Rate of HIV/AIDS per 1,000 Residents", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Life Expectancy", "ShortName": "lifexpXX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/lifexp", "Definition": "The average number of years a newborn can expect to live, assuming he or she experiences the currently prevailing rates of death through their lifespan. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Infant Mortality Rate", "ShortName": "mort1XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort1", "Definition": "The number of infant deaths (babies under one year of age) per 1,000 live births within the area in a five year period. This is the most stable and commonly measured indicator of mortality in this age group. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Mortality by Age (1-14 Years old)", "ShortName": "mort14XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort14", "Definition": "The number of deaths of persons between the ages of one and 14 per 10,000 persons within the area in a five year period. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Mortality by Age (15-24 Years Old)", "ShortName": "mort24XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort24", "Definition": "The number of deaths of persons between the ages of 15 and 24 per 10,000 persons within the area in a five year period.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Mortality by Age (25-44 Years Old)", "ShortName": "mort44XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort44", "Definition": "The number of deaths of persons between the ages of 25 and 44 per 10,000 persons within the area in a five year period.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Mortality by Age (45-64 Years Old)", "ShortName": "mort64XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort64", "Definition": "The number of deaths of persons between the ages of 45 and 64 per 10,000 persons within the area in a five year period. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Mortality by Age (65-84 Years Old)", "ShortName": "mort84XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort84", "Definition": "The number of deaths of persons between the ages of 65 and 84 per 10,000 persons within the area in a five year period.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Mortality by Age (85 and Over)", "ShortName": "mort85XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort85", "Definition": "The number of deaths of persons 85 years and older per 10,000 persons within the area in a five year period. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Number of Overdose Calls for Service per 1,000 Residents", "ShortName": "overdXX", "Section": "Children and Family Health", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Children and Family Health/overd", "Definition": "The rate of 911 calls to police for overdoses per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident.", "Years": "2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Causes of Death (analysis of top causes)", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Causes of Death (analysis of top causes)", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Causes of Death (analysis of top causes)", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Causes of Death (analysis of top causes)", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of persons with health insurance", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Persons with Library Cards per 1,000 Residents", "ShortName": "libcardXX", "Section": "Arts and Culture", "Source": "Enoch Pratt Free Library", "IndicatorPath": "/indicators/Arts and Culture/libcard", "Definition": "The rate of persons per 1,000 residents that possess a valid public library system card. This includes all library card types (first card, juvenile, young adult, adult). ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Event Permits Requested per 1,000 Residents", "ShortName": "artevntXX", "Section": "Arts and Culture", "Source": "ENVISTA, with permission from the Baltimore City Department of Transportation", "IndicatorPath": "/indicators/Arts and Culture/artevnt", "Definition": "The number of event permits requested per 1,000 residents. Events include, but are not limited to, festivals, block parties, races, and parades. In the event of a large event, the central point is used to calculate the location of the request.", "Years": "2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Public Art per 1,000 Residents", "ShortName": "publartxx", "Section": "Arts and Culture", "Source": "Baltimore Office of Promotion and the Arts", "IndicatorPath": "/indicators/Arts and Culture/publart", "Definition": "The number of works of public art per 1,000 residents. These works include, but are not exclusive to, murals, monuments, sculptures, mosaics, and stained glass. The Baltimore Office of Promotion and the Arts tracks works created through the 1% for Public Art and Baltimore Mural Programs and maintains general inventories of public art and murals. Additional inventories of public art exist, but not at a comprehensive citywide scale and hence cannot be broken down into cross-neighborhood analyses.", "Years": "2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Businesses that are Arts-Related per 1,000 Residents", "ShortName": "artbusXX", "Section": "Arts and Culture", "Source": "InfoUSA", "IndicatorPath": "/indicators/Arts and Culture/artbus", "Definition": "The rate of businesses (both for-profit and non-profit) that are directly related to arts and culture per 1,000 residents. Arts-related businesses are defined as belonging to industries that allow for the consumption and enjoyment of arts and culture. The following industries are identified by their primary NAICS code: music, literary, and visual arts-related retail/supplies (451140, 451211, 451220); art dealers (453920, 453920); libraries (519120); motion picture and film (521310, 532230); art schools (611610); performing arts (711110, 711120, 711130, 711190); independent artists, writers, and performers (711510); museums (712110); historical sites (712120); and zoos, gardens and nature parks (712130, 712190). The following industries are identified by their primary SIC codes: designers (152106); art publishers (274101), music, literary, and visual arts-related retail/supplies (393101, 519202, 573608, 573609, 593201, 594201, 594205, 594501, 594520, 594601, 599965, 769969); art galleries, dealers, and consultants (599969, 599988, 599989); photography (722121); calligraphers (733607); embroidery (738942); theatres (783201, 792207); theatrical support (792211, 792212); musical and live entertainment (792903, 792905, 792906, 792908, 792917, 792918, 792927); parks (799951); art and music instruction (804958, 829915, 829919); libraries (823111); museums (841201); arts organizations (841202); zoos (842201); writers (899903); visual artists (899907, 899912); art restoring (899908); and music arrangers and composers (899921).", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Total Employment in Arts-Related Businesses", "ShortName": "artempXX", "Section": "Arts and Culture", "Source": "InfoUSA", "IndicatorPath": "/indicators/Arts and Culture/artemp", "Definition": "The number of persons employed in arts-related businesses (both for-profit and non-profit). This number does not count those persons who identify themselves as being artists and does not count sole proprietorships or persons who work part-time in the arts. The same industries used to calculate the rate of arts-related businesses are used to calculate total employment in arts-related businesses. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percentage of Businesses that are Non-Profits", "ShortName": "nan", "Section": "Arts and Culture", "Source": "nan", "IndicatorPath": "/indicators/Arts and Culture/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent Population 16-64 Employed", "ShortName": "emplXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/empl", "Definition": "The percent of persons between the ages of 16 and 64 formally employed or self-employed and earning a formal income. It is used to understand how many persons are working out of the entire population, not just those in the labor force (persons who may be looking for work or working). ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent Population 16-64 Unemployed and Looking for Work", "ShortName": "unemplXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/unempl", "Definition": "The percent of persons between the ages of 16 and 64 not working out of all persons, not just those in the labor force (persons who may be looking for work). These persons are seeking work that pays a formal income. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent Population 16-64 Not in Labor Force", "ShortName": "nilfXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/nilf", "Definition": "The percent of persons who are not in the labor force out of all persons between the ages of 16 and 64 in the area. There are several reasons why persons may not be included in the labor force. These reasons may include: they are caretakers for children or other family members; they attend school or job training; they may have a disability; and they are discouraged or frustrated and have given up seeking a job or have a history that may include criminal activity. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Unemployment Rate", "ShortName": "unemprXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/unempr", "Definition": "The percent of persons between the ages of 16 and 64 that are in the labor force (and are looking for work) but are not currently working. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent Population (25 Years and over) With Less Than a High School Diploma or GED", "ShortName": "lesshsXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/lesshs", "Definition": "The percentage of persons that have not completed, graduated, or received a high school diploma or GED. This is a standard indicator used to measure the portion of the population with less than a basic level of skills needed for the workplace. Persons under the age of 25 are not included in this analysis since many of these persons are still attending various levels of schooling. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent Population (25 Years and over) With High School Diploma and Some College or Associates Degree", "ShortName": "hsdiplXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/hsdipl", "Definition": "The percentage of persons that have completed, graduated, or received a high school diploma or GED and also have taken some college courses or completed their Associate's degree. This is a standard indicator used to measure the portion of the population with a basic level of skills needed for the workplace. Persons under the age of 25 are not included in this analysis since many of these persons are still attending various levels of schooling. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent Population (25 Years and over) with a Bachelor's Degree or Above", "ShortName": "bahigherXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/bahigher", "Definition": "The percentage of persons that have completed, graduated, or received a Bachelor\u2019s or an advanced degree. This is an indicator used to measure the portion of the population having an advanced level of skills needed for the workplace. Persons under the age of 25 are not included in this analysis since many of these persons are still attending various levels of schooling. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Total Number of Commercial Properties", "ShortName": "compropXX", "Section": "Workforce and Economic Development", "Source": "MdProperty View", "IndicatorPath": "/indicators/Workforce and Economic Development/comprop", "Definition": "The total number of commercial properties located within an area in a particular year. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Percent of Commercial Properties with Rehab Permits Above $5,000", "ShortName": "crehabXX", "Section": "Workforce and Economic Development", "Source": "Baltimore City Department of Housing", "IndicatorPath": "/indicators/Workforce and Economic Development/crehab", "Definition": "The percentage of properties that are investing within their current establishment and not the level of their investment. Permits for work below $5,000 are considered to be minor and not included in this indicator. A single establishment can apply for and receive multiple permits. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Total Number of Businesses", "ShortName": "numbusXX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/numbus", "Definition": "The total number of businesses (both for-profit and non-profit) within an area at a single time in a year. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Total Number of Employees", "ShortName": "totempXX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/totemp", "Definition": "The total number of persons employed by businesses (both for-profit and non-profit) within an area at a single time in a year. ", "Years": "2010, 2011, 2012, 2013"}}, {"Indicator": {"IndicatorName": "Number of Businesses with Under 50 Employees", "ShortName": "smlbusXX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/smlbus", "Definition": "The total number of businesses (both for-profit and non-profit) that report having less than 50 persons employed within an area at a single time in a year. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Employed Residents who Work Outside the City", "ShortName": "wrkoutXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, Longitudinal Employer-Household Dynamics", "IndicatorPath": "/indicators/Workforce and Economic Development/wrkout", "Definition": "The percentage of workers that are employed by jobs located outside of Baltimore City. Only persons who report being employed and are at least 16 years old are included in the analysis. ", "Years": "2010, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Total Dollar Amount Invested in Small Businesses per 50 Businesses", "ShortName": "smlinvstXX", "Section": "Workforce and Economic Development", "Source": "Johns Hopkins University, 21st Century Cities Initiative", "IndicatorPath": "/indicators/Workforce and Economic Development/smlinvst", "Definition": "The total dollar amount invested in businesses with fewer than 500 employees per 50 businesses. Small business lending data to include FFIEC insured bank loans under $1 million to businesses made by large banks; venture capital investments; US Export-Import Bank loans; Small Business Innovation Research (SBIR) and Small business Technology Transfer Research (STTR) grants; government, philanthropic, and institutional grants supporting small businesses; Maryland Department of Commerce loans; State of Maryland Neighborhood BusinessWorks loans; Baltimore Development Corporation loans; and Small Business Administration 7a and 504 loans.", "Years": "2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Residential Mortgages Originated or Approved", "ShortName": "hmdaXX", "Section": "Housing and Community Development", "Source": "Consumer Financial Protection Bureau", "IndicatorPath": "/indicators/Housing and Community Development/hmda", "Definition": "The percent of first lien mortgage applications for single family homes that were originated or approved out of all applications in the area. The Home Mortgage Disclosure Act (HMDA) requires many financial institutions to maintain, report, and publicly disclose information about mortgages in neighborhoods. ", "Years": "2019"}}, {"Indicator": {"IndicatorName": "Number of Banks and Bank Branches per 1,000 Residents", "ShortName": "banksXX", "Section": "Workforce and Economic Development", "Source": "Federal Deposit Insurance Corporation", "IndicatorPath": "/indicators/Workforce and Economic Development/banks", "Definition": "The number of banks and bank branches per 1,000 residents within an area. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Businesses that are 1 Year old or Less", "ShortName": "biz1_XX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/biz1_", "Definition": "The percentage of businesses (both for-profit and non-profit) that report their establishment as being one year old or less. The age of the business is determined by the year that the first year they appeared in the InfoUSA database. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Businesses that are 2 Years old or Less", "ShortName": "biz2_XX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/biz2_", "Definition": "The percentage of businesses (both for-profit and non-profit) that report their establishment as being two years old or less. The age of the business is determined by the year that the first year they appeared in the business database. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Businesses that are 4 Years old or Less", "ShortName": "biz4_XX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/biz4_", "Definition": "The percentage of businesses (both for-profit and non-profit) that report their establishment as being four years old or less. The age of the business is determined by the year that the first year they appeared in the business database. A business that has been in operation more than four years has a greater likelihood of remaining open for a longer period of time. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Adult Population on Parole/Probation", "ShortName": "prbprlXX", "Section": "Workforce and Economic Development", "Source": "nan", "IndicatorPath": "/indicators/Workforce and Economic Development/prbprl", "Definition": "The percentage of the population age 18 and older that are on parole or probation.", "Years": "2013"}}, {"Indicator": {"IndicatorName": "Percent of CSA that is Either Low or Moderate income (by Census tract)", "ShortName": "nan", "Section": "Workforce and Economic Development", "Source": "nan", "IndicatorPath": "/indicators/Workforce and Economic Development/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of persons in MOED training programs (per 1,000 Residents)", "ShortName": "nan", "Section": "Workforce and Economic Development", "Source": "nan", "IndicatorPath": "/indicators/Workforce and Economic Development/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Households with No Internet at Home", "ShortName": "nohhintXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/nohhint", "Definition": "Percent of households with no home Internet of any kindThe percentage of households without an internet subscription at home.", "Years": "2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Number of Businesses by Selected Neighborhood Industry (NAICS Sectors)", "ShortName": "neiindXX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/neiind", "Definition": "The number of businesses (both for-profit and non-profit) that provide products and services to local residents. The industries included in this indicator are: Retail Trade (NAICS 44-45); Finance and Insurance (NAICS 52); Professional, Scientific, and Technical Services (NAICS 54); Health Care and Social Assistance (NAICS 62); Arts, Entertainment, and Recreation (NAICS 71); Accommodation and Food Services (NAICS 72); and Other Services except Public Administration (NAICS 81). The primary industry reported by each business was used to determine their inclusion. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Neighborhood Businesses per 1,000 Residents (NAICS Sectors)", "ShortName": "neibusXX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/neibus", "Definition": "The number of businesses (both for-profit and non-profit) that provide products and services to local residents per 1,000. The industries included in this indicator are: Retail Trade (NAICS 44-45); Finance and Insurance (NAICS 52); Professional, Scientific, and Technical Services (NAICS 54); Health Care and Social Assistance (NAICS 62); Arts, Entertainment, and Recreation (NAICS 71); Accommodation and Food Services (NAICS 72); and Other Services except Public Administration (NAICS 81). The primary industry reported by each business was used to deter-mine their inclusion. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Total number of Employees by Selected Neighborhood Industry (NAICS Sectors)", "ShortName": "neiempXX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/neiemp", "Definition": "The number of persons employed by businesses (both for-profit and non-profit) that provide products and services to local residents. The industries included in this indicator are: Retail Trade (NAICS 44-45); Finance and Insurance (NAICS 52); Professional, Scientific, and Technical Services (NAICS 54); Health Care and Social Assistance (NAICS 62); Arts, Entertainment, and Recreation (NAICS 71); Accommodation and Food Services (NAICS 72); and Other Services except Public Administration (NAICS 81). The primary industry reported by each business was used to determine their inclusion. The persons employed by these businesses may not necessarily live in the neighborhood where the business is located. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Population (Over the Age of 18) Who are Registered to Vote", "ShortName": "regvoteXX", "Section": "Sustainability", "Source": "Baltimore City Board of Elections", "IndicatorPath": "/indicators/Sustainability/regvote", "Definition": "The percentage of persons over the age of 18 registered to vote out of all persons 18 years and over.", "Years": "2010, 2012, 2014, 2016, 2018"}}, {"Indicator": {"IndicatorName": "Percent Population (Over the Age of 18) Who Voted in the General Election", "ShortName": "votedXX", "Section": "Sustainability", "Source": "Baltimore City Board of Elections", "IndicatorPath": "/indicators/Sustainability/voted", "Definition": "The percentage of persons who voted in the last general election out of all registered voters. ", "Years": "2010, 2012, 2014, 2016, 2018"}}, {"Indicator": {"IndicatorName": "Rate of Dirty Streets and Alleys Reports per 1,000 Residents", "ShortName": "dirtystXX", "Section": "Sustainability", "Source": "Baltimore City CitiStat", "IndicatorPath": "/indicators/Sustainability/dirtyst", "Definition": "The rate of service requests for dirty streets and alleys through Baltimore\u2019s 311 system per 1,000 residents. More than one service request may be made for the same issue but is logged as a unique request.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Rate of Clogged Storm Drain Reports per 1,000 Residents", "ShortName": "cloggedXX", "Section": "Sustainability", "Source": "Baltimore City CitiStat", "IndicatorPath": "/indicators/Sustainability/clogged", "Definition": "The rate of service requests for addressing clogged storm drains made through Baltimore\u2019s 311 system per 1,000 residents. More than one service request may be made for the same issue but is logged as a unique request.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percent of Population that Drove Alone to Work", "ShortName": "drvaloneXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/drvalone", "Definition": "The percentage of commuters driving alone out of all commuters aged 16 and above. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population that Carpool to Work", "ShortName": "carpoolXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/carpool", "Definition": "The percentage of commuters that carpool out of all commuters aged 16 and above. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population that Uses Public Transportation to Get to Work", "ShortName": "pubtranXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/pubtran", "Definition": "The percentage of commuters that use public transit out of all commuters aged 16 and above.", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population that Walks to Work", "ShortName": "walkedXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/walked", "Definition": "The percentage of commuters that walk to work out of all commuters aged 16 and above.", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Employed Population with Travel Time to Work of 0-14 Minutes", "ShortName": "trav14XX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/trav14", "Definition": "The percentage of commuters that spend less than 15 minutes commuting to work out of all commuters aged 16 and above. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Employed Population with Travel Time to Work of 15-29 Minutes", "ShortName": "trav29XX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/trav29", "Definition": "The percentage of commuters that spend between 15 and 29 minutes commuting to work out of all commuters aged 16 and above. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Employed Population with Travel Time to Work of 30-44 Minutes", "ShortName": "trav44XX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/trav44", "Definition": "The percentage of commuters that spend between 30 and 44 minutes travelling to work out of all commuters aged 16 and above. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Employed Population with Travel Time to Work of 45 Minutes and Over", "ShortName": "trav45XX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/trav45", "Definition": "The percentage of commuters that spend more than 45 minutes travelling to work out of all commuters aged 16 and above. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Area Covered by Trees", "ShortName": "treesXX", "Section": "Sustainability", "Source": "University of Vermont Spatial Analysis Lab", "IndicatorPath": "/indicators/Sustainability/trees", "Definition": "The percent of total land area comprised of tree canopy. The primary sources for this land cover layer were 2004 pan-sharpened 1m Ikonos satellite imagery, a normalized Digital Surface Model (nDSM) derived from 2006 LiDAR data, and LiDAR intensity data resulting from the 2006 acquisition. Other sources of data include the City's planimetric GIS database (building footprints and road casing polygons). The land cover classification was performed using automated object-based image analysis (OBIA) techniques in Definiens Developer/eCognition Server. No accuracy assessment was conducted, but the dataset was thoroughly reviewed at a scale of 1:2000. Over 370 corrections were made to the classification. ", "Years": "2007, 2015, 2017"}}, {"Indicator": {"IndicatorName": "Air Quality Risk", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Area Covered by Impervious Surface", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Community Managed Open Spaces", "ShortName": "cmosXX", "Section": "Sustainability", "Source": "Baltimore Neighborhood Indicators Alliance - Jacob France Institute", "IndicatorPath": "/indicators/Sustainability/cmos", "Definition": "The number of community managed open spaces in an area that include community gardens (food-producing or ornamental), Adopt-A-Lots, or some other green space managed by the community. ", "Years": "2011, 2014, 2015"}}, {"Indicator": {"IndicatorName": "Median Daily Water Consumption", "ShortName": "watercXX", "Section": "Sustainability", "Source": "Baltimore City Department of Public Works", "IndicatorPath": "/indicators/Sustainability/waterc", "Definition": "The median daily average water consumption of all city meters registering greater than 0.0 cubic meters per day.", "Years": "2011"}}, {"Indicator": {"IndicatorName": "Number of Downspout Disconnections per 1,000 Residential Units", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Public Trashcans", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Rate of Sewer/Water Main Breaks per 1,000 Residents", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Natural Gas Utilization", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Energy Use", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Residences Heated by Utility Gas", "ShortName": "heatgasXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/heatgas", "Definition": "The percentage of homes that use utility gas for heat and cooking out of all homes. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Residences Heated by Electricity", "ShortName": "elheatXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/elheat", "Definition": "The percentage of homes that use electricity for heat and cooking out of all homes. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households with No Vehicles Available", "ShortName": "novhclXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/novhcl", "Definition": "The percentage of households that do not have a personal vehicle available for use out of all households in an area. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Number of Photovoltaic/Solar Permits", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Homes Weatherized", "ShortName": "weatherXX", "Section": "Sustainability", "Source": "Maryland Department of Housing and Community Development", "IndicatorPath": "/indicators/Sustainability/weather", "Definition": "The percent of residential properties that were eligible for and received weatherization assistance such as air sealing or furnace replacements. The Weatherization Assistance Program helps eligible low-income households lower their energy costs by increasing the energy efficiency of their homes, while ensuring their health and safety. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016"}}, {"Indicator": {"IndicatorName": "Walk Score", "ShortName": "wlkscXX", "Section": "Sustainability", "Source": "Walk Score", "IndicatorPath": "/indicators/Sustainability/wlksc", "Definition": "The Walk Score\u00ae is calculated by mapping out the distance to amenities in nine different categories (grocery stores, restaurants, shopping, coffee shops, banks, parks, schools, book stores/libraries, and entertainment) and are weighted according to importance. The distance to a location, counts, and weights determine a base score of an address, which is then normalized to a score from 0 to 100. More information on Walk Score can be found at http://www.walkscore.com/. ", "Years": "2011, 2017"}}, {"Indicator": {"IndicatorName": "Aggregate Number of Community Assets", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Daily Bus Stop Loadings per 1,000 Residents", "ShortName": "busloadXX", "Section": "Sustainability", "Source": "Maryland Transit Administration", "IndicatorPath": "/indicators/Sustainability/busload", "Definition": "The median number of daily passengers getting on and off MTA buses by community.", "Years": "2017, 2018"}}, {"Indicator": {"IndicatorName": "Number of Bike Racks per 1,000 Residents", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Road Quality", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Miles of Bike Lanes", "ShortName": "bklnXX", "Section": "Sustainability", "Source": "Department of Transportation", "IndicatorPath": "/indicators/Sustainability/bkln", "Definition": "Measures the linear miles of designated bike lanes within the roadway system.", "Years": "2012, 2020"}}, {"Indicator": {"IndicatorName": "Percent of persons by occupation classification (major classifications)", "ShortName": "nan", "Section": "Workforce and Economic Development", "Source": "nan", "IndicatorPath": "/indicators/Workforce and Economic Development/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Population Using Other Means to Commute to Work (Taxi, Motorcycle, Bicycle, Other)", "ShortName": "othrcomXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/othrcom", "Definition": "The percentage of commuters that use other means to travel to work out of all commuters aged 16 and above.", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Number of Students Officially Enrolled in 1st - 5th Grade", "ShortName": "eenrolXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/eenrol", "Definition": "The number of children who have registered for and attend 1st through 5th grade at a Baltimore City Public School as of September 30th. This count only includes students enrolled in public schools. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Number of Students Officially Enrolled in 6th - 8th Grade", "ShortName": "menrolXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/menrol", "Definition": "The number of children who have registered for and attend 6th through 8th grade at a Baltimore City Public School as of September 30th. This count only includes students enrolled in public schools. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Number of Students Officially Enrolled in 9th - 12th Grade", "ShortName": "hsenrolXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hsenrol", "Definition": "The number of children who have registered for and attend 9th through 12th grade at a Baltimore City Public School as of September 30th. This count only includes students enrolled in public schools.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Average Healthy Food Availability Index", "ShortName": "hfaiXX", "Section": "Children and Family Health", "Source": "Johns Hopkins University, Center for a Livable Future", "IndicatorPath": "/indicators/Children and Family Health/hfai", "Definition": "The Johns Hopkins Center for a Livable Future (CLF) calculated HFAI scores for all food stores in Baltimore, in summer 2012, using an adapted version of the NEMS-S (Nutrition Environment Measures Survey in Stores) tool. The NEMS-S tool was developed by researchers at the Rollins School of Public Health at Emory University to measure the nutritional environment of food retail stores and was designed to assess healthy food availability in grocery and convenience stores. CLF obtained a food permit list from the Baltimore City Health Department in August 2011, which includes all sites that sell food, such as stores, restaurants, and temporary locations such as farmers\u2019 market stands and street carts. HFAI scores range from zero to 28.5, with higher scores indicating more availability of healthy and whole food in a food store.", "Years": "2012, 2015"}}, {"Indicator": {"IndicatorName": "Number of Trees Planted", "ShortName": "treeplntXX", "Section": "Sustainability", "Source": "TreeBaltimore", "IndicatorPath": "/indicators/Sustainability/treeplnt", "Definition": "Measures the number of trees planted annually by the TreeBaltimore program. ", "Years": "2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Rate of Housing Vouchers per 1,000 Rental Units", "ShortName": "hcvhouseXX", "Section": "Housing and Community Development", "Source": "Picture of Subsidized Housing, HUD", "IndicatorPath": "/indicators/Housing and Community Development/hcvhouse", "Definition": "Measures the ability of housing voucher holders to find housing in the private rental market. The Housing Choice Voucher (HCV) program is the federal government\u2019s largest low-income housing assistance program where people can seek housing in the private market. The maximum housing assistance is generally the lesser of the payment standard minus 30% of the family\u2019s monthly adjusted income or the gross rent for the unit minus 30% of monthly adjusted income.", "Years": "2013, 2014, 2015, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Rate of Businesses in the Creative Economy per 1,000 Residents", "ShortName": "cebusXX", "Section": "Arts and Culture", "Source": "InfoUSA", "IndicatorPath": "/indicators/Arts and Culture/cebus", "Definition": "The rate of businesses (both for-profit and non-profit) that are in the creative economy per 1,000 residents. The creative economy is defined as industries that use and support artistic and cultural skillsets to attract and generate capital, knowledge, and information. Arts-based businesses are included in the creative economy. In addition to the industries included in the rate of arts-based businesses indictor, the following industries are identified by their primary NAICS code: Textiles (313220); Commercial Printing (323111, 323113); Book Printers and Publishers (323117, 511130); Print Media (451212, 511110, 511120, 511199, 519110); Motion Picture & Video Production (512110); Music Publishers (512230); Sound Recording (512240); Radio (515112); Architecture (541310, 541320); Interior Design (541410); Graphic Design (541430); Advertising (541810, 541890); and Photography (541921, 541922). In addition to the industries included in the rate of arts-based businesses indictor, the following industries are identified by their primary SIC code: Print Media (271101, 271102, 271198, 272101, 272102, 272104, 273101, 273198, 596302, 599401); Publishers (273298, 274104, 274105, 874205); Printers (275202, 275202, 275902, 275998); Bookbinders (278902); Radio (483201); Television (483301, 484101, 792205, 824911); Textiles (513122, 594904); Advertising (519917, 731101, 731115, 731305, 731999); Fashion Designers (569901, 594408); Photography (722101, 722113, 722120, 733501, 738401); Graphic Design (733603); Commercial Artists (733604); Website Design (737311); General Media (738301); Interior Design (738902); Restoration (764112); Landscape Design (781030); Motion Picture and Video Support (781205, 781211, 781901); Architecture (871202, 871207, 871209, 874892); and Business Writers (899902).", "Years": "2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Employees in the Creative Economy", "ShortName": "ceempXX", "Section": "Arts and Culture", "Source": "InfoUSA", "IndicatorPath": "/indicators/Arts and Culture/ceemp", "Definition": "The number of persons employed in the creative economy (both for-profit and non-profit). This number does not count those persons who identify themselves as being artists and does not count sole proprietorships or persons who work part-time in the arts. The same industries used to calculate the rate businesses in the creative economy are used to calculate total employment in the creative economy.", "Years": "2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Public Murals", "ShortName": "muralsXX", "Section": "Arts and Culture", "Source": "Baltimore Office of Promotion of the Arts", "IndicatorPath": "/indicators/Arts and Culture/murals", "Definition": "The number of murals per CSA. Murals are also included in the \u201cPublic Art per 1,000 residents\u201d indicator. Murals are separated out as a sub-indicator so they can be analyzed at the point-level.", "Years": "2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Total Jobs Filled by Employees ", "ShortName": "totjobsXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, Longitudinal Employer-Household Dynamics", "IndicatorPath": "/indicators/Workforce and Economic Development/totjobs", "Definition": "The total number of jobs per neighborhood. This indicator only counts jobs that are currently held by employees.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017"}}, {"Indicator": {"IndicatorName": "Number of Arrests per 1,000 Residents", "ShortName": "arrestXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/arrest", "Definition": "The number of persons aged 18 and over arrested per 1,000 adults that live in an area. This indicator is calculated by where the individual was arrested and not by where the crime is committed. ", "Years": "2014, 2015, 2016"}}, {"Indicator": {"IndicatorName": "Percentage of 3rd Grade Students who Met or Exceeded PARCC Math", "ShortName": "pmath3XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/pmath3", "Definition": "The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of 3rd Grade Students who Met or Exceeded PARCC Reading", "ShortName": "pread3XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/pread3", "Definition": "The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of 5th Grade Students who Met or Exceeded PARCC Math", "ShortName": "pmath5XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/pmath5", "Definition": "The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of 5th Grade Students who Met or Exceeded PARCC Reading", "ShortName": "pread5XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/pread5", "Definition": "The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of 8th Grade Students who Met or Exceeded PARCC Math", "ShortName": "pmath8XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/pmath8", "Definition": "The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of 8th Grade Students who Met or Exceeded PARCC Reading", "ShortName": "pread8XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/pread8", "Definition": "The percentage of 8th grade students who met or exceeded expectations on the PARCC exam for reading. The Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of Students who Met or Exceeded PARCC Algebra I", "ShortName": "palg1XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/palg1", "Definition": "The percentage of high school students who have met or exceeded expectations on PARCC Algebra I exams out of all high school students that took the exam in the school year. ", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of Students who Met or Exceeded PARCC Algebra II", "ShortName": "palg2XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/palg2", "Definition": "The percentage of high school students who have met or exceeded expectations on PARCC Algebra II exams out of all high school students that took the exam in the school year. ", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Kindergarten Readiness", "ShortName": "kraXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/kra", "Definition": "The Kindergarten Readiness Assessment (KRA) measure children\u2019s readiness to do kindergarten work. The KRA is a developmentally appropriate assessment tool that measures of incoming public-school kindergarteners across four learning domains. A child is considered to be ready for kindergarten if assessed as \u201cdemonstrating\u201d the foundational skills and behaviors that prepare him/her for curriculum based on the kindergarten standards. ", "Years": "2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Rate of Street Light Outages per 1,000 Residents", "ShortName": "lightsXX", "Section": "Crime and Safety", "Source": "Baltimore City CitiStat", "IndicatorPath": "/indicators/Crime and Safety/lights", "Definition": "The rate of service requests for addressing street light outages made through Baltimore\u2019s 311 system per 1,000 residents. More than one service request may be made for the same issue but is logged as a unique request.", "Years": "2016, 2017, 2018, 2019, 2020"}}] ! echo {indList} > indList.js! echo {print( indList )} > indList1.js[{'Indicator': {'IndicatorName': 'Total Population', 'ShortName': 'tpopXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau', 'IndicatorPath': '/indicators/Census Demographics/tpop', 'Definition': 'The total number of persons of all ages that live within an area. This indicator is frequently used to normalize data to allow for comparison across areas.', 'Years': '2010'}}, {'Indicator': {'IndicatorName': 'Total Male Population', 'ShortName': 'maleXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau', 'IndicatorPath': '/indicators/Census Demographics/male', 'Definition': 'The total number of men of all ages of all ages that live within an area.', 'Years': '2010'}}, {'Indicator': {'IndicatorName': 'Total Female Population', 'ShortName': 'femaleXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau', 'IndicatorPath': '/indicators/Census Demographics/female', 'Definition': 'The total number of women of all ages that live within an area.', 'Years': '2010'}}, {'Indicator': {'IndicatorName': 'Percent of Residents - Black/African-American (Non-Hispanic)', 'ShortName': 'paaXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/paa', 'Definition': 'The total number of persons that identify themselves as being racially Black or African American (and ethnically non-Hispanic) out of the total number of persons living in an area. “Black or African American” refers to a person having origins in any of the Black racial groups of Africa. It includes people who indicated their race as “Black”.', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Residents - White/Caucasian (Non-Hispanic)', 'ShortName': 'pwhiteXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/pwhite', 'Definition': 'The total number of persons that identify themselves as being racially White (and ethnically non-Hispanic) out of the total number of persons living in an area. “White” refers to a person having origins in any of the original peoples of Europe, the Middle East, or North Africa. It includes people who indicated their race(s) as “White”. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Residents - Asian (Non-Hispanic)', 'ShortName': 'pasiXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/pasi', 'Definition': 'The total number of persons that identify themselves as being Asian (and non-Hispanic) out of the total number of persons living in an area. “Asian” refers to a person having origins in any of the original peoples of the Far East, Southeast Asia, or the Indian subcontinent, including, for example, Cambodia, China, India, Japan, Korea, Malaysia, Pakistan, the Philippine Islands, Thailand, and Vietnam. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Residents - Two or More Races (Non-Hispanic)', 'ShortName': 'p2moreXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/p2more', 'Definition': 'The total number of persons that identify themselves as being of two or more races (and non-Hispanic) out of the total number of persons living in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Residents - All Other Races (Hawaiian/ Pacific Islander, Alaskan/ Native American Other Race) (Non-Hispanic)', 'ShortName': 'ppacXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/ppac', 'Definition': 'The total number of persons that identify themselves as being of either American Indian, Alaskan Native, Native Hawaiian or Other Pacific Islander, or some other race (non-Hispanic) out of the total number of persons living in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Residents - Hispanic', 'ShortName': 'phispXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/phisp', 'Definition': 'The total number of persons that identify their ethnicity as being Hispanic or Latino out of the total number of persons living in an area. Hispanic origin can be viewed as the heritage, nationality group, lineage, or country of birth of the person or the person’s parents or ancestors before their arrival in the United States. People who identify their origin as Hispanic, Latino, or Spanish may be any race. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Racial Diversity Index', 'ShortName': 'racdivXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/racdiv', 'Definition': 'The percent chance that two people picked at random within an area will be of a different race/ethnicity. This number does not reflect which race/ethnicity is predominant within an area. The higher the value, the more racially and ethnically diverse an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Population Under 5 Years old', 'ShortName': 'age5_XX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/age5_', 'Definition': 'The percent of persons 5 years or under out of all persons living in an area.', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Population 5-17 Years old', 'ShortName': 'age18_XX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/age18_', 'Definition': 'The percent of persons aged 6 to 18 years old out of all persons living in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Population 18-24 Years old', 'ShortName': 'age24_XX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/age24_', 'Definition': 'The percent of persons aged 19 to 24 years old out of all persons living in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Population 25-64 Years old', 'ShortName': 'age64_XX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/age64_', 'Definition': 'The percent of persons aged 25 to 64 years old out of all persons living in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Population 65 Years and over', 'ShortName': 'age65_XX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/age65_', 'Definition': 'The total number of persons 65 years old and above out of all persons living in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Total Number of Households', 'ShortName': 'hhsXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/hhs', 'Definition': 'A household consists of all the people occupying a housing unit. A household includes related and unrelated persons, if any, such as lodgers, foster children, wards, or employees who share the housing unit. A person living alone in a housing unit, or a group of unrelated people sharing a housing unit such as partners or roomers, is also counted as a household. The count of households excludes group quarters. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Female-Headed Households with Children Under 18', 'ShortName': 'femhhsXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/femhhs', 'Definition': 'The percentage of female-headed households with children under 18 out of all households with children under 18 in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Households with Children Under 18', 'ShortName': 'famXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/fam', 'Definition': 'The percentage of households with children living in the household that are under the age of 18 out of all households. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Average Household Size', 'ShortName': 'hhsizeXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/hhsize', 'Definition': 'The median value of number of persons living within a household. The average size of a household is obtained by dividing the number of persons in households by the number of households (or householders). ', 'Years': '2010'}}, {'Indicator': {'IndicatorName': 'Median Household Income', 'ShortName': 'mhhiXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/mhhi', 'Definition': 'The median household income is the middle value of the incomes earned in the prior year by households within an area. Income and earnings are inflation-adjusted for the last year of the 5-year period. The median value is used as opposed to the average so that both extremely high and extremely low prices do not distort the total amount of income earned by households in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Households Earning Less than $25,000', 'ShortName': 'hh25incXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/hh25inc', 'Definition': 'The percentage of households earning less than $25,000 out of all households in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Households Earning $25,000 to $40,000', 'ShortName': 'hh40incXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/hh40inc', 'Definition': 'The percentage of households earning between $25,000 and $39,999 out of all households in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Households Earning $40,000 to $60,000', 'ShortName': 'hh60incXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/hh60inc', 'Definition': 'The percentage of households earning between $40,000 and $59,999 out of all households in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Households Earning $60,000 to $75,000', 'ShortName': 'hh75incXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/hh75inc', 'Definition': 'The percentage of households earning between $60,000 and $74,999 out of all households in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Households Earning More than $75,000', 'ShortName': 'hhm75XX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/hhm75', 'Definition': 'The percentage of households earning more than $75,000 out of all households in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Inequality Index', 'ShortName': 'nan', 'Section': 'Census Demographics', 'Source': 'nan', 'IndicatorPath': '/indicators/Census Demographics/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of Family Households Living Below the Poverty Line', 'ShortName': 'hhpovXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/hhpov', 'Definition': 'This indicator measures the percentage of households whose income fell below the poverty threshold out of all households in an area. Federal and state governments use such estimates to allocate funds to local communities. Local communities use these estimates to identify the number of individuals or families eligible for various programs. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Children Living Below the Poverty Line', 'ShortName': 'hhchpovXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/hhchpov', 'Definition': 'This indicator measures the percentage of persons under the age of 18 living in households where the total income fell below the poverty threshold out of all children in households in an area. Federal and state governments use such estimates to allocate funds to local communities. Local communities use these estimates to identify the number of individuals or families eligible for various programs. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Median Price of Homes Sold', 'ShortName': 'saleprXX', 'Section': 'Housing and Community Development', 'Source': 'First American Real Estate Solutions', 'IndicatorPath': '/indicators/Housing and Community Development/salepr', 'Definition': 'The median home sales price is the middle value of the prices for which homes are sold (both market and private transactions) within a calendar year. The median value is used as opposed to the average so that both extremely high and extremely low prices do not distort the prices for which homes are sold. This measure does not take into account the assessed value of a property.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Median Number of Days on the Market', 'ShortName': 'domXX', 'Section': 'Housing and Community Development', 'Source': 'RBIntel, Inc.', 'IndicatorPath': '/indicators/Housing and Community Development/dom', 'Definition': 'The median number of days that homes listed for sale sit on the public market in a given area. This time period is from the date it is listed for sale till the day the contract of sale is signed. Private (non-listed) home sale transactions are not included in this indicator. The median days on market is used as opposed to the average so that both extremely high and extremely low days on the market do not distort the length of time for which homes are listed on the market.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Number of Homes Sold', 'ShortName': 'shomesXX', 'Section': 'Housing and Community Development', 'Source': 'First American Real Estate Solutions', 'IndicatorPath': '/indicators/Housing and Community Development/shomes', 'Definition': 'The total number of residential properties sold in a calendar year. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Percentage of Housing Units that are Owner-Occupied', 'ShortName': 'ownrocXX', 'Section': 'Housing and Community Development', 'Source': 'MdProperty View', 'IndicatorPath': '/indicators/Housing and Community Development/ownroc', 'Definition': 'The percentage of homeowners that are the principal residents of a particular residential property out of all residential properties. It is important to note that a portion of these owner-occupied properties may be subdivided and have tenants that pay rent and are not included in the calculation.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Percentage of Properties Under Mortgage Foreclosure', 'ShortName': 'foreXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Circuit Court', 'IndicatorPath': '/indicators/Housing and Community Development/fore', 'Definition': 'The percentage of properties where the lending company or loan servicer has filed a foreclosure proceeding with the Baltimore City Circuit Court out of all residential properties within an area. This is not a measure of actual foreclosures since not every property that receives a filing results in a property dispossession.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Percentage of Residential Properties that are Vacant and Abandoned', 'ShortName': 'vacantXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Department of Housing and Community Development', 'IndicatorPath': '/indicators/Housing and Community Development/vacant', 'Definition': 'The percentage of residential properties that have been classified as being vacant and abandoned by the Baltimore City Department of Housing out of all properties. Properties are classified as being vacant and abandoned if: the property is not habitable and appears boarded up or open to the elements; the property was designated as being vacant prior to the current year and still remains vacant; and the property is a multi-family structure where all units are considered to be vacant. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Percentage of Residential Properties with Housing Violations (Excluding Vacants)', 'ShortName': 'vioXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Department of Housing and Community Development', 'IndicatorPath': '/indicators/Housing and Community Development/vio', 'Definition': 'The percentage of residential properties that have received at least one housing code violation from the Baltimore City Department of Housing out of all properties. Properties whose façade, structure, and/or surrounding area violate the City’s Housing Code are issued a notice and are considered open till the property is found in compliance. A property may receive multiple violations. ', 'Years': '2010, 2011, 2012, 2013, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Percentage of Properties with Rehabilitation Permits Exceeding $5,000', 'ShortName': 'resrehabXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Department of Housing and Community Development', 'IndicatorPath': '/indicators/Housing and Community Development/resrehab', 'Definition': 'The percent of residential properties that have applied for and received a permit to renovate the interior and/or exterior of a property where the cost of renovation will exceed $5,000. The threshold of $5,000 is used to differentiate a minor and more significant renovation project. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Total Number of Residential Properties', 'ShortName': 'totalresXX', 'Section': 'Housing and Community Development', 'Source': 'MdProperty View', 'IndicatorPath': '/indicators/Housing and Community Development/totalres', 'Definition': 'The total number of residential properties located within an area as identified by Maryland Property View. It is important to note that that this indicator is a count of properties (single family homes, condominiums, and duplexes) and that a property can be comprised of multiple housing units. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Percentage of Residential Sales for Cash', 'ShortName': 'cashsaXX', 'Section': 'Housing and Community Development', 'Source': 'RBIntel, Inc.', 'IndicatorPath': '/indicators/Housing and Community Development/cashsa', 'Definition': 'The percent of homes and condominiums sold for cash out of all residential properties sold in a calendar year. These types of sales tend to signify investor-based purchases as homes purchased for cash either become rental properties or later sold again in an effort to generate a profit. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Percentage of Residential Sales in Foreclosure (REO)', 'ShortName': 'reosaXX', 'Section': 'Housing and Community Development', 'Source': 'RBIntel, Inc.', 'IndicatorPath': '/indicators/Housing and Community Development/reosa', 'Definition': 'The portion of the homes and condominiums sold that were identified as being owned by the bank (REO) out of all residential properties sold in a calendar year.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Percentage of Residential Tax Lien Sales', 'ShortName': 'taxlienXX', 'Section': 'Housing and Community Development', 'Source': 'BidBaltimore', 'IndicatorPath': '/indicators/Housing and Community Development/taxlien', 'Definition': 'The percentage of residential properties with city liens sold as tax certificates at the annual tax lien certificate sale held in May. Tax sales are used to collect delinquent real property taxes and other unpaid charges to the city, which are liens against the real property. The tax certificate sale is a public online auction of City lien interests on properties that occurs annually in May.', 'Years': '2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Number of Demolition Permits per 1,000 Residential Properties', 'ShortName': 'demperXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Department of Housing and Community Development', 'IndicatorPath': '/indicators/Housing and Community Development/demper', 'Definition': 'The number of permits issued for the demolition of residential buildings per 1,000 existing residential properties. The permits are analyzed by date of issue and not date of actual demolition. ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Number of New Construction Permits per 1,000 Residential Properties', 'ShortName': 'constperXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Department of Housing and Community Development', 'IndicatorPath': '/indicators/Housing and Community Development/constper', 'Definition': 'The number of permits issued for new residential buildings per 1,000 existing residential properties within a community. The permits are analyzed by date of issue and not date of completion. ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Percentage of Vacant Properties Owned by Baltimore City', 'ShortName': 'baltvacXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Department of Housing and Community Development', 'IndicatorPath': '/indicators/Housing and Community Development/baltvac', 'Definition': 'The percent of properties that are classified as being vacant and abandoned that are owned by Baltimore City. Baltimore City has come to own these properties through a variety of ways including (but not limited to) eminent domain, unpaid tax or water bills, and direct purchase.', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Affordability Index - Mortgage', 'ShortName': 'affordmXX', 'Section': 'Housing and Community Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Housing and Community Development/affordm', 'Definition': 'The percentage of households that pay more than 30% of their total household income on mortgage and other housing-related expenses. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Affordability Index - Rent', 'ShortName': 'affordrXX', 'Section': 'Housing and Community Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Housing and Community Development/affordr', 'Definition': 'The percentage of households that pay more than 30% of their total household income on rent and related expenses out of all households in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Number of Historic Tax Credits per 1,000 Residential Units', 'ShortName': 'histaxXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Department of Finance', 'IndicatorPath': '/indicators/Housing and Community Development/histax', 'Definition': 'The number of residential properties that received the Historic Tax Credit per 1,000 residential properties within an area. The credit is granted on the increased assessment directly resulting from qualified improvements. The duration of the credit is for 10 years, and is applicable to properties located in designated areas of significant historical value.', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Number of Homestead Tax Credits per 1,000 Residential Units', 'ShortName': 'homtaxXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Department of Finance', 'IndicatorPath': '/indicators/Housing and Community Development/homtax', 'Definition': 'The number of residential properties that received the homestead tax credit per 1,000 residential properties within an area. The Homestead Credit limits the increase in taxable assessments each year to a fixed percentage. Every county and municipality in Maryland is required to limit taxable assessment increases to 10% or less each year, with the Baltimore City rate capped at 4%.', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': "Number of Homeowner's Tax Credits per 1,000 Residential Units", 'ShortName': 'owntaxXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Department of Finance', 'IndicatorPath': '/indicators/Housing and Community Development/owntax', 'Definition': 'The number of residential properties that received the homeowners tax credit per 1,000 residential properties within an area. The homeowner’s tax credit sets a limit on the amount of property taxes any homeowner must pay based upon his or her income.', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent Residential Properties that do Not Receive Mail', 'ShortName': 'nomailXX', 'Section': 'Housing and Community Development', 'Source': 'U.S. Postal Service, U.S. Department of Housing and Urban Development', 'IndicatorPath': '/indicators/Housing and Community Development/nomail', 'Definition': 'The percentage of residential addresses for which the United States Postal Service has identified as being unoccupied (no mail collection) for a period of at least 90 days or longer. These properties may be habitable, but are not currently being occupied. It is important to note that a single residential property can contain more than one address.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Part 1 Crime Rate per 1,000 Residents', 'ShortName': 'crimeXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/crime', 'Definition': 'The Part 1 crime rate captures incidents of homicide, rape, aggravated assault, robbery, burglary, larceny, and auto theft that are reported to the Police Department. These incidents are per 1,000 residents in the neighborhood to allow for comparison across areas.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Daytime Crime Rate per 1,000 Population', 'ShortName': 'nan', 'Section': 'Crime and Safety', 'Source': 'nan', 'IndicatorPath': '/indicators/Crime and Safety/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Violent Crime Rate per 1,000 Residents', 'ShortName': 'violXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/viol', 'Definition': 'The violent crime rate measures the number of Part 1 crimes identified as being violent (homicide, rape, aggravated assault, and robbery) that are reported to the Police Department. These incidents are per 1,000 residents in the neighborhood to allow for comparison across areas.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Property Crime Rate per 1,000 Residents', 'ShortName': 'propXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/prop', 'Definition': 'The property crime rate measures the number of Part 1 crimes identified as being property-based (burglary and auto theft) that are reported to the Police Department. These incidents are per 1,000 residents in the neighborhood to allow for comparison across areas. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Domestic Violence Calls For Service per 1,000 Residents', 'ShortName': 'domvioXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/domvio', 'Definition': 'The rate of calls to emergency 911 for domestic violence per 1,000 residents in an area. Calls for service are used rather than actual crime incidents since domestic violence can be classified as one of several types of criminal offenses. It is important to also note that not every case of domestic violence is reported and some claims of abuse may be unfounded. ', 'Years': '2010, 2011, 2012'}}, {'Indicator': {'IndicatorName': 'Juvenile Arrest Rate per 1,000 Juveniles', 'ShortName': 'juvarrXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/juvarr', 'Definition': 'The number of persons aged 10 to 17 arrested per 1,000 juveniles that live in an area. This indicator is calculated by where the arrested juvenile was arrested and not by where the crime is committed. Arrests are used instead of crimes committed since not all juveniles that are arrested are charged with committing a crime. This indicator also excludes offenders who are later charged as adults for their crime(s).', 'Years': '2011, 2012, 2013, 2014, 2015'}}, {'Indicator': {'IndicatorName': 'Juvenile Arrest Rate for Violent Offenses per 1,000 Juveniles', 'ShortName': 'juvviolXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/juvviol', 'Definition': 'The number of persons aged 10 to 17 arrested for violent offenses per 1,000 juveniles that live in an area. Violent offenses may include homicide, rape, assault (with or without a weapon), and robbery. This indicator is calculated by where the arrested juvenile was arrested and not by where the crime is committed. Arrests are used instead of crimes committed since not all juveniles that are arrested are charged with committing a crime. This indicator also excludes offenders who are later charged as adults for their crime(s).', 'Years': '2011, 2012, 2013, 2014, 2015'}}, {'Indicator': {'IndicatorName': 'Juvenile Arrest Rate for Drug-Related Offenses per 1,000 Juveniles', 'ShortName': 'juvdrugXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/juvdrug', 'Definition': 'The number of persons aged 10 to 17 arrested for drug-related offenses per 1,000 juveniles that live in an area. Drug-related offenses include arrests for possession, sale, manufacture, or abuse of illegal drugs, including alcohol. This indicator is calculated by where the arrested juvenile was arrested and not by where the crime is committed. Arrests are used instead of crimes committed since not all juveniles that are arrested are charged with committing a crime. This indicator also excludes offenders who are later charged as adults for their crime(s).', 'Years': '2011, 2012, 2013, 2014, 2015'}}, {'Indicator': {'IndicatorName': 'Number of Shootings per 1,000 Residents', 'ShortName': 'shootXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/shoot', 'Definition': 'The rate of 911 calls for shootings per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Number of Gun-Related Homicides per 1,000 Residents', 'ShortName': 'gunhomXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/gunhom', 'Definition': 'The rate of homicides by firearm as reported in the Part 1 crime data per 1,000 residents in an area. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Number of Common Assault Calls for Service per 1,000 Residents', 'ShortName': 'casltXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/caslt', 'Definition': 'The rate of calls for assaults that do not involve a weapon per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Number of Narcotics Calls for Service per 1,000 Residents', 'ShortName': 'narcXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/narc', 'Definition': 'The rate of calls for narcotics per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Number of Automobile Accident Calls for Service per 1,000 Residents', 'ShortName': 'caraccXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/caracc', 'Definition': 'The rate of calls for accidents involving motor vehicles per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident. Additionally, not every accident involving a motor vehicle is reported to the Police Department. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Rate of Fire and EMS Calls for Service per 1,000 Residents', 'ShortName': 'nan', 'Section': 'Crime and Safety', 'Source': 'nan', 'IndicatorPath': '/indicators/Crime and Safety/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Average Fire and EMS Response Time', 'ShortName': 'nan', 'Section': 'Crime and Safety', 'Source': 'nan', 'IndicatorPath': '/indicators/Crime and Safety/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Number of Children Enrolled in Head Start Programs', 'ShortName': 'nan', 'Section': 'Education and Youth', 'Source': 'nan', 'IndicatorPath': '/indicators/Education and Youth/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Number of Students Ever Attended 1st - 5th Grade', 'ShortName': 'eattendXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/eattend', 'Definition': 'The number of children who have registered for and attend 1st through 5th grade at a Baltimore City Public School at any point during the school year. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Number of Students Ever Attended 6th - 8th Grade', 'ShortName': 'mattendXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/mattend', 'Definition': 'The number of children who have registered for and attend 6th through 8th grade at a Baltimore City Public School at any point in the school year. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Number of Students Ever Attended 9th - 12th Grade', 'ShortName': 'hsattendXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/hsattend', 'Definition': 'The number of children who have registered for and attend 9th through 12th grade at a Baltimore City Public School at any point in the school year.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Percent of Students Enolled in CTE Programs', 'ShortName': 'nan', 'Section': 'Education and Youth', 'Source': 'nan', 'IndicatorPath': '/indicators/Education and Youth/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of Students that are African American (non-Hispanic)', 'ShortName': 'aastudXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/aastud', 'Definition': 'The percentage of Black/African American students of any grade that attend any Baltimore City Public School out of all public school students within an area in a school year.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Percent of Students that are White (non-Hispanic)', 'ShortName': 'wstudXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/wstud', 'Definition': 'The percentage of white (non-Hispanic) students of any grade that attend any Baltimore City Public School out of all public school students within an area in a school year. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Percent of Students that are Hispanic', 'ShortName': 'hstudXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/hstud', 'Definition': 'The percentage of students of any grade level who identify their ethnicity as being Hispanic that attend any Baltimore City Public School out of all public school students within an area in a school year. Ethnicity is separate from a student’s race. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Percent of 1st-5th Grade Students that are Chronically Absent (Missing at least 20 days)', 'ShortName': 'abseXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/abse', 'Definition': 'The percentage of 1st-5th grade students that were recognized as being absent from public school 20 or more days out of all students. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019'}}, {'Indicator': {'IndicatorName': 'Percent of 6th-8th Grade Students that are Chronically Absent (Missing at least 20 days)', 'ShortName': 'absmdXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/absmd', 'Definition': 'The percentage of 6th-8th grade students that were recognized as being absent from public school 20 or more days out of all students. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019'}}, {'Indicator': {'IndicatorName': 'Percent of 9th-12th Grade Students that are Chronically Absent (Missing at least 20 days)', 'ShortName': 'abshsXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/abshs', 'Definition': ' The percentage of 9th-12th grade students that were recognized as being absent from public school 20 or more days out of all students. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019'}}, {'Indicator': {'IndicatorName': 'Percentage of Students Suspended or Expelled During School Year', 'ShortName': 'suspXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/susp', 'Definition': 'The percentage of students of any grade level that were formally suspended or expelled for any reason during the school year out of all public school students within an area. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013'}}, {'Indicator': {'IndicatorName': 'Percentage of Students Receiving Free or Reduced Meals', 'ShortName': 'farmsXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/farms', 'Definition': 'The percentage of students of any grade that are eligible for and received free or reduced school meals out of all public school students. Eligibility for this program is based on the student’s household income. ', 'Years': '2009-2010, 2010-2011, 2011-2012'}}, {'Indicator': {'IndicatorName': 'Percentage of Students Enrolled in Special Education Programs', 'ShortName': 'spedXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/sped', 'Definition': 'The percentage of students of any grade that are eligible for and participated in public school special education programs out of all students. This includes all students with any diagnosed disability.', 'Years': '2009-2010, 2010-2011, 2011-2012'}}, {'Indicator': {'IndicatorName': 'Percentage of Students Enrolled in After School Programs', 'ShortName': 'nan', 'Section': 'Education and Youth', 'Source': 'nan', 'IndicatorPath': '/indicators/Education and Youth/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Kindergarten School Readiness', 'ShortName': 'readyXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/ready', 'Definition': 'The percentage of children whose composite score indicates full school readiness out of all kindergarten school children tested within an area in a school year. The Maryland Model for School Readiness (MMSR) is an assessment and instructional system that was designed to provide parents, teachers, and early childhood providers with a common understanding of what children know and are able to do upon entering school. Under the MMSR system, all children entering kindergarten are assessed for level of mastery across several learning domains. These domains include: social and personal development; language and literacy; mathematical thinking; scientific thinking; social studies; the arts; and physical development and health. Kindergarten teachers must evaluate students during the first few months of the kindergarten year using selected Work Sampling System (WSS) indicators and report their ratings by the end of November of each year to the state. ', 'Years': '2010-2011, 2011-2012'}}, {'Indicator': {'IndicatorName': 'Percentage of 3rd Grade Students Passing MSA Math', 'ShortName': 'math3XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/math3', 'Definition': 'The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'Percentage of 3rd Grade Students Passing MSA Reading', 'ShortName': 'read3XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/read3', 'Definition': 'The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'Percentage of 5th Grade Students Passing MSA Math', 'ShortName': 'math5XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/math5', 'Definition': 'The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'Percentage of 5th Grade Students Passing MSA Reading', 'ShortName': 'read5XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/read5', 'Definition': 'The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'Percentage of 8th Grade Students Passing MSA Math', 'ShortName': 'math8XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/math8', 'Definition': 'The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'Percentage of 8th Grade Students Passing MSA Reading', 'ShortName': 'read8XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/read8', 'Definition': 'The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'Percentage of Students Passing H.S.A. English ', 'ShortName': 'hsaengXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/hsaeng', 'Definition': 'The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'Percentage of Students Passing H.S.A. Biology', 'ShortName': 'hsabioXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/hsabio', 'Definition': 'The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'Percentage of Students Passing H.S.A. Government', 'ShortName': 'hsagovXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/hsagov', 'Definition': 'The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'Percentage of Students Passing H.S.A. Algebra', 'ShortName': 'hsaalgXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/hsaalg', 'Definition': 'The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'High School Dropout/Withdrawl Rate', 'ShortName': 'dropXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/drop', 'Definition': 'The percentage of 9th through 12th graders who withdrew from public school out of all high school students in a school year. Withdraw codes are used as a proxy for dropping out of school based upon the expectation that withdrawn students are no longer receiving educational services. A dropout is defined as a student who, for any reason other than death, leaves school before graduation or the completion of a Maryland-approved education program and is not known to enroll in another school or State-approved program during a current school year.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'High School Completion Rate', 'ShortName': 'complXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/compl', 'Definition': 'The percentage of 12th graders in a school year that successfully completed high school out of all 12th graders within an area. Completers are identified as completing their program of study at the high school level and satisfying the graduation requirements for a Maryland High School Diploma or the requirements for a Maryland Certificate of Program Completion.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Persons Receiving a GED', 'ShortName': 'nan', 'Section': 'Education and Youth', 'Source': 'nan', 'IndicatorPath': '/indicators/Education and Youth/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of Students Switching Schools within School Year', 'ShortName': 'sclswXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/sclsw', 'Definition': 'The percentage of 1st through 12th graders who change schools out of all students in a school year. Students must have attended both schools for which they were registered for at least one day. Additionally, this indicator only identifies the share of students that change schools for any reasons and not the frequency, number of school switches, or change in residences in a school year. The percentage reflects the last home address available for the student who changed schools. This may or may not be the home address provided for the first school that they are registered to attend. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019'}}, {'Indicator': {'IndicatorName': 'Percentage of Students Attending Zoned School ', 'ShortName': 'nan', 'Section': 'Education and Youth', 'Source': 'nan', 'IndicatorPath': '/indicators/Education and Youth/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Average Distance Travelled to School (6th-8th Grade)', 'ShortName': 'nan', 'Section': 'Education and Youth', 'Source': 'nan', 'IndicatorPath': '/indicators/Education and Youth/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Average Distance Travelled to School (9th-12th Grade)', 'ShortName': 'nan', 'Section': 'Education and Youth', 'Source': 'nan', 'IndicatorPath': '/indicators/Education and Youth/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percentage of Population aged 16-19 in School and/or Employed', 'ShortName': 'sclempXX', 'Section': 'Education and Youth', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Education and Youth/sclemp', 'Definition': 'The percentage of persons aged 16 to 19 who are in school and/or are employed out of all persons in their age cohort.', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Teen Birth Rate per 1,000 Females (Aged 15-19)', 'ShortName': 'teenbirXX', 'Section': 'Children and Family Health', 'Source': 'Maryland Department of Vital Statistics', 'IndicatorPath': '/indicators/Children and Family Health/teenbir', 'Definition': 'The rate of female teens aged 15-19 that gave birth per 1,000 females aged 15-19. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Births Delivered at Term (37-42 Weeks)', 'ShortName': 'termbirXX', 'Section': 'Children and Family Health', 'Source': 'Maryland Department of Vital Statistics', 'IndicatorPath': '/indicators/Children and Family Health/termbir', 'Definition': 'The percentage of births delivered at term measures the percentage of births in a calendar year where the baby is delivered between 37 and 42 weeks of gestation.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Babies Born with a Satisfactory Birth Weight', 'ShortName': 'birthwtXX', 'Section': 'Children and Family Health', 'Source': 'Maryland Department of Vital Statistics', 'IndicatorPath': '/indicators/Children and Family Health/birthwt', 'Definition': 'The percentage of children born with a birth weight of at least 5 ½ pounds out of all births in the area. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Births Where the Mother Received Early Prenatal Care (First Trimester)', 'ShortName': 'prenatalXX', 'Section': 'Children and Family Health', 'Source': 'Maryland Department of Vital Statistics', 'IndicatorPath': '/indicators/Children and Family Health/prenatal', 'Definition': 'The percentage of births where the mother received prenatal care during the first trimester of the pregnancy in a calendar year out of all births within an area. This information is calculated by the Vital Statistics registration information collected from each live birth. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Number of Children (Aged 0-6) Tested for Elevated Blood Lead Levels', 'ShortName': 'leadtestXX', 'Section': 'Children and Family Health', 'Source': 'Maryland Department of the Environment, Lead Poisoning Prevention Program', 'IndicatorPath': '/indicators/Children and Family Health/leadtest', 'Definition': 'This indicator reflects the total number of children aged 0-6 who are tested for the presence of blood lead in a calendar year.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Children (Aged 0-6) with Elevated Blood Lead Levels', 'ShortName': 'ebllXX', 'Section': 'Children and Family Health', 'Source': 'Maryland Department of the Environment, Lead Poisoning Prevention Program', 'IndicatorPath': '/indicators/Children and Family Health/ebll', 'Definition': 'The number of children aged 0-6 that are found to either have elevated blood lead levels (≥10Mg/dL) or lead poisoning (≥20 Mg/dL) out of the number of children tested within an area in a calendar year. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Lead Violations per 1,000 Residential Units', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Health Department', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of Families Receiving TANF', 'ShortName': 'tanfXX', 'Section': 'Children and Family Health', 'Source': 'Maryland Department of Human Resources', 'IndicatorPath': '/indicators/Children and Family Health/tanf', 'Definition': 'Temporary Assistance for Needy Families (TANF) is a federal assistance program. The Act provides temporary financial assistance while aiming to get people off of that assistance, primarily through employment. ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Persons receiving SNAP', 'ShortName': 'snapXX', 'Section': 'Children and Family Health', 'Source': 'Maryland Department of Human Resources', 'IndicatorPath': '/indicators/Children and Family Health/snap', 'Definition': 'The Supplemental Nutrition Assistance Program (SNAP), formerly known as Food Stamps, helps low-income households buy the food they need for good health. ', 'Years': '2019'}}, {'Indicator': {'IndicatorName': 'Fetal Mortality Rate', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'nan', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Liquor Outlet Density (per 1,000 Residents)', 'ShortName': 'liquorXX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Liquor Board', 'IndicatorPath': '/indicators/Children and Family Health/liquor', 'Definition': "This indicator reflects the number of business establishments that possess a Class A (Off Sale package goods no on-premises consumption - 6 days, 6:00 a.m.- Midnight. No Sunday sales except Sundays between Thanksgiving Day and New Year's Day upon issuance of a special license for each Sunday) or BD7 (tavern) business license that allows them to sell beer, wine, or liquor. Other liquor licenses to restaurants or on-premise consumption were not included in this analysis. This number is provided by 1,000 residents to allow for comparison across neighborhoods.", 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Fast Food Outlet Density (per 1,000 Residents)', 'ShortName': 'fastfdXX', 'Section': 'Children and Family Health', 'Source': 'Johns Hopkins University, Center for a Livable Future', 'IndicatorPath': '/indicators/Children and Family Health/fastfd', 'Definition': 'The Johns Hopkins Center for a Livable Future (CLF) obtained the food permit list from the Baltimore City Health Department in August 2011, which includes all sites that sell food, such as stores, restaurants and temporary locations such as farmers’ market stands and street carts. The restaurants were grouped into three categories, including full service restaurants, fast food chains and carryouts. Carryout and fast food chain restaurants were extracted from the restaurant layer and spatially joined with the 2010 Community Statistical Area (CSA) data layer, provided by BNIA-JFI. The prepared foods density, per 1,000 people, was calculated for each CSA using the CSA’s population and the total number of carryout and fast food restaurants, including vendors selling prepared foods in public markets, in each CSA.', 'Years': '2011, 2013, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Number of Persons calling UWCM 211 for Health-Related Services ', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'nan', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Rate of STDs per 1,000 Residents (Chlamydia, Gonorrhea, and Syphilis)', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'nan', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Rate of HIV/AIDS per 1,000 Residents', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'nan', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Life Expectancy', 'ShortName': 'lifexpXX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Health Department', 'IndicatorPath': '/indicators/Children and Family Health/lifexp', 'Definition': 'The average number of years a newborn can expect to live, assuming he or she experiences the currently prevailing rates of death through their lifespan. ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Infant Mortality Rate', 'ShortName': 'mort1XX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Health Department', 'IndicatorPath': '/indicators/Children and Family Health/mort1', 'Definition': 'The number of infant deaths (babies under one year of age) per 1,000 live births within the area in a five year period. This is the most stable and commonly measured indicator of mortality in this age group. ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Mortality by Age (1-14 Years old)', 'ShortName': 'mort14XX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Health Department', 'IndicatorPath': '/indicators/Children and Family Health/mort14', 'Definition': 'The number of deaths of persons between the ages of one and 14 per 10,000 persons within the area in a five year period. ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Mortality by Age (15-24 Years Old)', 'ShortName': 'mort24XX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Health Department', 'IndicatorPath': '/indicators/Children and Family Health/mort24', 'Definition': 'The number of deaths of persons between the ages of 15 and 24 per 10,000 persons within the area in a five year period.', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Mortality by Age (25-44 Years Old)', 'ShortName': 'mort44XX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Health Department', 'IndicatorPath': '/indicators/Children and Family Health/mort44', 'Definition': 'The number of deaths of persons between the ages of 25 and 44 per 10,000 persons within the area in a five year period.', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Mortality by Age (45-64 Years Old)', 'ShortName': 'mort64XX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Health Department', 'IndicatorPath': '/indicators/Children and Family Health/mort64', 'Definition': 'The number of deaths of persons between the ages of 45 and 64 per 10,000 persons within the area in a five year period. ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Mortality by Age (65-84 Years Old)', 'ShortName': 'mort84XX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Health Department', 'IndicatorPath': '/indicators/Children and Family Health/mort84', 'Definition': 'The number of deaths of persons between the ages of 65 and 84 per 10,000 persons within the area in a five year period.', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Mortality by Age (85 and Over)', 'ShortName': 'mort85XX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Health Department', 'IndicatorPath': '/indicators/Children and Family Health/mort85', 'Definition': 'The number of deaths of persons 85 years and older per 10,000 persons within the area in a five year period. ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Number of Overdose Calls for Service per 1,000 Residents', 'ShortName': 'overdXX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Children and Family Health/overd', 'Definition': 'The rate of 911 calls to police for overdoses per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident.', 'Years': '2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Causes of Death (analysis of top causes)', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'nan', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Causes of Death (analysis of top causes)', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'nan', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Causes of Death (analysis of top causes)', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'nan', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Causes of Death (analysis of top causes)', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'nan', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of persons with health insurance', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'nan', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Number of Persons with Library Cards per 1,000 Residents', 'ShortName': 'libcardXX', 'Section': 'Arts and Culture', 'Source': 'Enoch Pratt Free Library', 'IndicatorPath': '/indicators/Arts and Culture/libcard', 'Definition': 'The rate of persons per 1,000 residents that possess a valid public library system card. This includes all library card types (first card, juvenile, young adult, adult). ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Number of Event Permits Requested per 1,000 Residents', 'ShortName': 'artevntXX', 'Section': 'Arts and Culture', 'Source': 'ENVISTA, with permission from the Baltimore City Department of Transportation', 'IndicatorPath': '/indicators/Arts and Culture/artevnt', 'Definition': 'The number of event permits requested per 1,000 residents. Events include, but are not limited to, festivals, block parties, races, and parades. In the event of a large event, the central point is used to calculate the location of the request.', 'Years': '2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Public Art per 1,000 Residents', 'ShortName': 'publartxx', 'Section': 'Arts and Culture', 'Source': 'Baltimore Office of Promotion and the Arts', 'IndicatorPath': '/indicators/Arts and Culture/publart', 'Definition': 'The number of works of public art per 1,000 residents. These works include, but are not exclusive to, murals, monuments, sculptures, mosaics, and stained glass. The Baltimore Office of Promotion and the Arts tracks works created through the 1% for Public Art and Baltimore Mural Programs and maintains general inventories of public art and murals. Additional inventories of public art exist, but not at a comprehensive citywide scale and hence cannot be broken down into cross-neighborhood analyses.', 'Years': '2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Number of Businesses that are Arts-Related per 1,000 Residents', 'ShortName': 'artbusXX', 'Section': 'Arts and Culture', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Arts and Culture/artbus', 'Definition': 'The rate of businesses (both for-profit and non-profit) that are directly related to arts and culture per 1,000 residents. Arts-related businesses are defined as belonging to industries that allow for the consumption and enjoyment of arts and culture. The following industries are identified by their primary NAICS code: music, literary, and visual arts-related retail/supplies (451140, 451211, 451220); art dealers (453920, 453920); libraries (519120); motion picture and film (521310, 532230); art schools (611610); performing arts (711110, 711120, 711130, 711190); independent artists, writers, and performers (711510); museums (712110); historical sites (712120); and zoos, gardens and nature parks (712130, 712190). The following industries are identified by their primary SIC codes: designers (152106); art publishers (274101), music, literary, and visual arts-related retail/supplies (393101, 519202, 573608, 573609, 593201, 594201, 594205, 594501, 594520, 594601, 599965, 769969); art galleries, dealers, and consultants (599969, 599988, 599989); photography (722121); calligraphers (733607); embroidery (738942); theatres (783201, 792207); theatrical support (792211, 792212); musical and live entertainment (792903, 792905, 792906, 792908, 792917, 792918, 792927); parks (799951); art and music instruction (804958, 829915, 829919); libraries (823111); museums (841201); arts organizations (841202); zoos (842201); writers (899903); visual artists (899907, 899912); art restoring (899908); and music arrangers and composers (899921).', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Total Employment in Arts-Related Businesses', 'ShortName': 'artempXX', 'Section': 'Arts and Culture', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Arts and Culture/artemp', 'Definition': 'The number of persons employed in arts-related businesses (both for-profit and non-profit). This number does not count those persons who identify themselves as being artists and does not count sole proprietorships or persons who work part-time in the arts. The same industries used to calculate the rate of arts-related businesses are used to calculate total employment in arts-related businesses. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percentage of Businesses that are Non-Profits', 'ShortName': 'nan', 'Section': 'Arts and Culture', 'Source': 'nan', 'IndicatorPath': '/indicators/Arts and Culture/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent Population 16-64 Employed', 'ShortName': 'emplXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Workforce and Economic Development/empl', 'Definition': 'The percent of persons between the ages of 16 and 64 formally employed or self-employed and earning a formal income. It is used to understand how many persons are working out of the entire population, not just those in the labor force (persons who may be looking for work or working). ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent Population 16-64 Unemployed and Looking for Work', 'ShortName': 'unemplXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Workforce and Economic Development/unempl', 'Definition': 'The percent of persons between the ages of 16 and 64 not working out of all persons, not just those in the labor force (persons who may be looking for work). These persons are seeking work that pays a formal income. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent Population 16-64 Not in Labor Force', 'ShortName': 'nilfXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Workforce and Economic Development/nilf', 'Definition': 'The percent of persons who are not in the labor force out of all persons between the ages of 16 and 64 in the area. There are several reasons why persons may not be included in the labor force. These reasons may include: they are caretakers for children or other family members; they attend school or job training; they may have a disability; and they are discouraged or frustrated and have given up seeking a job or have a history that may include criminal activity. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Unemployment Rate', 'ShortName': 'unemprXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Workforce and Economic Development/unempr', 'Definition': 'The percent of persons between the ages of 16 and 64 that are in the labor force (and are looking for work) but are not currently working. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent Population (25 Years and over) With Less Than a High School Diploma or GED', 'ShortName': 'lesshsXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Workforce and Economic Development/lesshs', 'Definition': 'The percentage of persons that have not completed, graduated, or received a high school diploma or GED. This is a standard indicator used to measure the portion of the population with less than a basic level of skills needed for the workplace. Persons under the age of 25 are not included in this analysis since many of these persons are still attending various levels of schooling. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent Population (25 Years and over) With High School Diploma and Some College or Associates Degree', 'ShortName': 'hsdiplXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Workforce and Economic Development/hsdipl', 'Definition': "The percentage of persons that have completed, graduated, or received a high school diploma or GED and also have taken some college courses or completed their Associate's degree. This is a standard indicator used to measure the portion of the population with a basic level of skills needed for the workplace. Persons under the age of 25 are not included in this analysis since many of these persons are still attending various levels of schooling. ", 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': "Percent Population (25 Years and over) with a Bachelor's Degree or Above", 'ShortName': 'bahigherXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Workforce and Economic Development/bahigher', 'Definition': 'The percentage of persons that have completed, graduated, or received a Bachelor’s or an advanced degree. This is an indicator used to measure the portion of the population having an advanced level of skills needed for the workplace. Persons under the age of 25 are not included in this analysis since many of these persons are still attending various levels of schooling. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Total Number of Commercial Properties', 'ShortName': 'compropXX', 'Section': 'Workforce and Economic Development', 'Source': 'MdProperty View', 'IndicatorPath': '/indicators/Workforce and Economic Development/comprop', 'Definition': 'The total number of commercial properties located within an area in a particular year. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Percent of Commercial Properties with Rehab Permits Above $5,000', 'ShortName': 'crehabXX', 'Section': 'Workforce and Economic Development', 'Source': 'Baltimore City Department of Housing', 'IndicatorPath': '/indicators/Workforce and Economic Development/crehab', 'Definition': 'The percentage of properties that are investing within their current establishment and not the level of their investment. Permits for work below $5,000 are considered to be minor and not included in this indicator. A single establishment can apply for and receive multiple permits. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Total Number of Businesses', 'ShortName': 'numbusXX', 'Section': 'Workforce and Economic Development', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Workforce and Economic Development/numbus', 'Definition': 'The total number of businesses (both for-profit and non-profit) within an area at a single time in a year. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Total Number of Employees', 'ShortName': 'totempXX', 'Section': 'Workforce and Economic Development', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Workforce and Economic Development/totemp', 'Definition': 'The total number of persons employed by businesses (both for-profit and non-profit) within an area at a single time in a year. ', 'Years': '2010, 2011, 2012, 2013'}}, {'Indicator': {'IndicatorName': 'Number of Businesses with Under 50 Employees', 'ShortName': 'smlbusXX', 'Section': 'Workforce and Economic Development', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Workforce and Economic Development/smlbus', 'Definition': 'The total number of businesses (both for-profit and non-profit) that report having less than 50 persons employed within an area at a single time in a year. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Employed Residents who Work Outside the City', 'ShortName': 'wrkoutXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, Longitudinal Employer-Household Dynamics', 'IndicatorPath': '/indicators/Workforce and Economic Development/wrkout', 'Definition': 'The percentage of workers that are employed by jobs located outside of Baltimore City. Only persons who report being employed and are at least 16 years old are included in the analysis. ', 'Years': '2010, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Total Dollar Amount Invested in Small Businesses per 50 Businesses', 'ShortName': 'smlinvstXX', 'Section': 'Workforce and Economic Development', 'Source': 'Johns Hopkins University, 21st Century Cities Initiative', 'IndicatorPath': '/indicators/Workforce and Economic Development/smlinvst', 'Definition': 'The total dollar amount invested in businesses with fewer than 500 employees per 50 businesses. Small business lending data to include FFIEC insured bank loans under $1 million to businesses made by large banks; venture capital investments; US Export-Import Bank loans; Small Business Innovation Research (SBIR) and Small business Technology Transfer Research (STTR) grants; government, philanthropic, and institutional grants supporting small businesses; Maryland Department of Commerce loans; State of Maryland Neighborhood BusinessWorks loans; Baltimore Development Corporation loans; and Small Business Administration 7a and 504 loans.', 'Years': '2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Residential Mortgages Originated or Approved', 'ShortName': 'hmdaXX', 'Section': 'Housing and Community Development', 'Source': 'Consumer Financial Protection Bureau', 'IndicatorPath': '/indicators/Housing and Community Development/hmda', 'Definition': 'The percent of first lien mortgage applications for single family homes that were originated or approved out of all applications in the area. The Home Mortgage Disclosure Act (HMDA) requires many financial institutions to maintain, report, and publicly disclose information about mortgages in neighborhoods. ', 'Years': '2019'}}, {'Indicator': {'IndicatorName': 'Number of Banks and Bank Branches per 1,000 Residents', 'ShortName': 'banksXX', 'Section': 'Workforce and Economic Development', 'Source': 'Federal Deposit Insurance Corporation', 'IndicatorPath': '/indicators/Workforce and Economic Development/banks', 'Definition': 'The number of banks and bank branches per 1,000 residents within an area. ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Businesses that are 1 Year old or Less', 'ShortName': 'biz1_XX', 'Section': 'Workforce and Economic Development', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Workforce and Economic Development/biz1_', 'Definition': 'The percentage of businesses (both for-profit and non-profit) that report their establishment as being one year old or less. The age of the business is determined by the year that the first year they appeared in the InfoUSA database. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Businesses that are 2 Years old or Less', 'ShortName': 'biz2_XX', 'Section': 'Workforce and Economic Development', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Workforce and Economic Development/biz2_', 'Definition': 'The percentage of businesses (both for-profit and non-profit) that report their establishment as being two years old or less. The age of the business is determined by the year that the first year they appeared in the business database. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Businesses that are 4 Years old or Less', 'ShortName': 'biz4_XX', 'Section': 'Workforce and Economic Development', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Workforce and Economic Development/biz4_', 'Definition': 'The percentage of businesses (both for-profit and non-profit) that report their establishment as being four years old or less. The age of the business is determined by the year that the first year they appeared in the business database. A business that has been in operation more than four years has a greater likelihood of remaining open for a longer period of time. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Adult Population on Parole/Probation', 'ShortName': 'prbprlXX', 'Section': 'Workforce and Economic Development', 'Source': 'nan', 'IndicatorPath': '/indicators/Workforce and Economic Development/prbprl', 'Definition': 'The percentage of the population age 18 and older that are on parole or probation.', 'Years': '2013'}}, {'Indicator': {'IndicatorName': 'Percent of CSA that is Either Low or Moderate income (by Census tract)', 'ShortName': 'nan', 'Section': 'Workforce and Economic Development', 'Source': 'nan', 'IndicatorPath': '/indicators/Workforce and Economic Development/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of persons in MOED training programs (per 1,000 Residents)', 'ShortName': 'nan', 'Section': 'Workforce and Economic Development', 'Source': 'nan', 'IndicatorPath': '/indicators/Workforce and Economic Development/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of Households with No Internet at Home', 'ShortName': 'nohhintXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Workforce and Economic Development/nohhint', 'Definition': 'Percent of households with no home Internet of any kindThe percentage of households without an internet subscription at home.', 'Years': '2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Number of Businesses by Selected Neighborhood Industry (NAICS Sectors)', 'ShortName': 'neiindXX', 'Section': 'Workforce and Economic Development', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Workforce and Economic Development/neiind', 'Definition': 'The number of businesses (both for-profit and non-profit) that provide products and services to local residents. The industries included in this indicator are: Retail Trade (NAICS 44-45); Finance and Insurance (NAICS 52); Professional, Scientific, and Technical Services (NAICS 54); Health Care and Social Assistance (NAICS 62); Arts, Entertainment, and Recreation (NAICS 71); Accommodation and Food Services (NAICS 72); and Other Services except Public Administration (NAICS 81). The primary industry reported by each business was used to determine their inclusion. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Neighborhood Businesses per 1,000 Residents (NAICS Sectors)', 'ShortName': 'neibusXX', 'Section': 'Workforce and Economic Development', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Workforce and Economic Development/neibus', 'Definition': 'The number of businesses (both for-profit and non-profit) that provide products and services to local residents per 1,000. The industries included in this indicator are: Retail Trade (NAICS 44-45); Finance and Insurance (NAICS 52); Professional, Scientific, and Technical Services (NAICS 54); Health Care and Social Assistance (NAICS 62); Arts, Entertainment, and Recreation (NAICS 71); Accommodation and Food Services (NAICS 72); and Other Services except Public Administration (NAICS 81). The primary industry reported by each business was used to deter-mine their inclusion. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Total number of Employees by Selected Neighborhood Industry (NAICS Sectors)', 'ShortName': 'neiempXX', 'Section': 'Workforce and Economic Development', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Workforce and Economic Development/neiemp', 'Definition': 'The number of persons employed by businesses (both for-profit and non-profit) that provide products and services to local residents. The industries included in this indicator are: Retail Trade (NAICS 44-45); Finance and Insurance (NAICS 52); Professional, Scientific, and Technical Services (NAICS 54); Health Care and Social Assistance (NAICS 62); Arts, Entertainment, and Recreation (NAICS 71); Accommodation and Food Services (NAICS 72); and Other Services except Public Administration (NAICS 81). The primary industry reported by each business was used to determine their inclusion. The persons employed by these businesses may not necessarily live in the neighborhood where the business is located. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Population (Over the Age of 18) Who are Registered to Vote', 'ShortName': 'regvoteXX', 'Section': 'Sustainability', 'Source': 'Baltimore City Board of Elections', 'IndicatorPath': '/indicators/Sustainability/regvote', 'Definition': 'The percentage of persons over the age of 18 registered to vote out of all persons 18 years and over.', 'Years': '2010, 2012, 2014, 2016, 2018'}}, {'Indicator': {'IndicatorName': 'Percent Population (Over the Age of 18) Who Voted in the General Election', 'ShortName': 'votedXX', 'Section': 'Sustainability', 'Source': 'Baltimore City Board of Elections', 'IndicatorPath': '/indicators/Sustainability/voted', 'Definition': 'The percentage of persons who voted in the last general election out of all registered voters. ', 'Years': '2010, 2012, 2014, 2016, 2018'}}, {'Indicator': {'IndicatorName': 'Rate of Dirty Streets and Alleys Reports per 1,000 Residents', 'ShortName': 'dirtystXX', 'Section': 'Sustainability', 'Source': 'Baltimore City CitiStat', 'IndicatorPath': '/indicators/Sustainability/dirtyst', 'Definition': 'The rate of service requests for dirty streets and alleys through Baltimore’s 311 system per 1,000 residents. More than one service request may be made for the same issue but is logged as a unique request.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Rate of Clogged Storm Drain Reports per 1,000 Residents', 'ShortName': 'cloggedXX', 'Section': 'Sustainability', 'Source': 'Baltimore City CitiStat', 'IndicatorPath': '/indicators/Sustainability/clogged', 'Definition': 'The rate of service requests for addressing clogged storm drains made through Baltimore’s 311 system per 1,000 residents. More than one service request may be made for the same issue but is logged as a unique request.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Percent of Population that Drove Alone to Work', 'ShortName': 'drvaloneXX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/drvalone', 'Definition': 'The percentage of commuters driving alone out of all commuters aged 16 and above. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Population that Carpool to Work', 'ShortName': 'carpoolXX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/carpool', 'Definition': 'The percentage of commuters that carpool out of all commuters aged 16 and above. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Population that Uses Public Transportation to Get to Work', 'ShortName': 'pubtranXX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/pubtran', 'Definition': 'The percentage of commuters that use public transit out of all commuters aged 16 and above.', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Population that Walks to Work', 'ShortName': 'walkedXX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/walked', 'Definition': 'The percentage of commuters that walk to work out of all commuters aged 16 and above.', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Employed Population with Travel Time to Work of 0-14 Minutes', 'ShortName': 'trav14XX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/trav14', 'Definition': 'The percentage of commuters that spend less than 15 minutes commuting to work out of all commuters aged 16 and above. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Employed Population with Travel Time to Work of 15-29 Minutes', 'ShortName': 'trav29XX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/trav29', 'Definition': 'The percentage of commuters that spend between 15 and 29 minutes commuting to work out of all commuters aged 16 and above. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Employed Population with Travel Time to Work of 30-44 Minutes', 'ShortName': 'trav44XX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/trav44', 'Definition': 'The percentage of commuters that spend between 30 and 44 minutes travelling to work out of all commuters aged 16 and above. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Employed Population with Travel Time to Work of 45 Minutes and Over', 'ShortName': 'trav45XX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/trav45', 'Definition': 'The percentage of commuters that spend more than 45 minutes travelling to work out of all commuters aged 16 and above. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Area Covered by Trees', 'ShortName': 'treesXX', 'Section': 'Sustainability', 'Source': 'University of Vermont Spatial Analysis Lab', 'IndicatorPath': '/indicators/Sustainability/trees', 'Definition': "The percent of total land area comprised of tree canopy. The primary sources for this land cover layer were 2004 pan-sharpened 1m Ikonos satellite imagery, a normalized Digital Surface Model (nDSM) derived from 2006 LiDAR data, and LiDAR intensity data resulting from the 2006 acquisition. Other sources of data include the City's planimetric GIS database (building footprints and road casing polygons). The land cover classification was performed using automated object-based image analysis (OBIA) techniques in Definiens Developer/eCognition Server. No accuracy assessment was conducted, but the dataset was thoroughly reviewed at a scale of 1:2000. Over 370 corrections were made to the classification. ", 'Years': '2007, 2015, 2017'}}, {'Indicator': {'IndicatorName': 'Air Quality Risk', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of Area Covered by Impervious Surface', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Number of Community Managed Open Spaces', 'ShortName': 'cmosXX', 'Section': 'Sustainability', 'Source': 'Baltimore Neighborhood Indicators Alliance - Jacob France Institute', 'IndicatorPath': '/indicators/Sustainability/cmos', 'Definition': 'The number of community managed open spaces in an area that include community gardens (food-producing or ornamental), Adopt-A-Lots, or some other green space managed by the community. ', 'Years': '2011, 2014, 2015'}}, {'Indicator': {'IndicatorName': 'Median Daily Water Consumption', 'ShortName': 'watercXX', 'Section': 'Sustainability', 'Source': 'Baltimore City Department of Public Works', 'IndicatorPath': '/indicators/Sustainability/waterc', 'Definition': 'The median daily average water consumption of all city meters registering greater than 0.0 cubic meters per day.', 'Years': '2011'}}, {'Indicator': {'IndicatorName': 'Number of Downspout Disconnections per 1,000 Residential Units', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Number of Public Trashcans', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Rate of Sewer/Water Main Breaks per 1,000 Residents', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Natural Gas Utilization', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Energy Use', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of Residences Heated by Utility Gas', 'ShortName': 'heatgasXX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/heatgas', 'Definition': 'The percentage of homes that use utility gas for heat and cooking out of all homes. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Residences Heated by Electricity', 'ShortName': 'elheatXX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/elheat', 'Definition': 'The percentage of homes that use electricity for heat and cooking out of all homes. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Households with No Vehicles Available', 'ShortName': 'novhclXX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/novhcl', 'Definition': 'The percentage of households that do not have a personal vehicle available for use out of all households in an area. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Number of Photovoltaic/Solar Permits', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of Homes Weatherized', 'ShortName': 'weatherXX', 'Section': 'Sustainability', 'Source': 'Maryland Department of Housing and Community Development', 'IndicatorPath': '/indicators/Sustainability/weather', 'Definition': 'The percent of residential properties that were eligible for and received weatherization assistance such as air sealing or furnace replacements. The Weatherization Assistance Program helps eligible low-income households lower their energy costs by increasing the energy efficiency of their homes, while ensuring their health and safety. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016'}}, {'Indicator': {'IndicatorName': 'Walk Score', 'ShortName': 'wlkscXX', 'Section': 'Sustainability', 'Source': 'Walk Score', 'IndicatorPath': '/indicators/Sustainability/wlksc', 'Definition': 'The Walk Score® is calculated by mapping out the distance to amenities in nine different categories (grocery stores, restaurants, shopping, coffee shops, banks, parks, schools, book stores/libraries, and entertainment) and are weighted according to importance. The distance to a location, counts, and weights determine a base score of an address, which is then normalized to a score from 0 to 100. More information on Walk Score can be found at http://www.walkscore.com/. ', 'Years': '2011, 2017'}}, {'Indicator': {'IndicatorName': 'Aggregate Number of Community Assets', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Number of Daily Bus Stop Loadings per 1,000 Residents', 'ShortName': 'busloadXX', 'Section': 'Sustainability', 'Source': 'Maryland Transit Administration', 'IndicatorPath': '/indicators/Sustainability/busload', 'Definition': 'The median number of daily passengers getting on and off MTA buses by community.', 'Years': '2017, 2018'}}, {'Indicator': {'IndicatorName': 'Number of Bike Racks per 1,000 Residents', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Road Quality', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Number of Miles of Bike Lanes', 'ShortName': 'bklnXX', 'Section': 'Sustainability', 'Source': 'Department of Transportation', 'IndicatorPath': '/indicators/Sustainability/bkln', 'Definition': 'Measures the linear miles of designated bike lanes within the roadway system.', 'Years': '2012, 2020'}}, {'Indicator': {'IndicatorName': 'Percent of persons by occupation classification (major classifications)', 'ShortName': 'nan', 'Section': 'Workforce and Economic Development', 'Source': 'nan', 'IndicatorPath': '/indicators/Workforce and Economic Development/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of Population Using Other Means to Commute to Work (Taxi, Motorcycle, Bicycle, Other)', 'ShortName': 'othrcomXX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/othrcom', 'Definition': 'The percentage of commuters that use other means to travel to work out of all commuters aged 16 and above.', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Number of Students Officially Enrolled in 1st - 5th Grade', 'ShortName': 'eenrolXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/eenrol', 'Definition': 'The number of children who have registered for and attend 1st through 5th grade at a Baltimore City Public School as of September 30th. This count only includes students enrolled in public schools. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Number of Students Officially Enrolled in 6th - 8th Grade', 'ShortName': 'menrolXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/menrol', 'Definition': 'The number of children who have registered for and attend 6th through 8th grade at a Baltimore City Public School as of September 30th. This count only includes students enrolled in public schools. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Number of Students Officially Enrolled in 9th - 12th Grade', 'ShortName': 'hsenrolXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/hsenrol', 'Definition': 'The number of children who have registered for and attend 9th through 12th grade at a Baltimore City Public School as of September 30th. This count only includes students enrolled in public schools.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Average Healthy Food Availability Index', 'ShortName': 'hfaiXX', 'Section': 'Children and Family Health', 'Source': 'Johns Hopkins University, Center for a Livable Future', 'IndicatorPath': '/indicators/Children and Family Health/hfai', 'Definition': 'The Johns Hopkins Center for a Livable Future (CLF) calculated HFAI scores for all food stores in Baltimore, in summer 2012, using an adapted version of the NEMS-S (Nutrition Environment Measures Survey in Stores) tool. The NEMS-S tool was developed by researchers at the Rollins School of Public Health at Emory University to measure the nutritional environment of food retail stores and was designed to assess healthy food availability in grocery and convenience stores. CLF obtained a food permit list from the Baltimore City Health Department in August 2011, which includes all sites that sell food, such as stores, restaurants, and temporary locations such as farmers’ market stands and street carts. HFAI scores range from zero to 28.5, with higher scores indicating more availability of healthy and whole food in a food store.', 'Years': '2012, 2015'}}, {'Indicator': {'IndicatorName': 'Number of Trees Planted', 'ShortName': 'treeplntXX', 'Section': 'Sustainability', 'Source': 'TreeBaltimore', 'IndicatorPath': '/indicators/Sustainability/treeplnt', 'Definition': 'Measures the number of trees planted annually by the TreeBaltimore program. ', 'Years': '2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Rate of Housing Vouchers per 1,000 Rental Units', 'ShortName': 'hcvhouseXX', 'Section': 'Housing and Community Development', 'Source': 'Picture of Subsidized Housing, HUD', 'IndicatorPath': '/indicators/Housing and Community Development/hcvhouse', 'Definition': 'Measures the ability of housing voucher holders to find housing in the private rental market. The Housing Choice Voucher (HCV) program is the federal government’s largest low-income housing assistance program where people can seek housing in the private market. The maximum housing assistance is generally the lesser of the payment standard minus 30% of the family’s monthly adjusted income or the gross rent for the unit minus 30% of monthly adjusted income.', 'Years': '2013, 2014, 2015, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Rate of Businesses in the Creative Economy per 1,000 Residents', 'ShortName': 'cebusXX', 'Section': 'Arts and Culture', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Arts and Culture/cebus', 'Definition': 'The rate of businesses (both for-profit and non-profit) that are in the creative economy per 1,000 residents. The creative economy is defined as industries that use and support artistic and cultural skillsets to attract and generate capital, knowledge, and information. Arts-based businesses are included in the creative economy. In addition to the industries included in the rate of arts-based businesses indictor, the following industries are identified by their primary NAICS code: Textiles (313220); Commercial Printing (323111, 323113); Book Printers and Publishers (323117, 511130); Print Media (451212, 511110, 511120, 511199, 519110); Motion Picture & Video Production (512110); Music Publishers (512230); Sound Recording (512240); Radio (515112); Architecture (541310, 541320); Interior Design (541410); Graphic Design (541430); Advertising (541810, 541890); and Photography (541921, 541922). In addition to the industries included in the rate of arts-based businesses indictor, the following industries are identified by their primary SIC code: Print Media (271101, 271102, 271198, 272101, 272102, 272104, 273101, 273198, 596302, 599401); Publishers (273298, 274104, 274105, 874205); Printers (275202, 275202, 275902, 275998); Bookbinders (278902); Radio (483201); Television (483301, 484101, 792205, 824911); Textiles (513122, 594904); Advertising (519917, 731101, 731115, 731305, 731999); Fashion Designers (569901, 594408); Photography (722101, 722113, 722120, 733501, 738401); Graphic Design (733603); Commercial Artists (733604); Website Design (737311); General Media (738301); Interior Design (738902); Restoration (764112); Landscape Design (781030); Motion Picture and Video Support (781205, 781211, 781901); Architecture (871202, 871207, 871209, 874892); and Business Writers (899902).', 'Years': '2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Number of Employees in the Creative Economy', 'ShortName': 'ceempXX', 'Section': 'Arts and Culture', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Arts and Culture/ceemp', 'Definition': 'The number of persons employed in the creative economy (both for-profit and non-profit). This number does not count those persons who identify themselves as being artists and does not count sole proprietorships or persons who work part-time in the arts. The same industries used to calculate the rate businesses in the creative economy are used to calculate total employment in the creative economy.', 'Years': '2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Number of Public Murals', 'ShortName': 'muralsXX', 'Section': 'Arts and Culture', 'Source': 'Baltimore Office of Promotion of the Arts', 'IndicatorPath': '/indicators/Arts and Culture/murals', 'Definition': 'The number of murals per CSA. Murals are also included in the “Public Art per 1,000 residents” indicator. Murals are separated out as a sub-indicator so they can be analyzed at the point-level.', 'Years': '2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Number of Total Jobs Filled by Employees ', 'ShortName': 'totjobsXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, Longitudinal Employer-Household Dynamics', 'IndicatorPath': '/indicators/Workforce and Economic Development/totjobs', 'Definition': 'The total number of jobs per neighborhood. This indicator only counts jobs that are currently held by employees.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017'}}, {'Indicator': {'IndicatorName': 'Number of Arrests per 1,000 Residents', 'ShortName': 'arrestXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/arrest', 'Definition': 'The number of persons aged 18 and over arrested per 1,000 adults that live in an area. This indicator is calculated by where the individual was arrested and not by where the crime is committed. ', 'Years': '2014, 2015, 2016'}}, {'Indicator': {'IndicatorName': 'Percentage of 3rd Grade Students who Met or Exceeded PARCC Math', 'ShortName': 'pmath3XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/pmath3', 'Definition': 'The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.', 'Years': '2014-2015, 2015-2016, 2016-2017'}}, {'Indicator': {'IndicatorName': 'Percentage of 3rd Grade Students who Met or Exceeded PARCC Reading', 'ShortName': 'pread3XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/pread3', 'Definition': 'The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.', 'Years': '2014-2015, 2015-2016, 2016-2017'}}, {'Indicator': {'IndicatorName': 'Percentage of 5th Grade Students who Met or Exceeded PARCC Math', 'ShortName': 'pmath5XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/pmath5', 'Definition': 'The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.', 'Years': '2014-2015, 2015-2016, 2016-2017'}}, {'Indicator': {'IndicatorName': 'Percentage of 5th Grade Students who Met or Exceeded PARCC Reading', 'ShortName': 'pread5XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/pread5', 'Definition': 'The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.', 'Years': '2014-2015, 2015-2016, 2016-2017'}}, {'Indicator': {'IndicatorName': 'Percentage of 8th Grade Students who Met or Exceeded PARCC Math', 'ShortName': 'pmath8XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/pmath8', 'Definition': 'The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.', 'Years': '2014-2015, 2015-2016, 2016-2017'}}, {'Indicator': {'IndicatorName': 'Percentage of 8th Grade Students who Met or Exceeded PARCC Reading', 'ShortName': 'pread8XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/pread8', 'Definition': 'The percentage of 8th grade students who met or exceeded expectations on the PARCC exam for reading. The Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.', 'Years': '2014-2015, 2015-2016, 2016-2017'}}, {'Indicator': {'IndicatorName': 'Percentage of Students who Met or Exceeded PARCC Algebra I', 'ShortName': 'palg1XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/palg1', 'Definition': 'The percentage of high school students who have met or exceeded expectations on PARCC Algebra I exams out of all high school students that took the exam in the school year. ', 'Years': '2014-2015, 2015-2016, 2016-2017'}}, {'Indicator': {'IndicatorName': 'Percentage of Students who Met or Exceeded PARCC Algebra II', 'ShortName': 'palg2XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/palg2', 'Definition': 'The percentage of high school students who have met or exceeded expectations on PARCC Algebra II exams out of all high school students that took the exam in the school year. ', 'Years': '2014-2015, 2015-2016, 2016-2017'}}, {'Indicator': {'IndicatorName': 'Kindergarten Readiness', 'ShortName': 'kraXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/kra', 'Definition': 'The Kindergarten Readiness Assessment (KRA) measure children’s readiness to do kindergarten work. The KRA is a developmentally appropriate assessment tool that measures of incoming public-school kindergarteners across four learning domains. A child is considered to be ready for kindergarten if assessed as “demonstrating” the foundational skills and behaviors that prepare him/her for curriculum based on the kindergarten standards. ', 'Years': '2015-2016, 2016-2017'}}, {'Indicator': {'IndicatorName': 'Rate of Street Light Outages per 1,000 Residents', 'ShortName': 'lightsXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City CitiStat', 'IndicatorPath': '/indicators/Crime and Safety/lights', 'Definition': 'The rate of service requests for addressing street light outages made through Baltimore’s 311 system per 1,000 residents. More than one service request may be made for the same issue but is logged as a unique request.', 'Years': '2016, 2017, 2018, 2019, 2020'}}] ! echo {json.loads(indList)) } > indList2.js! echo {json.dumps(json.loads(indList))} > indList3.js/bin/bash: -c: line 0: syntax error near unexpected token `(' /bin/bash: -c: line 0: ` echo {json.dumps(json.loads(indList))} > indList3.js' ! echo {print(json.loads(indList)) } > indList3.jsprint( indList )[{'Indicator': {'IndicatorName': 'Total Population', 'ShortName': 'tpopXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau', 'IndicatorPath': '/indicators/Census Demographics/tpop', 'Definition': 'The total number of persons of all ages that live within an area. This indicator is frequently used to normalize data to allow for comparison across areas.', 'Years': '2010'}}, {'Indicator': {'IndicatorName': 'Total Male Population', 'ShortName': 'maleXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau', 'IndicatorPath': '/indicators/Census Demographics/male', 'Definition': 'The total number of men of all ages of all ages that live within an area.', 'Years': '2010'}}, {'Indicator': {'IndicatorName': 'Total Female Population', 'ShortName': 'femaleXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau', 'IndicatorPath': '/indicators/Census Demographics/female', 'Definition': 'The total number of women of all ages that live within an area.', 'Years': '2010'}}, {'Indicator': {'IndicatorName': 'Percent of Residents - Black/African-American (Non-Hispanic)', 'ShortName': 'paaXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/paa', 'Definition': 'The total number of persons that identify themselves as being racially Black or African American (and ethnically non-Hispanic) out of the total number of persons living in an area. “Black or African American” refers to a person having origins in any of the Black racial groups of Africa. It includes people who indicated their race as “Black”.', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Residents - White/Caucasian (Non-Hispanic)', 'ShortName': 'pwhiteXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/pwhite', 'Definition': 'The total number of persons that identify themselves as being racially White (and ethnically non-Hispanic) out of the total number of persons living in an area. “White” refers to a person having origins in any of the original peoples of Europe, the Middle East, or North Africa. It includes people who indicated their race(s) as “White”. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Residents - Asian (Non-Hispanic)', 'ShortName': 'pasiXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/pasi', 'Definition': 'The total number of persons that identify themselves as being Asian (and non-Hispanic) out of the total number of persons living in an area. “Asian” refers to a person having origins in any of the original peoples of the Far East, Southeast Asia, or the Indian subcontinent, including, for example, Cambodia, China, India, Japan, Korea, Malaysia, Pakistan, the Philippine Islands, Thailand, and Vietnam. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Residents - Two or More Races (Non-Hispanic)', 'ShortName': 'p2moreXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/p2more', 'Definition': 'The total number of persons that identify themselves as being of two or more races (and non-Hispanic) out of the total number of persons living in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Residents - All Other Races (Hawaiian/ Pacific Islander, Alaskan/ Native American Other Race) (Non-Hispanic)', 'ShortName': 'ppacXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/ppac', 'Definition': 'The total number of persons that identify themselves as being of either American Indian, Alaskan Native, Native Hawaiian or Other Pacific Islander, or some other race (non-Hispanic) out of the total number of persons living in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Residents - Hispanic', 'ShortName': 'phispXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/phisp', 'Definition': 'The total number of persons that identify their ethnicity as being Hispanic or Latino out of the total number of persons living in an area. Hispanic origin can be viewed as the heritage, nationality group, lineage, or country of birth of the person or the person’s parents or ancestors before their arrival in the United States. People who identify their origin as Hispanic, Latino, or Spanish may be any race. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Racial Diversity Index', 'ShortName': 'racdivXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/racdiv', 'Definition': 'The percent chance that two people picked at random within an area will be of a different race/ethnicity. This number does not reflect which race/ethnicity is predominant within an area. The higher the value, the more racially and ethnically diverse an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Population Under 5 Years old', 'ShortName': 'age5_XX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/age5_', 'Definition': 'The percent of persons 5 years or under out of all persons living in an area.', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Population 5-17 Years old', 'ShortName': 'age18_XX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/age18_', 'Definition': 'The percent of persons aged 6 to 18 years old out of all persons living in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Population 18-24 Years old', 'ShortName': 'age24_XX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/age24_', 'Definition': 'The percent of persons aged 19 to 24 years old out of all persons living in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Population 25-64 Years old', 'ShortName': 'age64_XX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/age64_', 'Definition': 'The percent of persons aged 25 to 64 years old out of all persons living in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Population 65 Years and over', 'ShortName': 'age65_XX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/age65_', 'Definition': 'The total number of persons 65 years old and above out of all persons living in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Total Number of Households', 'ShortName': 'hhsXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/hhs', 'Definition': 'A household consists of all the people occupying a housing unit. A household includes related and unrelated persons, if any, such as lodgers, foster children, wards, or employees who share the housing unit. A person living alone in a housing unit, or a group of unrelated people sharing a housing unit such as partners or roomers, is also counted as a household. The count of households excludes group quarters. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Female-Headed Households with Children Under 18', 'ShortName': 'femhhsXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/femhhs', 'Definition': 'The percentage of female-headed households with children under 18 out of all households with children under 18 in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Households with Children Under 18', 'ShortName': 'famXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/fam', 'Definition': 'The percentage of households with children living in the household that are under the age of 18 out of all households. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Average Household Size', 'ShortName': 'hhsizeXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/hhsize', 'Definition': 'The median value of number of persons living within a household. The average size of a household is obtained by dividing the number of persons in households by the number of households (or householders). ', 'Years': '2010'}}, {'Indicator': {'IndicatorName': 'Median Household Income', 'ShortName': 'mhhiXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/mhhi', 'Definition': 'The median household income is the middle value of the incomes earned in the prior year by households within an area. Income and earnings are inflation-adjusted for the last year of the 5-year period. The median value is used as opposed to the average so that both extremely high and extremely low prices do not distort the total amount of income earned by households in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Households Earning Less than $25,000', 'ShortName': 'hh25incXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/hh25inc', 'Definition': 'The percentage of households earning less than $25,000 out of all households in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Households Earning $25,000 to $40,000', 'ShortName': 'hh40incXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/hh40inc', 'Definition': 'The percentage of households earning between $25,000 and $39,999 out of all households in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Households Earning $40,000 to $60,000', 'ShortName': 'hh60incXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/hh60inc', 'Definition': 'The percentage of households earning between $40,000 and $59,999 out of all households in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Households Earning $60,000 to $75,000', 'ShortName': 'hh75incXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/hh75inc', 'Definition': 'The percentage of households earning between $60,000 and $74,999 out of all households in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Households Earning More than $75,000', 'ShortName': 'hhm75XX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/hhm75', 'Definition': 'The percentage of households earning more than $75,000 out of all households in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Inequality Index', 'ShortName': 'nan', 'Section': 'Census Demographics', 'Source': 'nan', 'IndicatorPath': '/indicators/Census Demographics/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of Family Households Living Below the Poverty Line', 'ShortName': 'hhpovXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/hhpov', 'Definition': 'This indicator measures the percentage of households whose income fell below the poverty threshold out of all households in an area. Federal and state governments use such estimates to allocate funds to local communities. Local communities use these estimates to identify the number of individuals or families eligible for various programs. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Children Living Below the Poverty Line', 'ShortName': 'hhchpovXX', 'Section': 'Census Demographics', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Census Demographics/hhchpov', 'Definition': 'This indicator measures the percentage of persons under the age of 18 living in households where the total income fell below the poverty threshold out of all children in households in an area. Federal and state governments use such estimates to allocate funds to local communities. Local communities use these estimates to identify the number of individuals or families eligible for various programs. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Median Price of Homes Sold', 'ShortName': 'saleprXX', 'Section': 'Housing and Community Development', 'Source': 'First American Real Estate Solutions', 'IndicatorPath': '/indicators/Housing and Community Development/salepr', 'Definition': 'The median home sales price is the middle value of the prices for which homes are sold (both market and private transactions) within a calendar year. The median value is used as opposed to the average so that both extremely high and extremely low prices do not distort the prices for which homes are sold. This measure does not take into account the assessed value of a property.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Median Number of Days on the Market', 'ShortName': 'domXX', 'Section': 'Housing and Community Development', 'Source': 'RBIntel, Inc.', 'IndicatorPath': '/indicators/Housing and Community Development/dom', 'Definition': 'The median number of days that homes listed for sale sit on the public market in a given area. This time period is from the date it is listed for sale till the day the contract of sale is signed. Private (non-listed) home sale transactions are not included in this indicator. The median days on market is used as opposed to the average so that both extremely high and extremely low days on the market do not distort the length of time for which homes are listed on the market.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Number of Homes Sold', 'ShortName': 'shomesXX', 'Section': 'Housing and Community Development', 'Source': 'First American Real Estate Solutions', 'IndicatorPath': '/indicators/Housing and Community Development/shomes', 'Definition': 'The total number of residential properties sold in a calendar year. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Percentage of Housing Units that are Owner-Occupied', 'ShortName': 'ownrocXX', 'Section': 'Housing and Community Development', 'Source': 'MdProperty View', 'IndicatorPath': '/indicators/Housing and Community Development/ownroc', 'Definition': 'The percentage of homeowners that are the principal residents of a particular residential property out of all residential properties. It is important to note that a portion of these owner-occupied properties may be subdivided and have tenants that pay rent and are not included in the calculation.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Percentage of Properties Under Mortgage Foreclosure', 'ShortName': 'foreXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Circuit Court', 'IndicatorPath': '/indicators/Housing and Community Development/fore', 'Definition': 'The percentage of properties where the lending company or loan servicer has filed a foreclosure proceeding with the Baltimore City Circuit Court out of all residential properties within an area. This is not a measure of actual foreclosures since not every property that receives a filing results in a property dispossession.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Percentage of Residential Properties that are Vacant and Abandoned', 'ShortName': 'vacantXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Department of Housing and Community Development', 'IndicatorPath': '/indicators/Housing and Community Development/vacant', 'Definition': 'The percentage of residential properties that have been classified as being vacant and abandoned by the Baltimore City Department of Housing out of all properties. Properties are classified as being vacant and abandoned if: the property is not habitable and appears boarded up or open to the elements; the property was designated as being vacant prior to the current year and still remains vacant; and the property is a multi-family structure where all units are considered to be vacant. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Percentage of Residential Properties with Housing Violations (Excluding Vacants)', 'ShortName': 'vioXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Department of Housing and Community Development', 'IndicatorPath': '/indicators/Housing and Community Development/vio', 'Definition': 'The percentage of residential properties that have received at least one housing code violation from the Baltimore City Department of Housing out of all properties. Properties whose façade, structure, and/or surrounding area violate the City’s Housing Code are issued a notice and are considered open till the property is found in compliance. A property may receive multiple violations. ', 'Years': '2010, 2011, 2012, 2013, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Percentage of Properties with Rehabilitation Permits Exceeding $5,000', 'ShortName': 'resrehabXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Department of Housing and Community Development', 'IndicatorPath': '/indicators/Housing and Community Development/resrehab', 'Definition': 'The percent of residential properties that have applied for and received a permit to renovate the interior and/or exterior of a property where the cost of renovation will exceed $5,000. The threshold of $5,000 is used to differentiate a minor and more significant renovation project. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Total Number of Residential Properties', 'ShortName': 'totalresXX', 'Section': 'Housing and Community Development', 'Source': 'MdProperty View', 'IndicatorPath': '/indicators/Housing and Community Development/totalres', 'Definition': 'The total number of residential properties located within an area as identified by Maryland Property View. It is important to note that that this indicator is a count of properties (single family homes, condominiums, and duplexes) and that a property can be comprised of multiple housing units. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Percentage of Residential Sales for Cash', 'ShortName': 'cashsaXX', 'Section': 'Housing and Community Development', 'Source': 'RBIntel, Inc.', 'IndicatorPath': '/indicators/Housing and Community Development/cashsa', 'Definition': 'The percent of homes and condominiums sold for cash out of all residential properties sold in a calendar year. These types of sales tend to signify investor-based purchases as homes purchased for cash either become rental properties or later sold again in an effort to generate a profit. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Percentage of Residential Sales in Foreclosure (REO)', 'ShortName': 'reosaXX', 'Section': 'Housing and Community Development', 'Source': 'RBIntel, Inc.', 'IndicatorPath': '/indicators/Housing and Community Development/reosa', 'Definition': 'The portion of the homes and condominiums sold that were identified as being owned by the bank (REO) out of all residential properties sold in a calendar year.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Percentage of Residential Tax Lien Sales', 'ShortName': 'taxlienXX', 'Section': 'Housing and Community Development', 'Source': 'BidBaltimore', 'IndicatorPath': '/indicators/Housing and Community Development/taxlien', 'Definition': 'The percentage of residential properties with city liens sold as tax certificates at the annual tax lien certificate sale held in May. Tax sales are used to collect delinquent real property taxes and other unpaid charges to the city, which are liens against the real property. The tax certificate sale is a public online auction of City lien interests on properties that occurs annually in May.', 'Years': '2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Number of Demolition Permits per 1,000 Residential Properties', 'ShortName': 'demperXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Department of Housing and Community Development', 'IndicatorPath': '/indicators/Housing and Community Development/demper', 'Definition': 'The number of permits issued for the demolition of residential buildings per 1,000 existing residential properties. The permits are analyzed by date of issue and not date of actual demolition. ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Number of New Construction Permits per 1,000 Residential Properties', 'ShortName': 'constperXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Department of Housing and Community Development', 'IndicatorPath': '/indicators/Housing and Community Development/constper', 'Definition': 'The number of permits issued for new residential buildings per 1,000 existing residential properties within a community. The permits are analyzed by date of issue and not date of completion. ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Percentage of Vacant Properties Owned by Baltimore City', 'ShortName': 'baltvacXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Department of Housing and Community Development', 'IndicatorPath': '/indicators/Housing and Community Development/baltvac', 'Definition': 'The percent of properties that are classified as being vacant and abandoned that are owned by Baltimore City. Baltimore City has come to own these properties through a variety of ways including (but not limited to) eminent domain, unpaid tax or water bills, and direct purchase.', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Affordability Index - Mortgage', 'ShortName': 'affordmXX', 'Section': 'Housing and Community Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Housing and Community Development/affordm', 'Definition': 'The percentage of households that pay more than 30% of their total household income on mortgage and other housing-related expenses. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Affordability Index - Rent', 'ShortName': 'affordrXX', 'Section': 'Housing and Community Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Housing and Community Development/affordr', 'Definition': 'The percentage of households that pay more than 30% of their total household income on rent and related expenses out of all households in an area. ', 'Years': '2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Number of Historic Tax Credits per 1,000 Residential Units', 'ShortName': 'histaxXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Department of Finance', 'IndicatorPath': '/indicators/Housing and Community Development/histax', 'Definition': 'The number of residential properties that received the Historic Tax Credit per 1,000 residential properties within an area. The credit is granted on the increased assessment directly resulting from qualified improvements. The duration of the credit is for 10 years, and is applicable to properties located in designated areas of significant historical value.', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Number of Homestead Tax Credits per 1,000 Residential Units', 'ShortName': 'homtaxXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Department of Finance', 'IndicatorPath': '/indicators/Housing and Community Development/homtax', 'Definition': 'The number of residential properties that received the homestead tax credit per 1,000 residential properties within an area. The Homestead Credit limits the increase in taxable assessments each year to a fixed percentage. Every county and municipality in Maryland is required to limit taxable assessment increases to 10% or less each year, with the Baltimore City rate capped at 4%.', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': "Number of Homeowner's Tax Credits per 1,000 Residential Units", 'ShortName': 'owntaxXX', 'Section': 'Housing and Community Development', 'Source': 'Baltimore City Department of Finance', 'IndicatorPath': '/indicators/Housing and Community Development/owntax', 'Definition': 'The number of residential properties that received the homeowners tax credit per 1,000 residential properties within an area. The homeowner’s tax credit sets a limit on the amount of property taxes any homeowner must pay based upon his or her income.', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent Residential Properties that do Not Receive Mail', 'ShortName': 'nomailXX', 'Section': 'Housing and Community Development', 'Source': 'U.S. Postal Service, U.S. Department of Housing and Urban Development', 'IndicatorPath': '/indicators/Housing and Community Development/nomail', 'Definition': 'The percentage of residential addresses for which the United States Postal Service has identified as being unoccupied (no mail collection) for a period of at least 90 days or longer. These properties may be habitable, but are not currently being occupied. It is important to note that a single residential property can contain more than one address.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Part 1 Crime Rate per 1,000 Residents', 'ShortName': 'crimeXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/crime', 'Definition': 'The Part 1 crime rate captures incidents of homicide, rape, aggravated assault, robbery, burglary, larceny, and auto theft that are reported to the Police Department. These incidents are per 1,000 residents in the neighborhood to allow for comparison across areas.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Daytime Crime Rate per 1,000 Population', 'ShortName': 'nan', 'Section': 'Crime and Safety', 'Source': 'nan', 'IndicatorPath': '/indicators/Crime and Safety/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Violent Crime Rate per 1,000 Residents', 'ShortName': 'violXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/viol', 'Definition': 'The violent crime rate measures the number of Part 1 crimes identified as being violent (homicide, rape, aggravated assault, and robbery) that are reported to the Police Department. These incidents are per 1,000 residents in the neighborhood to allow for comparison across areas.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Property Crime Rate per 1,000 Residents', 'ShortName': 'propXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/prop', 'Definition': 'The property crime rate measures the number of Part 1 crimes identified as being property-based (burglary and auto theft) that are reported to the Police Department. These incidents are per 1,000 residents in the neighborhood to allow for comparison across areas. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Domestic Violence Calls For Service per 1,000 Residents', 'ShortName': 'domvioXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/domvio', 'Definition': 'The rate of calls to emergency 911 for domestic violence per 1,000 residents in an area. Calls for service are used rather than actual crime incidents since domestic violence can be classified as one of several types of criminal offenses. It is important to also note that not every case of domestic violence is reported and some claims of abuse may be unfounded. ', 'Years': '2010, 2011, 2012'}}, {'Indicator': {'IndicatorName': 'Juvenile Arrest Rate per 1,000 Juveniles', 'ShortName': 'juvarrXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/juvarr', 'Definition': 'The number of persons aged 10 to 17 arrested per 1,000 juveniles that live in an area. This indicator is calculated by where the arrested juvenile was arrested and not by where the crime is committed. Arrests are used instead of crimes committed since not all juveniles that are arrested are charged with committing a crime. This indicator also excludes offenders who are later charged as adults for their crime(s).', 'Years': '2011, 2012, 2013, 2014, 2015'}}, {'Indicator': {'IndicatorName': 'Juvenile Arrest Rate for Violent Offenses per 1,000 Juveniles', 'ShortName': 'juvviolXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/juvviol', 'Definition': 'The number of persons aged 10 to 17 arrested for violent offenses per 1,000 juveniles that live in an area. Violent offenses may include homicide, rape, assault (with or without a weapon), and robbery. This indicator is calculated by where the arrested juvenile was arrested and not by where the crime is committed. Arrests are used instead of crimes committed since not all juveniles that are arrested are charged with committing a crime. This indicator also excludes offenders who are later charged as adults for their crime(s).', 'Years': '2011, 2012, 2013, 2014, 2015'}}, {'Indicator': {'IndicatorName': 'Juvenile Arrest Rate for Drug-Related Offenses per 1,000 Juveniles', 'ShortName': 'juvdrugXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/juvdrug', 'Definition': 'The number of persons aged 10 to 17 arrested for drug-related offenses per 1,000 juveniles that live in an area. Drug-related offenses include arrests for possession, sale, manufacture, or abuse of illegal drugs, including alcohol. This indicator is calculated by where the arrested juvenile was arrested and not by where the crime is committed. Arrests are used instead of crimes committed since not all juveniles that are arrested are charged with committing a crime. This indicator also excludes offenders who are later charged as adults for their crime(s).', 'Years': '2011, 2012, 2013, 2014, 2015'}}, {'Indicator': {'IndicatorName': 'Number of Shootings per 1,000 Residents', 'ShortName': 'shootXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/shoot', 'Definition': 'The rate of 911 calls for shootings per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Number of Gun-Related Homicides per 1,000 Residents', 'ShortName': 'gunhomXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/gunhom', 'Definition': 'The rate of homicides by firearm as reported in the Part 1 crime data per 1,000 residents in an area. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Number of Common Assault Calls for Service per 1,000 Residents', 'ShortName': 'casltXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/caslt', 'Definition': 'The rate of calls for assaults that do not involve a weapon per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Number of Narcotics Calls for Service per 1,000 Residents', 'ShortName': 'narcXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/narc', 'Definition': 'The rate of calls for narcotics per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Number of Automobile Accident Calls for Service per 1,000 Residents', 'ShortName': 'caraccXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/caracc', 'Definition': 'The rate of calls for accidents involving motor vehicles per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident. Additionally, not every accident involving a motor vehicle is reported to the Police Department. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Rate of Fire and EMS Calls for Service per 1,000 Residents', 'ShortName': 'nan', 'Section': 'Crime and Safety', 'Source': 'nan', 'IndicatorPath': '/indicators/Crime and Safety/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Average Fire and EMS Response Time', 'ShortName': 'nan', 'Section': 'Crime and Safety', 'Source': 'nan', 'IndicatorPath': '/indicators/Crime and Safety/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Number of Children Enrolled in Head Start Programs', 'ShortName': 'nan', 'Section': 'Education and Youth', 'Source': 'nan', 'IndicatorPath': '/indicators/Education and Youth/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Number of Students Ever Attended 1st - 5th Grade', 'ShortName': 'eattendXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/eattend', 'Definition': 'The number of children who have registered for and attend 1st through 5th grade at a Baltimore City Public School at any point during the school year. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Number of Students Ever Attended 6th - 8th Grade', 'ShortName': 'mattendXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/mattend', 'Definition': 'The number of children who have registered for and attend 6th through 8th grade at a Baltimore City Public School at any point in the school year. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Number of Students Ever Attended 9th - 12th Grade', 'ShortName': 'hsattendXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/hsattend', 'Definition': 'The number of children who have registered for and attend 9th through 12th grade at a Baltimore City Public School at any point in the school year.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Percent of Students Enolled in CTE Programs', 'ShortName': 'nan', 'Section': 'Education and Youth', 'Source': 'nan', 'IndicatorPath': '/indicators/Education and Youth/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of Students that are African American (non-Hispanic)', 'ShortName': 'aastudXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/aastud', 'Definition': 'The percentage of Black/African American students of any grade that attend any Baltimore City Public School out of all public school students within an area in a school year.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Percent of Students that are White (non-Hispanic)', 'ShortName': 'wstudXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/wstud', 'Definition': 'The percentage of white (non-Hispanic) students of any grade that attend any Baltimore City Public School out of all public school students within an area in a school year. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Percent of Students that are Hispanic', 'ShortName': 'hstudXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/hstud', 'Definition': 'The percentage of students of any grade level who identify their ethnicity as being Hispanic that attend any Baltimore City Public School out of all public school students within an area in a school year. Ethnicity is separate from a student’s race. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Percent of 1st-5th Grade Students that are Chronically Absent (Missing at least 20 days)', 'ShortName': 'abseXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/abse', 'Definition': 'The percentage of 1st-5th grade students that were recognized as being absent from public school 20 or more days out of all students. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019'}}, {'Indicator': {'IndicatorName': 'Percent of 6th-8th Grade Students that are Chronically Absent (Missing at least 20 days)', 'ShortName': 'absmdXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/absmd', 'Definition': 'The percentage of 6th-8th grade students that were recognized as being absent from public school 20 or more days out of all students. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019'}}, {'Indicator': {'IndicatorName': 'Percent of 9th-12th Grade Students that are Chronically Absent (Missing at least 20 days)', 'ShortName': 'abshsXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/abshs', 'Definition': ' The percentage of 9th-12th grade students that were recognized as being absent from public school 20 or more days out of all students. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019'}}, {'Indicator': {'IndicatorName': 'Percentage of Students Suspended or Expelled During School Year', 'ShortName': 'suspXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/susp', 'Definition': 'The percentage of students of any grade level that were formally suspended or expelled for any reason during the school year out of all public school students within an area. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013'}}, {'Indicator': {'IndicatorName': 'Percentage of Students Receiving Free or Reduced Meals', 'ShortName': 'farmsXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/farms', 'Definition': 'The percentage of students of any grade that are eligible for and received free or reduced school meals out of all public school students. Eligibility for this program is based on the student’s household income. ', 'Years': '2009-2010, 2010-2011, 2011-2012'}}, {'Indicator': {'IndicatorName': 'Percentage of Students Enrolled in Special Education Programs', 'ShortName': 'spedXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/sped', 'Definition': 'The percentage of students of any grade that are eligible for and participated in public school special education programs out of all students. This includes all students with any diagnosed disability.', 'Years': '2009-2010, 2010-2011, 2011-2012'}}, {'Indicator': {'IndicatorName': 'Percentage of Students Enrolled in After School Programs', 'ShortName': 'nan', 'Section': 'Education and Youth', 'Source': 'nan', 'IndicatorPath': '/indicators/Education and Youth/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Kindergarten School Readiness', 'ShortName': 'readyXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/ready', 'Definition': 'The percentage of children whose composite score indicates full school readiness out of all kindergarten school children tested within an area in a school year. The Maryland Model for School Readiness (MMSR) is an assessment and instructional system that was designed to provide parents, teachers, and early childhood providers with a common understanding of what children know and are able to do upon entering school. Under the MMSR system, all children entering kindergarten are assessed for level of mastery across several learning domains. These domains include: social and personal development; language and literacy; mathematical thinking; scientific thinking; social studies; the arts; and physical development and health. Kindergarten teachers must evaluate students during the first few months of the kindergarten year using selected Work Sampling System (WSS) indicators and report their ratings by the end of November of each year to the state. ', 'Years': '2010-2011, 2011-2012'}}, {'Indicator': {'IndicatorName': 'Percentage of 3rd Grade Students Passing MSA Math', 'ShortName': 'math3XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/math3', 'Definition': 'The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'Percentage of 3rd Grade Students Passing MSA Reading', 'ShortName': 'read3XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/read3', 'Definition': 'The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'Percentage of 5th Grade Students Passing MSA Math', 'ShortName': 'math5XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/math5', 'Definition': 'The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'Percentage of 5th Grade Students Passing MSA Reading', 'ShortName': 'read5XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/read5', 'Definition': 'The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'Percentage of 8th Grade Students Passing MSA Math', 'ShortName': 'math8XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/math8', 'Definition': 'The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'Percentage of 8th Grade Students Passing MSA Reading', 'ShortName': 'read8XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/read8', 'Definition': 'The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'Percentage of Students Passing H.S.A. English ', 'ShortName': 'hsaengXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/hsaeng', 'Definition': 'The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'Percentage of Students Passing H.S.A. Biology', 'ShortName': 'hsabioXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/hsabio', 'Definition': 'The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'Percentage of Students Passing H.S.A. Government', 'ShortName': 'hsagovXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/hsagov', 'Definition': 'The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'Percentage of Students Passing H.S.A. Algebra', 'ShortName': 'hsaalgXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/hsaalg', 'Definition': 'The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014'}}, {'Indicator': {'IndicatorName': 'High School Dropout/Withdrawl Rate', 'ShortName': 'dropXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/drop', 'Definition': 'The percentage of 9th through 12th graders who withdrew from public school out of all high school students in a school year. Withdraw codes are used as a proxy for dropping out of school based upon the expectation that withdrawn students are no longer receiving educational services. A dropout is defined as a student who, for any reason other than death, leaves school before graduation or the completion of a Maryland-approved education program and is not known to enroll in another school or State-approved program during a current school year.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'High School Completion Rate', 'ShortName': 'complXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/compl', 'Definition': 'The percentage of 12th graders in a school year that successfully completed high school out of all 12th graders within an area. Completers are identified as completing their program of study at the high school level and satisfying the graduation requirements for a Maryland High School Diploma or the requirements for a Maryland Certificate of Program Completion.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Persons Receiving a GED', 'ShortName': 'nan', 'Section': 'Education and Youth', 'Source': 'nan', 'IndicatorPath': '/indicators/Education and Youth/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of Students Switching Schools within School Year', 'ShortName': 'sclswXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/sclsw', 'Definition': 'The percentage of 1st through 12th graders who change schools out of all students in a school year. Students must have attended both schools for which they were registered for at least one day. Additionally, this indicator only identifies the share of students that change schools for any reasons and not the frequency, number of school switches, or change in residences in a school year. The percentage reflects the last home address available for the student who changed schools. This may or may not be the home address provided for the first school that they are registered to attend. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019'}}, {'Indicator': {'IndicatorName': 'Percentage of Students Attending Zoned School ', 'ShortName': 'nan', 'Section': 'Education and Youth', 'Source': 'nan', 'IndicatorPath': '/indicators/Education and Youth/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Average Distance Travelled to School (6th-8th Grade)', 'ShortName': 'nan', 'Section': 'Education and Youth', 'Source': 'nan', 'IndicatorPath': '/indicators/Education and Youth/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Average Distance Travelled to School (9th-12th Grade)', 'ShortName': 'nan', 'Section': 'Education and Youth', 'Source': 'nan', 'IndicatorPath': '/indicators/Education and Youth/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percentage of Population aged 16-19 in School and/or Employed', 'ShortName': 'sclempXX', 'Section': 'Education and Youth', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Education and Youth/sclemp', 'Definition': 'The percentage of persons aged 16 to 19 who are in school and/or are employed out of all persons in their age cohort.', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Teen Birth Rate per 1,000 Females (Aged 15-19)', 'ShortName': 'teenbirXX', 'Section': 'Children and Family Health', 'Source': 'Maryland Department of Vital Statistics', 'IndicatorPath': '/indicators/Children and Family Health/teenbir', 'Definition': 'The rate of female teens aged 15-19 that gave birth per 1,000 females aged 15-19. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Births Delivered at Term (37-42 Weeks)', 'ShortName': 'termbirXX', 'Section': 'Children and Family Health', 'Source': 'Maryland Department of Vital Statistics', 'IndicatorPath': '/indicators/Children and Family Health/termbir', 'Definition': 'The percentage of births delivered at term measures the percentage of births in a calendar year where the baby is delivered between 37 and 42 weeks of gestation.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Babies Born with a Satisfactory Birth Weight', 'ShortName': 'birthwtXX', 'Section': 'Children and Family Health', 'Source': 'Maryland Department of Vital Statistics', 'IndicatorPath': '/indicators/Children and Family Health/birthwt', 'Definition': 'The percentage of children born with a birth weight of at least 5 ½ pounds out of all births in the area. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Births Where the Mother Received Early Prenatal Care (First Trimester)', 'ShortName': 'prenatalXX', 'Section': 'Children and Family Health', 'Source': 'Maryland Department of Vital Statistics', 'IndicatorPath': '/indicators/Children and Family Health/prenatal', 'Definition': 'The percentage of births where the mother received prenatal care during the first trimester of the pregnancy in a calendar year out of all births within an area. This information is calculated by the Vital Statistics registration information collected from each live birth. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Number of Children (Aged 0-6) Tested for Elevated Blood Lead Levels', 'ShortName': 'leadtestXX', 'Section': 'Children and Family Health', 'Source': 'Maryland Department of the Environment, Lead Poisoning Prevention Program', 'IndicatorPath': '/indicators/Children and Family Health/leadtest', 'Definition': 'This indicator reflects the total number of children aged 0-6 who are tested for the presence of blood lead in a calendar year.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Children (Aged 0-6) with Elevated Blood Lead Levels', 'ShortName': 'ebllXX', 'Section': 'Children and Family Health', 'Source': 'Maryland Department of the Environment, Lead Poisoning Prevention Program', 'IndicatorPath': '/indicators/Children and Family Health/ebll', 'Definition': 'The number of children aged 0-6 that are found to either have elevated blood lead levels (≥10Mg/dL) or lead poisoning (≥20 Mg/dL) out of the number of children tested within an area in a calendar year. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Lead Violations per 1,000 Residential Units', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Health Department', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of Families Receiving TANF', 'ShortName': 'tanfXX', 'Section': 'Children and Family Health', 'Source': 'Maryland Department of Human Resources', 'IndicatorPath': '/indicators/Children and Family Health/tanf', 'Definition': 'Temporary Assistance for Needy Families (TANF) is a federal assistance program. The Act provides temporary financial assistance while aiming to get people off of that assistance, primarily through employment. ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Persons receiving SNAP', 'ShortName': 'snapXX', 'Section': 'Children and Family Health', 'Source': 'Maryland Department of Human Resources', 'IndicatorPath': '/indicators/Children and Family Health/snap', 'Definition': 'The Supplemental Nutrition Assistance Program (SNAP), formerly known as Food Stamps, helps low-income households buy the food they need for good health. ', 'Years': '2019'}}, {'Indicator': {'IndicatorName': 'Fetal Mortality Rate', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'nan', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Liquor Outlet Density (per 1,000 Residents)', 'ShortName': 'liquorXX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Liquor Board', 'IndicatorPath': '/indicators/Children and Family Health/liquor', 'Definition': "This indicator reflects the number of business establishments that possess a Class A (Off Sale package goods no on-premises consumption - 6 days, 6:00 a.m.- Midnight. No Sunday sales except Sundays between Thanksgiving Day and New Year's Day upon issuance of a special license for each Sunday) or BD7 (tavern) business license that allows them to sell beer, wine, or liquor. Other liquor licenses to restaurants or on-premise consumption were not included in this analysis. This number is provided by 1,000 residents to allow for comparison across neighborhoods.", 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Fast Food Outlet Density (per 1,000 Residents)', 'ShortName': 'fastfdXX', 'Section': 'Children and Family Health', 'Source': 'Johns Hopkins University, Center for a Livable Future', 'IndicatorPath': '/indicators/Children and Family Health/fastfd', 'Definition': 'The Johns Hopkins Center for a Livable Future (CLF) obtained the food permit list from the Baltimore City Health Department in August 2011, which includes all sites that sell food, such as stores, restaurants and temporary locations such as farmers’ market stands and street carts. The restaurants were grouped into three categories, including full service restaurants, fast food chains and carryouts. Carryout and fast food chain restaurants were extracted from the restaurant layer and spatially joined with the 2010 Community Statistical Area (CSA) data layer, provided by BNIA-JFI. The prepared foods density, per 1,000 people, was calculated for each CSA using the CSA’s population and the total number of carryout and fast food restaurants, including vendors selling prepared foods in public markets, in each CSA.', 'Years': '2011, 2013, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Number of Persons calling UWCM 211 for Health-Related Services ', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'nan', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Rate of STDs per 1,000 Residents (Chlamydia, Gonorrhea, and Syphilis)', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'nan', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Rate of HIV/AIDS per 1,000 Residents', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'nan', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Life Expectancy', 'ShortName': 'lifexpXX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Health Department', 'IndicatorPath': '/indicators/Children and Family Health/lifexp', 'Definition': 'The average number of years a newborn can expect to live, assuming he or she experiences the currently prevailing rates of death through their lifespan. ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Infant Mortality Rate', 'ShortName': 'mort1XX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Health Department', 'IndicatorPath': '/indicators/Children and Family Health/mort1', 'Definition': 'The number of infant deaths (babies under one year of age) per 1,000 live births within the area in a five year period. This is the most stable and commonly measured indicator of mortality in this age group. ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Mortality by Age (1-14 Years old)', 'ShortName': 'mort14XX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Health Department', 'IndicatorPath': '/indicators/Children and Family Health/mort14', 'Definition': 'The number of deaths of persons between the ages of one and 14 per 10,000 persons within the area in a five year period. ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Mortality by Age (15-24 Years Old)', 'ShortName': 'mort24XX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Health Department', 'IndicatorPath': '/indicators/Children and Family Health/mort24', 'Definition': 'The number of deaths of persons between the ages of 15 and 24 per 10,000 persons within the area in a five year period.', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Mortality by Age (25-44 Years Old)', 'ShortName': 'mort44XX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Health Department', 'IndicatorPath': '/indicators/Children and Family Health/mort44', 'Definition': 'The number of deaths of persons between the ages of 25 and 44 per 10,000 persons within the area in a five year period.', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Mortality by Age (45-64 Years Old)', 'ShortName': 'mort64XX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Health Department', 'IndicatorPath': '/indicators/Children and Family Health/mort64', 'Definition': 'The number of deaths of persons between the ages of 45 and 64 per 10,000 persons within the area in a five year period. ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Mortality by Age (65-84 Years Old)', 'ShortName': 'mort84XX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Health Department', 'IndicatorPath': '/indicators/Children and Family Health/mort84', 'Definition': 'The number of deaths of persons between the ages of 65 and 84 per 10,000 persons within the area in a five year period.', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Mortality by Age (85 and Over)', 'ShortName': 'mort85XX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Health Department', 'IndicatorPath': '/indicators/Children and Family Health/mort85', 'Definition': 'The number of deaths of persons 85 years and older per 10,000 persons within the area in a five year period. ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Number of Overdose Calls for Service per 1,000 Residents', 'ShortName': 'overdXX', 'Section': 'Children and Family Health', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Children and Family Health/overd', 'Definition': 'The rate of 911 calls to police for overdoses per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident.', 'Years': '2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Causes of Death (analysis of top causes)', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'nan', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Causes of Death (analysis of top causes)', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'nan', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Causes of Death (analysis of top causes)', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'nan', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Causes of Death (analysis of top causes)', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'nan', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of persons with health insurance', 'ShortName': 'nan', 'Section': 'Children and Family Health', 'Source': 'nan', 'IndicatorPath': '/indicators/Children and Family Health/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Number of Persons with Library Cards per 1,000 Residents', 'ShortName': 'libcardXX', 'Section': 'Arts and Culture', 'Source': 'Enoch Pratt Free Library', 'IndicatorPath': '/indicators/Arts and Culture/libcard', 'Definition': 'The rate of persons per 1,000 residents that possess a valid public library system card. This includes all library card types (first card, juvenile, young adult, adult). ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Number of Event Permits Requested per 1,000 Residents', 'ShortName': 'artevntXX', 'Section': 'Arts and Culture', 'Source': 'ENVISTA, with permission from the Baltimore City Department of Transportation', 'IndicatorPath': '/indicators/Arts and Culture/artevnt', 'Definition': 'The number of event permits requested per 1,000 residents. Events include, but are not limited to, festivals, block parties, races, and parades. In the event of a large event, the central point is used to calculate the location of the request.', 'Years': '2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Public Art per 1,000 Residents', 'ShortName': 'publartxx', 'Section': 'Arts and Culture', 'Source': 'Baltimore Office of Promotion and the Arts', 'IndicatorPath': '/indicators/Arts and Culture/publart', 'Definition': 'The number of works of public art per 1,000 residents. These works include, but are not exclusive to, murals, monuments, sculptures, mosaics, and stained glass. The Baltimore Office of Promotion and the Arts tracks works created through the 1% for Public Art and Baltimore Mural Programs and maintains general inventories of public art and murals. Additional inventories of public art exist, but not at a comprehensive citywide scale and hence cannot be broken down into cross-neighborhood analyses.', 'Years': '2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Number of Businesses that are Arts-Related per 1,000 Residents', 'ShortName': 'artbusXX', 'Section': 'Arts and Culture', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Arts and Culture/artbus', 'Definition': 'The rate of businesses (both for-profit and non-profit) that are directly related to arts and culture per 1,000 residents. Arts-related businesses are defined as belonging to industries that allow for the consumption and enjoyment of arts and culture. The following industries are identified by their primary NAICS code: music, literary, and visual arts-related retail/supplies (451140, 451211, 451220); art dealers (453920, 453920); libraries (519120); motion picture and film (521310, 532230); art schools (611610); performing arts (711110, 711120, 711130, 711190); independent artists, writers, and performers (711510); museums (712110); historical sites (712120); and zoos, gardens and nature parks (712130, 712190). The following industries are identified by their primary SIC codes: designers (152106); art publishers (274101), music, literary, and visual arts-related retail/supplies (393101, 519202, 573608, 573609, 593201, 594201, 594205, 594501, 594520, 594601, 599965, 769969); art galleries, dealers, and consultants (599969, 599988, 599989); photography (722121); calligraphers (733607); embroidery (738942); theatres (783201, 792207); theatrical support (792211, 792212); musical and live entertainment (792903, 792905, 792906, 792908, 792917, 792918, 792927); parks (799951); art and music instruction (804958, 829915, 829919); libraries (823111); museums (841201); arts organizations (841202); zoos (842201); writers (899903); visual artists (899907, 899912); art restoring (899908); and music arrangers and composers (899921).', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Total Employment in Arts-Related Businesses', 'ShortName': 'artempXX', 'Section': 'Arts and Culture', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Arts and Culture/artemp', 'Definition': 'The number of persons employed in arts-related businesses (both for-profit and non-profit). This number does not count those persons who identify themselves as being artists and does not count sole proprietorships or persons who work part-time in the arts. The same industries used to calculate the rate of arts-related businesses are used to calculate total employment in arts-related businesses. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percentage of Businesses that are Non-Profits', 'ShortName': 'nan', 'Section': 'Arts and Culture', 'Source': 'nan', 'IndicatorPath': '/indicators/Arts and Culture/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent Population 16-64 Employed', 'ShortName': 'emplXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Workforce and Economic Development/empl', 'Definition': 'The percent of persons between the ages of 16 and 64 formally employed or self-employed and earning a formal income. It is used to understand how many persons are working out of the entire population, not just those in the labor force (persons who may be looking for work or working). ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent Population 16-64 Unemployed and Looking for Work', 'ShortName': 'unemplXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Workforce and Economic Development/unempl', 'Definition': 'The percent of persons between the ages of 16 and 64 not working out of all persons, not just those in the labor force (persons who may be looking for work). These persons are seeking work that pays a formal income. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent Population 16-64 Not in Labor Force', 'ShortName': 'nilfXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Workforce and Economic Development/nilf', 'Definition': 'The percent of persons who are not in the labor force out of all persons between the ages of 16 and 64 in the area. There are several reasons why persons may not be included in the labor force. These reasons may include: they are caretakers for children or other family members; they attend school or job training; they may have a disability; and they are discouraged or frustrated and have given up seeking a job or have a history that may include criminal activity. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Unemployment Rate', 'ShortName': 'unemprXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Workforce and Economic Development/unempr', 'Definition': 'The percent of persons between the ages of 16 and 64 that are in the labor force (and are looking for work) but are not currently working. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent Population (25 Years and over) With Less Than a High School Diploma or GED', 'ShortName': 'lesshsXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Workforce and Economic Development/lesshs', 'Definition': 'The percentage of persons that have not completed, graduated, or received a high school diploma or GED. This is a standard indicator used to measure the portion of the population with less than a basic level of skills needed for the workplace. Persons under the age of 25 are not included in this analysis since many of these persons are still attending various levels of schooling. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent Population (25 Years and over) With High School Diploma and Some College or Associates Degree', 'ShortName': 'hsdiplXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Workforce and Economic Development/hsdipl', 'Definition': "The percentage of persons that have completed, graduated, or received a high school diploma or GED and also have taken some college courses or completed their Associate's degree. This is a standard indicator used to measure the portion of the population with a basic level of skills needed for the workplace. Persons under the age of 25 are not included in this analysis since many of these persons are still attending various levels of schooling. ", 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': "Percent Population (25 Years and over) with a Bachelor's Degree or Above", 'ShortName': 'bahigherXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Workforce and Economic Development/bahigher', 'Definition': 'The percentage of persons that have completed, graduated, or received a Bachelor’s or an advanced degree. This is an indicator used to measure the portion of the population having an advanced level of skills needed for the workplace. Persons under the age of 25 are not included in this analysis since many of these persons are still attending various levels of schooling. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Total Number of Commercial Properties', 'ShortName': 'compropXX', 'Section': 'Workforce and Economic Development', 'Source': 'MdProperty View', 'IndicatorPath': '/indicators/Workforce and Economic Development/comprop', 'Definition': 'The total number of commercial properties located within an area in a particular year. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Percent of Commercial Properties with Rehab Permits Above $5,000', 'ShortName': 'crehabXX', 'Section': 'Workforce and Economic Development', 'Source': 'Baltimore City Department of Housing', 'IndicatorPath': '/indicators/Workforce and Economic Development/crehab', 'Definition': 'The percentage of properties that are investing within their current establishment and not the level of their investment. Permits for work below $5,000 are considered to be minor and not included in this indicator. A single establishment can apply for and receive multiple permits. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Total Number of Businesses', 'ShortName': 'numbusXX', 'Section': 'Workforce and Economic Development', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Workforce and Economic Development/numbus', 'Definition': 'The total number of businesses (both for-profit and non-profit) within an area at a single time in a year. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Total Number of Employees', 'ShortName': 'totempXX', 'Section': 'Workforce and Economic Development', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Workforce and Economic Development/totemp', 'Definition': 'The total number of persons employed by businesses (both for-profit and non-profit) within an area at a single time in a year. ', 'Years': '2010, 2011, 2012, 2013'}}, {'Indicator': {'IndicatorName': 'Number of Businesses with Under 50 Employees', 'ShortName': 'smlbusXX', 'Section': 'Workforce and Economic Development', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Workforce and Economic Development/smlbus', 'Definition': 'The total number of businesses (both for-profit and non-profit) that report having less than 50 persons employed within an area at a single time in a year. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Employed Residents who Work Outside the City', 'ShortName': 'wrkoutXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, Longitudinal Employer-Household Dynamics', 'IndicatorPath': '/indicators/Workforce and Economic Development/wrkout', 'Definition': 'The percentage of workers that are employed by jobs located outside of Baltimore City. Only persons who report being employed and are at least 16 years old are included in the analysis. ', 'Years': '2010, 2014, 2015, 2016, 2017, 2018'}}, {'Indicator': {'IndicatorName': 'Total Dollar Amount Invested in Small Businesses per 50 Businesses', 'ShortName': 'smlinvstXX', 'Section': 'Workforce and Economic Development', 'Source': 'Johns Hopkins University, 21st Century Cities Initiative', 'IndicatorPath': '/indicators/Workforce and Economic Development/smlinvst', 'Definition': 'The total dollar amount invested in businesses with fewer than 500 employees per 50 businesses. Small business lending data to include FFIEC insured bank loans under $1 million to businesses made by large banks; venture capital investments; US Export-Import Bank loans; Small Business Innovation Research (SBIR) and Small business Technology Transfer Research (STTR) grants; government, philanthropic, and institutional grants supporting small businesses; Maryland Department of Commerce loans; State of Maryland Neighborhood BusinessWorks loans; Baltimore Development Corporation loans; and Small Business Administration 7a and 504 loans.', 'Years': '2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Residential Mortgages Originated or Approved', 'ShortName': 'hmdaXX', 'Section': 'Housing and Community Development', 'Source': 'Consumer Financial Protection Bureau', 'IndicatorPath': '/indicators/Housing and Community Development/hmda', 'Definition': 'The percent of first lien mortgage applications for single family homes that were originated or approved out of all applications in the area. The Home Mortgage Disclosure Act (HMDA) requires many financial institutions to maintain, report, and publicly disclose information about mortgages in neighborhoods. ', 'Years': '2019'}}, {'Indicator': {'IndicatorName': 'Number of Banks and Bank Branches per 1,000 Residents', 'ShortName': 'banksXX', 'Section': 'Workforce and Economic Development', 'Source': 'Federal Deposit Insurance Corporation', 'IndicatorPath': '/indicators/Workforce and Economic Development/banks', 'Definition': 'The number of banks and bank branches per 1,000 residents within an area. ', 'Years': '2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Businesses that are 1 Year old or Less', 'ShortName': 'biz1_XX', 'Section': 'Workforce and Economic Development', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Workforce and Economic Development/biz1_', 'Definition': 'The percentage of businesses (both for-profit and non-profit) that report their establishment as being one year old or less. The age of the business is determined by the year that the first year they appeared in the InfoUSA database. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Businesses that are 2 Years old or Less', 'ShortName': 'biz2_XX', 'Section': 'Workforce and Economic Development', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Workforce and Economic Development/biz2_', 'Definition': 'The percentage of businesses (both for-profit and non-profit) that report their establishment as being two years old or less. The age of the business is determined by the year that the first year they appeared in the business database. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Businesses that are 4 Years old or Less', 'ShortName': 'biz4_XX', 'Section': 'Workforce and Economic Development', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Workforce and Economic Development/biz4_', 'Definition': 'The percentage of businesses (both for-profit and non-profit) that report their establishment as being four years old or less. The age of the business is determined by the year that the first year they appeared in the business database. A business that has been in operation more than four years has a greater likelihood of remaining open for a longer period of time. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Adult Population on Parole/Probation', 'ShortName': 'prbprlXX', 'Section': 'Workforce and Economic Development', 'Source': 'nan', 'IndicatorPath': '/indicators/Workforce and Economic Development/prbprl', 'Definition': 'The percentage of the population age 18 and older that are on parole or probation.', 'Years': '2013'}}, {'Indicator': {'IndicatorName': 'Percent of CSA that is Either Low or Moderate income (by Census tract)', 'ShortName': 'nan', 'Section': 'Workforce and Economic Development', 'Source': 'nan', 'IndicatorPath': '/indicators/Workforce and Economic Development/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of persons in MOED training programs (per 1,000 Residents)', 'ShortName': 'nan', 'Section': 'Workforce and Economic Development', 'Source': 'nan', 'IndicatorPath': '/indicators/Workforce and Economic Development/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of Households with No Internet at Home', 'ShortName': 'nohhintXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Workforce and Economic Development/nohhint', 'Definition': 'Percent of households with no home Internet of any kindThe percentage of households without an internet subscription at home.', 'Years': '2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Number of Businesses by Selected Neighborhood Industry (NAICS Sectors)', 'ShortName': 'neiindXX', 'Section': 'Workforce and Economic Development', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Workforce and Economic Development/neiind', 'Definition': 'The number of businesses (both for-profit and non-profit) that provide products and services to local residents. The industries included in this indicator are: Retail Trade (NAICS 44-45); Finance and Insurance (NAICS 52); Professional, Scientific, and Technical Services (NAICS 54); Health Care and Social Assistance (NAICS 62); Arts, Entertainment, and Recreation (NAICS 71); Accommodation and Food Services (NAICS 72); and Other Services except Public Administration (NAICS 81). The primary industry reported by each business was used to determine their inclusion. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Neighborhood Businesses per 1,000 Residents (NAICS Sectors)', 'ShortName': 'neibusXX', 'Section': 'Workforce and Economic Development', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Workforce and Economic Development/neibus', 'Definition': 'The number of businesses (both for-profit and non-profit) that provide products and services to local residents per 1,000. The industries included in this indicator are: Retail Trade (NAICS 44-45); Finance and Insurance (NAICS 52); Professional, Scientific, and Technical Services (NAICS 54); Health Care and Social Assistance (NAICS 62); Arts, Entertainment, and Recreation (NAICS 71); Accommodation and Food Services (NAICS 72); and Other Services except Public Administration (NAICS 81). The primary industry reported by each business was used to deter-mine their inclusion. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Total number of Employees by Selected Neighborhood Industry (NAICS Sectors)', 'ShortName': 'neiempXX', 'Section': 'Workforce and Economic Development', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Workforce and Economic Development/neiemp', 'Definition': 'The number of persons employed by businesses (both for-profit and non-profit) that provide products and services to local residents. The industries included in this indicator are: Retail Trade (NAICS 44-45); Finance and Insurance (NAICS 52); Professional, Scientific, and Technical Services (NAICS 54); Health Care and Social Assistance (NAICS 62); Arts, Entertainment, and Recreation (NAICS 71); Accommodation and Food Services (NAICS 72); and Other Services except Public Administration (NAICS 81). The primary industry reported by each business was used to determine their inclusion. The persons employed by these businesses may not necessarily live in the neighborhood where the business is located. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Percent of Population (Over the Age of 18) Who are Registered to Vote', 'ShortName': 'regvoteXX', 'Section': 'Sustainability', 'Source': 'Baltimore City Board of Elections', 'IndicatorPath': '/indicators/Sustainability/regvote', 'Definition': 'The percentage of persons over the age of 18 registered to vote out of all persons 18 years and over.', 'Years': '2010, 2012, 2014, 2016, 2018'}}, {'Indicator': {'IndicatorName': 'Percent Population (Over the Age of 18) Who Voted in the General Election', 'ShortName': 'votedXX', 'Section': 'Sustainability', 'Source': 'Baltimore City Board of Elections', 'IndicatorPath': '/indicators/Sustainability/voted', 'Definition': 'The percentage of persons who voted in the last general election out of all registered voters. ', 'Years': '2010, 2012, 2014, 2016, 2018'}}, {'Indicator': {'IndicatorName': 'Rate of Dirty Streets and Alleys Reports per 1,000 Residents', 'ShortName': 'dirtystXX', 'Section': 'Sustainability', 'Source': 'Baltimore City CitiStat', 'IndicatorPath': '/indicators/Sustainability/dirtyst', 'Definition': 'The rate of service requests for dirty streets and alleys through Baltimore’s 311 system per 1,000 residents. More than one service request may be made for the same issue but is logged as a unique request.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Rate of Clogged Storm Drain Reports per 1,000 Residents', 'ShortName': 'cloggedXX', 'Section': 'Sustainability', 'Source': 'Baltimore City CitiStat', 'IndicatorPath': '/indicators/Sustainability/clogged', 'Definition': 'The rate of service requests for addressing clogged storm drains made through Baltimore’s 311 system per 1,000 residents. More than one service request may be made for the same issue but is logged as a unique request.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Percent of Population that Drove Alone to Work', 'ShortName': 'drvaloneXX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/drvalone', 'Definition': 'The percentage of commuters driving alone out of all commuters aged 16 and above. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Population that Carpool to Work', 'ShortName': 'carpoolXX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/carpool', 'Definition': 'The percentage of commuters that carpool out of all commuters aged 16 and above. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Population that Uses Public Transportation to Get to Work', 'ShortName': 'pubtranXX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/pubtran', 'Definition': 'The percentage of commuters that use public transit out of all commuters aged 16 and above.', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Population that Walks to Work', 'ShortName': 'walkedXX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/walked', 'Definition': 'The percentage of commuters that walk to work out of all commuters aged 16 and above.', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Employed Population with Travel Time to Work of 0-14 Minutes', 'ShortName': 'trav14XX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/trav14', 'Definition': 'The percentage of commuters that spend less than 15 minutes commuting to work out of all commuters aged 16 and above. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Employed Population with Travel Time to Work of 15-29 Minutes', 'ShortName': 'trav29XX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/trav29', 'Definition': 'The percentage of commuters that spend between 15 and 29 minutes commuting to work out of all commuters aged 16 and above. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Employed Population with Travel Time to Work of 30-44 Minutes', 'ShortName': 'trav44XX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/trav44', 'Definition': 'The percentage of commuters that spend between 30 and 44 minutes travelling to work out of all commuters aged 16 and above. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Employed Population with Travel Time to Work of 45 Minutes and Over', 'ShortName': 'trav45XX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/trav45', 'Definition': 'The percentage of commuters that spend more than 45 minutes travelling to work out of all commuters aged 16 and above. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Area Covered by Trees', 'ShortName': 'treesXX', 'Section': 'Sustainability', 'Source': 'University of Vermont Spatial Analysis Lab', 'IndicatorPath': '/indicators/Sustainability/trees', 'Definition': "The percent of total land area comprised of tree canopy. The primary sources for this land cover layer were 2004 pan-sharpened 1m Ikonos satellite imagery, a normalized Digital Surface Model (nDSM) derived from 2006 LiDAR data, and LiDAR intensity data resulting from the 2006 acquisition. Other sources of data include the City's planimetric GIS database (building footprints and road casing polygons). The land cover classification was performed using automated object-based image analysis (OBIA) techniques in Definiens Developer/eCognition Server. No accuracy assessment was conducted, but the dataset was thoroughly reviewed at a scale of 1:2000. Over 370 corrections were made to the classification. ", 'Years': '2007, 2015, 2017'}}, {'Indicator': {'IndicatorName': 'Air Quality Risk', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of Area Covered by Impervious Surface', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Number of Community Managed Open Spaces', 'ShortName': 'cmosXX', 'Section': 'Sustainability', 'Source': 'Baltimore Neighborhood Indicators Alliance - Jacob France Institute', 'IndicatorPath': '/indicators/Sustainability/cmos', 'Definition': 'The number of community managed open spaces in an area that include community gardens (food-producing or ornamental), Adopt-A-Lots, or some other green space managed by the community. ', 'Years': '2011, 2014, 2015'}}, {'Indicator': {'IndicatorName': 'Median Daily Water Consumption', 'ShortName': 'watercXX', 'Section': 'Sustainability', 'Source': 'Baltimore City Department of Public Works', 'IndicatorPath': '/indicators/Sustainability/waterc', 'Definition': 'The median daily average water consumption of all city meters registering greater than 0.0 cubic meters per day.', 'Years': '2011'}}, {'Indicator': {'IndicatorName': 'Number of Downspout Disconnections per 1,000 Residential Units', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Number of Public Trashcans', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Rate of Sewer/Water Main Breaks per 1,000 Residents', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Natural Gas Utilization', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Energy Use', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of Residences Heated by Utility Gas', 'ShortName': 'heatgasXX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/heatgas', 'Definition': 'The percentage of homes that use utility gas for heat and cooking out of all homes. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Residences Heated by Electricity', 'ShortName': 'elheatXX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/elheat', 'Definition': 'The percentage of homes that use electricity for heat and cooking out of all homes. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Percent of Households with No Vehicles Available', 'ShortName': 'novhclXX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/novhcl', 'Definition': 'The percentage of households that do not have a personal vehicle available for use out of all households in an area. ', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Number of Photovoltaic/Solar Permits', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of Homes Weatherized', 'ShortName': 'weatherXX', 'Section': 'Sustainability', 'Source': 'Maryland Department of Housing and Community Development', 'IndicatorPath': '/indicators/Sustainability/weather', 'Definition': 'The percent of residential properties that were eligible for and received weatherization assistance such as air sealing or furnace replacements. The Weatherization Assistance Program helps eligible low-income households lower their energy costs by increasing the energy efficiency of their homes, while ensuring their health and safety. ', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016'}}, {'Indicator': {'IndicatorName': 'Walk Score', 'ShortName': 'wlkscXX', 'Section': 'Sustainability', 'Source': 'Walk Score', 'IndicatorPath': '/indicators/Sustainability/wlksc', 'Definition': 'The Walk Score® is calculated by mapping out the distance to amenities in nine different categories (grocery stores, restaurants, shopping, coffee shops, banks, parks, schools, book stores/libraries, and entertainment) and are weighted according to importance. The distance to a location, counts, and weights determine a base score of an address, which is then normalized to a score from 0 to 100. More information on Walk Score can be found at http://www.walkscore.com/. ', 'Years': '2011, 2017'}}, {'Indicator': {'IndicatorName': 'Aggregate Number of Community Assets', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Number of Daily Bus Stop Loadings per 1,000 Residents', 'ShortName': 'busloadXX', 'Section': 'Sustainability', 'Source': 'Maryland Transit Administration', 'IndicatorPath': '/indicators/Sustainability/busload', 'Definition': 'The median number of daily passengers getting on and off MTA buses by community.', 'Years': '2017, 2018'}}, {'Indicator': {'IndicatorName': 'Number of Bike Racks per 1,000 Residents', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Road Quality', 'ShortName': 'nan', 'Section': 'Sustainability', 'Source': 'nan', 'IndicatorPath': '/indicators/Sustainability/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Number of Miles of Bike Lanes', 'ShortName': 'bklnXX', 'Section': 'Sustainability', 'Source': 'Department of Transportation', 'IndicatorPath': '/indicators/Sustainability/bkln', 'Definition': 'Measures the linear miles of designated bike lanes within the roadway system.', 'Years': '2012, 2020'}}, {'Indicator': {'IndicatorName': 'Percent of persons by occupation classification (major classifications)', 'ShortName': 'nan', 'Section': 'Workforce and Economic Development', 'Source': 'nan', 'IndicatorPath': '/indicators/Workforce and Economic Development/n', 'Definition': 'nan', 'Years': 'nan'}}, {'Indicator': {'IndicatorName': 'Percent of Population Using Other Means to Commute to Work (Taxi, Motorcycle, Bicycle, Other)', 'ShortName': 'othrcomXX', 'Section': 'Sustainability', 'Source': 'U.S. Census Bureau, American Community Survey', 'IndicatorPath': '/indicators/Sustainability/othrcom', 'Definition': 'The percentage of commuters that use other means to travel to work out of all commuters aged 16 and above.', 'Years': '2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019'}}, {'Indicator': {'IndicatorName': 'Number of Students Officially Enrolled in 1st - 5th Grade', 'ShortName': 'eenrolXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/eenrol', 'Definition': 'The number of children who have registered for and attend 1st through 5th grade at a Baltimore City Public School as of September 30th. This count only includes students enrolled in public schools. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Number of Students Officially Enrolled in 6th - 8th Grade', 'ShortName': 'menrolXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/menrol', 'Definition': 'The number of children who have registered for and attend 6th through 8th grade at a Baltimore City Public School as of September 30th. This count only includes students enrolled in public schools. ', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Number of Students Officially Enrolled in 9th - 12th Grade', 'ShortName': 'hsenrolXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/hsenrol', 'Definition': 'The number of children who have registered for and attend 9th through 12th grade at a Baltimore City Public School as of September 30th. This count only includes students enrolled in public schools.', 'Years': '2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020'}}, {'Indicator': {'IndicatorName': 'Average Healthy Food Availability Index', 'ShortName': 'hfaiXX', 'Section': 'Children and Family Health', 'Source': 'Johns Hopkins University, Center for a Livable Future', 'IndicatorPath': '/indicators/Children and Family Health/hfai', 'Definition': 'The Johns Hopkins Center for a Livable Future (CLF) calculated HFAI scores for all food stores in Baltimore, in summer 2012, using an adapted version of the NEMS-S (Nutrition Environment Measures Survey in Stores) tool. The NEMS-S tool was developed by researchers at the Rollins School of Public Health at Emory University to measure the nutritional environment of food retail stores and was designed to assess healthy food availability in grocery and convenience stores. CLF obtained a food permit list from the Baltimore City Health Department in August 2011, which includes all sites that sell food, such as stores, restaurants, and temporary locations such as farmers’ market stands and street carts. HFAI scores range from zero to 28.5, with higher scores indicating more availability of healthy and whole food in a food store.', 'Years': '2012, 2015'}}, {'Indicator': {'IndicatorName': 'Number of Trees Planted', 'ShortName': 'treeplntXX', 'Section': 'Sustainability', 'Source': 'TreeBaltimore', 'IndicatorPath': '/indicators/Sustainability/treeplnt', 'Definition': 'Measures the number of trees planted annually by the TreeBaltimore program. ', 'Years': '2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Rate of Housing Vouchers per 1,000 Rental Units', 'ShortName': 'hcvhouseXX', 'Section': 'Housing and Community Development', 'Source': 'Picture of Subsidized Housing, HUD', 'IndicatorPath': '/indicators/Housing and Community Development/hcvhouse', 'Definition': 'Measures the ability of housing voucher holders to find housing in the private rental market. The Housing Choice Voucher (HCV) program is the federal government’s largest low-income housing assistance program where people can seek housing in the private market. The maximum housing assistance is generally the lesser of the payment standard minus 30% of the family’s monthly adjusted income or the gross rent for the unit minus 30% of monthly adjusted income.', 'Years': '2013, 2014, 2015, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Rate of Businesses in the Creative Economy per 1,000 Residents', 'ShortName': 'cebusXX', 'Section': 'Arts and Culture', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Arts and Culture/cebus', 'Definition': 'The rate of businesses (both for-profit and non-profit) that are in the creative economy per 1,000 residents. The creative economy is defined as industries that use and support artistic and cultural skillsets to attract and generate capital, knowledge, and information. Arts-based businesses are included in the creative economy. In addition to the industries included in the rate of arts-based businesses indictor, the following industries are identified by their primary NAICS code: Textiles (313220); Commercial Printing (323111, 323113); Book Printers and Publishers (323117, 511130); Print Media (451212, 511110, 511120, 511199, 519110); Motion Picture & Video Production (512110); Music Publishers (512230); Sound Recording (512240); Radio (515112); Architecture (541310, 541320); Interior Design (541410); Graphic Design (541430); Advertising (541810, 541890); and Photography (541921, 541922). In addition to the industries included in the rate of arts-based businesses indictor, the following industries are identified by their primary SIC code: Print Media (271101, 271102, 271198, 272101, 272102, 272104, 273101, 273198, 596302, 599401); Publishers (273298, 274104, 274105, 874205); Printers (275202, 275202, 275902, 275998); Bookbinders (278902); Radio (483201); Television (483301, 484101, 792205, 824911); Textiles (513122, 594904); Advertising (519917, 731101, 731115, 731305, 731999); Fashion Designers (569901, 594408); Photography (722101, 722113, 722120, 733501, 738401); Graphic Design (733603); Commercial Artists (733604); Website Design (737311); General Media (738301); Interior Design (738902); Restoration (764112); Landscape Design (781030); Motion Picture and Video Support (781205, 781211, 781901); Architecture (871202, 871207, 871209, 874892); and Business Writers (899902).', 'Years': '2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Number of Employees in the Creative Economy', 'ShortName': 'ceempXX', 'Section': 'Arts and Culture', 'Source': 'InfoUSA', 'IndicatorPath': '/indicators/Arts and Culture/ceemp', 'Definition': 'The number of persons employed in the creative economy (both for-profit and non-profit). This number does not count those persons who identify themselves as being artists and does not count sole proprietorships or persons who work part-time in the arts. The same industries used to calculate the rate businesses in the creative economy are used to calculate total employment in the creative economy.', 'Years': '2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019'}}, {'Indicator': {'IndicatorName': 'Number of Public Murals', 'ShortName': 'muralsXX', 'Section': 'Arts and Culture', 'Source': 'Baltimore Office of Promotion of the Arts', 'IndicatorPath': '/indicators/Arts and Culture/murals', 'Definition': 'The number of murals per CSA. Murals are also included in the “Public Art per 1,000 residents” indicator. Murals are separated out as a sub-indicator so they can be analyzed at the point-level.', 'Years': '2014, 2015, 2016, 2017, 2018, 2019, 2020'}}, {'Indicator': {'IndicatorName': 'Number of Total Jobs Filled by Employees ', 'ShortName': 'totjobsXX', 'Section': 'Workforce and Economic Development', 'Source': 'U.S. Census Bureau, Longitudinal Employer-Household Dynamics', 'IndicatorPath': '/indicators/Workforce and Economic Development/totjobs', 'Definition': 'The total number of jobs per neighborhood. This indicator only counts jobs that are currently held by employees.', 'Years': '2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017'}}, {'Indicator': {'IndicatorName': 'Number of Arrests per 1,000 Residents', 'ShortName': 'arrestXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City Police Department', 'IndicatorPath': '/indicators/Crime and Safety/arrest', 'Definition': 'The number of persons aged 18 and over arrested per 1,000 adults that live in an area. This indicator is calculated by where the individual was arrested and not by where the crime is committed. ', 'Years': '2014, 2015, 2016'}}, {'Indicator': {'IndicatorName': 'Percentage of 3rd Grade Students who Met or Exceeded PARCC Math', 'ShortName': 'pmath3XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/pmath3', 'Definition': 'The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.', 'Years': '2014-2015, 2015-2016, 2016-2017'}}, {'Indicator': {'IndicatorName': 'Percentage of 3rd Grade Students who Met or Exceeded PARCC Reading', 'ShortName': 'pread3XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/pread3', 'Definition': 'The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.', 'Years': '2014-2015, 2015-2016, 2016-2017'}}, {'Indicator': {'IndicatorName': 'Percentage of 5th Grade Students who Met or Exceeded PARCC Math', 'ShortName': 'pmath5XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/pmath5', 'Definition': 'The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.', 'Years': '2014-2015, 2015-2016, 2016-2017'}}, {'Indicator': {'IndicatorName': 'Percentage of 5th Grade Students who Met or Exceeded PARCC Reading', 'ShortName': 'pread5XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/pread5', 'Definition': 'The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.', 'Years': '2014-2015, 2015-2016, 2016-2017'}}, {'Indicator': {'IndicatorName': 'Percentage of 8th Grade Students who Met or Exceeded PARCC Math', 'ShortName': 'pmath8XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/pmath8', 'Definition': 'The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.', 'Years': '2014-2015, 2015-2016, 2016-2017'}}, {'Indicator': {'IndicatorName': 'Percentage of 8th Grade Students who Met or Exceeded PARCC Reading', 'ShortName': 'pread8XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/pread8', 'Definition': 'The percentage of 8th grade students who met or exceeded expectations on the PARCC exam for reading. The Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.', 'Years': '2014-2015, 2015-2016, 2016-2017'}}, {'Indicator': {'IndicatorName': 'Percentage of Students who Met or Exceeded PARCC Algebra I', 'ShortName': 'palg1XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/palg1', 'Definition': 'The percentage of high school students who have met or exceeded expectations on PARCC Algebra I exams out of all high school students that took the exam in the school year. ', 'Years': '2014-2015, 2015-2016, 2016-2017'}}, {'Indicator': {'IndicatorName': 'Percentage of Students who Met or Exceeded PARCC Algebra II', 'ShortName': 'palg2XX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/palg2', 'Definition': 'The percentage of high school students who have met or exceeded expectations on PARCC Algebra II exams out of all high school students that took the exam in the school year. ', 'Years': '2014-2015, 2015-2016, 2016-2017'}}, {'Indicator': {'IndicatorName': 'Kindergarten Readiness', 'ShortName': 'kraXX', 'Section': 'Education and Youth', 'Source': 'Baltimore City Public Schools', 'IndicatorPath': '/indicators/Education and Youth/kra', 'Definition': 'The Kindergarten Readiness Assessment (KRA) measure children’s readiness to do kindergarten work. The KRA is a developmentally appropriate assessment tool that measures of incoming public-school kindergarteners across four learning domains. A child is considered to be ready for kindergarten if assessed as “demonstrating” the foundational skills and behaviors that prepare him/her for curriculum based on the kindergarten standards. ', 'Years': '2015-2016, 2016-2017'}}, {'Indicator': {'IndicatorName': 'Rate of Street Light Outages per 1,000 Residents', 'ShortName': 'lightsXX', 'Section': 'Crime and Safety', 'Source': 'Baltimore City CitiStat', 'IndicatorPath': '/indicators/Crime and Safety/lights', 'Definition': 'The rate of service requests for addressing street light outages made through Baltimore’s 311 system per 1,000 residents. More than one service request may be made for the same issue but is logged as a unique request.', 'Years': '2016, 2017, 2018, 2019, 2020'}}] json.dumps(indList)'[{"Indicator": {"IndicatorName": "Total Population", "ShortName": "tpopXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau", "IndicatorPath": "/indicators/Census Demographics/tpop", "Definition": "The total number of persons of all ages that live within an area. This indicator is frequently used to normalize data to allow for comparison across areas.", "Years": "2010"}}, {"Indicator": {"IndicatorName": "Total Male Population", "ShortName": "maleXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau", "IndicatorPath": "/indicators/Census Demographics/male", "Definition": "The total number of men of all ages of all ages that live within an area.", "Years": "2010"}}, {"Indicator": {"IndicatorName": "Total Female Population", "ShortName": "femaleXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau", "IndicatorPath": "/indicators/Census Demographics/female", "Definition": "The total number of women of all ages that live within an area.", "Years": "2010"}}, {"Indicator": {"IndicatorName": "Percent of Residents - Black/African-American (Non-Hispanic)", "ShortName": "paaXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/paa", "Definition": "The total number of persons that identify themselves as being racially Black or African American (and ethnically non-Hispanic) out of the total number of persons living in an area. \\u201cBlack or African American\\u201d refers to a person having origins in any of the Black racial groups of Africa. It includes people who indicated their race as \\u201cBlack\\u201d.", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Residents - White/Caucasian (Non-Hispanic)", "ShortName": "pwhiteXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/pwhite", "Definition": "The total number of persons that identify themselves as being racially White (and ethnically non-Hispanic) out of the total number of persons living in an area. \\u201cWhite\\u201d refers to a person having origins in any of the original peoples of Europe, the Middle East, or North Africa. It includes people who indicated their race(s) as \\u201cWhite\\u201d. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Residents - Asian (Non-Hispanic)", "ShortName": "pasiXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/pasi", "Definition": "The total number of persons that identify themselves as being Asian (and non-Hispanic) out of the total number of persons living in an area. \\u201cAsian\\u201d refers to a person having origins in any of the original peoples of the Far East, Southeast Asia, or the Indian subcontinent, including, for example, Cambodia, China, India, Japan, Korea, Malaysia, Pakistan, the Philippine Islands, Thailand, and Vietnam. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Residents - Two or More Races (Non-Hispanic)", "ShortName": "p2moreXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/p2more", "Definition": "The total number of persons that identify themselves as being of two or more races (and non-Hispanic) out of the total number of persons living in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Residents - All Other Races (Hawaiian/ Pacific Islander, Alaskan/ Native American Other Race) (Non-Hispanic)", "ShortName": "ppacXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/ppac", "Definition": "The total number of persons that identify themselves as being of either American Indian, Alaskan Native, Native Hawaiian or Other Pacific Islander, or some other race (non-Hispanic) out of the total number of persons living in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Residents - Hispanic", "ShortName": "phispXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/phisp", "Definition": "The total number of persons that identify their ethnicity as being Hispanic or Latino out of the total number of persons living in an area. Hispanic origin can be viewed as the heritage, nationality group, lineage, or country of birth of the person or the person\\u2019s parents or ancestors before their arrival in the United States. People who identify their origin as Hispanic, Latino, or Spanish may be any race. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Racial Diversity Index", "ShortName": "racdivXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/racdiv", "Definition": "The percent chance that two people picked at random within an area will be of a different race/ethnicity. This number does not reflect which race/ethnicity is predominant within an area. The higher the value, the more racially and ethnically diverse an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population Under 5 Years old", "ShortName": "age5_XX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/age5_", "Definition": "The percent of persons 5 years or under out of all persons living in an area.", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population 5-17 Years old", "ShortName": "age18_XX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/age18_", "Definition": "The percent of persons aged 6 to 18 years old out of all persons living in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population 18-24 Years old", "ShortName": "age24_XX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/age24_", "Definition": "The percent of persons aged 19 to 24 years old out of all persons living in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population 25-64 Years old", "ShortName": "age64_XX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/age64_", "Definition": "The percent of persons aged 25 to 64 years old out of all persons living in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population 65 Years and over", "ShortName": "age65_XX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/age65_", "Definition": "The total number of persons 65 years old and above out of all persons living in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Total Number of Households", "ShortName": "hhsXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hhs", "Definition": "A household consists of all the people occupying a housing unit. A household includes related and unrelated persons, if any, such as lodgers, foster children, wards, or employees who share the housing unit. A person living alone in a housing unit, or a group of unrelated people sharing a housing unit such as partners or roomers, is also counted as a household. The count of households excludes group quarters. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Female-Headed Households with Children Under 18", "ShortName": "femhhsXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/femhhs", "Definition": "The percentage of female-headed households with children under 18 out of all households with children under 18 in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households with Children Under 18", "ShortName": "famXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/fam", "Definition": "The percentage of households with children living in the household that are under the age of 18 out of all households. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Average Household Size", "ShortName": "hhsizeXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hhsize", "Definition": "The median value of number of persons living within a household. The average size of a household is obtained by dividing the number of persons in households by the number of households (or householders). ", "Years": "2010"}}, {"Indicator": {"IndicatorName": "Median Household Income", "ShortName": "mhhiXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/mhhi", "Definition": "The median household income is the middle value of the incomes earned in the prior year by households within an area. Income and earnings are inflation-adjusted for the last year of the 5-year period. The median value is used as opposed to the average so that both extremely high and extremely low prices do not distort the total amount of income earned by households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households Earning Less than $25,000", "ShortName": "hh25incXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hh25inc", "Definition": "The percentage of households earning less than $25,000 out of all households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households Earning $25,000 to $40,000", "ShortName": "hh40incXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hh40inc", "Definition": "The percentage of households earning between $25,000 and $39,999 out of all households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households Earning $40,000 to $60,000", "ShortName": "hh60incXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hh60inc", "Definition": "The percentage of households earning between $40,000 and $59,999 out of all households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households Earning $60,000 to $75,000", "ShortName": "hh75incXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hh75inc", "Definition": "The percentage of households earning between $60,000 and $74,999 out of all households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households Earning More than $75,000", "ShortName": "hhm75XX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hhm75", "Definition": "The percentage of households earning more than $75,000 out of all households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Inequality Index", "ShortName": "nan", "Section": "Census Demographics", "Source": "nan", "IndicatorPath": "/indicators/Census Demographics/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Family Households Living Below the Poverty Line", "ShortName": "hhpovXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hhpov", "Definition": "This indicator measures the percentage of households whose income fell below the poverty threshold out of all households in an area. Federal and state governments use such estimates to allocate funds to local communities. Local communities use these estimates to identify the number of individuals or families eligible for various programs. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Children Living Below the Poverty Line", "ShortName": "hhchpovXX", "Section": "Census Demographics", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Census Demographics/hhchpov", "Definition": "This indicator measures the percentage of persons under the age of 18 living in households where the total income fell below the poverty threshold out of all children in households in an area. Federal and state governments use such estimates to allocate funds to local communities. Local communities use these estimates to identify the number of individuals or families eligible for various programs. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Median Price of Homes Sold", "ShortName": "saleprXX", "Section": "Housing and Community Development", "Source": "First American Real Estate Solutions", "IndicatorPath": "/indicators/Housing and Community Development/salepr", "Definition": "The median home sales price is the middle value of the prices for which homes are sold (both market and private transactions) within a calendar year. The median value is used as opposed to the average so that both extremely high and extremely low prices do not distort the prices for which homes are sold. This measure does not take into account the assessed value of a property.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Median Number of Days on the Market", "ShortName": "domXX", "Section": "Housing and Community Development", "Source": "RBIntel, Inc.", "IndicatorPath": "/indicators/Housing and Community Development/dom", "Definition": "The median number of days that homes listed for sale sit on the public market in a given area. This time period is from the date it is listed for sale till the day the contract of sale is signed. Private (non-listed) home sale transactions are not included in this indicator. The median days on market is used as opposed to the average so that both extremely high and extremely low days on the market do not distort the length of time for which homes are listed on the market.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Homes Sold", "ShortName": "shomesXX", "Section": "Housing and Community Development", "Source": "First American Real Estate Solutions", "IndicatorPath": "/indicators/Housing and Community Development/shomes", "Definition": "The total number of residential properties sold in a calendar year. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Percentage of Housing Units that are Owner-Occupied", "ShortName": "ownrocXX", "Section": "Housing and Community Development", "Source": "MdProperty View", "IndicatorPath": "/indicators/Housing and Community Development/ownroc", "Definition": "The percentage of homeowners that are the principal residents of a particular residential property out of all residential properties. It is important to note that a portion of these owner-occupied properties may be subdivided and have tenants that pay rent and are not included in the calculation.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Properties Under Mortgage Foreclosure", "ShortName": "foreXX", "Section": "Housing and Community Development", "Source": "Baltimore City Circuit Court", "IndicatorPath": "/indicators/Housing and Community Development/fore", "Definition": "The percentage of properties where the lending company or loan servicer has filed a foreclosure proceeding with the Baltimore City Circuit Court out of all residential properties within an area. This is not a measure of actual foreclosures since not every property that receives a filing results in a property dispossession.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Residential Properties that are Vacant and Abandoned", "ShortName": "vacantXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Housing and Community Development", "IndicatorPath": "/indicators/Housing and Community Development/vacant", "Definition": "The percentage of residential properties that have been classified as being vacant and abandoned by the Baltimore City Department of Housing out of all properties. Properties are classified as being vacant and abandoned if: the property is not habitable and appears boarded up or open to the elements; the property was designated as being vacant prior to the current year and still remains vacant; and the property is a multi-family structure where all units are considered to be vacant. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Residential Properties with Housing Violations (Excluding Vacants)", "ShortName": "vioXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Housing and Community Development", "IndicatorPath": "/indicators/Housing and Community Development/vio", "Definition": "The percentage of residential properties that have received at least one housing code violation from the Baltimore City Department of Housing out of all properties. Properties whose fa\\u00e7ade, structure, and/or surrounding area violate the City\\u2019s Housing Code are issued a notice and are considered open till the property is found in compliance. A property may receive multiple violations. ", "Years": "2010, 2011, 2012, 2013, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Properties with Rehabilitation Permits Exceeding $5,000", "ShortName": "resrehabXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Housing and Community Development", "IndicatorPath": "/indicators/Housing and Community Development/resrehab", "Definition": "The percent of residential properties that have applied for and received a permit to renovate the interior and/or exterior of a property where the cost of renovation will exceed $5,000. The threshold of $5,000 is used to differentiate a minor and more significant renovation project. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Total Number of Residential Properties", "ShortName": "totalresXX", "Section": "Housing and Community Development", "Source": "MdProperty View", "IndicatorPath": "/indicators/Housing and Community Development/totalres", "Definition": "The total number of residential properties located within an area as identified by Maryland Property View. It is important to note that that this indicator is a count of properties (single family homes, condominiums, and duplexes) and that a property can be comprised of multiple housing units. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Residential Sales for Cash", "ShortName": "cashsaXX", "Section": "Housing and Community Development", "Source": "RBIntel, Inc.", "IndicatorPath": "/indicators/Housing and Community Development/cashsa", "Definition": "The percent of homes and condominiums sold for cash out of all residential properties sold in a calendar year. These types of sales tend to signify investor-based purchases as homes purchased for cash either become rental properties or later sold again in an effort to generate a profit. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Percentage of Residential Sales in Foreclosure (REO)", "ShortName": "reosaXX", "Section": "Housing and Community Development", "Source": "RBIntel, Inc.", "IndicatorPath": "/indicators/Housing and Community Development/reosa", "Definition": "The portion of the homes and condominiums sold that were identified as being owned by the bank (REO) out of all residential properties sold in a calendar year.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Residential Tax Lien Sales", "ShortName": "taxlienXX", "Section": "Housing and Community Development", "Source": "BidBaltimore", "IndicatorPath": "/indicators/Housing and Community Development/taxlien", "Definition": "The percentage of residential properties with city liens sold as tax certificates at the annual tax lien certificate sale held in May. Tax sales are used to collect delinquent real property taxes and other unpaid charges to the city, which are liens against the real property. The tax certificate sale is a public online auction of City lien interests on properties that occurs annually in May.", "Years": "2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Demolition Permits per 1,000 Residential Properties", "ShortName": "demperXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Housing and Community Development", "IndicatorPath": "/indicators/Housing and Community Development/demper", "Definition": "The number of permits issued for the demolition of residential buildings per 1,000 existing residential properties. The permits are analyzed by date of issue and not date of actual demolition. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of New Construction Permits per 1,000 Residential Properties", "ShortName": "constperXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Housing and Community Development", "IndicatorPath": "/indicators/Housing and Community Development/constper", "Definition": "The number of permits issued for new residential buildings per 1,000 existing residential properties within a community. The permits are analyzed by date of issue and not date of completion. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percentage of Vacant Properties Owned by Baltimore City", "ShortName": "baltvacXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Housing and Community Development", "IndicatorPath": "/indicators/Housing and Community Development/baltvac", "Definition": "The percent of properties that are classified as being vacant and abandoned that are owned by Baltimore City. Baltimore City has come to own these properties through a variety of ways including (but not limited to) eminent domain, unpaid tax or water bills, and direct purchase.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Affordability Index - Mortgage", "ShortName": "affordmXX", "Section": "Housing and Community Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Housing and Community Development/affordm", "Definition": "The percentage of households that pay more than 30% of their total household income on mortgage and other housing-related expenses. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Affordability Index - Rent", "ShortName": "affordrXX", "Section": "Housing and Community Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Housing and Community Development/affordr", "Definition": "The percentage of households that pay more than 30% of their total household income on rent and related expenses out of all households in an area. ", "Years": "2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Number of Historic Tax Credits per 1,000 Residential Units", "ShortName": "histaxXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Finance", "IndicatorPath": "/indicators/Housing and Community Development/histax", "Definition": "The number of residential properties that received the Historic Tax Credit per 1,000 residential properties within an area. The credit is granted on the increased assessment directly resulting from qualified improvements. The duration of the credit is for 10 years, and is applicable to properties located in designated areas of significant historical value.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Homestead Tax Credits per 1,000 Residential Units", "ShortName": "homtaxXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Finance", "IndicatorPath": "/indicators/Housing and Community Development/homtax", "Definition": "The number of residential properties that received the homestead tax credit per 1,000 residential properties within an area. The Homestead Credit limits the increase in taxable assessments each year to a fixed percentage. Every county and municipality in Maryland is required to limit taxable assessment increases to 10% or less each year, with the Baltimore City rate capped at 4%.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Homeowner\'s Tax Credits per 1,000 Residential Units", "ShortName": "owntaxXX", "Section": "Housing and Community Development", "Source": "Baltimore City Department of Finance", "IndicatorPath": "/indicators/Housing and Community Development/owntax", "Definition": "The number of residential properties that received the homeowners tax credit per 1,000 residential properties within an area. The homeowner\\u2019s tax credit sets a limit on the amount of property taxes any homeowner must pay based upon his or her income.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent Residential Properties that do Not Receive Mail", "ShortName": "nomailXX", "Section": "Housing and Community Development", "Source": "U.S. Postal Service, U.S. Department of Housing and Urban Development", "IndicatorPath": "/indicators/Housing and Community Development/nomail", "Definition": "The percentage of residential addresses for which the United States Postal Service has identified as being unoccupied (no mail collection) for a period of at least 90 days or longer. These properties may be habitable, but are not currently being occupied. It is important to note that a single residential property can contain more than one address.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Part 1 Crime Rate per 1,000 Residents", "ShortName": "crimeXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/crime", "Definition": "The Part 1 crime rate captures incidents of homicide, rape, aggravated assault, robbery, burglary, larceny, and auto theft that are reported to the Police Department. These incidents are per 1,000 residents in the neighborhood to allow for comparison across areas.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Daytime Crime Rate per 1,000 Population", "ShortName": "nan", "Section": "Crime and Safety", "Source": "nan", "IndicatorPath": "/indicators/Crime and Safety/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Violent Crime Rate per 1,000 Residents", "ShortName": "violXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/viol", "Definition": "The violent crime rate measures the number of Part 1 crimes identified as being violent (homicide, rape, aggravated assault, and robbery) that are reported to the Police Department. These incidents are per 1,000 residents in the neighborhood to allow for comparison across areas.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Property Crime Rate per 1,000 Residents", "ShortName": "propXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/prop", "Definition": "The property crime rate measures the number of Part 1 crimes identified as being property-based (burglary and auto theft) that are reported to the Police Department. These incidents are per 1,000 residents in the neighborhood to allow for comparison across areas. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Domestic Violence Calls For Service per 1,000 Residents", "ShortName": "domvioXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/domvio", "Definition": "The rate of calls to emergency 911 for domestic violence per 1,000 residents in an area. Calls for service are used rather than actual crime incidents since domestic violence can be classified as one of several types of criminal offenses. It is important to also note that not every case of domestic violence is reported and some claims of abuse may be unfounded. ", "Years": "2010, 2011, 2012"}}, {"Indicator": {"IndicatorName": "Juvenile Arrest Rate per 1,000 Juveniles", "ShortName": "juvarrXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/juvarr", "Definition": "The number of persons aged 10 to 17 arrested per 1,000 juveniles that live in an area. This indicator is calculated by where the arrested juvenile was arrested and not by where the crime is committed. Arrests are used instead of crimes committed since not all juveniles that are arrested are charged with committing a crime. This indicator also excludes offenders who are later charged as adults for their crime(s).", "Years": "2011, 2012, 2013, 2014, 2015"}}, {"Indicator": {"IndicatorName": "Juvenile Arrest Rate for Violent Offenses per 1,000 Juveniles", "ShortName": "juvviolXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/juvviol", "Definition": "The number of persons aged 10 to 17 arrested for violent offenses per 1,000 juveniles that live in an area. Violent offenses may include homicide, rape, assault (with or without a weapon), and robbery. This indicator is calculated by where the arrested juvenile was arrested and not by where the crime is committed. Arrests are used instead of crimes committed since not all juveniles that are arrested are charged with committing a crime. This indicator also excludes offenders who are later charged as adults for their crime(s).", "Years": "2011, 2012, 2013, 2014, 2015"}}, {"Indicator": {"IndicatorName": "Juvenile Arrest Rate for Drug-Related Offenses per 1,000 Juveniles", "ShortName": "juvdrugXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/juvdrug", "Definition": "The number of persons aged 10 to 17 arrested for drug-related offenses per 1,000 juveniles that live in an area. Drug-related offenses include arrests for possession, sale, manufacture, or abuse of illegal drugs, including alcohol. This indicator is calculated by where the arrested juvenile was arrested and not by where the crime is committed. Arrests are used instead of crimes committed since not all juveniles that are arrested are charged with committing a crime. This indicator also excludes offenders who are later charged as adults for their crime(s).", "Years": "2011, 2012, 2013, 2014, 2015"}}, {"Indicator": {"IndicatorName": "Number of Shootings per 1,000 Residents", "ShortName": "shootXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/shoot", "Definition": "The rate of 911 calls for shootings per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Gun-Related Homicides per 1,000 Residents", "ShortName": "gunhomXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/gunhom", "Definition": "The rate of homicides by firearm as reported in the Part 1 crime data per 1,000 residents in an area. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Common Assault Calls for Service per 1,000 Residents", "ShortName": "casltXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/caslt", "Definition": "The rate of calls for assaults that do not involve a weapon per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Narcotics Calls for Service per 1,000 Residents", "ShortName": "narcXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/narc", "Definition": "The rate of calls for narcotics per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Automobile Accident Calls for Service per 1,000 Residents", "ShortName": "caraccXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/caracc", "Definition": "The rate of calls for accidents involving motor vehicles per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident. Additionally, not every accident involving a motor vehicle is reported to the Police Department. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Rate of Fire and EMS Calls for Service per 1,000 Residents", "ShortName": "nan", "Section": "Crime and Safety", "Source": "nan", "IndicatorPath": "/indicators/Crime and Safety/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Average Fire and EMS Response Time", "ShortName": "nan", "Section": "Crime and Safety", "Source": "nan", "IndicatorPath": "/indicators/Crime and Safety/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Children Enrolled in Head Start Programs", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Students Ever Attended 1st - 5th Grade", "ShortName": "eattendXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/eattend", "Definition": "The number of children who have registered for and attend 1st through 5th grade at a Baltimore City Public School at any point during the school year. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Number of Students Ever Attended 6th - 8th Grade", "ShortName": "mattendXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/mattend", "Definition": "The number of children who have registered for and attend 6th through 8th grade at a Baltimore City Public School at any point in the school year. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Number of Students Ever Attended 9th - 12th Grade", "ShortName": "hsattendXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hsattend", "Definition": "The number of children who have registered for and attend 9th through 12th grade at a Baltimore City Public School at any point in the school year.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Percent of Students Enolled in CTE Programs", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Students that are African American (non-Hispanic)", "ShortName": "aastudXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/aastud", "Definition": "The percentage of Black/African American students of any grade that attend any Baltimore City Public School out of all public school students within an area in a school year.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Percent of Students that are White (non-Hispanic)", "ShortName": "wstudXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/wstud", "Definition": "The percentage of white (non-Hispanic) students of any grade that attend any Baltimore City Public School out of all public school students within an area in a school year. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Percent of Students that are Hispanic", "ShortName": "hstudXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hstud", "Definition": "The percentage of students of any grade level who identify their ethnicity as being Hispanic that attend any Baltimore City Public School out of all public school students within an area in a school year. Ethnicity is separate from a student\\u2019s race. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Percent of 1st-5th Grade Students that are Chronically Absent (Missing at least 20 days)", "ShortName": "abseXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/abse", "Definition": "The percentage of 1st-5th grade students that were recognized as being absent from public school 20 or more days out of all students. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019"}}, {"Indicator": {"IndicatorName": "Percent of 6th-8th Grade Students that are Chronically Absent (Missing at least 20 days)", "ShortName": "absmdXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/absmd", "Definition": "The percentage of 6th-8th grade students that were recognized as being absent from public school 20 or more days out of all students. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019"}}, {"Indicator": {"IndicatorName": "Percent of 9th-12th Grade Students that are Chronically Absent (Missing at least 20 days)", "ShortName": "abshsXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/abshs", "Definition": " The percentage of 9th-12th grade students that were recognized as being absent from public school 20 or more days out of all students. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019"}}, {"Indicator": {"IndicatorName": "Percentage of Students Suspended or Expelled During School Year", "ShortName": "suspXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/susp", "Definition": "The percentage of students of any grade level that were formally suspended or expelled for any reason during the school year out of all public school students within an area. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013"}}, {"Indicator": {"IndicatorName": "Percentage of Students Receiving Free or Reduced Meals", "ShortName": "farmsXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/farms", "Definition": "The percentage of students of any grade that are eligible for and received free or reduced school meals out of all public school students. Eligibility for this program is based on the student\\u2019s household income. ", "Years": "2009-2010, 2010-2011, 2011-2012"}}, {"Indicator": {"IndicatorName": "Percentage of Students Enrolled in Special Education Programs", "ShortName": "spedXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/sped", "Definition": "The percentage of students of any grade that are eligible for and participated in public school special education programs out of all students. This includes all students with any diagnosed disability.", "Years": "2009-2010, 2010-2011, 2011-2012"}}, {"Indicator": {"IndicatorName": "Percentage of Students Enrolled in After School Programs", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Kindergarten School Readiness", "ShortName": "readyXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/ready", "Definition": "The percentage of children whose composite score indicates full school readiness out of all kindergarten school children tested within an area in a school year. The Maryland Model for School Readiness (MMSR) is an assessment and instructional system that was designed to provide parents, teachers, and early childhood providers with a common understanding of what children know and are able to do upon entering school. Under the MMSR system, all children entering kindergarten are assessed for level of mastery across several learning domains. These domains include: social and personal development; language and literacy; mathematical thinking; scientific thinking; social studies; the arts; and physical development and health. Kindergarten teachers must evaluate students during the first few months of the kindergarten year using selected Work Sampling System (WSS) indicators and report their ratings by the end of November of each year to the state. ", "Years": "2010-2011, 2011-2012"}}, {"Indicator": {"IndicatorName": "Percentage of 3rd Grade Students Passing MSA Math", "ShortName": "math3XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/math3", "Definition": "The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of 3rd Grade Students Passing MSA Reading", "ShortName": "read3XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/read3", "Definition": "The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of 5th Grade Students Passing MSA Math", "ShortName": "math5XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/math5", "Definition": "The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of 5th Grade Students Passing MSA Reading", "ShortName": "read5XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/read5", "Definition": "The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of 8th Grade Students Passing MSA Math", "ShortName": "math8XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/math8", "Definition": "The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of 8th Grade Students Passing MSA Reading", "ShortName": "read8XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/read8", "Definition": "The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of Students Passing H.S.A. English ", "ShortName": "hsaengXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hsaeng", "Definition": "The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of Students Passing H.S.A. Biology", "ShortName": "hsabioXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hsabio", "Definition": "The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of Students Passing H.S.A. Government", "ShortName": "hsagovXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hsagov", "Definition": "The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "Percentage of Students Passing H.S.A. Algebra", "ShortName": "hsaalgXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hsaalg", "Definition": "The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014"}}, {"Indicator": {"IndicatorName": "High School Dropout/Withdrawl Rate", "ShortName": "dropXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/drop", "Definition": "The percentage of 9th through 12th graders who withdrew from public school out of all high school students in a school year. Withdraw codes are used as a proxy for dropping out of school based upon the expectation that withdrawn students are no longer receiving educational services. A dropout is defined as a student who, for any reason other than death, leaves school before graduation or the completion of a Maryland-approved education program and is not known to enroll in another school or State-approved program during a current school year.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "High School Completion Rate", "ShortName": "complXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/compl", "Definition": "The percentage of 12th graders in a school year that successfully completed high school out of all 12th graders within an area. Completers are identified as completing their program of study at the high school level and satisfying the graduation requirements for a Maryland High School Diploma or the requirements for a Maryland Certificate of Program Completion.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Persons Receiving a GED", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Students Switching Schools within School Year", "ShortName": "sclswXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/sclsw", "Definition": "The percentage of 1st through 12th graders who change schools out of all students in a school year. Students must have attended both schools for which they were registered for at least one day. Additionally, this indicator only identifies the share of students that change schools for any reasons and not the frequency, number of school switches, or change in residences in a school year. The percentage reflects the last home address available for the student who changed schools. This may or may not be the home address provided for the first school that they are registered to attend. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019"}}, {"Indicator": {"IndicatorName": "Percentage of Students Attending Zoned School ", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Average Distance Travelled to School (6th-8th Grade)", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Average Distance Travelled to School (9th-12th Grade)", "ShortName": "nan", "Section": "Education and Youth", "Source": "nan", "IndicatorPath": "/indicators/Education and Youth/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percentage of Population aged 16-19 in School and/or Employed", "ShortName": "sclempXX", "Section": "Education and Youth", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Education and Youth/sclemp", "Definition": "The percentage of persons aged 16 to 19 who are in school and/or are employed out of all persons in their age cohort.", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Teen Birth Rate per 1,000 Females (Aged 15-19)", "ShortName": "teenbirXX", "Section": "Children and Family Health", "Source": "Maryland Department of Vital Statistics", "IndicatorPath": "/indicators/Children and Family Health/teenbir", "Definition": "The rate of female teens aged 15-19 that gave birth per 1,000 females aged 15-19. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Births Delivered at Term (37-42 Weeks)", "ShortName": "termbirXX", "Section": "Children and Family Health", "Source": "Maryland Department of Vital Statistics", "IndicatorPath": "/indicators/Children and Family Health/termbir", "Definition": "The percentage of births delivered at term measures the percentage of births in a calendar year where the baby is delivered between 37 and 42 weeks of gestation.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Babies Born with a Satisfactory Birth Weight", "ShortName": "birthwtXX", "Section": "Children and Family Health", "Source": "Maryland Department of Vital Statistics", "IndicatorPath": "/indicators/Children and Family Health/birthwt", "Definition": "The percentage of children born with a birth weight of at least 5 \\u00bd pounds out of all births in the area. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Births Where the Mother Received Early Prenatal Care (First Trimester)", "ShortName": "prenatalXX", "Section": "Children and Family Health", "Source": "Maryland Department of Vital Statistics", "IndicatorPath": "/indicators/Children and Family Health/prenatal", "Definition": "The percentage of births where the mother received prenatal care during the first trimester of the pregnancy in a calendar year out of all births within an area. This information is calculated by the Vital Statistics registration information collected from each live birth. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Children (Aged 0-6) Tested for Elevated Blood Lead Levels", "ShortName": "leadtestXX", "Section": "Children and Family Health", "Source": "Maryland Department of the Environment, Lead Poisoning Prevention Program", "IndicatorPath": "/indicators/Children and Family Health/leadtest", "Definition": "This indicator reflects the total number of children aged 0-6 who are tested for the presence of blood lead in a calendar year.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Children (Aged 0-6) with Elevated Blood Lead Levels", "ShortName": "ebllXX", "Section": "Children and Family Health", "Source": "Maryland Department of the Environment, Lead Poisoning Prevention Program", "IndicatorPath": "/indicators/Children and Family Health/ebll", "Definition": "The number of children aged 0-6 that are found to either have elevated blood lead levels (\\u226510Mg/dL) or lead poisoning (\\u226520 Mg/dL) out of the number of children tested within an area in a calendar year. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Lead Violations per 1,000 Residential Units", "ShortName": "nan", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Families Receiving TANF", "ShortName": "tanfXX", "Section": "Children and Family Health", "Source": "Maryland Department of Human Resources", "IndicatorPath": "/indicators/Children and Family Health/tanf", "Definition": "Temporary Assistance for Needy Families (TANF) is a federal assistance program. The Act provides temporary financial assistance while aiming to get people off of that assistance, primarily through employment. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Persons receiving SNAP", "ShortName": "snapXX", "Section": "Children and Family Health", "Source": "Maryland Department of Human Resources", "IndicatorPath": "/indicators/Children and Family Health/snap", "Definition": "The Supplemental Nutrition Assistance Program (SNAP), formerly known as Food Stamps, helps low-income households buy the food they need for good health. ", "Years": "2019"}}, {"Indicator": {"IndicatorName": "Fetal Mortality Rate", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Liquor Outlet Density (per 1,000 Residents)", "ShortName": "liquorXX", "Section": "Children and Family Health", "Source": "Baltimore City Liquor Board", "IndicatorPath": "/indicators/Children and Family Health/liquor", "Definition": "This indicator reflects the number of business establishments that possess a Class A (Off Sale package goods no on-premises consumption - 6 days, 6:00 a.m.- Midnight. No Sunday sales except Sundays between Thanksgiving Day and New Year\'s Day upon issuance of a special license for each Sunday) or BD7 (tavern) business license that allows them to sell beer, wine, or liquor. Other liquor licenses to restaurants or on-premise consumption were not included in this analysis. This number is provided by 1,000 residents to allow for comparison across neighborhoods.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Fast Food Outlet Density (per 1,000 Residents)", "ShortName": "fastfdXX", "Section": "Children and Family Health", "Source": "Johns Hopkins University, Center for a Livable Future", "IndicatorPath": "/indicators/Children and Family Health/fastfd", "Definition": "The Johns Hopkins Center for a Livable Future (CLF) obtained the food permit list from the Baltimore City Health Department in August 2011, which includes all sites that sell food, such as stores, restaurants and temporary locations such as farmers\\u2019 market stands and street carts. The restaurants were grouped into three categories, including full service restaurants, fast food chains and carryouts. Carryout and fast food chain restaurants were extracted from the restaurant layer and spatially joined with the 2010 Community Statistical Area (CSA) data layer, provided by BNIA-JFI. The prepared foods density, per 1,000 people, was calculated for each CSA using the CSA\\u2019s population and the total number of carryout and fast food restaurants, including vendors selling prepared foods in public markets, in each CSA.", "Years": "2011, 2013, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Persons calling UWCM 211 for Health-Related Services ", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Rate of STDs per 1,000 Residents (Chlamydia, Gonorrhea, and Syphilis)", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Rate of HIV/AIDS per 1,000 Residents", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Life Expectancy", "ShortName": "lifexpXX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/lifexp", "Definition": "The average number of years a newborn can expect to live, assuming he or she experiences the currently prevailing rates of death through their lifespan. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Infant Mortality Rate", "ShortName": "mort1XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort1", "Definition": "The number of infant deaths (babies under one year of age) per 1,000 live births within the area in a five year period. This is the most stable and commonly measured indicator of mortality in this age group. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Mortality by Age (1-14 Years old)", "ShortName": "mort14XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort14", "Definition": "The number of deaths of persons between the ages of one and 14 per 10,000 persons within the area in a five year period. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Mortality by Age (15-24 Years Old)", "ShortName": "mort24XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort24", "Definition": "The number of deaths of persons between the ages of 15 and 24 per 10,000 persons within the area in a five year period.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Mortality by Age (25-44 Years Old)", "ShortName": "mort44XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort44", "Definition": "The number of deaths of persons between the ages of 25 and 44 per 10,000 persons within the area in a five year period.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Mortality by Age (45-64 Years Old)", "ShortName": "mort64XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort64", "Definition": "The number of deaths of persons between the ages of 45 and 64 per 10,000 persons within the area in a five year period. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Mortality by Age (65-84 Years Old)", "ShortName": "mort84XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort84", "Definition": "The number of deaths of persons between the ages of 65 and 84 per 10,000 persons within the area in a five year period.", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Mortality by Age (85 and Over)", "ShortName": "mort85XX", "Section": "Children and Family Health", "Source": "Baltimore City Health Department", "IndicatorPath": "/indicators/Children and Family Health/mort85", "Definition": "The number of deaths of persons 85 years and older per 10,000 persons within the area in a five year period. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Number of Overdose Calls for Service per 1,000 Residents", "ShortName": "overdXX", "Section": "Children and Family Health", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Children and Family Health/overd", "Definition": "The rate of 911 calls to police for overdoses per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident.", "Years": "2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Causes of Death (analysis of top causes)", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Causes of Death (analysis of top causes)", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Causes of Death (analysis of top causes)", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Causes of Death (analysis of top causes)", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of persons with health insurance", "ShortName": "nan", "Section": "Children and Family Health", "Source": "nan", "IndicatorPath": "/indicators/Children and Family Health/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Persons with Library Cards per 1,000 Residents", "ShortName": "libcardXX", "Section": "Arts and Culture", "Source": "Enoch Pratt Free Library", "IndicatorPath": "/indicators/Arts and Culture/libcard", "Definition": "The rate of persons per 1,000 residents that possess a valid public library system card. This includes all library card types (first card, juvenile, young adult, adult). ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Event Permits Requested per 1,000 Residents", "ShortName": "artevntXX", "Section": "Arts and Culture", "Source": "ENVISTA, with permission from the Baltimore City Department of Transportation", "IndicatorPath": "/indicators/Arts and Culture/artevnt", "Definition": "The number of event permits requested per 1,000 residents. Events include, but are not limited to, festivals, block parties, races, and parades. In the event of a large event, the central point is used to calculate the location of the request.", "Years": "2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Public Art per 1,000 Residents", "ShortName": "publartxx", "Section": "Arts and Culture", "Source": "Baltimore Office of Promotion and the Arts", "IndicatorPath": "/indicators/Arts and Culture/publart", "Definition": "The number of works of public art per 1,000 residents. These works include, but are not exclusive to, murals, monuments, sculptures, mosaics, and stained glass. The Baltimore Office of Promotion and the Arts tracks works created through the 1% for Public Art and Baltimore Mural Programs and maintains general inventories of public art and murals. Additional inventories of public art exist, but not at a comprehensive citywide scale and hence cannot be broken down into cross-neighborhood analyses.", "Years": "2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Businesses that are Arts-Related per 1,000 Residents", "ShortName": "artbusXX", "Section": "Arts and Culture", "Source": "InfoUSA", "IndicatorPath": "/indicators/Arts and Culture/artbus", "Definition": "The rate of businesses (both for-profit and non-profit) that are directly related to arts and culture per 1,000 residents. Arts-related businesses are defined as belonging to industries that allow for the consumption and enjoyment of arts and culture. The following industries are identified by their primary NAICS code: music, literary, and visual arts-related retail/supplies (451140, 451211, 451220); art dealers (453920, 453920); libraries (519120); motion picture and film (521310, 532230); art schools (611610); performing arts (711110, 711120, 711130, 711190); independent artists, writers, and performers (711510); museums (712110); historical sites (712120); and zoos, gardens and nature parks (712130, 712190). The following industries are identified by their primary SIC codes: designers (152106); art publishers (274101), music, literary, and visual arts-related retail/supplies (393101, 519202, 573608, 573609, 593201, 594201, 594205, 594501, 594520, 594601, 599965, 769969); art galleries, dealers, and consultants (599969, 599988, 599989); photography (722121); calligraphers (733607); embroidery (738942); theatres (783201, 792207); theatrical support (792211, 792212); musical and live entertainment (792903, 792905, 792906, 792908, 792917, 792918, 792927); parks (799951); art and music instruction (804958, 829915, 829919); libraries (823111); museums (841201); arts organizations (841202); zoos (842201); writers (899903); visual artists (899907, 899912); art restoring (899908); and music arrangers and composers (899921).", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Total Employment in Arts-Related Businesses", "ShortName": "artempXX", "Section": "Arts and Culture", "Source": "InfoUSA", "IndicatorPath": "/indicators/Arts and Culture/artemp", "Definition": "The number of persons employed in arts-related businesses (both for-profit and non-profit). This number does not count those persons who identify themselves as being artists and does not count sole proprietorships or persons who work part-time in the arts. The same industries used to calculate the rate of arts-related businesses are used to calculate total employment in arts-related businesses. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percentage of Businesses that are Non-Profits", "ShortName": "nan", "Section": "Arts and Culture", "Source": "nan", "IndicatorPath": "/indicators/Arts and Culture/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent Population 16-64 Employed", "ShortName": "emplXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/empl", "Definition": "The percent of persons between the ages of 16 and 64 formally employed or self-employed and earning a formal income. It is used to understand how many persons are working out of the entire population, not just those in the labor force (persons who may be looking for work or working). ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent Population 16-64 Unemployed and Looking for Work", "ShortName": "unemplXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/unempl", "Definition": "The percent of persons between the ages of 16 and 64 not working out of all persons, not just those in the labor force (persons who may be looking for work). These persons are seeking work that pays a formal income. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent Population 16-64 Not in Labor Force", "ShortName": "nilfXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/nilf", "Definition": "The percent of persons who are not in the labor force out of all persons between the ages of 16 and 64 in the area. There are several reasons why persons may not be included in the labor force. These reasons may include: they are caretakers for children or other family members; they attend school or job training; they may have a disability; and they are discouraged or frustrated and have given up seeking a job or have a history that may include criminal activity. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Unemployment Rate", "ShortName": "unemprXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/unempr", "Definition": "The percent of persons between the ages of 16 and 64 that are in the labor force (and are looking for work) but are not currently working. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent Population (25 Years and over) With Less Than a High School Diploma or GED", "ShortName": "lesshsXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/lesshs", "Definition": "The percentage of persons that have not completed, graduated, or received a high school diploma or GED. This is a standard indicator used to measure the portion of the population with less than a basic level of skills needed for the workplace. Persons under the age of 25 are not included in this analysis since many of these persons are still attending various levels of schooling. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent Population (25 Years and over) With High School Diploma and Some College or Associates Degree", "ShortName": "hsdiplXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/hsdipl", "Definition": "The percentage of persons that have completed, graduated, or received a high school diploma or GED and also have taken some college courses or completed their Associate\'s degree. This is a standard indicator used to measure the portion of the population with a basic level of skills needed for the workplace. Persons under the age of 25 are not included in this analysis since many of these persons are still attending various levels of schooling. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent Population (25 Years and over) with a Bachelor\'s Degree or Above", "ShortName": "bahigherXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/bahigher", "Definition": "The percentage of persons that have completed, graduated, or received a Bachelor\\u2019s or an advanced degree. This is an indicator used to measure the portion of the population having an advanced level of skills needed for the workplace. Persons under the age of 25 are not included in this analysis since many of these persons are still attending various levels of schooling. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Total Number of Commercial Properties", "ShortName": "compropXX", "Section": "Workforce and Economic Development", "Source": "MdProperty View", "IndicatorPath": "/indicators/Workforce and Economic Development/comprop", "Definition": "The total number of commercial properties located within an area in a particular year. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Percent of Commercial Properties with Rehab Permits Above $5,000", "ShortName": "crehabXX", "Section": "Workforce and Economic Development", "Source": "Baltimore City Department of Housing", "IndicatorPath": "/indicators/Workforce and Economic Development/crehab", "Definition": "The percentage of properties that are investing within their current establishment and not the level of their investment. Permits for work below $5,000 are considered to be minor and not included in this indicator. A single establishment can apply for and receive multiple permits. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Total Number of Businesses", "ShortName": "numbusXX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/numbus", "Definition": "The total number of businesses (both for-profit and non-profit) within an area at a single time in a year. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Total Number of Employees", "ShortName": "totempXX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/totemp", "Definition": "The total number of persons employed by businesses (both for-profit and non-profit) within an area at a single time in a year. ", "Years": "2010, 2011, 2012, 2013"}}, {"Indicator": {"IndicatorName": "Number of Businesses with Under 50 Employees", "ShortName": "smlbusXX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/smlbus", "Definition": "The total number of businesses (both for-profit and non-profit) that report having less than 50 persons employed within an area at a single time in a year. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Employed Residents who Work Outside the City", "ShortName": "wrkoutXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, Longitudinal Employer-Household Dynamics", "IndicatorPath": "/indicators/Workforce and Economic Development/wrkout", "Definition": "The percentage of workers that are employed by jobs located outside of Baltimore City. Only persons who report being employed and are at least 16 years old are included in the analysis. ", "Years": "2010, 2014, 2015, 2016, 2017, 2018"}}, {"Indicator": {"IndicatorName": "Total Dollar Amount Invested in Small Businesses per 50 Businesses", "ShortName": "smlinvstXX", "Section": "Workforce and Economic Development", "Source": "Johns Hopkins University, 21st Century Cities Initiative", "IndicatorPath": "/indicators/Workforce and Economic Development/smlinvst", "Definition": "The total dollar amount invested in businesses with fewer than 500 employees per 50 businesses. Small business lending data to include FFIEC insured bank loans under $1 million to businesses made by large banks; venture capital investments; US Export-Import Bank loans; Small Business Innovation Research (SBIR) and Small business Technology Transfer Research (STTR) grants; government, philanthropic, and institutional grants supporting small businesses; Maryland Department of Commerce loans; State of Maryland Neighborhood BusinessWorks loans; Baltimore Development Corporation loans; and Small Business Administration 7a and 504 loans.", "Years": "2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Residential Mortgages Originated or Approved", "ShortName": "hmdaXX", "Section": "Housing and Community Development", "Source": "Consumer Financial Protection Bureau", "IndicatorPath": "/indicators/Housing and Community Development/hmda", "Definition": "The percent of first lien mortgage applications for single family homes that were originated or approved out of all applications in the area. The Home Mortgage Disclosure Act (HMDA) requires many financial institutions to maintain, report, and publicly disclose information about mortgages in neighborhoods. ", "Years": "2019"}}, {"Indicator": {"IndicatorName": "Number of Banks and Bank Branches per 1,000 Residents", "ShortName": "banksXX", "Section": "Workforce and Economic Development", "Source": "Federal Deposit Insurance Corporation", "IndicatorPath": "/indicators/Workforce and Economic Development/banks", "Definition": "The number of banks and bank branches per 1,000 residents within an area. ", "Years": "2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Businesses that are 1 Year old or Less", "ShortName": "biz1_XX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/biz1_", "Definition": "The percentage of businesses (both for-profit and non-profit) that report their establishment as being one year old or less. The age of the business is determined by the year that the first year they appeared in the InfoUSA database. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Businesses that are 2 Years old or Less", "ShortName": "biz2_XX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/biz2_", "Definition": "The percentage of businesses (both for-profit and non-profit) that report their establishment as being two years old or less. The age of the business is determined by the year that the first year they appeared in the business database. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Businesses that are 4 Years old or Less", "ShortName": "biz4_XX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/biz4_", "Definition": "The percentage of businesses (both for-profit and non-profit) that report their establishment as being four years old or less. The age of the business is determined by the year that the first year they appeared in the business database. A business that has been in operation more than four years has a greater likelihood of remaining open for a longer period of time. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Adult Population on Parole/Probation", "ShortName": "prbprlXX", "Section": "Workforce and Economic Development", "Source": "nan", "IndicatorPath": "/indicators/Workforce and Economic Development/prbprl", "Definition": "The percentage of the population age 18 and older that are on parole or probation.", "Years": "2013"}}, {"Indicator": {"IndicatorName": "Percent of CSA that is Either Low or Moderate income (by Census tract)", "ShortName": "nan", "Section": "Workforce and Economic Development", "Source": "nan", "IndicatorPath": "/indicators/Workforce and Economic Development/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of persons in MOED training programs (per 1,000 Residents)", "ShortName": "nan", "Section": "Workforce and Economic Development", "Source": "nan", "IndicatorPath": "/indicators/Workforce and Economic Development/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Households with No Internet at Home", "ShortName": "nohhintXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Workforce and Economic Development/nohhint", "Definition": "Percent of households with no home Internet of any kindThe percentage of households without an internet subscription at home.", "Years": "2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Number of Businesses by Selected Neighborhood Industry (NAICS Sectors)", "ShortName": "neiindXX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/neiind", "Definition": "The number of businesses (both for-profit and non-profit) that provide products and services to local residents. The industries included in this indicator are: Retail Trade (NAICS 44-45); Finance and Insurance (NAICS 52); Professional, Scientific, and Technical Services (NAICS 54); Health Care and Social Assistance (NAICS 62); Arts, Entertainment, and Recreation (NAICS 71); Accommodation and Food Services (NAICS 72); and Other Services except Public Administration (NAICS 81). The primary industry reported by each business was used to determine their inclusion. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Neighborhood Businesses per 1,000 Residents (NAICS Sectors)", "ShortName": "neibusXX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/neibus", "Definition": "The number of businesses (both for-profit and non-profit) that provide products and services to local residents per 1,000. The industries included in this indicator are: Retail Trade (NAICS 44-45); Finance and Insurance (NAICS 52); Professional, Scientific, and Technical Services (NAICS 54); Health Care and Social Assistance (NAICS 62); Arts, Entertainment, and Recreation (NAICS 71); Accommodation and Food Services (NAICS 72); and Other Services except Public Administration (NAICS 81). The primary industry reported by each business was used to deter-mine their inclusion. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Total number of Employees by Selected Neighborhood Industry (NAICS Sectors)", "ShortName": "neiempXX", "Section": "Workforce and Economic Development", "Source": "InfoUSA", "IndicatorPath": "/indicators/Workforce and Economic Development/neiemp", "Definition": "The number of persons employed by businesses (both for-profit and non-profit) that provide products and services to local residents. The industries included in this indicator are: Retail Trade (NAICS 44-45); Finance and Insurance (NAICS 52); Professional, Scientific, and Technical Services (NAICS 54); Health Care and Social Assistance (NAICS 62); Arts, Entertainment, and Recreation (NAICS 71); Accommodation and Food Services (NAICS 72); and Other Services except Public Administration (NAICS 81). The primary industry reported by each business was used to determine their inclusion. The persons employed by these businesses may not necessarily live in the neighborhood where the business is located. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Percent of Population (Over the Age of 18) Who are Registered to Vote", "ShortName": "regvoteXX", "Section": "Sustainability", "Source": "Baltimore City Board of Elections", "IndicatorPath": "/indicators/Sustainability/regvote", "Definition": "The percentage of persons over the age of 18 registered to vote out of all persons 18 years and over.", "Years": "2010, 2012, 2014, 2016, 2018"}}, {"Indicator": {"IndicatorName": "Percent Population (Over the Age of 18) Who Voted in the General Election", "ShortName": "votedXX", "Section": "Sustainability", "Source": "Baltimore City Board of Elections", "IndicatorPath": "/indicators/Sustainability/voted", "Definition": "The percentage of persons who voted in the last general election out of all registered voters. ", "Years": "2010, 2012, 2014, 2016, 2018"}}, {"Indicator": {"IndicatorName": "Rate of Dirty Streets and Alleys Reports per 1,000 Residents", "ShortName": "dirtystXX", "Section": "Sustainability", "Source": "Baltimore City CitiStat", "IndicatorPath": "/indicators/Sustainability/dirtyst", "Definition": "The rate of service requests for dirty streets and alleys through Baltimore\\u2019s 311 system per 1,000 residents. More than one service request may be made for the same issue but is logged as a unique request.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Rate of Clogged Storm Drain Reports per 1,000 Residents", "ShortName": "cloggedXX", "Section": "Sustainability", "Source": "Baltimore City CitiStat", "IndicatorPath": "/indicators/Sustainability/clogged", "Definition": "The rate of service requests for addressing clogged storm drains made through Baltimore\\u2019s 311 system per 1,000 residents. More than one service request may be made for the same issue but is logged as a unique request.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Percent of Population that Drove Alone to Work", "ShortName": "drvaloneXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/drvalone", "Definition": "The percentage of commuters driving alone out of all commuters aged 16 and above. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population that Carpool to Work", "ShortName": "carpoolXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/carpool", "Definition": "The percentage of commuters that carpool out of all commuters aged 16 and above. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population that Uses Public Transportation to Get to Work", "ShortName": "pubtranXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/pubtran", "Definition": "The percentage of commuters that use public transit out of all commuters aged 16 and above.", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Population that Walks to Work", "ShortName": "walkedXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/walked", "Definition": "The percentage of commuters that walk to work out of all commuters aged 16 and above.", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Employed Population with Travel Time to Work of 0-14 Minutes", "ShortName": "trav14XX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/trav14", "Definition": "The percentage of commuters that spend less than 15 minutes commuting to work out of all commuters aged 16 and above. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Employed Population with Travel Time to Work of 15-29 Minutes", "ShortName": "trav29XX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/trav29", "Definition": "The percentage of commuters that spend between 15 and 29 minutes commuting to work out of all commuters aged 16 and above. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Employed Population with Travel Time to Work of 30-44 Minutes", "ShortName": "trav44XX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/trav44", "Definition": "The percentage of commuters that spend between 30 and 44 minutes travelling to work out of all commuters aged 16 and above. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Employed Population with Travel Time to Work of 45 Minutes and Over", "ShortName": "trav45XX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/trav45", "Definition": "The percentage of commuters that spend more than 45 minutes travelling to work out of all commuters aged 16 and above. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Area Covered by Trees", "ShortName": "treesXX", "Section": "Sustainability", "Source": "University of Vermont Spatial Analysis Lab", "IndicatorPath": "/indicators/Sustainability/trees", "Definition": "The percent of total land area comprised of tree canopy. The primary sources for this land cover layer were 2004 pan-sharpened 1m Ikonos satellite imagery, a normalized Digital Surface Model (nDSM) derived from 2006 LiDAR data, and LiDAR intensity data resulting from the 2006 acquisition. Other sources of data include the City\'s planimetric GIS database (building footprints and road casing polygons). The land cover classification was performed using automated object-based image analysis (OBIA) techniques in Definiens Developer/eCognition Server. No accuracy assessment was conducted, but the dataset was thoroughly reviewed at a scale of 1:2000. Over 370 corrections were made to the classification. ", "Years": "2007, 2015, 2017"}}, {"Indicator": {"IndicatorName": "Air Quality Risk", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Area Covered by Impervious Surface", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Community Managed Open Spaces", "ShortName": "cmosXX", "Section": "Sustainability", "Source": "Baltimore Neighborhood Indicators Alliance - Jacob France Institute", "IndicatorPath": "/indicators/Sustainability/cmos", "Definition": "The number of community managed open spaces in an area that include community gardens (food-producing or ornamental), Adopt-A-Lots, or some other green space managed by the community. ", "Years": "2011, 2014, 2015"}}, {"Indicator": {"IndicatorName": "Median Daily Water Consumption", "ShortName": "watercXX", "Section": "Sustainability", "Source": "Baltimore City Department of Public Works", "IndicatorPath": "/indicators/Sustainability/waterc", "Definition": "The median daily average water consumption of all city meters registering greater than 0.0 cubic meters per day.", "Years": "2011"}}, {"Indicator": {"IndicatorName": "Number of Downspout Disconnections per 1,000 Residential Units", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Public Trashcans", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Rate of Sewer/Water Main Breaks per 1,000 Residents", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Natural Gas Utilization", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Energy Use", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Residences Heated by Utility Gas", "ShortName": "heatgasXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/heatgas", "Definition": "The percentage of homes that use utility gas for heat and cooking out of all homes. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Residences Heated by Electricity", "ShortName": "elheatXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/elheat", "Definition": "The percentage of homes that use electricity for heat and cooking out of all homes. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Percent of Households with No Vehicles Available", "ShortName": "novhclXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/novhcl", "Definition": "The percentage of households that do not have a personal vehicle available for use out of all households in an area. ", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Number of Photovoltaic/Solar Permits", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Homes Weatherized", "ShortName": "weatherXX", "Section": "Sustainability", "Source": "Maryland Department of Housing and Community Development", "IndicatorPath": "/indicators/Sustainability/weather", "Definition": "The percent of residential properties that were eligible for and received weatherization assistance such as air sealing or furnace replacements. The Weatherization Assistance Program helps eligible low-income households lower their energy costs by increasing the energy efficiency of their homes, while ensuring their health and safety. ", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016"}}, {"Indicator": {"IndicatorName": "Walk Score", "ShortName": "wlkscXX", "Section": "Sustainability", "Source": "Walk Score", "IndicatorPath": "/indicators/Sustainability/wlksc", "Definition": "The Walk Score\\u00ae is calculated by mapping out the distance to amenities in nine different categories (grocery stores, restaurants, shopping, coffee shops, banks, parks, schools, book stores/libraries, and entertainment) and are weighted according to importance. The distance to a location, counts, and weights determine a base score of an address, which is then normalized to a score from 0 to 100. More information on Walk Score can be found at http://www.walkscore.com/. ", "Years": "2011, 2017"}}, {"Indicator": {"IndicatorName": "Aggregate Number of Community Assets", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Daily Bus Stop Loadings per 1,000 Residents", "ShortName": "busloadXX", "Section": "Sustainability", "Source": "Maryland Transit Administration", "IndicatorPath": "/indicators/Sustainability/busload", "Definition": "The median number of daily passengers getting on and off MTA buses by community.", "Years": "2017, 2018"}}, {"Indicator": {"IndicatorName": "Number of Bike Racks per 1,000 Residents", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Road Quality", "ShortName": "nan", "Section": "Sustainability", "Source": "nan", "IndicatorPath": "/indicators/Sustainability/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Number of Miles of Bike Lanes", "ShortName": "bklnXX", "Section": "Sustainability", "Source": "Department of Transportation", "IndicatorPath": "/indicators/Sustainability/bkln", "Definition": "Measures the linear miles of designated bike lanes within the roadway system.", "Years": "2012, 2020"}}, {"Indicator": {"IndicatorName": "Percent of persons by occupation classification (major classifications)", "ShortName": "nan", "Section": "Workforce and Economic Development", "Source": "nan", "IndicatorPath": "/indicators/Workforce and Economic Development/n", "Definition": "nan", "Years": "nan"}}, {"Indicator": {"IndicatorName": "Percent of Population Using Other Means to Commute to Work (Taxi, Motorcycle, Bicycle, Other)", "ShortName": "othrcomXX", "Section": "Sustainability", "Source": "U.S. Census Bureau, American Community Survey", "IndicatorPath": "/indicators/Sustainability/othrcom", "Definition": "The percentage of commuters that use other means to travel to work out of all commuters aged 16 and above.", "Years": "2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019"}}, {"Indicator": {"IndicatorName": "Number of Students Officially Enrolled in 1st - 5th Grade", "ShortName": "eenrolXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/eenrol", "Definition": "The number of children who have registered for and attend 1st through 5th grade at a Baltimore City Public School as of September 30th. This count only includes students enrolled in public schools. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Number of Students Officially Enrolled in 6th - 8th Grade", "ShortName": "menrolXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/menrol", "Definition": "The number of children who have registered for and attend 6th through 8th grade at a Baltimore City Public School as of September 30th. This count only includes students enrolled in public schools. ", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Number of Students Officially Enrolled in 9th - 12th Grade", "ShortName": "hsenrolXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/hsenrol", "Definition": "The number of children who have registered for and attend 9th through 12th grade at a Baltimore City Public School as of September 30th. This count only includes students enrolled in public schools.", "Years": "2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020"}}, {"Indicator": {"IndicatorName": "Average Healthy Food Availability Index", "ShortName": "hfaiXX", "Section": "Children and Family Health", "Source": "Johns Hopkins University, Center for a Livable Future", "IndicatorPath": "/indicators/Children and Family Health/hfai", "Definition": "The Johns Hopkins Center for a Livable Future (CLF) calculated HFAI scores for all food stores in Baltimore, in summer 2012, using an adapted version of the NEMS-S (Nutrition Environment Measures Survey in Stores) tool. The NEMS-S tool was developed by researchers at the Rollins School of Public Health at Emory University to measure the nutritional environment of food retail stores and was designed to assess healthy food availability in grocery and convenience stores. CLF obtained a food permit list from the Baltimore City Health Department in August 2011, which includes all sites that sell food, such as stores, restaurants, and temporary locations such as farmers\\u2019 market stands and street carts. HFAI scores range from zero to 28.5, with higher scores indicating more availability of healthy and whole food in a food store.", "Years": "2012, 2015"}}, {"Indicator": {"IndicatorName": "Number of Trees Planted", "ShortName": "treeplntXX", "Section": "Sustainability", "Source": "TreeBaltimore", "IndicatorPath": "/indicators/Sustainability/treeplnt", "Definition": "Measures the number of trees planted annually by the TreeBaltimore program. ", "Years": "2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Rate of Housing Vouchers per 1,000 Rental Units", "ShortName": "hcvhouseXX", "Section": "Housing and Community Development", "Source": "Picture of Subsidized Housing, HUD", "IndicatorPath": "/indicators/Housing and Community Development/hcvhouse", "Definition": "Measures the ability of housing voucher holders to find housing in the private rental market. The Housing Choice Voucher (HCV) program is the federal government\\u2019s largest low-income housing assistance program where people can seek housing in the private market. The maximum housing assistance is generally the lesser of the payment standard minus 30% of the family\\u2019s monthly adjusted income or the gross rent for the unit minus 30% of monthly adjusted income.", "Years": "2013, 2014, 2015, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Rate of Businesses in the Creative Economy per 1,000 Residents", "ShortName": "cebusXX", "Section": "Arts and Culture", "Source": "InfoUSA", "IndicatorPath": "/indicators/Arts and Culture/cebus", "Definition": "The rate of businesses (both for-profit and non-profit) that are in the creative economy per 1,000 residents. The creative economy is defined as industries that use and support artistic and cultural skillsets to attract and generate capital, knowledge, and information. Arts-based businesses are included in the creative economy. In addition to the industries included in the rate of arts-based businesses indictor, the following industries are identified by their primary NAICS code: Textiles (313220); Commercial Printing (323111, 323113); Book Printers and Publishers (323117, 511130); Print Media (451212, 511110, 511120, 511199, 519110); Motion Picture & Video Production (512110); Music Publishers (512230); Sound Recording (512240); Radio (515112); Architecture (541310, 541320); Interior Design (541410); Graphic Design (541430); Advertising (541810, 541890); and Photography (541921, 541922). In addition to the industries included in the rate of arts-based businesses indictor, the following industries are identified by their primary SIC code: Print Media (271101, 271102, 271198, 272101, 272102, 272104, 273101, 273198, 596302, 599401); Publishers (273298, 274104, 274105, 874205); Printers (275202, 275202, 275902, 275998); Bookbinders (278902); Radio (483201); Television (483301, 484101, 792205, 824911); Textiles (513122, 594904); Advertising (519917, 731101, 731115, 731305, 731999); Fashion Designers (569901, 594408); Photography (722101, 722113, 722120, 733501, 738401); Graphic Design (733603); Commercial Artists (733604); Website Design (737311); General Media (738301); Interior Design (738902); Restoration (764112); Landscape Design (781030); Motion Picture and Video Support (781205, 781211, 781901); Architecture (871202, 871207, 871209, 874892); and Business Writers (899902).", "Years": "2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Employees in the Creative Economy", "ShortName": "ceempXX", "Section": "Arts and Culture", "Source": "InfoUSA", "IndicatorPath": "/indicators/Arts and Culture/ceemp", "Definition": "The number of persons employed in the creative economy (both for-profit and non-profit). This number does not count those persons who identify themselves as being artists and does not count sole proprietorships or persons who work part-time in the arts. The same industries used to calculate the rate businesses in the creative economy are used to calculate total employment in the creative economy.", "Years": "2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019"}}, {"Indicator": {"IndicatorName": "Number of Public Murals", "ShortName": "muralsXX", "Section": "Arts and Culture", "Source": "Baltimore Office of Promotion of the Arts", "IndicatorPath": "/indicators/Arts and Culture/murals", "Definition": "The number of murals per CSA. Murals are also included in the \\u201cPublic Art per 1,000 residents\\u201d indicator. Murals are separated out as a sub-indicator so they can be analyzed at the point-level.", "Years": "2014, 2015, 2016, 2017, 2018, 2019, 2020"}}, {"Indicator": {"IndicatorName": "Number of Total Jobs Filled by Employees ", "ShortName": "totjobsXX", "Section": "Workforce and Economic Development", "Source": "U.S. Census Bureau, Longitudinal Employer-Household Dynamics", "IndicatorPath": "/indicators/Workforce and Economic Development/totjobs", "Definition": "The total number of jobs per neighborhood. This indicator only counts jobs that are currently held by employees.", "Years": "2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017"}}, {"Indicator": {"IndicatorName": "Number of Arrests per 1,000 Residents", "ShortName": "arrestXX", "Section": "Crime and Safety", "Source": "Baltimore City Police Department", "IndicatorPath": "/indicators/Crime and Safety/arrest", "Definition": "The number of persons aged 18 and over arrested per 1,000 adults that live in an area. This indicator is calculated by where the individual was arrested and not by where the crime is committed. ", "Years": "2014, 2015, 2016"}}, {"Indicator": {"IndicatorName": "Percentage of 3rd Grade Students who Met or Exceeded PARCC Math", "ShortName": "pmath3XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/pmath3", "Definition": "The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of 3rd Grade Students who Met or Exceeded PARCC Reading", "ShortName": "pread3XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/pread3", "Definition": "The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of 5th Grade Students who Met or Exceeded PARCC Math", "ShortName": "pmath5XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/pmath5", "Definition": "The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of 5th Grade Students who Met or Exceeded PARCC Reading", "ShortName": "pread5XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/pread5", "Definition": "The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of 8th Grade Students who Met or Exceeded PARCC Math", "ShortName": "pmath8XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/pmath8", "Definition": "The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of 8th Grade Students who Met or Exceeded PARCC Reading", "ShortName": "pread8XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/pread8", "Definition": "The percentage of 8th grade students who met or exceeded expectations on the PARCC exam for reading. The Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations.", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of Students who Met or Exceeded PARCC Algebra I", "ShortName": "palg1XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/palg1", "Definition": "The percentage of high school students who have met or exceeded expectations on PARCC Algebra I exams out of all high school students that took the exam in the school year. ", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Percentage of Students who Met or Exceeded PARCC Algebra II", "ShortName": "palg2XX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/palg2", "Definition": "The percentage of high school students who have met or exceeded expectations on PARCC Algebra II exams out of all high school students that took the exam in the school year. ", "Years": "2014-2015, 2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Kindergarten Readiness", "ShortName": "kraXX", "Section": "Education and Youth", "Source": "Baltimore City Public Schools", "IndicatorPath": "/indicators/Education and Youth/kra", "Definition": "The Kindergarten Readiness Assessment (KRA) measure children\\u2019s readiness to do kindergarten work. The KRA is a developmentally appropriate assessment tool that measures of incoming public-school kindergarteners across four learning domains. A child is considered to be ready for kindergarten if assessed as \\u201cdemonstrating\\u201d the foundational skills and behaviors that prepare him/her for curriculum based on the kindergarten standards. ", "Years": "2015-2016, 2016-2017"}}, {"Indicator": {"IndicatorName": "Rate of Street Light Outages per 1,000 Residents", "ShortName": "lightsXX", "Section": "Crime and Safety", "Source": "Baltimore City CitiStat", "IndicatorPath": "/indicators/Crime and Safety/lights", "Definition": "The rate of service requests for addressing street light outages made through Baltimore\\u2019s 311 system per 1,000 residents. More than one service request may be made for the same issue but is logged as a unique request.", "Years": "2016, 2017, 2018, 2019, 2020"}}]'import json data = json.dumps(indList) with open('output.json','w') as f: json.dump(data,f,indent=4)!echo {txt}var indList = [{Indicator: {IndicatorName: Total Population, ShortName: tpopXX, Section: Census Demographics, Source: U.S. Census Bureau, IndicatorPath: /indicators/Census Demographics/tpop, Definition: The total number of persons of all ages that live within an area. This indicator is frequently used to normalize data to allow for comparison across areas., Years: 2010}}, {Indicator: {IndicatorName: Total Male Population, ShortName: maleXX, Section: Census Demographics, Source: U.S. Census Bureau, IndicatorPath: /indicators/Census Demographics/male, Definition: The total number of men of all ages of all ages that live within an area., Years: 2010}}, {Indicator: {IndicatorName: Total Female Population, ShortName: femaleXX, Section: Census Demographics, Source: U.S. Census Bureau, IndicatorPath: /indicators/Census Demographics/female, Definition: The total number of women of all ages that live within an area., Years: 2010}}, {Indicator: {IndicatorName: Percent of Residents - Black/African-American (Non-Hispanic), ShortName: paaXX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/paa, Definition: The total number of persons that identify themselves as being racially Black or African American (and ethnically non-Hispanic) out of the total number of persons living in an area. \u201cBlack or African American\u201d refers to a person having origins in any of the Black racial groups of Africa. It includes people who indicated their race as \u201cBlack\u201d., Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Residents - White/Caucasian (Non-Hispanic), ShortName: pwhiteXX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/pwhite, Definition: The total number of persons that identify themselves as being racially White (and ethnically non-Hispanic) out of the total number of persons living in an area. \u201cWhite\u201d refers to a person having origins in any of the original peoples of Europe, the Middle East, or North Africa. It includes people who indicated their race(s) as \u201cWhite\u201d. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Residents - Asian (Non-Hispanic), ShortName: pasiXX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/pasi, Definition: The total number of persons that identify themselves as being Asian (and non-Hispanic) out of the total number of persons living in an area. \u201cAsian\u201d refers to a person having origins in any of the original peoples of the Far East, Southeast Asia, or the Indian subcontinent, including, for example, Cambodia, China, India, Japan, Korea, Malaysia, Pakistan, the Philippine Islands, Thailand, and Vietnam. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Residents - Two or More Races (Non-Hispanic), ShortName: p2moreXX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/p2more, Definition: The total number of persons that identify themselves as being of two or more races (and non-Hispanic) out of the total number of persons living in an area. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Residents - All Other Races (Hawaiian/ Pacific Islander, Alaskan/ Native American Other Race) (Non-Hispanic), ShortName: ppacXX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/ppac, Definition: The total number of persons that identify themselves as being of either American Indian, Alaskan Native, Native Hawaiian or Other Pacific Islander, or some other race (non-Hispanic) out of the total number of persons living in an area. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Residents - Hispanic, ShortName: phispXX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/phisp, Definition: The total number of persons that identify their ethnicity as being Hispanic or Latino out of the total number of persons living in an area. Hispanic origin can be viewed as the heritage, nationality group, lineage, or country of birth of the person or the person\u2019s parents or ancestors before their arrival in the United States. People who identify their origin as Hispanic, Latino, or Spanish may be any race. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Racial Diversity Index, ShortName: racdivXX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/racdiv, Definition: The percent chance that two people picked at random within an area will be of a different race/ethnicity. This number does not reflect which race/ethnicity is predominant within an area. The higher the value, the more racially and ethnically diverse an area. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Population Under 5 Years old, ShortName: age5_XX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/age5_, Definition: The percent of persons 5 years or under out of all persons living in an area., Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Population 5-17 Years old, ShortName: age18_XX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/age18_, Definition: The percent of persons aged 6 to 18 years old out of all persons living in an area. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Population 18-24 Years old, ShortName: age24_XX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/age24_, Definition: The percent of persons aged 19 to 24 years old out of all persons living in an area. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Population 25-64 Years old, ShortName: age64_XX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/age64_, Definition: The percent of persons aged 25 to 64 years old out of all persons living in an area. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Population 65 Years and over, ShortName: age65_XX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/age65_, Definition: The total number of persons 65 years old and above out of all persons living in an area. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Total Number of Households, ShortName: hhsXX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/hhs, Definition: A household consists of all the people occupying a housing unit. A household includes related and unrelated persons, if any, such as lodgers, foster children, wards, or employees who share the housing unit. A person living alone in a housing unit, or a group of unrelated people sharing a housing unit such as partners or roomers, is also counted as a household. The count of households excludes group quarters. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Female-Headed Households with Children Under 18, ShortName: femhhsXX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/femhhs, Definition: The percentage of female-headed households with children under 18 out of all households with children under 18 in an area. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Households with Children Under 18, ShortName: famXX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/fam, Definition: The percentage of households with children living in the household that are under the age of 18 out of all households. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Average Household Size, ShortName: hhsizeXX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/hhsize, Definition: The median value of number of persons living within a household. The average size of a household is obtained by dividing the number of persons in households by the number of households (or householders). , Years: 2010}}, {Indicator: {IndicatorName: Median Household Income, ShortName: mhhiXX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/mhhi, Definition: The median household income is the middle value of the incomes earned in the prior year by households within an area. Income and earnings are inflation-adjusted for the last year of the 5-year period. The median value is used as opposed to the average so that both extremely high and extremely low prices do not distort the total amount of income earned by households in an area. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Households Earning Less than 5,000, ShortName: hh25incXX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/hh25inc, Definition: The percentage of households earning less than 5,000 out of all households in an area. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Households Earning 5,000 to 0,000, ShortName: hh40incXX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/hh40inc, Definition: The percentage of households earning between 5,000 and 9,999 out of all households in an area. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Households Earning 0,000 to 0,000, ShortName: hh60incXX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/hh60inc, Definition: The percentage of households earning between 0,000 and 9,999 out of all households in an area. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Households Earning 0,000 to 5,000, ShortName: hh75incXX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/hh75inc, Definition: The percentage of households earning between 0,000 and 4,999 out of all households in an area. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Households Earning More than 5,000, ShortName: hhm75XX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/hhm75, Definition: The percentage of households earning more than 5,000 out of all households in an area. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Inequality Index, ShortName: nan, Section: Census Demographics, Source: nan, IndicatorPath: /indicators/Census Demographics/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Percent of Family Households Living Below the Poverty Line, ShortName: hhpovXX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/hhpov, Definition: This indicator measures the percentage of households whose income fell below the poverty threshold out of all households in an area. Federal and state governments use such estimates to allocate funds to local communities. Local communities use these estimates to identify the number of individuals or families eligible for various programs. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Children Living Below the Poverty Line, ShortName: hhchpovXX, Section: Census Demographics, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Census Demographics/hhchpov, Definition: This indicator measures the percentage of persons under the age of 18 living in households where the total income fell below the poverty threshold out of all children in households in an area. Federal and state governments use such estimates to allocate funds to local communities. Local communities use these estimates to identify the number of individuals or families eligible for various programs. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Median Price of Homes Sold, ShortName: saleprXX, Section: Housing and Community Development, Source: First American Real Estate Solutions, IndicatorPath: /indicators/Housing and Community Development/salepr, Definition: The median home sales price is the middle value of the prices for which homes are sold (both market and private transactions) within a calendar year. The median value is used as opposed to the average so that both extremely high and extremely low prices do not distort the prices for which homes are sold. This measure does not take into account the assessed value of a property., Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Median Number of Days on the Market, ShortName: domXX, Section: Housing and Community Development, Source: RBIntel, Inc., IndicatorPath: /indicators/Housing and Community Development/dom, Definition: The median number of days that homes listed for sale sit on the public market in a given area. This time period is from the date it is listed for sale till the day the contract of sale is signed. Private (non-listed) home sale transactions are not included in this indicator. The median days on market is used as opposed to the average so that both extremely high and extremely low days on the market do not distort the length of time for which homes are listed on the market., Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Number of Homes Sold, ShortName: shomesXX, Section: Housing and Community Development, Source: First American Real Estate Solutions, IndicatorPath: /indicators/Housing and Community Development/shomes, Definition: The total number of residential properties sold in a calendar year. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018}}, {Indicator: {IndicatorName: Percentage of Housing Units that are Owner-Occupied, ShortName: ownrocXX, Section: Housing and Community Development, Source: MdProperty View, IndicatorPath: /indicators/Housing and Community Development/ownroc, Definition: The percentage of homeowners that are the principal residents of a particular residential property out of all residential properties. It is important to note that a portion of these owner-occupied properties may be subdivided and have tenants that pay rent and are not included in the calculation., Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Percentage of Properties Under Mortgage Foreclosure, ShortName: foreXX, Section: Housing and Community Development, Source: Baltimore City Circuit Court, IndicatorPath: /indicators/Housing and Community Development/fore, Definition: The percentage of properties where the lending company or loan servicer has filed a foreclosure proceeding with the Baltimore City Circuit Court out of all residential properties within an area. This is not a measure of actual foreclosures since not every property that receives a filing results in a property dispossession., Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Percentage of Residential Properties that are Vacant and Abandoned, ShortName: vacantXX, Section: Housing and Community Development, Source: Baltimore City Department of Housing and Community Development, IndicatorPath: /indicators/Housing and Community Development/vacant, Definition: The percentage of residential properties that have been classified as being vacant and abandoned by the Baltimore City Department of Housing out of all properties. Properties are classified as being vacant and abandoned if: the property is not habitable and appears boarded up or open to the elements; the property was designated as being vacant prior to the current year and still remains vacant; and the property is a multi-family structure where all units are considered to be vacant. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Percentage of Residential Properties with Housing Violations (Excluding Vacants), ShortName: vioXX, Section: Housing and Community Development, Source: Baltimore City Department of Housing and Community Development, IndicatorPath: /indicators/Housing and Community Development/vio, Definition: The percentage of residential properties that have received at least one housing code violation from the Baltimore City Department of Housing out of all properties. Properties whose fa\u00e7ade, structure, and/or surrounding area violate the City\u2019s Housing Code are issued a notice and are considered open till the property is found in compliance. A property may receive multiple violations. , Years: 2010, 2011, 2012, 2013, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Percentage of Properties with Rehabilitation Permits Exceeding ,000, ShortName: resrehabXX, Section: Housing and Community Development, Source: Baltimore City Department of Housing and Community Development, IndicatorPath: /indicators/Housing and Community Development/resrehab, Definition: The percent of residential properties that have applied for and received a permit to renovate the interior and/or exterior of a property where the cost of renovation will exceed ,000. The threshold of ,000 is used to differentiate a minor and more significant renovation project. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Total Number of Residential Properties, ShortName: totalresXX, Section: Housing and Community Development, Source: MdProperty View, IndicatorPath: /indicators/Housing and Community Development/totalres, Definition: The total number of residential properties located within an area as identified by Maryland Property View. It is important to note that that this indicator is a count of properties (single family homes, condominiums, and duplexes) and that a property can be comprised of multiple housing units. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Percentage of Residential Sales for Cash, ShortName: cashsaXX, Section: Housing and Community Development, Source: RBIntel, Inc., IndicatorPath: /indicators/Housing and Community Development/cashsa, Definition: The percent of homes and condominiums sold for cash out of all residential properties sold in a calendar year. These types of sales tend to signify investor-based purchases as homes purchased for cash either become rental properties or later sold again in an effort to generate a profit. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018}}, {Indicator: {IndicatorName: Percentage of Residential Sales in Foreclosure (REO), ShortName: reosaXX, Section: Housing and Community Development, Source: RBIntel, Inc., IndicatorPath: /indicators/Housing and Community Development/reosa, Definition: The portion of the homes and condominiums sold that were identified as being owned by the bank (REO) out of all residential properties sold in a calendar year., Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Percentage of Residential Tax Lien Sales, ShortName: taxlienXX, Section: Housing and Community Development, Source: BidBaltimore, IndicatorPath: /indicators/Housing and Community Development/taxlien, Definition: The percentage of residential properties with city liens sold as tax certificates at the annual tax lien certificate sale held in May. Tax sales are used to collect delinquent real property taxes and other unpaid charges to the city, which are liens against the real property. The tax certificate sale is a public online auction of City lien interests on properties that occurs annually in May., Years: 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Number of Demolition Permits per 1,000 Residential Properties, ShortName: demperXX, Section: Housing and Community Development, Source: Baltimore City Department of Housing and Community Development, IndicatorPath: /indicators/Housing and Community Development/demper, Definition: The number of permits issued for the demolition of residential buildings per 1,000 existing residential properties. The permits are analyzed by date of issue and not date of actual demolition. , Years: 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Number of New Construction Permits per 1,000 Residential Properties, ShortName: constperXX, Section: Housing and Community Development, Source: Baltimore City Department of Housing and Community Development, IndicatorPath: /indicators/Housing and Community Development/constper, Definition: The number of permits issued for new residential buildings per 1,000 existing residential properties within a community. The permits are analyzed by date of issue and not date of completion. , Years: 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Percentage of Vacant Properties Owned by Baltimore City, ShortName: baltvacXX, Section: Housing and Community Development, Source: Baltimore City Department of Housing and Community Development, IndicatorPath: /indicators/Housing and Community Development/baltvac, Definition: The percent of properties that are classified as being vacant and abandoned that are owned by Baltimore City. Baltimore City has come to own these properties through a variety of ways including (but not limited to) eminent domain, unpaid tax or water bills, and direct purchase., Years: 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Affordability Index - Mortgage, ShortName: affordmXX, Section: Housing and Community Development, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Housing and Community Development/affordm, Definition: The percentage of households that pay more than 30% of their total household income on mortgage and other housing-related expenses. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Affordability Index - Rent, ShortName: affordrXX, Section: Housing and Community Development, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Housing and Community Development/affordr, Definition: The percentage of households that pay more than 30% of their total household income on rent and related expenses out of all households in an area. , Years: 2010, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Number of Historic Tax Credits per 1,000 Residential Units, ShortName: histaxXX, Section: Housing and Community Development, Source: Baltimore City Department of Finance, IndicatorPath: /indicators/Housing and Community Development/histax, Definition: The number of residential properties that received the Historic Tax Credit per 1,000 residential properties within an area. The credit is granted on the increased assessment directly resulting from qualified improvements. The duration of the credit is for 10 years, and is applicable to properties located in designated areas of significant historical value., Years: 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Number of Homestead Tax Credits per 1,000 Residential Units, ShortName: homtaxXX, Section: Housing and Community Development, Source: Baltimore City Department of Finance, IndicatorPath: /indicators/Housing and Community Development/homtax, Definition: The number of residential properties that received the homestead tax credit per 1,000 residential properties within an area. The Homestead Credit limits the increase in taxable assessments each year to a fixed percentage. Every county and municipality in Maryland is required to limit taxable assessment increases to 10% or less each year, with the Baltimore City rate capped at 4%., Years: 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Number of Homeowner's Tax Credits per 1,000 Residential Units, ShortName: owntaxXX, Section: Housing and Community Development, Source: Baltimore City Department of Finance, IndicatorPath: /indicators/Housing and Community Development/owntax, Definition: The number of residential properties that received the homeowners tax credit per 1,000 residential properties within an area. The homeowner\u2019s tax credit sets a limit on the amount of property taxes any homeowner must pay based upon his or her income., Years: 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Percent Residential Properties that do Not Receive Mail, ShortName: nomailXX, Section: Housing and Community Development, Source: U.S. Postal Service, U.S. Department of Housing and Urban Development, IndicatorPath: /indicators/Housing and Community Development/nomail, Definition: The percentage of residential addresses for which the United States Postal Service has identified as being unoccupied (no mail collection) for a period of at least 90 days or longer. These properties may be habitable, but are not currently being occupied. It is important to note that a single residential property can contain more than one address., Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Part 1 Crime Rate per 1,000 Residents, ShortName: crimeXX, Section: Crime and Safety, Source: Baltimore City Police Department, IndicatorPath: /indicators/Crime and Safety/crime, Definition: The Part 1 crime rate captures incidents of homicide, rape, aggravated assault, robbery, burglary, larceny, and auto theft that are reported to the Police Department. These incidents are per 1,000 residents in the neighborhood to allow for comparison across areas., Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Daytime Crime Rate per 1,000 Population, ShortName: nan, Section: Crime and Safety, Source: nan, IndicatorPath: /indicators/Crime and Safety/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Violent Crime Rate per 1,000 Residents, ShortName: violXX, Section: Crime and Safety, Source: Baltimore City Police Department, IndicatorPath: /indicators/Crime and Safety/viol, Definition: The violent crime rate measures the number of Part 1 crimes identified as being violent (homicide, rape, aggravated assault, and robbery) that are reported to the Police Department. These incidents are per 1,000 residents in the neighborhood to allow for comparison across areas., Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Property Crime Rate per 1,000 Residents, ShortName: propXX, Section: Crime and Safety, Source: Baltimore City Police Department, IndicatorPath: /indicators/Crime and Safety/prop, Definition: The property crime rate measures the number of Part 1 crimes identified as being property-based (burglary and auto theft) that are reported to the Police Department. These incidents are per 1,000 residents in the neighborhood to allow for comparison across areas. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Domestic Violence Calls For Service per 1,000 Residents, ShortName: domvioXX, Section: Crime and Safety, Source: Baltimore City Police Department, IndicatorPath: /indicators/Crime and Safety/domvio, Definition: The rate of calls to emergency 911 for domestic violence per 1,000 residents in an area. Calls for service are used rather than actual crime incidents since domestic violence can be classified as one of several types of criminal offenses. It is important to also note that not every case of domestic violence is reported and some claims of abuse may be unfounded. , Years: 2010, 2011, 2012}}, {Indicator: {IndicatorName: Juvenile Arrest Rate per 1,000 Juveniles, ShortName: juvarrXX, Section: Crime and Safety, Source: Baltimore City Police Department, IndicatorPath: /indicators/Crime and Safety/juvarr, Definition: The number of persons aged 10 to 17 arrested per 1,000 juveniles that live in an area. This indicator is calculated by where the arrested juvenile was arrested and not by where the crime is committed. Arrests are used instead of crimes committed since not all juveniles that are arrested are charged with committing a crime. This indicator also excludes offenders who are later charged as adults for their crime(s)., Years: 2011, 2012, 2013, 2014, 2015}}, {Indicator: {IndicatorName: Juvenile Arrest Rate for Violent Offenses per 1,000 Juveniles, ShortName: juvviolXX, Section: Crime and Safety, Source: Baltimore City Police Department, IndicatorPath: /indicators/Crime and Safety/juvviol, Definition: The number of persons aged 10 to 17 arrested for violent offenses per 1,000 juveniles that live in an area. Violent offenses may include homicide, rape, assault (with or without a weapon), and robbery. This indicator is calculated by where the arrested juvenile was arrested and not by where the crime is committed. Arrests are used instead of crimes committed since not all juveniles that are arrested are charged with committing a crime. This indicator also excludes offenders who are later charged as adults for their crime(s)., Years: 2011, 2012, 2013, 2014, 2015}}, {Indicator: {IndicatorName: Juvenile Arrest Rate for Drug-Related Offenses per 1,000 Juveniles, ShortName: juvdrugXX, Section: Crime and Safety, Source: Baltimore City Police Department, IndicatorPath: /indicators/Crime and Safety/juvdrug, Definition: The number of persons aged 10 to 17 arrested for drug-related offenses per 1,000 juveniles that live in an area. Drug-related offenses include arrests for possession, sale, manufacture, or abuse of illegal drugs, including alcohol. This indicator is calculated by where the arrested juvenile was arrested and not by where the crime is committed. Arrests are used instead of crimes committed since not all juveniles that are arrested are charged with committing a crime. This indicator also excludes offenders who are later charged as adults for their crime(s)., Years: 2011, 2012, 2013, 2014, 2015}}, {Indicator: {IndicatorName: Number of Shootings per 1,000 Residents, ShortName: shootXX, Section: Crime and Safety, Source: Baltimore City Police Department, IndicatorPath: /indicators/Crime and Safety/shoot, Definition: The rate of 911 calls for shootings per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident., Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Number of Gun-Related Homicides per 1,000 Residents, ShortName: gunhomXX, Section: Crime and Safety, Source: Baltimore City Police Department, IndicatorPath: /indicators/Crime and Safety/gunhom, Definition: The rate of homicides by firearm as reported in the Part 1 crime data per 1,000 residents in an area. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Number of Common Assault Calls for Service per 1,000 Residents, ShortName: casltXX, Section: Crime and Safety, Source: Baltimore City Police Department, IndicatorPath: /indicators/Crime and Safety/caslt, Definition: The rate of calls for assaults that do not involve a weapon per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Number of Narcotics Calls for Service per 1,000 Residents, ShortName: narcXX, Section: Crime and Safety, Source: Baltimore City Police Department, IndicatorPath: /indicators/Crime and Safety/narc, Definition: The rate of calls for narcotics per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Number of Automobile Accident Calls for Service per 1,000 Residents, ShortName: caraccXX, Section: Crime and Safety, Source: Baltimore City Police Department, IndicatorPath: /indicators/Crime and Safety/caracc, Definition: The rate of calls for accidents involving motor vehicles per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident. Additionally, not every accident involving a motor vehicle is reported to the Police Department. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Rate of Fire and EMS Calls for Service per 1,000 Residents, ShortName: nan, Section: Crime and Safety, Source: nan, IndicatorPath: /indicators/Crime and Safety/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Average Fire and EMS Response Time, ShortName: nan, Section: Crime and Safety, Source: nan, IndicatorPath: /indicators/Crime and Safety/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Number of Children Enrolled in Head Start Programs, ShortName: nan, Section: Education and Youth, Source: nan, IndicatorPath: /indicators/Education and Youth/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Number of Students Ever Attended 1st - 5th Grade, ShortName: eattendXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/eattend, Definition: The number of children who have registered for and attend 1st through 5th grade at a Baltimore City Public School at any point during the school year. , Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020}}, {Indicator: {IndicatorName: Number of Students Ever Attended 6th - 8th Grade, ShortName: mattendXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/mattend, Definition: The number of children who have registered for and attend 6th through 8th grade at a Baltimore City Public School at any point in the school year. , Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020}}, {Indicator: {IndicatorName: Number of Students Ever Attended 9th - 12th Grade, ShortName: hsattendXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/hsattend, Definition: The number of children who have registered for and attend 9th through 12th grade at a Baltimore City Public School at any point in the school year., Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020}}, {Indicator: {IndicatorName: Percent of Students Enolled in CTE Programs, ShortName: nan, Section: Education and Youth, Source: nan, IndicatorPath: /indicators/Education and Youth/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Percent of Students that are African American (non-Hispanic), ShortName: aastudXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/aastud, Definition: The percentage of Black/African American students of any grade that attend any Baltimore City Public School out of all public school students within an area in a school year., Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020}}, {Indicator: {IndicatorName: Percent of Students that are White (non-Hispanic), ShortName: wstudXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/wstud, Definition: The percentage of white (non-Hispanic) students of any grade that attend any Baltimore City Public School out of all public school students within an area in a school year. , Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020}}, {Indicator: {IndicatorName: Percent of Students that are Hispanic, ShortName: hstudXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/hstud, Definition: The percentage of students of any grade level who identify their ethnicity as being Hispanic that attend any Baltimore City Public School out of all public school students within an area in a school year. Ethnicity is separate from a student\u2019s race. , Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020}}, {Indicator: {IndicatorName: Percent of 1st-5th Grade Students that are Chronically Absent (Missing at least 20 days), ShortName: abseXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/abse, Definition: The percentage of 1st-5th grade students that were recognized as being absent from public school 20 or more days out of all students. , Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019}}, {Indicator: {IndicatorName: Percent of 6th-8th Grade Students that are Chronically Absent (Missing at least 20 days), ShortName: absmdXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/absmd, Definition: The percentage of 6th-8th grade students that were recognized as being absent from public school 20 or more days out of all students. , Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019}}, {Indicator: {IndicatorName: Percent of 9th-12th Grade Students that are Chronically Absent (Missing at least 20 days), ShortName: abshsXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/abshs, Definition: The percentage of 9th-12th grade students that were recognized as being absent from public school 20 or more days out of all students. , Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019}}, {Indicator: {IndicatorName: Percentage of Students Suspended or Expelled During School Year, ShortName: suspXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/susp, Definition: The percentage of students of any grade level that were formally suspended or expelled for any reason during the school year out of all public school students within an area. , Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013}}, {Indicator: {IndicatorName: Percentage of Students Receiving Free or Reduced Meals, ShortName: farmsXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/farms, Definition: The percentage of students of any grade that are eligible for and received free or reduced school meals out of all public school students. Eligibility for this program is based on the student\u2019s household income. , Years: 2009-2010, 2010-2011, 2011-2012}}, {Indicator: {IndicatorName: Percentage of Students Enrolled in Special Education Programs, ShortName: spedXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/sped, Definition: The percentage of students of any grade that are eligible for and participated in public school special education programs out of all students. This includes all students with any diagnosed disability., Years: 2009-2010, 2010-2011, 2011-2012}}, {Indicator: {IndicatorName: Percentage of Students Enrolled in After School Programs, ShortName: nan, Section: Education and Youth, Source: nan, IndicatorPath: /indicators/Education and Youth/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Kindergarten School Readiness, ShortName: readyXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/ready, Definition: The percentage of children whose composite score indicates full school readiness out of all kindergarten school children tested within an area in a school year. The Maryland Model for School Readiness (MMSR) is an assessment and instructional system that was designed to provide parents, teachers, and early childhood providers with a common understanding of what children know and are able to do upon entering school. Under the MMSR system, all children entering kindergarten are assessed for level of mastery across several learning domains. These domains include: social and personal development; language and literacy; mathematical thinking; scientific thinking; social studies; the arts; and physical development and health. Kindergarten teachers must evaluate students during the first few months of the kindergarten year using selected Work Sampling System (WSS) indicators and report their ratings by the end of November of each year to the state. , Years: 2010-2011, 2011-2012}}, {Indicator: {IndicatorName: Percentage of 3rd Grade Students Passing MSA Math, ShortName: math3XX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/math3, Definition: The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient., Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014}}, {Indicator: {IndicatorName: Percentage of 3rd Grade Students Passing MSA Reading, ShortName: read3XX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/read3, Definition: The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient., Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014}}, {Indicator: {IndicatorName: Percentage of 5th Grade Students Passing MSA Math, ShortName: math5XX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/math5, Definition: The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient., Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014}}, {Indicator: {IndicatorName: Percentage of 5th Grade Students Passing MSA Reading, ShortName: read5XX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/read5, Definition: The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient., Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014}}, {Indicator: {IndicatorName: Percentage of 8th Grade Students Passing MSA Math, ShortName: math8XX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/math8, Definition: The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient., Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014}}, {Indicator: {IndicatorName: Percentage of 8th Grade Students Passing MSA Reading, ShortName: read8XX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/read8, Definition: The percentage of students passing M.S.A. exams in reading and mathematics in 3rd, 5th, and 8th grades. Maryland School Assessment (MSA) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as advanced, proficient, or having basic knowledge of a subject. This indicator includes only those students who have tested as advanced or proficient., Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014}}, {Indicator: {IndicatorName: Percentage of Students Passing H.S.A. English , ShortName: hsaengXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/hsaeng, Definition: The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass., Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014}}, {Indicator: {IndicatorName: Percentage of Students Passing H.S.A. Biology, ShortName: hsabioXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/hsabio, Definition: The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass., Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014}}, {Indicator: {IndicatorName: Percentage of Students Passing H.S.A. Government, ShortName: hsagovXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/hsagov, Definition: The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass., Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014}}, {Indicator: {IndicatorName: Percentage of Students Passing H.S.A. Algebra, ShortName: hsaalgXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/hsaalg, Definition: The percentage of high school students who have successfully passed the H.S.A. exams out of all high school students that took the exam in the school year (considering only the highest score per subject area). In Maryland, all students who entered 9th grade in or after 2005 are required to take and pass the High School Assessments (H.S.A.) in order to graduate, including students in special education, English language learners (ELLs), and students with 504 plans. There are currently three H.S.A. exams: English, Algebra/Data Analysis; and Biology (a H.S.A. in Government has since been discontinued). Students can retake the HSAs as many times as necessary to pass., Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014}}, {Indicator: {IndicatorName: High School Dropout/Withdrawl Rate, ShortName: dropXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/drop, Definition: The percentage of 9th through 12th graders who withdrew from public school out of all high school students in a school year. Withdraw codes are used as a proxy for dropping out of school based upon the expectation that withdrawn students are no longer receiving educational services. A dropout is defined as a student who, for any reason other than death, leaves school before graduation or the completion of a Maryland-approved education program and is not known to enroll in another school or State-approved program during a current school year., Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020}}, {Indicator: {IndicatorName: High School Completion Rate, ShortName: complXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/compl, Definition: The percentage of 12th graders in a school year that successfully completed high school out of all 12th graders within an area. Completers are identified as completing their program of study at the high school level and satisfying the graduation requirements for a Maryland High School Diploma or the requirements for a Maryland Certificate of Program Completion., Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020}}, {Indicator: {IndicatorName: Persons Receiving a GED, ShortName: nan, Section: Education and Youth, Source: nan, IndicatorPath: /indicators/Education and Youth/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Percent of Students Switching Schools within School Year, ShortName: sclswXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/sclsw, Definition: The percentage of 1st through 12th graders who change schools out of all students in a school year. Students must have attended both schools for which they were registered for at least one day. Additionally, this indicator only identifies the share of students that change schools for any reasons and not the frequency, number of school switches, or change in residences in a school year. The percentage reflects the last home address available for the student who changed schools. This may or may not be the home address provided for the first school that they are registered to attend. , Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019}}, {Indicator: {IndicatorName: Percentage of Students Attending Zoned School , ShortName: nan, Section: Education and Youth, Source: nan, IndicatorPath: /indicators/Education and Youth/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Average Distance Travelled to School (6th-8th Grade), ShortName: nan, Section: Education and Youth, Source: nan, IndicatorPath: /indicators/Education and Youth/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Average Distance Travelled to School (9th-12th Grade), ShortName: nan, Section: Education and Youth, Source: nan, IndicatorPath: /indicators/Education and Youth/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Percentage of Population aged 16-19 in School and/or Employed, ShortName: sclempXX, Section: Education and Youth, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Education and Youth/sclemp, Definition: The percentage of persons aged 16 to 19 who are in school and/or are employed out of all persons in their age cohort., Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Teen Birth Rate per 1,000 Females (Aged 15-19), ShortName: teenbirXX, Section: Children and Family Health, Source: Maryland Department of Vital Statistics, IndicatorPath: /indicators/Children and Family Health/teenbir, Definition: The rate of female teens aged 15-19 that gave birth per 1,000 females aged 15-19. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Percent of Births Delivered at Term (37-42 Weeks), ShortName: termbirXX, Section: Children and Family Health, Source: Maryland Department of Vital Statistics, IndicatorPath: /indicators/Children and Family Health/termbir, Definition: The percentage of births delivered at term measures the percentage of births in a calendar year where the baby is delivered between 37 and 42 weeks of gestation., Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Percent of Babies Born with a Satisfactory Birth Weight, ShortName: birthwtXX, Section: Children and Family Health, Source: Maryland Department of Vital Statistics, IndicatorPath: /indicators/Children and Family Health/birthwt, Definition: The percentage of children born with a birth weight of at least 5 \u00bd pounds out of all births in the area. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Percent of Births Where the Mother Received Early Prenatal Care (First Trimester), ShortName: prenatalXX, Section: Children and Family Health, Source: Maryland Department of Vital Statistics, IndicatorPath: /indicators/Children and Family Health/prenatal, Definition: The percentage of births where the mother received prenatal care during the first trimester of the pregnancy in a calendar year out of all births within an area. This information is calculated by the Vital Statistics registration information collected from each live birth. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Number of Children (Aged 0-6) Tested for Elevated Blood Lead Levels, ShortName: leadtestXX, Section: Children and Family Health, Source: Maryland Department of the Environment, Lead Poisoning Prevention Program, IndicatorPath: /indicators/Children and Family Health/leadtest, Definition: This indicator reflects the total number of children aged 0-6 who are tested for the presence of blood lead in a calendar year., Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Percent of Children (Aged 0-6) with Elevated Blood Lead Levels, ShortName: ebllXX, Section: Children and Family Health, Source: Maryland Department of the Environment, Lead Poisoning Prevention Program, IndicatorPath: /indicators/Children and Family Health/ebll, Definition: The number of children aged 0-6 that are found to either have elevated blood lead levels (\u226510Mg/dL) or lead poisoning (\u226520 Mg/dL) out of the number of children tested within an area in a calendar year. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Percent of Lead Violations per 1,000 Residential Units, ShortName: nan, Section: Children and Family Health, Source: Baltimore City Health Department, IndicatorPath: /indicators/Children and Family Health/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Percent of Families Receiving TANF, ShortName: tanfXX, Section: Children and Family Health, Source: Maryland Department of Human Resources, IndicatorPath: /indicators/Children and Family Health/tanf, Definition: Temporary Assistance for Needy Families (TANF) is a federal assistance program. The Act provides temporary financial assistance while aiming to get people off of that assistance, primarily through employment. , Years: 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Percent of Persons receiving SNAP, ShortName: snapXX, Section: Children and Family Health, Source: Maryland Department of Human Resources, IndicatorPath: /indicators/Children and Family Health/snap, Definition: The Supplemental Nutrition Assistance Program (SNAP), formerly known as Food Stamps, helps low-income households buy the food they need for good health. , Years: 2019}}, {Indicator: {IndicatorName: Fetal Mortality Rate, ShortName: nan, Section: Children and Family Health, Source: nan, IndicatorPath: /indicators/Children and Family Health/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Liquor Outlet Density (per 1,000 Residents), ShortName: liquorXX, Section: Children and Family Health, Source: Baltimore City Liquor Board, IndicatorPath: /indicators/Children and Family Health/liquor, Definition: This indicator reflects the number of business establishments that possess a Class A (Off Sale package goods no on-premises consumption - 6 days, 6:00 a.m.- Midnight. No Sunday sales except Sundays between Thanksgiving Day and New Year's Day upon issuance of a special license for each Sunday) or BD7 (tavern) business license that allows them to sell beer, wine, or liquor. Other liquor licenses to restaurants or on-premise consumption were not included in this analysis. This number is provided by 1,000 residents to allow for comparison across neighborhoods., Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Fast Food Outlet Density (per 1,000 Residents), ShortName: fastfdXX, Section: Children and Family Health, Source: Johns Hopkins University, Center for a Livable Future, IndicatorPath: /indicators/Children and Family Health/fastfd, Definition: The Johns Hopkins Center for a Livable Future (CLF) obtained the food permit list from the Baltimore City Health Department in August 2011, which includes all sites that sell food, such as stores, restaurants and temporary locations such as farmers\u2019 market stands and street carts. The restaurants were grouped into three categories, including full service restaurants, fast food chains and carryouts. Carryout and fast food chain restaurants were extracted from the restaurant layer and spatially joined with the 2010 Community Statistical Area (CSA) data layer, provided by BNIA-JFI. The prepared foods density, per 1,000 people, was calculated for each CSA using the CSA\u2019s population and the total number of carryout and fast food restaurants, including vendors selling prepared foods in public markets, in each CSA., Years: 2011, 2013, 2018, 2019}}, {Indicator: {IndicatorName: Number of Persons calling UWCM 211 for Health-Related Services , ShortName: nan, Section: Children and Family Health, Source: nan, IndicatorPath: /indicators/Children and Family Health/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Rate of STDs per 1,000 Residents (Chlamydia, Gonorrhea, and Syphilis), ShortName: nan, Section: Children and Family Health, Source: nan, IndicatorPath: /indicators/Children and Family Health/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Rate of HIV/AIDS per 1,000 Residents, ShortName: nan, Section: Children and Family Health, Source: nan, IndicatorPath: /indicators/Children and Family Health/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Life Expectancy, ShortName: lifexpXX, Section: Children and Family Health, Source: Baltimore City Health Department, IndicatorPath: /indicators/Children and Family Health/lifexp, Definition: The average number of years a newborn can expect to live, assuming he or she experiences the currently prevailing rates of death through their lifespan. , Years: 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018}}, {Indicator: {IndicatorName: Infant Mortality Rate, ShortName: mort1XX, Section: Children and Family Health, Source: Baltimore City Health Department, IndicatorPath: /indicators/Children and Family Health/mort1, Definition: The number of infant deaths (babies under one year of age) per 1,000 live births within the area in a five year period. This is the most stable and commonly measured indicator of mortality in this age group. , Years: 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018}}, {Indicator: {IndicatorName: Mortality by Age (1-14 Years old), ShortName: mort14XX, Section: Children and Family Health, Source: Baltimore City Health Department, IndicatorPath: /indicators/Children and Family Health/mort14, Definition: The number of deaths of persons between the ages of one and 14 per 10,000 persons within the area in a five year period. , Years: 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018}}, {Indicator: {IndicatorName: Mortality by Age (15-24 Years Old), ShortName: mort24XX, Section: Children and Family Health, Source: Baltimore City Health Department, IndicatorPath: /indicators/Children and Family Health/mort24, Definition: The number of deaths of persons between the ages of 15 and 24 per 10,000 persons within the area in a five year period., Years: 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018}}, {Indicator: {IndicatorName: Mortality by Age (25-44 Years Old), ShortName: mort44XX, Section: Children and Family Health, Source: Baltimore City Health Department, IndicatorPath: /indicators/Children and Family Health/mort44, Definition: The number of deaths of persons between the ages of 25 and 44 per 10,000 persons within the area in a five year period., Years: 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018}}, {Indicator: {IndicatorName: Mortality by Age (45-64 Years Old), ShortName: mort64XX, Section: Children and Family Health, Source: Baltimore City Health Department, IndicatorPath: /indicators/Children and Family Health/mort64, Definition: The number of deaths of persons between the ages of 45 and 64 per 10,000 persons within the area in a five year period. , Years: 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018}}, {Indicator: {IndicatorName: Mortality by Age (65-84 Years Old), ShortName: mort84XX, Section: Children and Family Health, Source: Baltimore City Health Department, IndicatorPath: /indicators/Children and Family Health/mort84, Definition: The number of deaths of persons between the ages of 65 and 84 per 10,000 persons within the area in a five year period., Years: 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018}}, {Indicator: {IndicatorName: Mortality by Age (85 and Over), ShortName: mort85XX, Section: Children and Family Health, Source: Baltimore City Health Department, IndicatorPath: /indicators/Children and Family Health/mort85, Definition: The number of deaths of persons 85 years and older per 10,000 persons within the area in a five year period. , Years: 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018}}, {Indicator: {IndicatorName: Number of Overdose Calls for Service per 1,000 Residents, ShortName: overdXX, Section: Children and Family Health, Source: Baltimore City Police Department, IndicatorPath: /indicators/Children and Family Health/overd, Definition: The rate of 911 calls to police for overdoses per 1,000 residents in an area. Since the data comes from 911 calls, it is possible that multiple calls could be made for a single incident., Years: 2018, 2019, 2020}}, {Indicator: {IndicatorName: Causes of Death (analysis of top causes), ShortName: nan, Section: Children and Family Health, Source: nan, IndicatorPath: /indicators/Children and Family Health/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Causes of Death (analysis of top causes), ShortName: nan, Section: Children and Family Health, Source: nan, IndicatorPath: /indicators/Children and Family Health/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Causes of Death (analysis of top causes), ShortName: nan, Section: Children and Family Health, Source: nan, IndicatorPath: /indicators/Children and Family Health/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Causes of Death (analysis of top causes), ShortName: nan, Section: Children and Family Health, Source: nan, IndicatorPath: /indicators/Children and Family Health/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Percent of persons with health insurance, ShortName: nan, Section: Children and Family Health, Source: nan, IndicatorPath: /indicators/Children and Family Health/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Number of Persons with Library Cards per 1,000 Residents, ShortName: libcardXX, Section: Arts and Culture, Source: Enoch Pratt Free Library, IndicatorPath: /indicators/Arts and Culture/libcard, Definition: The rate of persons per 1,000 residents that possess a valid public library system card. This includes all library card types (first card, juvenile, young adult, adult). , Years: 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Number of Event Permits Requested per 1,000 Residents, ShortName: artevntXX, Section: Arts and Culture, Source: ENVISTA, with permission from the Baltimore City Department of Transportation, IndicatorPath: /indicators/Arts and Culture/artevnt, Definition: The number of event permits requested per 1,000 residents. Events include, but are not limited to, festivals, block parties, races, and parades. In the event of a large event, the central point is used to calculate the location of the request., Years: 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Public Art per 1,000 Residents, ShortName: publartxx, Section: Arts and Culture, Source: Baltimore Office of Promotion and the Arts, IndicatorPath: /indicators/Arts and Culture/publart, Definition: The number of works of public art per 1,000 residents. These works include, but are not exclusive to, murals, monuments, sculptures, mosaics, and stained glass. The Baltimore Office of Promotion and the Arts tracks works created through the 1% for Public Art and Baltimore Mural Programs and maintains general inventories of public art and murals. Additional inventories of public art exist, but not at a comprehensive citywide scale and hence cannot be broken down into cross-neighborhood analyses., Years: 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Number of Businesses that are Arts-Related per 1,000 Residents, ShortName: artbusXX, Section: Arts and Culture, Source: InfoUSA, IndicatorPath: /indicators/Arts and Culture/artbus, Definition: The rate of businesses (both for-profit and non-profit) that are directly related to arts and culture per 1,000 residents. Arts-related businesses are defined as belonging to industries that allow for the consumption and enjoyment of arts and culture. The following industries are identified by their primary NAICS code: music, literary, and visual arts-related retail/supplies (451140, 451211, 451220); art dealers (453920, 453920); libraries (519120); motion picture and film (521310, 532230); art schools (611610); performing arts (711110, 711120, 711130, 711190); independent artists, writers, and performers (711510); museums (712110); historical sites (712120); and zoos, gardens and nature parks (712130, 712190). The following industries are identified by their primary SIC codes: designers (152106); art publishers (274101), music, literary, and visual arts-related retail/supplies (393101, 519202, 573608, 573609, 593201, 594201, 594205, 594501, 594520, 594601, 599965, 769969); art galleries, dealers, and consultants (599969, 599988, 599989); photography (722121); calligraphers (733607); embroidery (738942); theatres (783201, 792207); theatrical support (792211, 792212); musical and live entertainment (792903, 792905, 792906, 792908, 792917, 792918, 792927); parks (799951); art and music instruction (804958, 829915, 829919); libraries (823111); museums (841201); arts organizations (841202); zoos (842201); writers (899903); visual artists (899907, 899912); art restoring (899908); and music arrangers and composers (899921)., Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Total Employment in Arts-Related Businesses, ShortName: artempXX, Section: Arts and Culture, Source: InfoUSA, IndicatorPath: /indicators/Arts and Culture/artemp, Definition: The number of persons employed in arts-related businesses (both for-profit and non-profit). This number does not count those persons who identify themselves as being artists and does not count sole proprietorships or persons who work part-time in the arts. The same industries used to calculate the rate of arts-related businesses are used to calculate total employment in arts-related businesses. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Percentage of Businesses that are Non-Profits, ShortName: nan, Section: Arts and Culture, Source: nan, IndicatorPath: /indicators/Arts and Culture/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Percent Population 16-64 Employed, ShortName: emplXX, Section: Workforce and Economic Development, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Workforce and Economic Development/empl, Definition: The percent of persons between the ages of 16 and 64 formally employed or self-employed and earning a formal income. It is used to understand how many persons are working out of the entire population, not just those in the labor force (persons who may be looking for work or working). , Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent Population 16-64 Unemployed and Looking for Work, ShortName: unemplXX, Section: Workforce and Economic Development, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Workforce and Economic Development/unempl, Definition: The percent of persons between the ages of 16 and 64 not working out of all persons, not just those in the labor force (persons who may be looking for work). These persons are seeking work that pays a formal income. , Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent Population 16-64 Not in Labor Force, ShortName: nilfXX, Section: Workforce and Economic Development, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Workforce and Economic Development/nilf, Definition: The percent of persons who are not in the labor force out of all persons between the ages of 16 and 64 in the area. There are several reasons why persons may not be included in the labor force. These reasons may include: they are caretakers for children or other family members; they attend school or job training; they may have a disability; and they are discouraged or frustrated and have given up seeking a job or have a history that may include criminal activity. , Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Unemployment Rate, ShortName: unemprXX, Section: Workforce and Economic Development, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Workforce and Economic Development/unempr, Definition: The percent of persons between the ages of 16 and 64 that are in the labor force (and are looking for work) but are not currently working. , Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent Population (25 Years and over) With Less Than a High School Diploma or GED, ShortName: lesshsXX, Section: Workforce and Economic Development, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Workforce and Economic Development/lesshs, Definition: The percentage of persons that have not completed, graduated, or received a high school diploma or GED. This is a standard indicator used to measure the portion of the population with less than a basic level of skills needed for the workplace. Persons under the age of 25 are not included in this analysis since many of these persons are still attending various levels of schooling. , Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent Population (25 Years and over) With High School Diploma and Some College or Associates Degree, ShortName: hsdiplXX, Section: Workforce and Economic Development, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Workforce and Economic Development/hsdipl, Definition: The percentage of persons that have completed, graduated, or received a high school diploma or GED and also have taken some college courses or completed their Associate's degree. This is a standard indicator used to measure the portion of the population with a basic level of skills needed for the workplace. Persons under the age of 25 are not included in this analysis since many of these persons are still attending various levels of schooling. , Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent Population (25 Years and over) with a Bachelor's Degree or Above, ShortName: bahigherXX, Section: Workforce and Economic Development, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Workforce and Economic Development/bahigher, Definition: The percentage of persons that have completed, graduated, or received a Bachelor\u2019s or an advanced degree. This is an indicator used to measure the portion of the population having an advanced level of skills needed for the workplace. Persons under the age of 25 are not included in this analysis since many of these persons are still attending various levels of schooling. , Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Total Number of Commercial Properties, ShortName: compropXX, Section: Workforce and Economic Development, Source: MdProperty View, IndicatorPath: /indicators/Workforce and Economic Development/comprop, Definition: The total number of commercial properties located within an area in a particular year. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018}}, {Indicator: {IndicatorName: Percent of Commercial Properties with Rehab Permits Above ,000, ShortName: crehabXX, Section: Workforce and Economic Development, Source: Baltimore City Department of Housing, IndicatorPath: /indicators/Workforce and Economic Development/crehab, Definition: The percentage of properties that are investing within their current establishment and not the level of their investment. Permits for work below ,000 are considered to be minor and not included in this indicator. A single establishment can apply for and receive multiple permits. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Total Number of Businesses, ShortName: numbusXX, Section: Workforce and Economic Development, Source: InfoUSA, IndicatorPath: /indicators/Workforce and Economic Development/numbus, Definition: The total number of businesses (both for-profit and non-profit) within an area at a single time in a year. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Total Number of Employees, ShortName: totempXX, Section: Workforce and Economic Development, Source: InfoUSA, IndicatorPath: /indicators/Workforce and Economic Development/totemp, Definition: The total number of persons employed by businesses (both for-profit and non-profit) within an area at a single time in a year. , Years: 2010, 2011, 2012, 2013}}, {Indicator: {IndicatorName: Number of Businesses with Under 50 Employees, ShortName: smlbusXX, Section: Workforce and Economic Development, Source: InfoUSA, IndicatorPath: /indicators/Workforce and Economic Development/smlbus, Definition: The total number of businesses (both for-profit and non-profit) that report having less than 50 persons employed within an area at a single time in a year. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Percent of Employed Residents who Work Outside the City, ShortName: wrkoutXX, Section: Workforce and Economic Development, Source: U.S. Census Bureau, Longitudinal Employer-Household Dynamics, IndicatorPath: /indicators/Workforce and Economic Development/wrkout, Definition: The percentage of workers that are employed by jobs located outside of Baltimore City. Only persons who report being employed and are at least 16 years old are included in the analysis. , Years: 2010, 2014, 2015, 2016, 2017, 2018}}, {Indicator: {IndicatorName: Total Dollar Amount Invested in Small Businesses per 50 Businesses, ShortName: smlinvstXX, Section: Workforce and Economic Development, Source: Johns Hopkins University, 21st Century Cities Initiative, IndicatorPath: /indicators/Workforce and Economic Development/smlinvst, Definition: The total dollar amount invested in businesses with fewer than 500 employees per 50 businesses. Small business lending data to include FFIEC insured bank loans under million to businesses made by large banks; venture capital investments; US Export-Import Bank loans; Small Business Innovation Research (SBIR) and Small business Technology Transfer Research (STTR) grants; government, philanthropic, and institutional grants supporting small businesses; Maryland Department of Commerce loans; State of Maryland Neighborhood BusinessWorks loans; Baltimore Development Corporation loans; and Small Business Administration 7a and 504 loans., Years: 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Percent of Residential Mortgages Originated or Approved, ShortName: hmdaXX, Section: Housing and Community Development, Source: Consumer Financial Protection Bureau, IndicatorPath: /indicators/Housing and Community Development/hmda, Definition: The percent of first lien mortgage applications for single family homes that were originated or approved out of all applications in the area. The Home Mortgage Disclosure Act (HMDA) requires many financial institutions to maintain, report, and publicly disclose information about mortgages in neighborhoods. , Years: 2019}}, {Indicator: {IndicatorName: Number of Banks and Bank Branches per 1,000 Residents, ShortName: banksXX, Section: Workforce and Economic Development, Source: Federal Deposit Insurance Corporation, IndicatorPath: /indicators/Workforce and Economic Development/banks, Definition: The number of banks and bank branches per 1,000 residents within an area. , Years: 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Percent of Businesses that are 1 Year old or Less, ShortName: biz1_XX, Section: Workforce and Economic Development, Source: InfoUSA, IndicatorPath: /indicators/Workforce and Economic Development/biz1_, Definition: The percentage of businesses (both for-profit and non-profit) that report their establishment as being one year old or less. The age of the business is determined by the year that the first year they appeared in the InfoUSA database. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Percent of Businesses that are 2 Years old or Less, ShortName: biz2_XX, Section: Workforce and Economic Development, Source: InfoUSA, IndicatorPath: /indicators/Workforce and Economic Development/biz2_, Definition: The percentage of businesses (both for-profit and non-profit) that report their establishment as being two years old or less. The age of the business is determined by the year that the first year they appeared in the business database. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Percent of Businesses that are 4 Years old or Less, ShortName: biz4_XX, Section: Workforce and Economic Development, Source: InfoUSA, IndicatorPath: /indicators/Workforce and Economic Development/biz4_, Definition: The percentage of businesses (both for-profit and non-profit) that report their establishment as being four years old or less. The age of the business is determined by the year that the first year they appeared in the business database. A business that has been in operation more than four years has a greater likelihood of remaining open for a longer period of time. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Percent of Adult Population on Parole/Probation, ShortName: prbprlXX, Section: Workforce and Economic Development, Source: nan, IndicatorPath: /indicators/Workforce and Economic Development/prbprl, Definition: The percentage of the population age 18 and older that are on parole or probation., Years: 2013}}, {Indicator: {IndicatorName: Percent of CSA that is Either Low or Moderate income (by Census tract), ShortName: nan, Section: Workforce and Economic Development, Source: nan, IndicatorPath: /indicators/Workforce and Economic Development/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Percent of persons in MOED training programs (per 1,000 Residents), ShortName: nan, Section: Workforce and Economic Development, Source: nan, IndicatorPath: /indicators/Workforce and Economic Development/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Percent of Households with No Internet at Home, ShortName: nohhintXX, Section: Workforce and Economic Development, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Workforce and Economic Development/nohhint, Definition: Percent of households with no home Internet of any kindThe percentage of households without an internet subscription at home., Years: 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Number of Businesses by Selected Neighborhood Industry (NAICS Sectors), ShortName: neiindXX, Section: Workforce and Economic Development, Source: InfoUSA, IndicatorPath: /indicators/Workforce and Economic Development/neiind, Definition: The number of businesses (both for-profit and non-profit) that provide products and services to local residents. The industries included in this indicator are: Retail Trade (NAICS 44-45); Finance and Insurance (NAICS 52); Professional, Scientific, and Technical Services (NAICS 54); Health Care and Social Assistance (NAICS 62); Arts, Entertainment, and Recreation (NAICS 71); Accommodation and Food Services (NAICS 72); and Other Services except Public Administration (NAICS 81). The primary industry reported by each business was used to determine their inclusion. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Neighborhood Businesses per 1,000 Residents (NAICS Sectors), ShortName: neibusXX, Section: Workforce and Economic Development, Source: InfoUSA, IndicatorPath: /indicators/Workforce and Economic Development/neibus, Definition: The number of businesses (both for-profit and non-profit) that provide products and services to local residents per 1,000. The industries included in this indicator are: Retail Trade (NAICS 44-45); Finance and Insurance (NAICS 52); Professional, Scientific, and Technical Services (NAICS 54); Health Care and Social Assistance (NAICS 62); Arts, Entertainment, and Recreation (NAICS 71); Accommodation and Food Services (NAICS 72); and Other Services except Public Administration (NAICS 81). The primary industry reported by each business was used to deter-mine their inclusion. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Total number of Employees by Selected Neighborhood Industry (NAICS Sectors), ShortName: neiempXX, Section: Workforce and Economic Development, Source: InfoUSA, IndicatorPath: /indicators/Workforce and Economic Development/neiemp, Definition: The number of persons employed by businesses (both for-profit and non-profit) that provide products and services to local residents. The industries included in this indicator are: Retail Trade (NAICS 44-45); Finance and Insurance (NAICS 52); Professional, Scientific, and Technical Services (NAICS 54); Health Care and Social Assistance (NAICS 62); Arts, Entertainment, and Recreation (NAICS 71); Accommodation and Food Services (NAICS 72); and Other Services except Public Administration (NAICS 81). The primary industry reported by each business was used to determine their inclusion. The persons employed by these businesses may not necessarily live in the neighborhood where the business is located. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Percent of Population (Over the Age of 18) Who are Registered to Vote, ShortName: regvoteXX, Section: Sustainability, Source: Baltimore City Board of Elections, IndicatorPath: /indicators/Sustainability/regvote, Definition: The percentage of persons over the age of 18 registered to vote out of all persons 18 years and over., Years: 2010, 2012, 2014, 2016, 2018}}, {Indicator: {IndicatorName: Percent Population (Over the Age of 18) Who Voted in the General Election, ShortName: votedXX, Section: Sustainability, Source: Baltimore City Board of Elections, IndicatorPath: /indicators/Sustainability/voted, Definition: The percentage of persons who voted in the last general election out of all registered voters. , Years: 2010, 2012, 2014, 2016, 2018}}, {Indicator: {IndicatorName: Rate of Dirty Streets and Alleys Reports per 1,000 Residents, ShortName: dirtystXX, Section: Sustainability, Source: Baltimore City CitiStat, IndicatorPath: /indicators/Sustainability/dirtyst, Definition: The rate of service requests for dirty streets and alleys through Baltimore\u2019s 311 system per 1,000 residents. More than one service request may be made for the same issue but is logged as a unique request., Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Rate of Clogged Storm Drain Reports per 1,000 Residents, ShortName: cloggedXX, Section: Sustainability, Source: Baltimore City CitiStat, IndicatorPath: /indicators/Sustainability/clogged, Definition: The rate of service requests for addressing clogged storm drains made through Baltimore\u2019s 311 system per 1,000 residents. More than one service request may be made for the same issue but is logged as a unique request., Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Percent of Population that Drove Alone to Work, ShortName: drvaloneXX, Section: Sustainability, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Sustainability/drvalone, Definition: The percentage of commuters driving alone out of all commuters aged 16 and above. , Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Population that Carpool to Work, ShortName: carpoolXX, Section: Sustainability, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Sustainability/carpool, Definition: The percentage of commuters that carpool out of all commuters aged 16 and above. , Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Population that Uses Public Transportation to Get to Work, ShortName: pubtranXX, Section: Sustainability, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Sustainability/pubtran, Definition: The percentage of commuters that use public transit out of all commuters aged 16 and above., Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Population that Walks to Work, ShortName: walkedXX, Section: Sustainability, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Sustainability/walked, Definition: The percentage of commuters that walk to work out of all commuters aged 16 and above., Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Employed Population with Travel Time to Work of 0-14 Minutes, ShortName: trav14XX, Section: Sustainability, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Sustainability/trav14, Definition: The percentage of commuters that spend less than 15 minutes commuting to work out of all commuters aged 16 and above. , Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Employed Population with Travel Time to Work of 15-29 Minutes, ShortName: trav29XX, Section: Sustainability, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Sustainability/trav29, Definition: The percentage of commuters that spend between 15 and 29 minutes commuting to work out of all commuters aged 16 and above. , Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Employed Population with Travel Time to Work of 30-44 Minutes, ShortName: trav44XX, Section: Sustainability, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Sustainability/trav44, Definition: The percentage of commuters that spend between 30 and 44 minutes travelling to work out of all commuters aged 16 and above. , Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Employed Population with Travel Time to Work of 45 Minutes and Over, ShortName: trav45XX, Section: Sustainability, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Sustainability/trav45, Definition: The percentage of commuters that spend more than 45 minutes travelling to work out of all commuters aged 16 and above. , Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Area Covered by Trees, ShortName: treesXX, Section: Sustainability, Source: University of Vermont Spatial Analysis Lab, IndicatorPath: /indicators/Sustainability/trees, Definition: The percent of total land area comprised of tree canopy. The primary sources for this land cover layer were 2004 pan-sharpened 1m Ikonos satellite imagery, a normalized Digital Surface Model (nDSM) derived from 2006 LiDAR data, and LiDAR intensity data resulting from the 2006 acquisition. Other sources of data include the City's planimetric GIS database (building footprints and road casing polygons). The land cover classification was performed using automated object-based image analysis (OBIA) techniques in Definiens Developer/eCognition Server. No accuracy assessment was conducted, but the dataset was thoroughly reviewed at a scale of 1:2000. Over 370 corrections were made to the classification. , Years: 2007, 2015, 2017}}, {Indicator: {IndicatorName: Air Quality Risk, ShortName: nan, Section: Sustainability, Source: nan, IndicatorPath: /indicators/Sustainability/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Percent of Area Covered by Impervious Surface, ShortName: nan, Section: Sustainability, Source: nan, IndicatorPath: /indicators/Sustainability/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Number of Community Managed Open Spaces, ShortName: cmosXX, Section: Sustainability, Source: Baltimore Neighborhood Indicators Alliance - Jacob France Institute, IndicatorPath: /indicators/Sustainability/cmos, Definition: The number of community managed open spaces in an area that include community gardens (food-producing or ornamental), Adopt-A-Lots, or some other green space managed by the community. , Years: 2011, 2014, 2015}}, {Indicator: {IndicatorName: Median Daily Water Consumption, ShortName: watercXX, Section: Sustainability, Source: Baltimore City Department of Public Works, IndicatorPath: /indicators/Sustainability/waterc, Definition: The median daily average water consumption of all city meters registering greater than 0.0 cubic meters per day., Years: 2011}}, {Indicator: {IndicatorName: Number of Downspout Disconnections per 1,000 Residential Units, ShortName: nan, Section: Sustainability, Source: nan, IndicatorPath: /indicators/Sustainability/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Number of Public Trashcans, ShortName: nan, Section: Sustainability, Source: nan, IndicatorPath: /indicators/Sustainability/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Rate of Sewer/Water Main Breaks per 1,000 Residents, ShortName: nan, Section: Sustainability, Source: nan, IndicatorPath: /indicators/Sustainability/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Natural Gas Utilization, ShortName: nan, Section: Sustainability, Source: nan, IndicatorPath: /indicators/Sustainability/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Energy Use, ShortName: nan, Section: Sustainability, Source: nan, IndicatorPath: /indicators/Sustainability/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Percent of Residences Heated by Utility Gas, ShortName: heatgasXX, Section: Sustainability, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Sustainability/heatgas, Definition: The percentage of homes that use utility gas for heat and cooking out of all homes. , Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Residences Heated by Electricity, ShortName: elheatXX, Section: Sustainability, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Sustainability/elheat, Definition: The percentage of homes that use electricity for heat and cooking out of all homes. , Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Percent of Households with No Vehicles Available, ShortName: novhclXX, Section: Sustainability, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Sustainability/novhcl, Definition: The percentage of households that do not have a personal vehicle available for use out of all households in an area. , Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Number of Photovoltaic/Solar Permits, ShortName: nan, Section: Sustainability, Source: nan, IndicatorPath: /indicators/Sustainability/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Percent of Homes Weatherized, ShortName: weatherXX, Section: Sustainability, Source: Maryland Department of Housing and Community Development, IndicatorPath: /indicators/Sustainability/weather, Definition: The percent of residential properties that were eligible for and received weatherization assistance such as air sealing or furnace replacements. The Weatherization Assistance Program helps eligible low-income households lower their energy costs by increasing the energy efficiency of their homes, while ensuring their health and safety. , Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016}}, {Indicator: {IndicatorName: Walk Score, ShortName: wlkscXX, Section: Sustainability, Source: Walk Score, IndicatorPath: /indicators/Sustainability/wlksc, Definition: The Walk Score\u00ae is calculated by mapping out the distance to amenities in nine different categories (grocery stores, restaurants, shopping, coffee shops, banks, parks, schools, book stores/libraries, and entertainment) and are weighted according to importance. The distance to a location, counts, and weights determine a base score of an address, which is then normalized to a score from 0 to 100. More information on Walk Score can be found at http://www.walkscore.com/. , Years: 2011, 2017}}, {Indicator: {IndicatorName: Aggregate Number of Community Assets, ShortName: nan, Section: Sustainability, Source: nan, IndicatorPath: /indicators/Sustainability/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Number of Daily Bus Stop Loadings per 1,000 Residents, ShortName: busloadXX, Section: Sustainability, Source: Maryland Transit Administration, IndicatorPath: /indicators/Sustainability/busload, Definition: The median number of daily passengers getting on and off MTA buses by community., Years: 2017, 2018}}, {Indicator: {IndicatorName: Number of Bike Racks per 1,000 Residents, ShortName: nan, Section: Sustainability, Source: nan, IndicatorPath: /indicators/Sustainability/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Road Quality, ShortName: nan, Section: Sustainability, Source: nan, IndicatorPath: /indicators/Sustainability/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Number of Miles of Bike Lanes, ShortName: bklnXX, Section: Sustainability, Source: Department of Transportation, IndicatorPath: /indicators/Sustainability/bkln, Definition: Measures the linear miles of designated bike lanes within the roadway system., Years: 2012, 2020}}, {Indicator: {IndicatorName: Percent of persons by occupation classification (major classifications), ShortName: nan, Section: Workforce and Economic Development, Source: nan, IndicatorPath: /indicators/Workforce and Economic Development/n, Definition: nan, Years: nan}}, {Indicator: {IndicatorName: Percent of Population Using Other Means to Commute to Work (Taxi, Motorcycle, Bicycle, Other), ShortName: othrcomXX, Section: Sustainability, Source: U.S. Census Bureau, American Community Survey, IndicatorPath: /indicators/Sustainability/othrcom, Definition: The percentage of commuters that use other means to travel to work out of all commuters aged 16 and above., Years: 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019}}, {Indicator: {IndicatorName: Number of Students Officially Enrolled in 1st - 5th Grade, ShortName: eenrolXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/eenrol, Definition: The number of children who have registered for and attend 1st through 5th grade at a Baltimore City Public School as of September 30th. This count only includes students enrolled in public schools. , Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020}}, {Indicator: {IndicatorName: Number of Students Officially Enrolled in 6th - 8th Grade, ShortName: menrolXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/menrol, Definition: The number of children who have registered for and attend 6th through 8th grade at a Baltimore City Public School as of September 30th. This count only includes students enrolled in public schools. , Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020}}, {Indicator: {IndicatorName: Number of Students Officially Enrolled in 9th - 12th Grade, ShortName: hsenrolXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/hsenrol, Definition: The number of children who have registered for and attend 9th through 12th grade at a Baltimore City Public School as of September 30th. This count only includes students enrolled in public schools., Years: 2009-2010, 2010-2011, 2011-2012, 2012-2013, 2013-2014, 2014-2015, 2015-2016, 2016-2017, 2018-2019, 2019-2020}}, {Indicator: {IndicatorName: Average Healthy Food Availability Index, ShortName: hfaiXX, Section: Children and Family Health, Source: Johns Hopkins University, Center for a Livable Future, IndicatorPath: /indicators/Children and Family Health/hfai, Definition: The Johns Hopkins Center for a Livable Future (CLF) calculated HFAI scores for all food stores in Baltimore, in summer 2012, using an adapted version of the NEMS-S (Nutrition Environment Measures Survey in Stores) tool. The NEMS-S tool was developed by researchers at the Rollins School of Public Health at Emory University to measure the nutritional environment of food retail stores and was designed to assess healthy food availability in grocery and convenience stores. CLF obtained a food permit list from the Baltimore City Health Department in August 2011, which includes all sites that sell food, such as stores, restaurants, and temporary locations such as farmers\u2019 market stands and street carts. HFAI scores range from zero to 28.5, with higher scores indicating more availability of healthy and whole food in a food store., Years: 2012, 2015}}, {Indicator: {IndicatorName: Number of Trees Planted, ShortName: treeplntXX, Section: Sustainability, Source: TreeBaltimore, IndicatorPath: /indicators/Sustainability/treeplnt, Definition: Measures the number of trees planted annually by the TreeBaltimore program. , Years: 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Rate of Housing Vouchers per 1,000 Rental Units, ShortName: hcvhouseXX, Section: Housing and Community Development, Source: Picture of Subsidized Housing, HUD, IndicatorPath: /indicators/Housing and Community Development/hcvhouse, Definition: Measures the ability of housing voucher holders to find housing in the private rental market. The Housing Choice Voucher (HCV) program is the federal government\u2019s largest low-income housing assistance program where people can seek housing in the private market. The maximum housing assistance is generally the lesser of the payment standard minus 30% of the family\u2019s monthly adjusted income or the gross rent for the unit minus 30% of monthly adjusted income., Years: 2013, 2014, 2015, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Rate of Businesses in the Creative Economy per 1,000 Residents, ShortName: cebusXX, Section: Arts and Culture, Source: InfoUSA, IndicatorPath: /indicators/Arts and Culture/cebus, Definition: The rate of businesses (both for-profit and non-profit) that are in the creative economy per 1,000 residents. The creative economy is defined as industries that use and support artistic and cultural skillsets to attract and generate capital, knowledge, and information. Arts-based businesses are included in the creative economy. In addition to the industries included in the rate of arts-based businesses indictor, the following industries are identified by their primary NAICS code: Textiles (313220); Commercial Printing (323111, 323113); Book Printers and Publishers (323117, 511130); Print Media (451212, 511110, 511120, 511199, 519110); Motion Picture & Video Production (512110); Music Publishers (512230); Sound Recording (512240); Radio (515112); Architecture (541310, 541320); Interior Design (541410); Graphic Design (541430); Advertising (541810, 541890); and Photography (541921, 541922). In addition to the industries included in the rate of arts-based businesses indictor, the following industries are identified by their primary SIC code: Print Media (271101, 271102, 271198, 272101, 272102, 272104, 273101, 273198, 596302, 599401); Publishers (273298, 274104, 274105, 874205); Printers (275202, 275202, 275902, 275998); Bookbinders (278902); Radio (483201); Television (483301, 484101, 792205, 824911); Textiles (513122, 594904); Advertising (519917, 731101, 731115, 731305, 731999); Fashion Designers (569901, 594408); Photography (722101, 722113, 722120, 733501, 738401); Graphic Design (733603); Commercial Artists (733604); Website Design (737311); General Media (738301); Interior Design (738902); Restoration (764112); Landscape Design (781030); Motion Picture and Video Support (781205, 781211, 781901); Architecture (871202, 871207, 871209, 874892); and Business Writers (899902)., Years: 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Number of Employees in the Creative Economy, ShortName: ceempXX, Section: Arts and Culture, Source: InfoUSA, IndicatorPath: /indicators/Arts and Culture/ceemp, Definition: The number of persons employed in the creative economy (both for-profit and non-profit). This number does not count those persons who identify themselves as being artists and does not count sole proprietorships or persons who work part-time in the arts. The same industries used to calculate the rate businesses in the creative economy are used to calculate total employment in the creative economy., Years: 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019}}, {Indicator: {IndicatorName: Number of Public Murals, ShortName: muralsXX, Section: Arts and Culture, Source: Baltimore Office of Promotion of the Arts, IndicatorPath: /indicators/Arts and Culture/murals, Definition: The number of murals per CSA. Murals are also included in the \u201cPublic Art per 1,000 residents\u201d indicator. Murals are separated out as a sub-indicator so they can be analyzed at the point-level., Years: 2014, 2015, 2016, 2017, 2018, 2019, 2020}}, {Indicator: {IndicatorName: Number of Total Jobs Filled by Employees , ShortName: totjobsXX, Section: Workforce and Economic Development, Source: U.S. Census Bureau, Longitudinal Employer-Household Dynamics, IndicatorPath: /indicators/Workforce and Economic Development/totjobs, Definition: The total number of jobs per neighborhood. This indicator only counts jobs that are currently held by employees., Years: 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017}}, {Indicator: {IndicatorName: Number of Arrests per 1,000 Residents, ShortName: arrestXX, Section: Crime and Safety, Source: Baltimore City Police Department, IndicatorPath: /indicators/Crime and Safety/arrest, Definition: The number of persons aged 18 and over arrested per 1,000 adults that live in an area. This indicator is calculated by where the individual was arrested and not by where the crime is committed. , Years: 2014, 2015, 2016}}, {Indicator: {IndicatorName: Percentage of 3rd Grade Students who Met or Exceeded PARCC Math, ShortName: pmath3XX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/pmath3, Definition: The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations., Years: 2014-2015, 2015-2016, 2016-2017}}, {Indicator: {IndicatorName: Percentage of 3rd Grade Students who Met or Exceeded PARCC Reading, ShortName: pread3XX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/pread3, Definition: The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations., Years: 2014-2015, 2015-2016, 2016-2017}}, {Indicator: {IndicatorName: Percentage of 5th Grade Students who Met or Exceeded PARCC Math, ShortName: pmath5XX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/pmath5, Definition: The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations., Years: 2014-2015, 2015-2016, 2016-2017}}, {Indicator: {IndicatorName: Percentage of 5th Grade Students who Met or Exceeded PARCC Reading, ShortName: pread5XX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/pread5, Definition: The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations., Years: 2014-2015, 2015-2016, 2016-2017}}, {Indicator: {IndicatorName: Percentage of 8th Grade Students who Met or Exceeded PARCC Math, ShortName: pmath8XX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/pmath8, Definition: The percentage of students who met or exceeded PARCC exams in reading and mathematics in 3rd, 5th, and 8th grades. Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations., Years: 2014-2015, 2015-2016, 2016-2017}}, {Indicator: {IndicatorName: Percentage of 8th Grade Students who Met or Exceeded PARCC Reading, ShortName: pread8XX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/pread8, Definition: The percentage of 8th grade students who met or exceeded expectations on the PARCC exam for reading. The Partnership for Assessment of Readiness for College and Careers (PARCC) scores measure the number of students scoring in one of three classifications out of all students enrolled in that grade. Students can either be rated as exceeded, met, approached, partially met, or did not meet expectations of a subject. This indicator includes only those students who have tested as exceeded or met expectations., Years: 2014-2015, 2015-2016, 2016-2017}}, {Indicator: {IndicatorName: Percentage of Students who Met or Exceeded PARCC Algebra I, ShortName: palg1XX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/palg1, Definition: The percentage of high school students who have met or exceeded expectations on PARCC Algebra I exams out of all high school students that took the exam in the school year. , Years: 2014-2015, 2015-2016, 2016-2017}}, {Indicator: {IndicatorName: Percentage of Students who Met or Exceeded PARCC Algebra II, ShortName: palg2XX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/palg2, Definition: The percentage of high school students who have met or exceeded expectations on PARCC Algebra II exams out of all high school students that took the exam in the school year. , Years: 2014-2015, 2015-2016, 2016-2017}}, {Indicator: {IndicatorName: Kindergarten Readiness, ShortName: kraXX, Section: Education and Youth, Source: Baltimore City Public Schools, IndicatorPath: /indicators/Education and Youth/kra, Definition: The Kindergarten Readiness Assessment (KRA) measure children\u2019s readiness to do kindergarten work. The KRA is a developmentally appropriate assessment tool that measures of incoming public-school kindergarteners across four learning domains. A child is considered to be ready for kindergarten if assessed as \u201cdemonstrating\u201d the foundational skills and behaviors that prepare him/her for curriculum based on the kindergarten standards. , Years: 2015-2016, 2016-2017}}, {Indicator: {IndicatorName: Rate of Street Light Outages per 1,000 Residents, ShortName: lightsXX, Section: Crime and Safety, Source: Baltimore City CitiStat, IndicatorPath: /indicators/Crime and Safety/lights, Definition: The rate of service requests for addressing street light outages made through Baltimore\u2019s 311 system per 1,000 residents. More than one service request may be made for the same issue but is logged as a unique request., Years: 2016, 2017, 2018, 2019, 2020}}] with open('output.js', 'a') as f: f.write(txt + '\n')

### SEARCH

### CONNECT WITH US

- Facebook
- Twitter
- YouTube
- RSS

### DONATE

Help us keep this resource free and available to the public. Donate now!

Donate to BNIA-JFI

### CONTACT US

Baltimore Neighborhood Indicators Alliance
The Jacob France Institute
1420 N. Charles Street, Baltimore, MD 21201
410-837-4377 | bnia-jfi@ubalt.edu